function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Base class with utility methods for API calls
 * @author Box
 */
import noop from 'lodash/noop';
import Xhr from '../utils/Xhr';
import Cache from '../utils/Cache';
import UploadsReachability from './uploads/UploadsReachability';
import { getTypedFileId } from '../utils/file';
import { getBadItemError, getBadPermissionsError } from '../utils/error';
import { DEFAULT_HOSTNAME_API, DEFAULT_HOSTNAME_UPLOAD, HTTP_GET, HTTP_POST, HTTP_PUT, HTTP_DELETE } from '../constants';

class Base {
  /**
   * @property {Cache}
   */

  /**
   * @property {boolean}
   */

  /**
   * @property {Xhr}
   */

  /**
   * @property {string}
   */

  /**
   * @property {string}
   */

  /**
   * @property {*}
   */

  /**
   * @property {Function}
   */

  /**
   * @property {Function}
   */

  /**
   * @property {string}
   */

  /**
   * @property {Function}
   */

  /**
   * @property {Function}
   */

  /**
   * @property {UploadsReachability}
   */

  /**
   * [constructor]
   *
   * @param {Object} [options]
   * @param {string} [options.token] - Auth token
   * @param {string} [options.sharedLink] - Shared link
   * @param {string} [options.sharedLinkPassword] - Shared link password
   * @param {string} [options.apiHost] - Api host
   * @param {string} [options.uploadHost] - Upload host name
   * @return {Base} Base instance
   */
  constructor(options) {
    _defineProperty(this, "successHandler", data => {
      if (!this.isDestroyed() && typeof this.successCallback === 'function') {
        this.successCallback(data);
      }
    });

    _defineProperty(this, "errorHandler", error => {
      if (!this.isDestroyed() && typeof this.errorCallback === 'function') {
        const {
          response
        } = error;

        if (response && response.data) {
          this.errorCallback(response.data, this.errorCode);
        } else {
          this.errorCallback(error, this.errorCode);
        }
      }
    });

    this.cache = options.cache || new Cache();
    this.apiHost = options.apiHost || DEFAULT_HOSTNAME_API;
    this.uploadHost = options.uploadHost || DEFAULT_HOSTNAME_UPLOAD; // @TODO: avoid keeping another copy of data in this.options

    this.options = _objectSpread({}, options, {
      apiHost: this.apiHost,
      uploadHost: this.uploadHost,
      cache: this.cache
    });
    this.xhr = new Xhr(this.options);
    this.destroyed = false;
    this.consoleLog = !!options.consoleLog && !!window.console ? window.console.log || noop : noop;
    this.consoleError = !!options.consoleError && !!window.console ? window.console.error || noop : noop;
    this.uploadsReachability = new UploadsReachability();
  }
  /**
   * [destructor]
   *
   * @return {void}
   */


  destroy() {
    this.xhr.abort();
    this.destroyed = true;
  }
  /**
   * Asks the API if its destructor has been called
   *
   * @return {void}
   */


  isDestroyed() {
    return this.destroyed;
  }
  /**
   * Checks that our desired API call has sufficient permissions and an item ID
   *
   * @param {string} permissionToCheck - Permission to check
   * @param {Object} permissions - Permissions object
   * @param {string} id - Item id
   * @return {void}
   */


  checkApiCallValidity(permissionToCheck, permissions, id) {
    if (!id || !permissions) {
      throw getBadItemError();
    }

    const permission = permissions[permissionToCheck];

    if (!permission) {
      throw getBadPermissionsError();
    }
  }
  /**
   * Base URL for api
   *
   * @return {string} base url
   */


  getBaseApiUrl() {
    const suffix = this.apiHost.endsWith('/') ? '2.0' : '/2.0';
    return "".concat(this.apiHost).concat(suffix);
  }
  /**
   * Base URL for api uploads
   *
   * @return {string} base url
   */


  getBaseUploadUrl() {
    const suffix = this.uploadHost.endsWith('/') ? 'api/2.0' : '/api/2.0';
    return "".concat(this.uploadHost).concat(suffix);
  }
  /**
   * Gets the cache instance
   *
   * @return {Cache} cache instance
   */


  getCache() {
    return this.cache;
  }
  /**
   * Generic success handler
   *
   * @param {Object} data - The response data
   */


  /**
   * Gets the URL for the API, meant to be overridden
   * @param {string} id - The item id
   */

  /* eslint-disable no-unused-vars */
  getUrl(id) {
    /* eslint-enable no-unused-vars */
    throw new Error('Implement me!');
  }
  /**
   * Formats an API entry for use in components
   * @param {string} entry - an API response entry
   */

  /* eslint-disable no-unused-vars */


  format(entry) {
    /* eslint-enable no-unused-vars */
    throw new Error('Implement me!');
  }
  /**
   * Generic API GET
   *
   * @param {string} id - The file id
   * @param {Function} successCallback - The success callback
   * @param {Function} errorCallback - The error callback
   * @param {Object} requestData - additional request data
   * @param {string} url - API url
   * @returns {Promise}
   */


  get(_ref) {
    let {
      id,
      successCallback,
      errorCallback,
      requestData,
      // Note: this is inconsistent, other methods use `data`
      url
    } = _ref;
    const apiUrl = url || this.getUrl(id);
    return this.makeRequest(HTTP_GET, id, apiUrl, successCallback, errorCallback, requestData);
  }
  /**
   * Generic API POST
   *
   * @param {string} id - The file id
   * @param {string} url - The url to post to
   * @param {Object} data - The data to post
   * @param {Function} successCallback - The success callback
   * @param {Function} errorCallback - The error callback
   */


  post(_ref2) {
    let {
      id,
      url,
      data,
      successCallback,
      errorCallback
    } = _ref2;
    return this.makeRequest(HTTP_POST, id, url, successCallback, errorCallback, data);
  }
  /**
   * Generic API PUT
   *
   * @param {string} id - The file id
   * @param {string} url - The url to put to
   * @param {Object} data - The data to put
   * @param {Function} successCallback - The success callback
   * @param {Function} errorCallback - The error callback
   */


  put(_ref3) {
    let {
      id,
      url,
      data,
      successCallback,
      errorCallback
    } = _ref3;
    return this.makeRequest(HTTP_PUT, id, url, successCallback, errorCallback, data);
  }
  /**
   * Generic API DELETE
   *
   * @param {string} id - The file id
   * @param {string} url - The url of the item to delete
   * @param {Function} successCallback - The success callback
   * @param {Function} errorCallback - The error callback
   * @param {Object} data optional data to delete
   */


  delete(_ref4) {
    let {
      id,
      url,
      data,
      successCallback,
      errorCallback
    } = _ref4;
    return this.makeRequest(HTTP_DELETE, id, url, successCallback, errorCallback, data);
  }
  /**
   * Generic API CRUD operations
   *
   * @param {string} method - which REST method to execute (GET, POST, PUT, DELETE)
   * @param {string} id - The file id
   * @param {string} url - The url of the item to operate on
   * @param {Function} successCallback - The success callback
   * @param {Function} errorCallback - The error callback
   * @param {Object} requestData - Optional info to be added to the API call such as params or request body data
   */


  async makeRequest(method, id, url, successCallback, errorCallback) {
    let requestData = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : {};

    if (this.isDestroyed()) {
      return;
    }

    this.successCallback = successCallback;
    this.errorCallback = errorCallback; // $FlowFixMe

    const xhrMethod = this.xhr[method.toLowerCase()].bind(this.xhr);

    try {
      const {
        data
      } = await xhrMethod(_objectSpread({
        id: getTypedFileId(id),
        url
      }, requestData));
      this.successHandler(data);
    } catch (error) {
      this.errorHandler(error);
    }
  }

}

export default Base;
//# sourceMappingURL=Base.js.map