function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Helper for the Box Collaborations API
 * @author Box
 *
 * The Collaborations API is different from the other APIs related to collaborations/collaborators.
 * - The Item Collaborations (File Collaborations and Folder Collaborations) API only accepts GET requests for a single item;
 *   it returns an object containing all the users who are collaborated on that item.
 * - The File Collaborators API is used exclusively in the ContentSidebar UI Element.
 * - This API enables CRUD actions on a single collaboration for a single item. For more information, see the API docs at
 *   https://developer.box.com/reference/resources/collaboration/.
 */
import Base from './Base';

class Collaborations extends Base {
  constructor() {
    super(...arguments);

    _defineProperty(this, "addCollaboration", (item, collaboration, successCallback, errorCallback) => {
      const {
        id
      } = item;
      this.post({
        id,
        data: {
          data: _objectSpread({
            item
          }, collaboration)
        },
        errorCallback,
        successCallback,
        url: this.getUrl()
      });
    });
  }

  /**
   * API URL for collaborations
   *
   * @return {string} Base URL for collaborations
   */
  getUrl() {
    return "".concat(this.getBaseApiUrl(), "/collaborations");
  }
  /**
   * Add a collaboration for a single user or a single group to a file or folder.
   * Users can be added by ID or login (email); groups can only be added by ID.
   *
   * @param {BoxItem} item
   * @param {$Shape<Collaboration>} collaboration
   * @param {(data?: Object) => void} successCallback
   * @param {ElementsErrorCallback} errorCallback
   */


}

export default Collaborations;
//# sourceMappingURL=Collaborations.js.map