function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * 
 * @file Helper for activity feed API's
 * @author Box
 */
import noop from 'lodash/noop';
import uniqueId from 'lodash/uniqueId';
import { getBadItemError, getBadUserError, getMissingItemTextOrStatus, isUserCorrectableError } from '../utils/error';
import commonMessages from '../elements/common/messages';
import messages from './messages';
import { sortFeedItems } from '../utils/sorter';
import { FEED_FILE_VERSIONS_FIELDS_TO_FETCH } from '../utils/fields';
import Base from './Base';
import AnnotationsAPI from './Annotations';
import CommentsAPI from './Comments';
import ThreadedCommentsAPI from './ThreadedComments';
import FileActivitiesAPI from './FileActivities';
import VersionsAPI from './Versions';
import TasksNewAPI from './tasks/TasksNew';
import GroupsAPI from './Groups';
import TaskCollaboratorsAPI from './tasks/TaskCollaborators';
import TaskLinksAPI from './tasks/TaskLinks';
import AppActivityAPI from './AppActivity';
import { ACTION_TYPE_CREATED, ACTION_TYPE_RESTORED, ACTION_TYPE_TRASHED, ERROR_CODE_CREATE_TASK, ERROR_CODE_UPDATE_TASK, ERROR_CODE_GROUP_EXCEEDS_LIMIT, FEED_ITEM_TYPE_ANNOTATION, FEED_ITEM_TYPE_COMMENT, FEED_ITEM_TYPE_TASK, FEED_ITEM_TYPE_VERSION, FILE_ACTIVITY_TYPE_ANNOTATION, FILE_ACTIVITY_TYPE_APP_ACTIVITY, FILE_ACTIVITY_TYPE_COMMENT, FILE_ACTIVITY_TYPE_TASK, FILE_ACTIVITY_TYPE_VERSION, HTTP_STATUS_CODE_CONFLICT, IS_ERROR_DISPLAYED, PERMISSION_CAN_VIEW_ANNOTATIONS, PERMISSION_CAN_COMMENT, TASK_NEW_APPROVED, TASK_NEW_COMPLETED, TASK_NEW_REJECTED, TASK_NEW_NOT_STARTED, TYPED_ID_FEED_PREFIX, TASK_MAX_GROUP_ASSIGNEES } from '../constants';
const TASK_NEW_INITIAL_STATUS = TASK_NEW_NOT_STARTED;

const getItemWithFilteredReplies = (item, replyId) => {
  const {
    replies = []
  } = item,
        rest = _objectWithoutProperties(item, ["replies"]);

  return _objectSpread({
    replies: replies.filter((_ref) => {
      let {
        id
      } = _ref;
      return id !== replyId;
    })
  }, rest);
};

const getItemWithPendingReply = (item, reply) => {
  const {
    replies = []
  } = item,
        rest = _objectWithoutProperties(item, ["replies"]);

  return _objectSpread({
    replies: [...replies, reply]
  }, rest);
};

const parseReplies = replies => {
  const parsedReplies = [...replies];
  return parsedReplies.map(reply => {
    return _objectSpread({}, reply, {
      tagged_message: reply.tagged_message || reply.message || ''
    });
  });
};

export const getParsedFileActivitiesResponse = response => {
  if (!response || !response.entries || !response.entries.length) {
    return [];
  }

  const data = response.entries;
  const parsedData = data.map(item => {
    if (!item.source) {
      return null;
    }

    const source = _objectSpread({}, item.source);

    switch (item.activity_type) {
      case FILE_ACTIVITY_TYPE_TASK:
        {
          var _taskItem$assigned_to;

          const taskItem = _objectSpread({}, source[FILE_ACTIVITY_TYPE_TASK]); // UAA follows a lowercased enum naming convention, convert to uppercase to align with task api


          if ((_taskItem$assigned_to = taskItem.assigned_to) === null || _taskItem$assigned_to === void 0 ? void 0 : _taskItem$assigned_to.entries) {
            const assignedToEntries = taskItem.assigned_to.entries.map(entry => {
              const assignedToEntry = _objectSpread({}, entry);

              assignedToEntry.role = entry.role.toUpperCase();
              assignedToEntry.status = entry.status.toUpperCase();
              return assignedToEntry;
            }); // $FlowFixMe Using the toUpperCase method makes Flow assume role and status is a string type, which is incompatible with string literal

            taskItem.assigned_to.entries = assignedToEntries;
          }

          if (taskItem.completion_rule) {
            taskItem.completion_rule = taskItem.completion_rule.toUpperCase();
          }

          if (taskItem.status) {
            taskItem.status = taskItem.status.toUpperCase();
          }

          if (taskItem.task_type) {
            taskItem.task_type = taskItem.task_type.toUpperCase();
          } // $FlowFixMe File Activities only returns a created_by user, Flow type fix is needed


          taskItem.created_by = {
            target: taskItem.created_by
          };
          return taskItem;
        }

      case FILE_ACTIVITY_TYPE_COMMENT:
        {
          const commentItem = _objectSpread({}, source[FILE_ACTIVITY_TYPE_COMMENT]);

          if (commentItem.replies && commentItem.replies.length) {
            const replies = parseReplies(commentItem.replies);
            commentItem.replies = replies;
          }

          commentItem.tagged_message = commentItem.tagged_message || commentItem.message || '';
          return commentItem;
        }

      case FILE_ACTIVITY_TYPE_ANNOTATION:
        {
          const annotationItem = _objectSpread({}, source[FILE_ACTIVITY_TYPE_ANNOTATION]);

          if (annotationItem.replies && annotationItem.replies.length) {
            const replies = parseReplies(annotationItem.replies);
            annotationItem.replies = replies;
          }

          return annotationItem;
        }

      case FILE_ACTIVITY_TYPE_APP_ACTIVITY:
        {
          const appActivityItem = _objectSpread({}, source[FILE_ACTIVITY_TYPE_APP_ACTIVITY]);

          appActivityItem.created_at = appActivityItem.occurred_at;
          return appActivityItem;
        }

      case FILE_ACTIVITY_TYPE_VERSION:
        {
          var _versionsItem$end, _versionsItem$start;

          const versionsItem = _objectSpread({}, source[FILE_ACTIVITY_TYPE_VERSION]);

          versionsItem.type = FEED_ITEM_TYPE_VERSION;

          if (versionsItem.action_by) {
            const collaborators = {};

            if (versionsItem.action_by.length === 1) {
              versionsItem.uploader_display_name = versionsItem.action_by[0].name;
            }

            versionsItem.action_by.map(collaborator => {
              collaborators[collaborator.id] = _objectSpread({}, collaborator);
              return collaborator;
            });
            versionsItem.collaborators = collaborators;
          }

          if ((_versionsItem$end = versionsItem.end) === null || _versionsItem$end === void 0 ? void 0 : _versionsItem$end.number) {
            versionsItem.version_end = versionsItem.end.number;
            versionsItem.id = versionsItem.end.id;
          }

          if ((_versionsItem$start = versionsItem.start) === null || _versionsItem$start === void 0 ? void 0 : _versionsItem$start.number) {
            versionsItem.version_start = versionsItem.start.number;
          }

          if (versionsItem.version_start === versionsItem.version_end) {
            var _versionsItem$start2, _versionsItem$start3, _versionsItem$start4, _versionsItem$start5, _versionsItem$start6, _versionsItem$start7;

            versionsItem.version_number = versionsItem.version_start;

            if (versionsItem.action_type === ACTION_TYPE_CREATED && ((_versionsItem$start2 = versionsItem.start) === null || _versionsItem$start2 === void 0 ? void 0 : _versionsItem$start2.created_at) && ((_versionsItem$start3 = versionsItem.start) === null || _versionsItem$start3 === void 0 ? void 0 : _versionsItem$start3.created_by)) {
              versionsItem.modified_at = versionsItem.start.created_at;
              versionsItem.modified_by = _objectSpread({}, versionsItem.start.created_by);
            }

            if (versionsItem.action_type === ACTION_TYPE_TRASHED && ((_versionsItem$start4 = versionsItem.start) === null || _versionsItem$start4 === void 0 ? void 0 : _versionsItem$start4.trashed_at) && ((_versionsItem$start5 = versionsItem.start) === null || _versionsItem$start5 === void 0 ? void 0 : _versionsItem$start5.trashed_by)) {
              versionsItem.trashed_at = versionsItem.start.trashed_at;
              versionsItem.trashed_by = _objectSpread({}, versionsItem.start.trashed_by);
            }

            if (versionsItem.action_type === ACTION_TYPE_RESTORED && ((_versionsItem$start6 = versionsItem.start) === null || _versionsItem$start6 === void 0 ? void 0 : _versionsItem$start6.restored_at) && ((_versionsItem$start7 = versionsItem.start) === null || _versionsItem$start7 === void 0 ? void 0 : _versionsItem$start7.restored_by)) {
              versionsItem.restored_at = versionsItem.start.restored_at;
              versionsItem.restored_by = _objectSpread({}, versionsItem.start.restored_by);
            }
          }

          return versionsItem;
        }

      default:
        {
          return null;
        }
    }
  }).filter(item => !!item).reverse();
  return parsedData;
};

class Feed extends Base {
  /**
   * @property {AnnotationsAPI}
   */

  /**
   * @property {VersionsAPI}
   */

  /**
   * @property {CommentsAPI}
   */

  /**
   * @property {AppActivityAPI}
   */

  /**
   * @property {TasksNewAPI}
   */

  /**
   * @property {TaskCollaboratorsAPI}
   */

  /**
   * @property {TaskLinksAPI}
   */

  /**
   * @property {ThreadedCommentsAPI}
   */

  /**
   * @property {FileActivitiesAPI}
   */

  /**
   * @property {BoxItem}
   */

  /**
   * @property {ElementsXhrError}
   */
  constructor(options) {
    var _this;

    super(options);
    _this = this;

    _defineProperty(this, "updateAnnotation", (file, annotationId, text, status, permissions, successCallback, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      if (!text && !status) {
        throw getMissingItemTextOrStatus();
      }

      this.annotationsAPI = new AnnotationsAPI(this.options);
      this.file = file;
      this.errorCallback = errorCallback;
      const feedItemChanges = {};

      if (text) {
        feedItemChanges.message = text;
      }

      if (status) {
        feedItemChanges.status = status;
      }

      this.updateFeedItem(_objectSpread({}, feedItemChanges, {
        isPending: true
      }), annotationId);
      this.annotationsAPI.updateAnnotation(this.file.id, annotationId, permissions, feedItemChanges, annotation => {
        const {
          replies,
          total_reply_count
        } = annotation,
              annotationBase = _objectWithoutProperties(annotation, ["replies", "total_reply_count"]);

        this.updateFeedItem(_objectSpread({}, annotationBase, {
          isPending: false
        }), annotationId);

        if (!this.isDestroyed()) {
          successCallback(annotation);
        }
      }, (e, code) => {
        this.updateCommentErrorCallback(e, code, annotationId);
      });
    });

    _defineProperty(this, "updateCommentErrorCallback", (e, code, id) => {
      this.updateFeedItem(this.createFeedError(messages.commentUpdateErrorMessage), id);
      this.feedErrorCallback(true, e, code);
    });

    _defineProperty(this, "updateReplyErrorCallback", (error, code, id, parentId) => {
      this.updateReplyItem(this.createFeedError(messages.commentUpdateErrorMessage), parentId, id);
      this.feedErrorCallback(true, error, code);
    });

    _defineProperty(this, "fetchRepliesErrorCallback", (error, code, id) => {
      this.updateFeedItem(this.createFeedError(messages.repliesFetchErrorMessage), id);
      this.feedErrorCallback(true, error, code);
    });

    _defineProperty(this, "deleteAnnotation", (file, annotationId, permissions, successCallBack, errorCallback) => {
      this.annotationsAPI = new AnnotationsAPI(this.options);

      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateFeedItem({
        isPending: true
      }, annotationId);
      this.annotationsAPI.deleteAnnotation(this.file.id, annotationId, permissions, this.deleteFeedItem.bind(this, annotationId, successCallBack), (error, code) => {
        // Reusing comment error handler since annotations are treated as comments to user
        this.deleteCommentErrorCallback(error, code, annotationId);
      });
    });

    _defineProperty(this, "fetchThreadedCommentSuccessCallback", (resolve, successCallback, comment) => {
      successCallback(comment);
      resolve();
    });

    _defineProperty(this, "updateTaskCollaborator", (file, taskId, taskCollaboratorId, taskCollaboratorStatus, _successCallback, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateFeedItem({
        isPending: true
      }, taskId);
      const collaboratorsApi = new TaskCollaboratorsAPI(this.options);
      this.taskCollaboratorsAPI.push(collaboratorsApi);
      const taskCollaboratorPayload = {
        id: taskCollaboratorId,
        status: taskCollaboratorStatus
      };

      const handleError = (e, code) => {
        let errorMessage;

        switch (taskCollaboratorStatus) {
          case TASK_NEW_APPROVED:
            errorMessage = messages.taskApproveErrorMessage;
            break;

          case TASK_NEW_COMPLETED:
            errorMessage = messages.taskCompleteErrorMessage;
            break;

          case TASK_NEW_REJECTED:
            errorMessage = messages.taskRejectErrorMessage;
            break;

          default:
            errorMessage = messages.taskCompleteErrorMessage;
        }

        this.updateFeedItem(this.createFeedError(errorMessage, messages.taskActionErrorTitle), taskId);
        this.feedErrorCallback(true, e, code);
      };

      collaboratorsApi.updateTaskCollaborator({
        file,
        taskCollaborator: taskCollaboratorPayload,
        successCallback: taskCollab => {
          this.updateTaskCollaboratorSuccessCallback(taskId, file, taskCollab, _successCallback, handleError);
        },
        errorCallback: handleError
      });
    });

    _defineProperty(this, "updateTaskCollaboratorSuccessCallback", (taskId, file, updatedCollaborator, _successCallback2, errorCallback) => {
      this.tasksNewAPI = new TasksNewAPI(this.options);
      this.tasksNewAPI.getTask({
        id: taskId,
        file,
        successCallback: task => {
          this.updateFeedItem(_objectSpread({}, task, {
            isPending: false
          }), taskId);

          _successCallback2(updatedCollaborator);
        },
        errorCallback
      });
    });

    _defineProperty(this, "updateTaskNew", async function (file, task) {
      let successCallback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : noop;
      let errorCallback = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : noop;

      if (!file.id) {
        throw getBadItemError();
      }

      _this.file = file;
      _this.errorCallback = errorCallback;
      _this.tasksNewAPI = new TasksNewAPI(_this.options);

      _this.updateFeedItem({
        isPending: true
      }, task.id);

      try {
        // create request for the size of each group by ID
        // TODO: use async/await for both creating and editing tasks
        const groupInfoPromises = task.addedAssignees.filter(assignee => assignee.item && assignee.item.type === 'group').map(assignee => assignee.id).map(groupId => {
          return new GroupsAPI(_this.options).getGroupCount({
            file,
            group: {
              id: groupId
            }
          });
        });
        const groupCounts = await Promise.all(groupInfoPromises);
        const hasAnyGroupCountExceeded = groupCounts.some(groupInfo => groupInfo.total_count > TASK_MAX_GROUP_ASSIGNEES);
        const warning = {
          code: ERROR_CODE_GROUP_EXCEEDS_LIMIT,
          type: 'warning'
        };

        if (hasAnyGroupCountExceeded) {
          _this.feedErrorCallback(false, warning, ERROR_CODE_GROUP_EXCEEDS_LIMIT);

          return;
        }

        await new Promise((resolve, reject) => {
          _this.tasksNewAPI.updateTaskWithDeps({
            file,
            task,
            successCallback: resolve,
            errorCallback: reject
          });
        });
        await new Promise((resolve, reject) => {
          _this.tasksNewAPI.getTask({
            file,
            id: task.id,
            successCallback: taskData => {
              _this.updateFeedItem(_objectSpread({}, taskData, {
                isPending: false
              }), task.id);

              resolve();
            },
            errorCallback: e => {
              _this.updateFeedItem({
                isPending: false
              }, task.id);

              _this.feedErrorCallback(false, e, ERROR_CODE_UPDATE_TASK);

              reject();
            }
          });
        }); // everything succeeded, so call the passed in success callback

        if (!_this.isDestroyed()) {
          successCallback();
        }
      } catch (e) {
        _this.updateFeedItem({
          isPending: false
        }, task.id);

        _this.feedErrorCallback(false, e, ERROR_CODE_UPDATE_TASK);
      }
    });

    _defineProperty(this, "deleteComment", (file, commentId, permissions, successCallback, errorCallback) => {
      this.commentsAPI = new CommentsAPI(this.options);

      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateFeedItem({
        isPending: true
      }, commentId);
      this.commentsAPI.deleteComment({
        file,
        commentId,
        permissions,
        successCallback: this.deleteFeedItem.bind(this, commentId, successCallback),
        errorCallback: (e, code) => {
          this.deleteCommentErrorCallback(e, code, commentId);
        }
      });
    });

    _defineProperty(this, "deleteThreadedComment", (file, commentId, permissions, successCallback, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateFeedItem({
        isPending: true
      }, commentId);
      this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
      this.threadedCommentsAPI.deleteComment({
        fileId: file.id,
        commentId,
        permissions,
        successCallback: this.deleteFeedItem.bind(this, commentId, successCallback),
        errorCallback: (e, code) => {
          this.deleteCommentErrorCallback(e, code, commentId);
        }
      });
    });

    _defineProperty(this, "deleteReply", (file, id, parentId, permissions, successCallback, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateReplyItem({
        isPending: true
      }, parentId, id);
      this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
      this.threadedCommentsAPI.deleteComment({
        fileId: file.id,
        commentId: id,
        permissions,
        successCallback: this.deleteReplySuccessCallback.bind(this, id, parentId, successCallback),
        errorCallback: (e, code) => {
          this.deleteReplyErrorCallback(e, code, id, parentId);
        }
      });
    });

    _defineProperty(this, "deleteReplySuccessCallback", (id, parentId, successCallback) => {
      this.modifyFeedItemRepliesCountBy(parentId, -1);
      this.deleteReplyItem(id, parentId, successCallback);
    });

    _defineProperty(this, "deleteCommentErrorCallback", (e, code, commentId) => {
      this.updateFeedItem(this.createFeedError(messages.commentDeleteErrorMessage), commentId);
      this.feedErrorCallback(true, e, code);
    });

    _defineProperty(this, "deleteReplyErrorCallback", (error, code, id, parentId) => {
      this.updateReplyItem(this.createFeedError(messages.commentDeleteErrorMessage), parentId, id);
      this.feedErrorCallback(true, error, code);
    });

    _defineProperty(this, "createTaskNew", (file, currentUser, message, assignees, taskType, dueAt, completionRule, _successCallback3, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      const uuid = uniqueId('task_');
      let dueAtString;

      if (dueAt) {
        const dueAtDate = new Date(dueAt);
        dueAtString = dueAtDate.toISOString();
      } // TODO: make pending task generator a function


      const pendingTask = {
        created_by: {
          type: 'task_collaborator',
          target: currentUser,
          id: uniqueId(),
          role: 'CREATOR',
          status: TASK_NEW_INITIAL_STATUS
        },
        completion_rule: completionRule,
        created_at: new Date().toISOString(),
        due_at: dueAtString,
        id: uuid,
        description: message,
        type: FEED_ITEM_TYPE_TASK,
        assigned_to: {
          entries: assignees.map(assignee => ({
            id: uniqueId(),
            target: _objectSpread({}, assignee, {
              avatar_url: '',
              type: 'user'
            }),
            status: TASK_NEW_INITIAL_STATUS,
            permissions: {
              can_delete: false,
              can_update: false
            },
            role: 'ASSIGNEE',
            type: 'task_collaborator'
          })),
          limit: 10,
          next_marker: null
        },
        permissions: {
          can_update: false,
          can_delete: false,
          can_create_task_collaborator: false,
          can_create_task_link: false
        },
        task_links: {
          entries: [{
            id: uniqueId(),
            type: 'task_link',
            target: _objectSpread({
              type: 'file'
            }, file),
            permissions: {
              can_delete: false,
              can_update: false
            }
          }],
          limit: 1,
          next_marker: null
        },
        task_type: taskType,
        status: TASK_NEW_NOT_STARTED
      };
      const taskPayload = {
        description: message,
        due_at: dueAtString,
        task_type: taskType,
        completion_rule: completionRule
      }; // create request for the size of each group by ID

      const groupInfoPromises = assignees.filter(assignee => (assignee.item && assignee.item.type) === 'group').map(assignee => assignee.id).map(groupId => {
        return new GroupsAPI(this.options).getGroupCount({
          file,
          group: {
            id: groupId
          }
        });
      }); // Fetch each group size in parallel --> return an array of group sizes

      Promise.all(groupInfoPromises).then(groupCounts => {
        const hasAnyGroupCountExceeded = groupCounts.some(groupInfo => groupInfo.total_count > TASK_MAX_GROUP_ASSIGNEES);
        const warning = {
          code: ERROR_CODE_GROUP_EXCEEDS_LIMIT,
          type: 'warning'
        };

        if (hasAnyGroupCountExceeded) {
          this.feedErrorCallback(false, warning, ERROR_CODE_GROUP_EXCEEDS_LIMIT);
          return;
        }

        this.tasksNewAPI = new TasksNewAPI(this.options);
        this.tasksNewAPI.createTaskWithDeps({
          file,
          task: taskPayload,
          assignees,
          successCallback: taskWithDepsData => {
            this.addPendingItem(this.file.id, currentUser, pendingTask);
            this.updateFeedItem(_objectSpread({}, taskWithDepsData, {
              task_links: {
                entries: taskWithDepsData.task_links,
                next_marker: null,
                limit: 1
              },
              assigned_to: {
                entries: taskWithDepsData.assigned_to,
                next_marker: null,
                limit: taskWithDepsData.assigned_to.length
              },
              isPending: false
            }), uuid);

            _successCallback3(taskWithDepsData);
          },
          errorCallback: (e, code) => {
            this.feedErrorCallback(false, e, code);
          }
        });
      }).catch(error => {
        this.feedErrorCallback(false, error, ERROR_CODE_CREATE_TASK);
      });
    });

    _defineProperty(this, "deleteTaskNew", function (file, task) {
      let successCallback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : noop;
      let errorCallback = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : noop;

      if (!file.id) {
        throw getBadItemError();
      }

      _this.file = file;
      _this.errorCallback = errorCallback;
      _this.tasksNewAPI = new TasksNewAPI(_this.options);

      _this.updateFeedItem({
        isPending: true
      }, task.id);

      _this.tasksNewAPI.deleteTask({
        file,
        task,
        successCallback: _this.deleteFeedItem.bind(_this, task.id, successCallback),
        errorCallback: (e, code) => {
          _this.updateFeedItem(_this.createFeedError(messages.taskDeleteErrorMessage), task.id);

          _this.feedErrorCallback(true, e, code);
        }
      });
    });

    _defineProperty(this, "deleteFeedItem", function (id) {
      let successCallback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : noop;

      const cachedItems = _this.getCachedItems(_this.file.id);

      if (cachedItems) {
        const feedItems = cachedItems.items.filter(feedItem => feedItem.id !== id);

        _this.setCachedItems(_this.file.id, feedItems);

        if (!_this.isDestroyed()) {
          successCallback(id);
        }
      }
    });

    _defineProperty(this, "deleteReplyItem", function (id, parentId) {
      let successCallback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : noop;
      const cachedItems = _this.getCachedItems(_this.file.id) || {
        items: [],
        errors: []
      };
      const feedItems = cachedItems.items.map(item => {
        if (item.id !== parentId) {
          return item;
        }

        if (item.type === FEED_ITEM_TYPE_ANNOTATION) {
          return getItemWithFilteredReplies(item, id);
        }

        if (item.type === FEED_ITEM_TYPE_COMMENT) {
          return getItemWithFilteredReplies(item, id);
        }

        return item;
      });

      _this.setCachedItems(_this.file.id, feedItems);

      if (!_this.isDestroyed()) {
        successCallback(id, parentId);
      }
    });

    _defineProperty(this, "feedErrorCallback", function () {
      let hasError = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
      let e = arguments.length > 1 ? arguments[1] : undefined;
      let code = arguments.length > 2 ? arguments[2] : undefined;

      if (hasError) {
        _this.errors.push(_objectSpread({}, e, {
          code
        }));
      }

      if (!_this.isDestroyed() && _this.errorCallback) {
        _this.errorCallback(e, code, {
          error: e,
          [IS_ERROR_DISPLAYED]: hasError
        });
      }

      console.error(e); // eslint-disable-line no-console
    });

    _defineProperty(this, "addPendingItem", (id, currentUser, itemBase) => {
      if (!currentUser) {
        throw getBadUserError();
      }

      const date = new Date().toISOString();

      const pendingFeedItem = _objectSpread({
        created_at: date,
        created_by: currentUser,
        modified_at: date,
        isPending: true
      }, itemBase);

      const cachedItems = this.getCachedItems(this.file.id);
      const feedItems = cachedItems ? cachedItems.items : [];
      const feedItemsWithPendingItem = [...feedItems, pendingFeedItem];
      this.setCachedItems(id, feedItemsWithPendingItem);
      return pendingFeedItem;
    });

    _defineProperty(this, "addPendingReply", (parentId, currentUser, commentBase) => {
      if (!this.file.id) {
        throw getBadItemError();
      }

      if (!currentUser) {
        throw getBadUserError();
      }

      const date = new Date().toISOString();

      const pendingReply = _objectSpread({
        created_at: date,
        created_by: currentUser,
        modified_at: date,
        isPending: true
      }, commentBase);

      const cachedItems = this.getCachedItems(this.file.id);

      if (cachedItems) {
        const updatedFeedItems = cachedItems.items.map(item => {
          if (item.id === parentId && item.type === FEED_ITEM_TYPE_COMMENT) {
            return getItemWithPendingReply(item, pendingReply);
          }

          if (item.id === parentId && item.type === FEED_ITEM_TYPE_ANNOTATION) {
            return getItemWithPendingReply(item, pendingReply);
          }

          return item;
        });
        this.setCachedItems(this.file.id, updatedFeedItems);
      }

      return pendingReply;
    });

    _defineProperty(this, "createCommentSuccessCallback", (commentData, id, successCallback) => {
      const {
        message = '',
        tagged_message = ''
      } = commentData; // Comment component uses tagged_message only

      commentData.tagged_message = tagged_message || message;
      this.updateFeedItem(_objectSpread({}, commentData, {
        isPending: false
      }), id);

      if (!this.isDestroyed()) {
        successCallback(commentData);
      }
    });

    _defineProperty(this, "createCommentErrorCallback", (e, code, id) => {
      const errorMessage = e.status === HTTP_STATUS_CODE_CONFLICT ? messages.commentCreateConflictMessage : messages.commentCreateErrorMessage;
      this.updateFeedItem(this.createFeedError(errorMessage), id);
      this.feedErrorCallback(false, e, code);
    });

    _defineProperty(this, "createReplySuccessCallback", (commentData, parentId, id, successCallback) => {
      this.updateReplyItem(_objectSpread({}, commentData, {
        isPending: false
      }), parentId, id);

      if (!this.isDestroyed()) {
        successCallback(commentData);
      }
    });

    _defineProperty(this, "createReplyErrorCallback", (error, code, parentId, id) => {
      const errorMessage = error.status === HTTP_STATUS_CODE_CONFLICT ? messages.commentCreateConflictMessage : messages.commentCreateErrorMessage;
      this.updateReplyItem(this.createFeedError(errorMessage), parentId, id);
      this.feedErrorCallback(false, error, code);
    });

    _defineProperty(this, "updateFeedItem", (updates, id) => {
      if (!this.file.id) {
        throw getBadItemError();
      }

      const cachedItems = this.getCachedItems(this.file.id);

      if (cachedItems) {
        const updatedFeedItems = cachedItems.items.map(item => {
          if (item.id === id) {
            return _objectSpread({}, item, {}, updates);
          }

          return item;
        });
        this.setCachedItems(this.file.id, updatedFeedItems);
        return updatedFeedItems;
      }

      return null;
    });

    _defineProperty(this, "updateReplyItem", (replyUpdates, parentId, id) => {
      if (!this.file.id) {
        throw getBadItemError();
      }

      const getItemWithUpdatedReply = (item, replyId, updates) => {
        const updatedItem = _objectSpread({}, item);

        if (updatedItem.replies) {
          updatedItem.replies = updatedItem.replies.map(reply => {
            if (reply.id === replyId) {
              return _objectSpread({}, reply, {}, updates);
            }

            return reply;
          });
        }

        return updatedItem;
      };

      const cachedItems = this.getCachedItems(this.file.id);

      if (cachedItems) {
        const updatedFeedItems = cachedItems.items.map(item => {
          if (item.id === parentId && item.type === FEED_ITEM_TYPE_COMMENT) {
            return getItemWithUpdatedReply(item, id, replyUpdates);
          }

          if (item.id === parentId && item.type === FEED_ITEM_TYPE_ANNOTATION) {
            return getItemWithUpdatedReply(item, id, replyUpdates);
          }

          return item;
        });
        this.setCachedItems(this.file.id, updatedFeedItems);
      }
    });

    _defineProperty(this, "createComment", (file, currentUser, text, hasMention, _successCallback4, errorCallback) => {
      const uuid = uniqueId('comment_');
      const commentData = {
        id: uuid,
        tagged_message: text,
        type: FEED_ITEM_TYPE_COMMENT
      };

      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.addPendingItem(this.file.id, currentUser, commentData);
      const message = {};

      if (hasMention) {
        message.taggedMessage = text;
      } else {
        message.message = text;
      }

      this.commentsAPI = new CommentsAPI(this.options);
      this.commentsAPI.createComment(_objectSpread({
        file
      }, message, {
        successCallback: comment => {
          this.createCommentSuccessCallback(comment, uuid, _successCallback4);
        },
        errorCallback: (e, code) => {
          this.createCommentErrorCallback(e, code, uuid);
        }
      }));
    });

    _defineProperty(this, "createThreadedComment", (file, currentUser, text, _successCallback5, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      const uuid = uniqueId('comment_');
      const commentData = {
        id: uuid,
        tagged_message: text,
        type: FEED_ITEM_TYPE_COMMENT
      };
      this.file = file;
      this.errorCallback = errorCallback;
      this.addPendingItem(this.file.id, currentUser, commentData);
      this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
      this.threadedCommentsAPI.createComment({
        file,
        message: text,
        successCallback: comment => {
          this.createCommentSuccessCallback(comment, uuid, _successCallback5);
        },
        errorCallback: (e, code) => {
          this.createCommentErrorCallback(e, code, uuid);
        }
      });
    });

    _defineProperty(this, "updateComment", (file, commentId, text, hasMention, permissions, _successCallback6, errorCallback) => {
      const commentData = {
        tagged_message: text
      };

      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateFeedItem(_objectSpread({}, commentData, {
        isPending: true
      }), commentId);
      const message = {};

      if (hasMention) {
        message.tagged_message = text;
      } else {
        message.message = text;
      }

      this.commentsAPI = new CommentsAPI(this.options);
      this.commentsAPI.updateComment(_objectSpread({
        file,
        commentId,
        permissions
      }, message, {
        successCallback: comment => {
          // use the request payload instead of response in the
          // feed item update because response may not contain
          // the tagged version of the message
          this.updateFeedItem(_objectSpread({}, message, {
            isPending: false
          }), commentId);

          if (!this.isDestroyed()) {
            _successCallback6(comment);
          }
        },
        errorCallback: (e, code) => {
          this.updateCommentErrorCallback(e, code, commentId);
        }
      }));
    });

    _defineProperty(this, "updateThreadedComment", (file, commentId, text, status, permissions, _successCallback7, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      if (!text && !status) {
        throw getMissingItemTextOrStatus();
      }

      const commentData = {};

      if (text) {
        commentData.tagged_message = text;
      }

      if (status) {
        commentData.status = status;
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateFeedItem(_objectSpread({}, commentData, {
        isPending: true
      }), commentId);
      this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
      this.threadedCommentsAPI.updateComment({
        fileId: file.id,
        commentId,
        permissions,
        message: text,
        status,
        successCallback: comment => {
          const {
            replies,
            total_reply_count
          } = comment,
                commentBase = _objectWithoutProperties(comment, ["replies", "total_reply_count"]);

          this.updateFeedItem(_objectSpread({}, commentBase, {
            isPending: false
          }), commentId);

          if (!this.isDestroyed()) {
            _successCallback7(comment);
          }
        },
        errorCallback: (e, code) => {
          this.updateCommentErrorCallback(e, code, commentId);
        }
      });
    });

    _defineProperty(this, "updateReply", (file, id, parentId, text, permissions, _successCallback8, errorCallback) => {
      if (!file.id) {
        throw getBadItemError();
      }

      this.file = file;
      this.errorCallback = errorCallback;
      this.updateReplyItem({
        tagged_message: text,
        isPending: true
      }, parentId, id);
      this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
      this.threadedCommentsAPI.updateComment({
        fileId: file.id,
        commentId: id,
        permissions,
        message: text,
        undefined,
        successCallback: comment => {
          this.updateReplyItem(_objectSpread({}, comment, {
            isPending: false
          }), parentId, id);

          if (!this.isDestroyed()) {
            _successCallback8(comment);
          }
        },
        errorCallback: (error, code) => {
          this.updateReplyErrorCallback(error, code, id, parentId);
        }
      });
    });

    _defineProperty(this, "modifyFeedItemRepliesCountBy", (id, n) => {
      if (!this.file.id) {
        throw getBadItemError();
      }

      const {
        items: feedItems = []
      } = this.getCachedItems(this.file.id) || {};
      const feedItem = feedItems.find((_ref2) => {
        let {
          id: itemId
        } = _ref2;
        return itemId === id;
      });

      if (!feedItem || feedItem.type !== 'annotation' && feedItem.type !== 'comment') {
        return;
      }

      const newReplyCount = (feedItem.total_reply_count || 0) + n;

      if (newReplyCount >= 0) {
        this.updateFeedItem({
          total_reply_count: newReplyCount
        }, id);
      }
    });

    _defineProperty(this, "deleteAppActivity", (file, appActivityId, successCallback, errorCallback) => {
      const {
        id
      } = file;

      if (!id) {
        throw getBadItemError();
      }

      this.appActivityAPI = new AppActivityAPI(this.options);
      this.file = file;
      this.errorCallback = errorCallback;
      this.updateFeedItem({
        isPending: true
      }, appActivityId);
      this.appActivityAPI.deleteAppActivity({
        id,
        appActivityId,
        successCallback: this.deleteFeedItem.bind(this, appActivityId, successCallback),
        errorCallback: (e, code) => {
          this.deleteAppActivityErrorCallback(e, code, appActivityId);
        }
      });
    });

    _defineProperty(this, "deleteAppActivityErrorCallback", (e, code, id) => {
      this.updateFeedItem(this.createFeedError(messages.appActivityDeleteErrorMessage), id);
      this.feedErrorCallback(true, e, code);
    });

    this.taskCollaboratorsAPI = [];
    this.taskLinksAPI = [];
    this.errors = [];
  }
  /**
   * Creates pending card on create_start action, then updates card on next call
   * @param {BoxItem} file - The file to which the annotation is assigned
   * @param {Object} currentUser - the user who performed the action
   * @param {Annotation} annotation - the current annotation to be created
   * @param {string} id - unique id for the incoming annotation
   * @param {boolean} isPending - indicates the current creation process of the annotation
   */


  addAnnotation(file, currentUser, annotation, id, isPending) {
    if (!file.id) {
      throw getBadItemError();
    }

    this.file = file; // Add the pending interstitial card

    if (isPending) {
      const newAnnotation = _objectSpread({}, annotation, {
        created_by: currentUser,
        id,
        type: FEED_ITEM_TYPE_ANNOTATION
      });

      this.addPendingItem(this.file.id, currentUser, newAnnotation);
      return;
    } // Create action has completed, so update the existing pending item


    this.updateFeedItem(_objectSpread({}, annotation, {
      isPending: false
    }), id);
  }

  /**
   * Creates a key for the cache
   *
   * @param {string} id folder id
   * @return {string} key
   */
  getCacheKey(id) {
    return "".concat(TYPED_ID_FEED_PREFIX).concat(id);
  }
  /**
   * Gets the items from the cache
   *
   * @param {string} id the cache id
   */


  getCachedItems(id) {
    const cache = this.getCache();
    const cacheKey = this.getCacheKey(id);
    return cache.get(cacheKey);
  }
  /**
   * Sets the items in the cache
   *
   * @param {string} id - the cache id
   * @param {Array} items - the feed items to cache
   */


  setCachedItems(id, items) {
    const cache = this.getCache();
    const cacheKey = this.getCacheKey(id);
    cache.set(cacheKey, {
      errors: this.errors,
      items
    });
  }
  /**
   * Gets the feed items
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {boolean} shouldRefreshCache - Optionally updates the cache
   * @param {Function} successCallback - the success callback  which is called after data fetching is complete
   * @param {Function} errorCallback - the error callback which is called after data fetching is complete if there was an error
   * @param {Function} onError - the function to be called immediately after an error occurs
   * @param {Object} [options]- feature flips, etc
   * @param {Object} [options.shouldShowAppActivity] - feature flip the new app activity api
   */


  feedItems(file, shouldRefreshCache, successCallback, errorCallback, onError) {
    let {
      shouldShowAnnotations = false,
      shouldShowAppActivity = false,
      shouldShowReplies = false,
      shouldShowTasks = true,
      shouldShowVersions = true,
      shouldUseUAA = false
    } = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : {};
    const {
      id,
      permissions = {}
    } = file;
    const cachedItems = this.getCachedItems(id);

    if (cachedItems) {
      const {
        errors,
        items
      } = cachedItems;

      if (errors.length) {
        errorCallback(items, errors);
      } else {
        successCallback(items);
      }

      if (!shouldRefreshCache) {
        return;
      }
    }

    this.file = file;
    this.errors = [];
    this.errorCallback = onError; // Using the UAA File Activities endpoint replaces the need for these calls

    const annotationsPromise = !shouldUseUAA && shouldShowAnnotations ? this.fetchAnnotations(permissions, shouldShowReplies) : Promise.resolve();

    const commentsPromise = () => {
      if (shouldUseUAA) {
        return Promise.resolve();
      }

      return shouldShowReplies ? this.fetchThreadedComments(permissions) : this.fetchComments(permissions);
    };

    const tasksPromise = !shouldUseUAA && shouldShowTasks ? this.fetchTasksNew() : Promise.resolve();
    const appActivityPromise = !shouldUseUAA && shouldShowAppActivity ? this.fetchAppActivity(permissions) : Promise.resolve();
    const versionsPromise = !shouldUseUAA && shouldShowVersions ? this.fetchVersions() : Promise.resolve();
    const currentVersionPromise = !shouldUseUAA && shouldShowVersions ? this.fetchCurrentVersion() : Promise.resolve();
    const annotationActivityType = shouldShowAnnotations && permissions[PERMISSION_CAN_VIEW_ANNOTATIONS] ? [FILE_ACTIVITY_TYPE_ANNOTATION] : [];
    const appActivityActivityType = shouldShowAppActivity ? [FILE_ACTIVITY_TYPE_APP_ACTIVITY] : [];
    const taskActivityType = shouldShowTasks ? [FILE_ACTIVITY_TYPE_TASK] : [];
    const versionsActivityType = shouldShowVersions ? [FILE_ACTIVITY_TYPE_VERSION] : [];
    const commentActivityType = permissions[PERMISSION_CAN_COMMENT] ? [FILE_ACTIVITY_TYPE_COMMENT] : [];
    const filteredActivityTypes = [...annotationActivityType, ...appActivityActivityType, ...commentActivityType, ...taskActivityType, ...versionsActivityType];
    const fileActivitiesPromise = // Only fetch when activity types are explicitly stated
    shouldUseUAA && filteredActivityTypes.length ? this.fetchFileActivities(permissions, filteredActivityTypes, shouldShowReplies) : Promise.resolve();

    const handleFeedItems = feedItems => {
      if (!this.isDestroyed()) {
        this.setCachedItems(id, feedItems);

        if (this.errors.length) {
          errorCallback(feedItems, this.errors);
        } else {
          successCallback(feedItems);
        }
      }
    };

    if (shouldUseUAA) {
      fileActivitiesPromise.then(response => {
        if (!response) {
          return;
        }

        const parsedFeedItems = getParsedFileActivitiesResponse(response);
        handleFeedItems(parsedFeedItems);
      });
    } else {
      Promise.all([versionsPromise, currentVersionPromise, commentsPromise(), tasksPromise, appActivityPromise, annotationsPromise]).then((_ref3) => {
        let [versions, currentVersion, ...feedItems] = _ref3;
        const versionsWithCurrent = currentVersion ? this.versionsAPI.addCurrentVersion(currentVersion, versions, this.file) : undefined;
        const sortedFeedItems = sortFeedItems(versionsWithCurrent, ...feedItems);
        handleFeedItems(sortedFeedItems);
      });
    }
  }

  fetchAnnotations(permissions, shouldFetchReplies) {
    this.annotationsAPI = new AnnotationsAPI(this.options);
    return new Promise(resolve => {
      this.annotationsAPI.getAnnotations(this.file.id, undefined, permissions, resolve, this.fetchFeedItemErrorCallback.bind(this, resolve), undefined, undefined, shouldFetchReplies);
    });
  }
  /**
   * Fetches the comments for a file
   *
   * @param {Object} permissions - the file permissions
   * @return {Promise} - the file comments
   */


  fetchComments(permissions) {
    this.commentsAPI = new CommentsAPI(this.options);
    return new Promise(resolve => {
      this.commentsAPI.getComments(this.file.id, permissions, resolve, this.fetchFeedItemErrorCallback.bind(this, resolve));
    });
  }
  /**
   * Fetches a comment for a file
   *
   * @param {BoxItem} file - The file to which the comment belongs to
   * @param {string} commentId - comment id
   * @param {Function} successCallback
   * @param {ErrorCallback} errorCallback
   * @return {Promise} - the file comments
   */


  fetchThreadedComment(file, commentId, successCallback, errorCallback) {
    const {
      id,
      permissions
    } = file;

    if (!id || !permissions) {
      throw getBadItemError();
    }

    this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
    return new Promise(resolve => {
      this.threadedCommentsAPI.getComment({
        commentId,
        errorCallback,
        fileId: id,
        permissions,
        successCallback: this.fetchThreadedCommentSuccessCallback.bind(this, resolve, successCallback)
      });
    });
  }
  /**
   * Callback for successful fetch of a comment
   *
   * @param {Function} resolve - resolve function
   * @param {Function} successCallback - success callback
   * @param {Comment} comment - comment data
   * @return {void}
   */


  /**
   * Fetches the comments with replies for a file
   *
   * @param {Object} permissions - the file permissions
   * @return {Promise} - the file comments
   */
  fetchThreadedComments(permissions) {
    this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
    return new Promise(resolve => {
      this.threadedCommentsAPI.getComments({
        errorCallback: this.fetchFeedItemErrorCallback.bind(this, resolve),
        fileId: this.file.id,
        permissions,
        successCallback: resolve
      });
    });
  }
  /**
   * Fetches the file activities for a file
   *
   * @param {BoxItemPermission} permissions - the file permissions
   * @param {FileActivityTypes[]} activityTypes - the activity types to filter by
   * @param {boolean} shouldShowReplies - specify if replies should be included in the response
   * @return {Promise} - the file comments
   */


  fetchFileActivities(permissions, activityTypes) {
    let shouldShowReplies = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    this.fileActivitiesAPI = new FileActivitiesAPI(this.options);
    return new Promise(resolve => {
      this.fileActivitiesAPI.getActivities({
        errorCallback: this.fetchFeedItemErrorCallback.bind(this, resolve),
        fileID: this.file.id,
        permissions,
        successCallback: resolve,
        activityTypes,
        shouldShowReplies
      });
    });
  }
  /**
   * Fetches replies (comments) of a comment or annotation
   *
   * @param {BoxItem} file - The file to which the comment or annotation belongs to
   * @param {string} commentFeedItemId - ID of the comment or annotation
   * @param {CommentFeedItemType} commentFeedItemType - Type of the comment or annotation
   * @param {Function} successCallback
   * @param {ErrorCallback} errorCallback
   * @return {void}
   */


  fetchReplies(file, commentFeedItemId, commentFeedItemType, successCallback, errorCallback) {
    const {
      id,
      permissions
    } = file;

    if (!id || !permissions) {
      throw getBadItemError();
    }

    this.file = file;
    this.errorCallback = errorCallback;
    this.updateFeedItem({
      isRepliesLoading: true
    }, commentFeedItemId);

    const successCallbackFn = (_ref4) => {
      let {
        entries
      } = _ref4;
      this.updateFeedItem({
        isRepliesLoading: false,
        replies: entries,
        total_reply_count: entries.length
      }, commentFeedItemId);
      successCallback(entries);
    };

    const errorCallbackFn = (error, code) => {
      this.fetchRepliesErrorCallback(error, code, commentFeedItemId);
    };

    if (commentFeedItemType === FEED_ITEM_TYPE_ANNOTATION) {
      this.annotationsAPI = new AnnotationsAPI(this.options);
      this.annotationsAPI.getAnnotationReplies(file.id, commentFeedItemId, permissions, successCallbackFn, errorCallbackFn);
    } else if (commentFeedItemType === FEED_ITEM_TYPE_COMMENT) {
      this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
      this.threadedCommentsAPI.getCommentReplies({
        fileId: file.id,
        commentId: commentFeedItemId,
        permissions,
        successCallback: successCallbackFn,
        errorCallback: errorCallbackFn
      });
    }
  }
  /**
   * Fetches the versions for a file
   *
   * @return {Promise} - the file versions
   */


  fetchVersions() {
    this.versionsAPI = new VersionsAPI(this.options);
    return new Promise(resolve => {
      this.versionsAPI.getVersions(this.file.id, resolve, this.fetchFeedItemErrorCallback.bind(this, resolve), undefined, undefined, FEED_FILE_VERSIONS_FIELDS_TO_FETCH);
    });
  }
  /**
   * Fetches the current version for a file
   *
   * @return {Promise} - the file versions
   */


  fetchCurrentVersion() {
    this.versionsAPI = new VersionsAPI(this.options);
    return new Promise(resolve => {
      const {
        file_version = {}
      } = this.file;
      this.versionsAPI.getVersion(this.file.id, file_version.id, resolve, this.fetchFeedItemErrorCallback.bind(this, resolve));
    });
  }
  /**
   * Fetches the tasks for a file
   *
   * @return {Promise} - the feed items
   */


  fetchTasksNew() {
    this.tasksNewAPI = new TasksNewAPI(this.options);
    return new Promise(resolve => {
      this.tasksNewAPI.getTasksForFile({
        file: {
          id: this.file.id
        },
        successCallback: resolve,
        errorCallback: (err, code) => this.fetchFeedItemErrorCallback(resolve, err, code)
      });
    });
  }
  /**
   * Error callback for fetching feed items.
   * Should only call the error callback if the response is a 401, 429 or >= 500
   *
   * @param {Function} resolve - the function which will be called on error
   * @param {Object} e - the axios error
   * @param {string} code - the error code
   * @return {void}
   */


  fetchFeedItemErrorCallback(resolve, e, code) {
    const {
      status
    } = e;
    const shouldDisplayError = isUserCorrectableError(status);
    this.feedErrorCallback(shouldDisplayError, e, code);
    resolve();
  }
  /**
   * Updates a task assignment
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {string} taskId - ID of task to be updated
   * @param {string} taskCollaboratorId - Task assignment ID
   * @param {TaskCollabStatus} taskCollaboratorStatus - New task assignment status
   * @param {Function} successCallback - the function which will be called on success
   * @param {Function} errorCallback - the function which will be called on error
   * @return {void}
   */


  /**
   * Creates a task group via the API.
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {Task|TaskUpdatePayload} task - The newly created or existing task from the API
   * @param {SelectorItem} assignee - The user assigned to this task
   * @param {Function} errorCallback - Task create error callback
   * @return {Promise<TaskAssignment>}
   */
  createTaskCollaboratorsforGroup(file, task, assignee) {
    if (!file.id) {
      throw getBadItemError();
    }

    this.file = file;
    return new Promise((resolve, reject) => {
      const taskCollaboratorsAPI = new TaskCollaboratorsAPI(this.options);
      this.taskCollaboratorsAPI.push(taskCollaboratorsAPI);
      taskCollaboratorsAPI.createTaskCollaboratorsforGroup({
        file,
        task,
        group: assignee,
        successCallback: resolve,
        errorCallback: e => {
          reject(e);
        }
      });
    });
  }
  /**
   * Creates a task collaborator via the API.
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {Task|TaskUpdatePayload} task - The newly created or existing task from the API
   * @param {SelectorItem} assignee - The user assigned to this task
   * @param {Function} errorCallback - Task create error callback
   * @return {Promise<TaskAssignment>}
   */


  createTaskCollaborator(file, task, assignee) {
    if (!file.id) {
      throw getBadItemError();
    }

    this.file = file;
    return new Promise((resolve, reject) => {
      const taskCollaboratorsAPI = new TaskCollaboratorsAPI(this.options);
      this.taskCollaboratorsAPI.push(taskCollaboratorsAPI);
      taskCollaboratorsAPI.createTaskCollaborator({
        file,
        task,
        user: assignee,
        successCallback: resolve,
        errorCallback: e => {
          reject(e);
        }
      });
    });
  }
  /**
   * Deletes a task collaborator via the API.
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {Task|TaskUpdatePayload} task - The newly deleted or existing task from the API
   * @param {TaskCollabAssignee} assignee - The user assigned to this task
   * @param {Function} errorCallback - Task delete error callback
   * @return {Promise<TaskAssignment>}
   */


  deleteTaskCollaborator(file, task, assignee) {
    if (!file.id) {
      throw getBadItemError();
    }

    this.file.id = file.id;
    return new Promise((resolve, reject) => {
      const taskCollaboratorsAPI = new TaskCollaboratorsAPI(this.options);
      this.taskCollaboratorsAPI.push(taskCollaboratorsAPI);
      taskCollaboratorsAPI.deleteTaskCollaborator({
        file,
        task,
        taskCollaborator: {
          id: assignee.id
        },
        successCallback: resolve,
        errorCallback: e => {
          reject(e);
        }
      });
    });
  }
  /**
   * Creates a task link via the API.
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {Task} task - The newly created task from the API
   * @param {Function} errorCallback - Task create error callback
   * @return {Promise<TaskAssignment}
   */


  createTaskLink(file, task) {
    if (!file.id) {
      throw getBadItemError();
    }

    this.file = file;
    return new Promise((resolve, reject) => {
      const taskLinksAPI = new TaskLinksAPI(this.options);
      this.taskLinksAPI.push(taskLinksAPI);
      taskLinksAPI.createTaskLink({
        file,
        task,
        successCallback: resolve,
        errorCallback: reject
      });
    });
  }
  /**
   * Deletes a task in the new API
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {string} taskId - The task's id
   * @param {Function} successCallback - the function which will be called on success
   * @param {Function} errorCallback - the function which will be called on error
   * @return {void}
   */


  /**
   * Constructs an error object that renders to an inline feed error
   *
   * @param {string} message - The error message body.
   * @param {string} title - The error message title.
   * @return {Object} An error message object
   */
  createFeedError(message) {
    let title = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : commonMessages.errorOccured;
    return {
      error: {
        message,
        title
      }
    };
  }
  /**
   * Replace a feed item with new feed item data.
   *
   * @param {Object} updates - The new data to be applied to the feed item.
   * @param {string} id - ID of the feed item to replace.
   * @return {void}
   */


  /**
   * Create a reply to annotation or comment, and make a pending item to be replaced once the API is successful.
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {Object} currentUser - the user who performed the action
   * @param {string} parentId - id of the parent item
   * @param {CommentFeedItemType} parentType - type of the parent item
   * @param {string} text - the comment text
   * @param {Function} successCallback - the success callback
   * @param {Function} errorCallback - the error callback
   * @return {void}
   */
  createReply(file, currentUser, parentId, parentType, text, successCallback, errorCallback) {
    const {
      id,
      permissions
    } = file;

    if (!id || !permissions) {
      throw getBadItemError();
    }

    const uuid = uniqueId('comment_');
    const commentData = {
      id: uuid,
      tagged_message: text,
      type: FEED_ITEM_TYPE_COMMENT
    };
    this.file = file;
    this.errorCallback = errorCallback;
    this.addPendingReply(parentId, currentUser, commentData);
    this.modifyFeedItemRepliesCountBy(parentId, 1);

    const successCallbackFn = comment => {
      this.createReplySuccessCallback(comment, parentId, uuid, successCallback);
    };

    const errorCallbackFn = (error, code) => {
      this.createReplyErrorCallback(error, code, parentId, uuid);
    };

    if (parentType === FEED_ITEM_TYPE_ANNOTATION) {
      this.annotationsAPI = new AnnotationsAPI(this.options);
      this.annotationsAPI.createAnnotationReply(file.id, parentId, permissions, text, successCallbackFn, errorCallbackFn);
    } else if (parentType === FEED_ITEM_TYPE_COMMENT) {
      this.threadedCommentsAPI = new ThreadedCommentsAPI(this.options);
      this.threadedCommentsAPI.createCommentReply({
        fileId: file.id,
        commentId: parentId,
        permissions,
        message: text,
        successCallback: successCallbackFn,
        errorCallback: errorCallbackFn
      });
    }
  }
  /**
   * Update a comment
   *
   * @param {BoxItem} file - The file to which the task is assigned
   * @param {string} commentId - Comment ID
   * @param {string} text - the comment text
   * @param {boolean} hasMention - true if there is an @mention in the text
   * @param {BoxCommentPermission} permissions - Permissions to attach to the app activity items
   * @param {Function} successCallback - the success callback
   * @param {Function} errorCallback - the error callback
   * @return {void}
   */


  destroyTaskCollaborators() {
    if (Array.isArray(this.taskCollaboratorsAPI)) {
      this.taskCollaboratorsAPI.forEach(api => api.destroy());
      this.taskCollaboratorsAPI = [];
    }
  }

  destroyTaskLinks() {
    if (Array.isArray(this.taskLinksAPI)) {
      this.taskLinksAPI.forEach(api => api.destroy());
      this.taskLinksAPI = [];
    }
  }
  /**
   * Fetches app activities for a file
   * @param {BoxItemPermission} permissions - Permissions to attach to the app activity items
   *
   * @return {Promise} - the feed items
   */


  fetchAppActivity(permissions) {
    this.appActivityAPI = new AppActivityAPI(this.options);
    return new Promise(resolve => {
      this.appActivityAPI.getAppActivity(this.file.id, permissions, resolve, this.fetchFeedItemErrorCallback.bind(this, resolve));
    });
  }
  /**
   * Deletes an app activity item.
   *
   * @param {BoxItem} file - The file to which the app activity belongs to
   * @param {string} appActivityId - The app activity item id to delete
   * @param {Function} successCallback - the function which will be called on success
   * @param {Function} errorCallback - the function which will be called on error
   * @return {void}
   */


  /**
   * Destroys all the task feed API's
   *
   * @return {void}
   */
  destroy() {
    super.destroy();

    if (this.annotationsAPI) {
      this.annotationsAPI.destroy();
      delete this.annotationsAPI;
    }

    if (this.commentsAPI) {
      this.commentsAPI.destroy();
      delete this.commentsAPI;
    }

    if (this.threadedCommentsAPI) {
      this.threadedCommentsAPI.destroy();
      delete this.threadedCommentsAPI;
    }

    if (this.versionsAPI) {
      this.versionsAPI.destroy();
      delete this.versionsAPI;
    }

    if (this.appActivityAPI) {
      this.appActivityAPI.destroy();
      delete this.appActivityAPI;
    }

    if (this.tasksNewAPI) {
      this.tasksNewAPI.destroy();
      delete this.tasksNewAPI;
    }

    this.destroyTaskCollaborators();
    this.destroyTaskLinks();
  }

}

export default Feed;
//# sourceMappingURL=Feed.js.map