function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Helper for the box File Activity API
 * @author Box
 */
import Base from './Base';
import { ERROR_CODE_FETCH_ACTIVITY, FILE_ACTIVITY_TYPE_ANNOTATION, FILE_ACTIVITY_TYPE_COMMENT, PERMISSION_CAN_COMMENT, PERMISSION_CAN_VIEW_ANNOTATIONS } from '../constants';
// We only show the latest reply in the UI
const REPLY_LIMIT = 1;

const getFileActivityQueryParams = function getFileActivityQueryParams(fileID) {
  let activityTypes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  let shouldShowReplies = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  const baseEndpoint = "/file_activities?file_id=".concat(fileID);
  const hasActivityTypes = !!activityTypes && !!activityTypes.length;
  const enableReplies = shouldShowReplies ? 'true' : 'false';
  const enabledRepliesQueryParam = "&enable_replies=".concat(enableReplies, "&reply_limit=").concat(REPLY_LIMIT);
  const activityTypeQueryParam = hasActivityTypes ? "&activity_types=".concat(activityTypes.join()) : '';
  return "".concat(baseEndpoint).concat(activityTypeQueryParam).concat(enabledRepliesQueryParam);
};

class FileActivities extends Base {
  /**
   * API URL for filtered file activities
   *
   * @param {string} [id] - a box file id
   * @param {Array<FileActivityTypes>} activityTypes - optional. Array of File Activity types to filter by, returns all Activity Types if omitted.
   * @param {boolean} shouldShowReplies - optional. Specify if replies should be included in the response
   * @return {string} base url for files
   */
  getFilteredUrl(id, activityTypes, shouldShowReplies) {
    return "".concat(this.getBaseApiUrl()).concat(getFileActivityQueryParams(id, activityTypes, shouldShowReplies));
  }
  /**
   * API for fetching file activities
   *
   * @param {Array<FileActivityTypes>} activityTypes - optional. Array of File Activity types to filter by, returns all Activity Types if omitted.
   * @param {Function} errorCallback - the error callback
   * @param {string} fileId - the file id
   * @param {BoxItemPermission} permissions - the permissions for the file
   * @param {number} repliesCount - number of replies to return, by default all replies are returned
   * @param {boolean} shouldShowReplies - specify if replies should be included in the response
   * @param {Function} successCallback - the success callback
   * @returns {void}
   */


  getActivities(_ref) {
    let {
      activityTypes,
      errorCallback,
      fileID,
      permissions,
      repliesCount,
      shouldShowReplies,
      successCallback
    } = _ref;
    this.errorCode = ERROR_CODE_FETCH_ACTIVITY;

    try {
      if (!fileID) {
        throw new Error('Missing file id!');
      }

      if (activityTypes.includes(FILE_ACTIVITY_TYPE_COMMENT)) {
        this.checkApiCallValidity(PERMISSION_CAN_COMMENT, permissions, fileID);
      }

      if (activityTypes.includes(FILE_ACTIVITY_TYPE_ANNOTATION)) {
        this.checkApiCallValidity(PERMISSION_CAN_VIEW_ANNOTATIONS, permissions, fileID);
      }
    } catch (e) {
      errorCallback(e, this.errorCode);
      return;
    }

    this.get({
      id: fileID,
      successCallback,
      errorCallback,
      requestData: _objectSpread({}, repliesCount ? {
        replies_count: repliesCount
      } : null),
      url: this.getFilteredUrl(fileID, activityTypes, shouldShowReplies)
    });
  }

}

export default FileActivities;
//# sourceMappingURL=FileActivities.js.map