function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file class for Box offset based API's to inherit common functionality from
 * @author Box
 */
import { getTypedFileId } from '../utils/file';
import Base from './Base';
import { DEFAULT_FETCH_START, DEFAULT_FETCH_END } from '../constants';

class OffsetBasedApi extends Base {
  /**
   * @property {Data}
   */

  /**
   * Gets query params for the API
   *
   * @param {number} offset the offset from the start to start fetching at
   * @param {number} limit the number of items to fetch
   * @param {array} fields the fields to fetch
   * @return the query params object
   */
  getQueryParameters(offset, limit, fields) {
    const queryParams = {
      offset,
      limit
    };

    if (fields && fields.length > 0) {
      queryParams.fields = fields.toString();
    }

    return queryParams;
  }
  /**
   * Determines if the API has more items to fetch
   *
   * @param {number} offset the offset from the start to start fetching at
   * @param {number} totalCount the total number of items
   * @return {boolean} true if there are more items
   */


  hasMoreItems(offset, totalCount) {
    return totalCount === undefined || offset < totalCount;
  }
  /**
   * Helper for get
   *
   * @param {string} id the file id
   * @param {number} offset the offset from the start to start fetching at
   * @param {number} limit the number of items to fetch
   * @param {array} fields the fields to fetch
   * @param {boolean} shouldFetchAll true if should get all the pages before calling the sucessCallback
   * @private
   */


  async offsetGetRequest(id, offset, limit, shouldFetchAll, fields) {
    if (this.isDestroyed()) {
      return;
    } // Make the XHR request


    try {
      const params = this.getQueryParameters(offset, limit, fields);
      const url = this.getUrl(id);
      const {
        data
      } = await this.xhr.get({
        url,
        id: getTypedFileId(id),
        params
      });
      const entries = this.data ? this.data.entries : [];
      this.data = _objectSpread({}, data, {
        entries: entries.concat(data.entries)
      });
      const totalCount = data.total_count;
      const nextOffset = offset + limit;

      if (shouldFetchAll && this.hasMoreItems(nextOffset, totalCount)) {
        this.offsetGetRequest(id, nextOffset, limit, shouldFetchAll, fields);
        return;
      }

      this.successHandler(this.data);
    } catch (error) {
      this.errorHandler(error);
    }
  }
  /**
   * Offset based API get
   *
   * @param {string} id the file id
   * @param {Function} successCallback the success callback
   * @param {Function} errorCallback the error callback
   * @param {number} offset the offset from the start to start fetching at
   * @param {number} limit the number of items to fetch
   * @param {array} fields the fields to fetch
   * @param {boolean} shouldFetchAll true if should get all the pages before calling the sucessCallback
   */


  async offsetGet(id, successCallback, errorCallback) {
    let offset = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : DEFAULT_FETCH_START;
    let limit = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : DEFAULT_FETCH_END;
    let fields = arguments.length > 5 ? arguments[5] : undefined;
    let shouldFetchAll = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : true;
    this.successCallback = successCallback;
    this.errorCallback = errorCallback;
    return this.offsetGetRequest(id, offset, limit, shouldFetchAll, fields);
  }

}

export default OffsetBasedApi;
//# sourceMappingURL=OffsetBasedAPI.js.map