function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Helper for the box recents api
 * @author Box
 */
import flatten from '../utils/flatten';
import { getBadItemError } from '../utils/error';
import { FOLDER_FIELDS_TO_FETCH } from '../utils/fields';
import Base from './Base';
import FileAPI from './File';
import FolderAPI from './Folder';
import WebLinkAPI from './WebLink';
import { DEFAULT_ROOT, CACHE_PREFIX_RECENTS, ERROR_CODE_FETCH_RECENTS, FIELD_DATE, FIELD_REPRESENTATIONS, X_REP_HINT_HEADER_DIMENSIONS_DEFAULT, SORT_DESC } from '../constants';

class Recents extends Base {
  constructor() {
    super(...arguments);

    _defineProperty(this, "recentsSuccessHandler", (_ref) => {
      let {
        data
      } = _ref;

      if (this.isDestroyed()) {
        return;
      }

      const {
        entries,
        order: {
          by,
          direction
        }
      } = data;
      const items = [];
      entries.forEach((_ref2) => {
        let {
          item,
          interacted_at
        } = _ref2;
        const {
          path_collection
        } = item;
        const shouldInclude = this.id === DEFAULT_ROOT || !!path_collection && path_collection.entries.findIndex(crumb => crumb.id === this.id) !== -1;

        if (shouldInclude) {
          items.push(_extends(item, {
            interacted_at
          }));
        }
      });
      const flattenedItems = flatten(items, new FolderAPI(this.options), new FileAPI(this.options), new WebLinkAPI(this.options));
      this.getCache().set(this.key, {
        item_collection: {
          entries: flattenedItems,
          order: [{
            by,
            direction
          }]
        }
      });
      this.finish();
    });

    _defineProperty(this, "recentsErrorHandler", error => {
      if (this.isDestroyed()) {
        return;
      }

      this.errorCallback(error, this.errorCode);
    });
  }

  /**
   * @property {string}
   */

  /**
   * @property {string}
   */

  /**
   * @property {Function}
   */

  /**
   * @property {Function}
   */

  /**
   * Creates a key for the cache
   *
   * @param {string} id folder id
   * @return {string} key
   */
  getCacheKey(id) {
    return "".concat(CACHE_PREFIX_RECENTS).concat(id);
  }
  /**
   * URL for recents api
   *
   * @return {string} base url for files
   */


  getUrl() {
    return "".concat(this.getBaseApiUrl(), "/recent_items");
  }
  /**
   * Returns the results
   *
   * @return {void}
   */


  finish() {
    if (this.isDestroyed()) {
      return;
    }

    const cache = this.getCache();
    const recents = cache.get(this.key);
    const {
      item_collection
    } = recents;

    if (!item_collection) {
      throw getBadItemError();
    }

    const {
      entries
    } = item_collection;

    if (!Array.isArray(entries)) {
      throw getBadItemError();
    }

    const collection = {
      id: this.id,
      items: entries.map(key => cache.get(key)),
      percentLoaded: 100,
      sortBy: FIELD_DATE,
      // Results are always sorted by date
      sortDirection: SORT_DESC // Results are always sorted descending

    };
    this.successCallback(collection);
  }
  /**
   * Handles the folder Recents response
   *
   * @param {Object} response
   * @return {void}
   */


  /**
   * Does the network request
   *
   * @param {RequestOptions} options - options for request
   * @return {Promise}
   */
  recentsRequest() {
    let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    if (this.isDestroyed()) {
      return Promise.reject();
    }

    const {
      fields
    } = options;
    const requestFields = fields || FOLDER_FIELDS_TO_FETCH;
    this.errorCode = ERROR_CODE_FETCH_RECENTS;
    return this.xhr.get({
      url: this.getUrl(),
      params: {
        fields: requestFields.toString()
      },
      headers: requestFields.includes(FIELD_REPRESENTATIONS) ? {
        'X-Rep-Hints': X_REP_HINT_HEADER_DIMENSIONS_DEFAULT
      } : {}
    }).then(this.recentsSuccessHandler).catch(this.recentsErrorHandler);
  }
  /**
   * Gets recent files
   *
   * @param {string} id - parent folder id
   * @param {Function} successCallback - Function to call with results
   * @param {Function} errorCallback - Function to call with errors
   * @param {boolean|void} [options.forceFetch] - Bypasses the cache
   * @return {void}
   */


  recents(id, successCallback, errorCallback) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

    if (this.isDestroyed()) {
      return;
    } // Save references


    this.id = id;
    this.successCallback = successCallback;
    this.errorCallback = errorCallback;
    const cache = this.getCache();
    this.key = this.getCacheKey(this.id); // Clear the cache if needed

    if (options.forceFetch) {
      cache.unset(this.key);
    } // Return the Cache value if it exists


    if (cache.has(this.key)) {
      this.finish();
      return;
    } // Make the XHR request


    this.recentsRequest(options);
  }

}

export default Recents;
//# sourceMappingURL=Recents.js.map