function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Folder upload bootstrapping
 * @author Box
 */
import { getEntryFromDataTransferItem, getFile, getFileAPIOptions, getDataTransferItem, getDataTransferItemAPIOptions } from '../../utils/uploads';
import FolderUploadNode from './FolderUploadNode';
const PATH_DELIMITER = '/';

class FolderUpload {
  /**
   * [constructor]
   *
   * @param {Function} addFilesToUploadQueue
   * @param {string} destinationFolderId
   * @param {Function} addFolderToUploadQueue
   * @param {Object} baseAPIOptions
   * @return {void}
   */
  constructor(addFilesToUploadQueue, destinationFolderId, addFolderToUploadQueue, baseAPIOptions) {
    _defineProperty(this, "files", []);

    this.addFilesToUploadQueue = addFilesToUploadQueue;
    this.destinationFolderId = destinationFolderId;
    this.addFolderToUploadQueue = addFolderToUploadQueue;
    this.baseAPIOptions = baseAPIOptions;
  }
  /**
   * Create a folder tree from fileList wekbkitRelativePath
   *
   * @public
   * @param  {Array} Array<UploadFileWithAPIOptions | UploadFile> | FileList
   * @returns {void}
   */


  buildFolderTreeFromWebkitRelativePath(fileList) {
    Array.from(fileList).forEach(fileData => {
      const file = getFile(fileData);
      const {
        webkitRelativePath
      } = file;

      if (!webkitRelativePath) {
        return;
      }

      const fileAPIOptions = getFileAPIOptions(fileData);
      const pathArray = webkitRelativePath.split(PATH_DELIMITER).slice(0, -1);

      if (pathArray.length <= 0) {
        return;
      } // Since only 1 folder tree can be uploaded a time with using webkitRelativePath, the root folder name
      // of all the files should be the same.


      if (!this.folder) {
        const rootFolderName = pathArray[0];
        this.folder = this.createFolderUploadNode(rootFolderName, fileAPIOptions);
      } // Add file to the root folder


      if (pathArray.length === 1) {
        this.folder.files.push(file);
      }

      let subTree = this.folder.folders; // Walk the path after the root folder

      const pathArryAfterRoot = pathArray.slice(1);
      pathArryAfterRoot.forEach((folderName, index) => {
        // Create new child folder
        if (!subTree[folderName]) {
          subTree[folderName] = this.createFolderUploadNode(folderName, fileAPIOptions);
        }

        if (index === pathArryAfterRoot.length - 1) {
          // end of path, push the file
          subTree[folderName].files.push(file);
        } else {
          // walk the tree
          subTree = subTree[folderName].folders;
        }
      });
    });
  }
  /**
   * Build folder tree from dataTransferItem, which can only represent 1 folder tree
   *
   * @param {DataTransferItem | UploadDataTransferItemWithAPIOptions} dataTransferItem
   * @returns {Promise<any>}
   */


  async buildFolderTreeFromDataTransferItem(dataTransferItem) {
    const item = getDataTransferItem(dataTransferItem);
    const apiOptions = getDataTransferItemAPIOptions(dataTransferItem);
    const entry = getEntryFromDataTransferItem(item);
    const {
      name
    } = entry;
    this.folder = this.createFolderUploadNode(name, apiOptions, entry);
  }
  /**
   * Create a FolderUploadNode instance
   *
   * @param {string} name
   * @param {Object} apiOptions
   * @param {FileSystemFileEntry} [entry]
   * @returns {FolderUploadNode}
   */


  createFolderUploadNode(name, apiOptions, entry) {
    return new FolderUploadNode(name, this.addFilesToUploadQueue, this.addFolderToUploadQueue, apiOptions, _objectSpread({}, this.baseAPIOptions, {}, apiOptions), entry);
  }
  /**
   * Upload folders
   *
   * @public
   * @param {Object} Options
   * @param {Function} options.errorCallback
   * @returns {Promise<any>}
   */


  async upload(_ref) {
    let {
      errorCallback,
      successCallback
    } = _ref;
    await this.folder.upload(this.destinationFolderId, errorCallback, true); // If the folder upload failed then a folderID will not be set

    const newFolderId = this.folder.getFolderId();

    if (newFolderId) {
      successCallback([{
        id: newFolderId
      }]);
    }
  }
  /**
   * Noop cancel
   *
   * @public
   */


  cancel() {}

}

export default FolderUpload;
//# sourceMappingURL=FolderUpload.js.map