function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Recursively create folder and upload files
 * @author Box
 */
import noop from 'lodash/noop';
import { getFileFromEntry } from '../../utils/uploads';
import FolderAPI from '../Folder';
import { STATUS_COMPLETE, STATUS_ERROR, ERROR_CODE_UPLOAD_CHILD_FOLDER_FAILED, ERROR_CODE_ITEM_NAME_IN_USE } from '../../constants';

class FolderUploadNode {
  /**
   * [constructor]
   *
   * @param {string} name
   * @param {Function} addFilesToUploadQueue
   * @param {Function} addFolderToUploadQueue
   * @returns {void}
   */
  constructor(_name, addFilesToUploadQueue, addFolderToUploadQueue, fileAPIOptions, baseAPIOptions, _entry) {
    _defineProperty(this, "files", []);

    _defineProperty(this, "folders", {});

    _defineProperty(this, "uploadChildFolders", async errorCallback => {
      // $FlowFixMe
      const folders = Object.values(this.folders);
      const promises = folders.map(folder => folder.upload(this.folderId, errorCallback));
      await Promise.all(promises);
    });

    _defineProperty(this, "createAndUploadFolder", async (errorCallback, isRoot) => {
      await this.buildCurrentFolderFromEntry();
      let errorEncountered = false;
      let errorCode = '';

      try {
        const data = await this.createFolder();
        this.folderId = data.id;
      } catch (error) {
        // @TODO: Handle 429
        if (error.code === ERROR_CODE_ITEM_NAME_IN_USE) {
          this.folderId = error.context_info.conflicts[0].id;
        } else if (isRoot) {
          errorCallback(error);
        } else {
          // If this is a child folder of the folder being uploaded, this errorCallback will set
          // an error message on the root folder being uploaded. Set a generic messages saying that a
          // child has caused the error. The child folder will be tagged with the error message in
          // the call to this.addFolderToUploadQueue below
          errorEncountered = true;
          errorCode = error.code;
          errorCallback({
            code: ERROR_CODE_UPLOAD_CHILD_FOLDER_FAILED
          });
        }
      } // The root folder has already been added to the upload queue in ContentUploader


      if (isRoot) {
        return;
      }

      const folderObject = {
        extension: '',
        name: this.name,
        status: STATUS_COMPLETE,
        isFolder: true,
        size: 1,
        progress: 100
      };

      if (errorEncountered) {
        folderObject.status = STATUS_ERROR;
        folderObject.error = {
          code: errorCode
        };
      }

      this.addFolderToUploadQueue(folderObject);
    });

    _defineProperty(this, "getFormattedFiles", () => this.files.map(file => ({
      file,
      options: _objectSpread({}, this.fileAPIOptions, {
        folderId: this.folderId,
        uploadInitTimestamp: Date.now()
      })
    })));

    _defineProperty(this, "createFolderUploadNodesFromEntries", async entries => {
      await Promise.all(entries.map(async entry => {
        const {
          isFile,
          name
        } = entry;

        if (isFile) {
          const file = await getFileFromEntry(entry);
          this.files.push(file);
          return;
        }

        this.folders[name] = new FolderUploadNode(name, this.addFilesToUploadQueue, this.addFolderToUploadQueue, this.fileAPIOptions, _objectSpread({}, this.baseAPIOptions, {}, this.fileAPIOptions), entry);
      }));
    });

    _defineProperty(this, "readEntry", (reader, resolve) => {
      reader.readEntries(async entries => {
        // Quit recursing when there are no remaining entries.
        if (!entries.length) {
          resolve();
          return;
        }

        await this.createFolderUploadNodesFromEntries(entries);
        this.readEntry(reader, resolve);
      }, noop);
    });

    _defineProperty(this, "buildCurrentFolderFromEntry", () => {
      if (!this.entry) {
        return Promise.resolve();
      }

      return new Promise(resolve => {
        // $FlowFixMe entry is not empty
        const reader = this.entry.createReader();
        this.readEntry(reader, resolve);
      });
    });

    _defineProperty(this, "getFolderId", () => {
      return this.folderId;
    });

    this.name = _name;
    this.addFilesToUploadQueue = addFilesToUploadQueue;
    this.addFolderToUploadQueue = addFolderToUploadQueue;
    this.fileAPIOptions = fileAPIOptions;
    this.baseAPIOptions = baseAPIOptions;
    this.entry = _entry;
  }
  /**
   * Upload a folder
   *
   * @public
   * @param {string} parentFolderId
   * @param {Function} errorCallback
   * @param {boolean} isRoot
   * @returns {Promise}
   */


  async upload(parentFolderId, errorCallback) {
    let isRoot = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    this.parentFolderId = parentFolderId;
    await this.createAndUploadFolder(errorCallback, isRoot); // Check if folder was successfully created before we attempt to upload its contents.

    if (this.getFolderId()) {
      this.addFilesToUploadQueue(this.getFormattedFiles(), noop, true);
      await this.uploadChildFolders(errorCallback);
    }
  }
  /**
   * Upload all child folders
   *
   * @private
   * @param {Function} errorCallback
   * @returns {Promise}
   */


  /**
   * Promisify create folder
   *
   * @private
   * @returns {Promise}
   */
  createFolder() {
    const folderAPI = new FolderAPI(_objectSpread({}, this.baseAPIOptions, {
      id: "folder_".concat(this.parentFolderId)
    }));
    return new Promise((resolve, reject) => {
      folderAPI.create(this.parentFolderId, this.name, resolve, reject);
    });
  }
  /**
   * Create FolderUploadNode instances from entries
   *
   * @private
   * @param {Array<FileSystemFileEntry>} entries
   * @returns {Promise<any>}
   */


}

export default FolderUploadNode;
//# sourceMappingURL=FolderUploadNode.js.map