import * as React from 'react';
import { injectIntl } from 'react-intl';
import classNames from 'classnames';
import { MenuLinkItem } from '../menu';
import EllipsisCrumb from './EllipsisCrumb';
import Crumb from './Crumb';
import messages from './messages';
import './Breadcrumb.scss';

const Breadcrumb = (_ref) => {
  let {
    children,
    className = '',
    hasReverseOverflowOrder = false,
    intl,
    numItemsBeforeOverflow = 1,
    overflowMenuButton,
    threshold = 4
  } = _ref;
  const breadcrumbs = React.Children.toArray(children);

  const constructChildren = () => {
    const overflowItems = breadcrumbs.slice(numItemsBeforeOverflow, breadcrumbs.length + 1 - threshold);
    const dotDotDotItems = hasReverseOverflowOrder ? overflowItems : overflowItems.reverse();
    const menuCrumbsItems = React.createElement(EllipsisCrumb, {
      menuButton: overflowMenuButton
    }, dotDotDotItems.map((crumb, index) => React.createElement(MenuLinkItem, {
      key: index
    }, crumb)));
    return [...breadcrumbs.slice(0, numItemsBeforeOverflow), menuCrumbsItems, ...breadcrumbs.slice(1 - threshold)];
  };

  const renderBreadcrumbs = () => {
    let newChildren = breadcrumbs;
    let {
      length
    } = breadcrumbs;
    let hasEllipsis = false;

    if (length > threshold) {
      newChildren = constructChildren();
      length = newChildren.length;
      hasEllipsis = true;
    }

    return React.Children.map(newChildren, (item, i) => {
      const isLastCrumb = length === 0 || i === length - 1;
      return React.createElement(Crumb, {
        className: classNames({
          'no-shrink': hasEllipsis && i === numItemsBeforeOverflow
        }),
        isLastCrumb: isLastCrumb
      }, item);
    });
  };

  return React.createElement("nav", {
    "aria-label": intl.formatMessage(messages.breadcrumbLabel),
    className: classNames('breadcrumbs', className)
  }, React.createElement("ol", null, renderBreadcrumbs()));
};

export { Breadcrumb as BreadcrumbBase };
export default injectIntl(Breadcrumb);
//# sourceMappingURL=Breadcrumb.js.map