function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import LoadingIndicator from '../loading-indicator';
import RadarAnimation from '../radar';
export let ButtonType;

(function (ButtonType) {
  ButtonType["BUTTON"] = "button";
  ButtonType["RESET"] = "reset";
  ButtonType["SUBMIT"] = "submit";
})(ButtonType || (ButtonType = {}));

class Button extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "btnElement", null);

    _defineProperty(this, "handleClick", event => {
      const {
        isDisabled,
        onClick
      } = this.props;

      if (isDisabled || this.btnElement && this.btnElement.classList.contains('is-disabled')) {
        event.preventDefault();
        event.stopPropagation();
        return;
      }

      if (onClick) {
        onClick(event);
      }
    });
  }

  render() {
    const _this$props = this.props,
          {
      children,
      className,
      icon,
      isDisabled,
      isLoading,
      isSelected,
      setRef,
      size,
      type,
      showRadar
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["children", "className", "icon", "isDisabled", "isLoading", "isSelected", "setRef", "size", "type", "showRadar"]);

    const buttonProps = omit(rest, ['onClick']);

    if (isDisabled) {
      buttonProps['aria-disabled'] = true;
    }

    const styleClassName = classNames('btn', {
      'is-disabled': isDisabled,
      'is-loading': isLoading,
      'is-selected': isSelected,
      'bdl-is-disabled': isDisabled,
      'bdl-btn--large': size === 'large',
      'bdl-has-icon': !!icon
    }, className);
    let button = // eslint-disable-next-line react/button-has-type
    React.createElement("button", _extends({
      ref: element => {
        this.btnElement = element;

        if (setRef) {
          setRef(element);
        }
      },
      className: styleClassName,
      onClick: this.handleClick,
      type: type
    }, buttonProps), children ? React.createElement("span", {
      className: "btn-content"
    }, children) : null, icon ? React.createElement("span", {
      className: "bdl-btn-icon"
    }, React.cloneElement(icon, {
      width: icon && children ? 16 : 20,
      height: icon && children ? 16 : 20
    })) : null, isLoading && React.createElement(LoadingIndicator, {
      className: "btn-loading-indicator"
    }));

    if (showRadar) {
      button = React.createElement(RadarAnimation, null, button);
    }

    return button;
  }

}

_defineProperty(Button, "defaultProps", {
  className: '',
  isLoading: false,
  showRadar: false,
  type: ButtonType.SUBMIT
});

export default Button;
//# sourceMappingURL=Button.js.map