function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import Measure from 'react-measure';
import forEach from 'lodash/forEach';
import CategorySelectorComponent from './CategorySelectorComponent';
import './CategorySelector.scss';

const CategorySelector = (_ref) => {
  let {
    categories,
    categoryProps = {},
    className = '',
    currentCategory = '',
    onSelect
  } = _ref;
  const linksRef = React.useRef(null);
  const moreRef = React.useRef(null);
  const [maxLinks, setMaxLinks] = React.useState(categories.length);
  const defaultLinkWidths = {};
  const [linkWidths, setLinkWidths] = React.useState(defaultLinkWidths);
  const [moreWidth, setMoreWidth] = React.useState(0);

  const outerWidth = element => {
    const style = getComputedStyle(element);
    return element.offsetWidth + parseFloat(style.marginLeft) + parseFloat(style.marginRight) + 1;
  };

  const checkLinks = React.useCallback(contentRect => {
    const {
      width
    } = contentRect.client;
    if (!linksRef.current) return; // Pull in some common widths we'll need

    const containerWidth = width - moreWidth; // Get all the links

    const elements = linksRef.current.querySelectorAll('[data-category]'); // First, calculate the total width of all links in the main section

    let linksWidth = 0;
    forEach(elements, element => {
      linksWidth += outerWidth(element);
    });

    if (linksWidth > containerWidth) {
      // The links exceed the container's width. Figure out how many need to be removed
      const linksToRemove = {};
      let counter = 1;

      while (linksWidth > containerWidth && counter < elements.length) {
        var _element$dataset$cate;

        const element = elements[elements.length - counter];
        const elementWidth = outerWidth(element);
        linksWidth -= elementWidth;
        const category = (_element$dataset$cate = element.dataset.category) !== null && _element$dataset$cate !== void 0 ? _element$dataset$cate : ''; // Save the width of the link being removed for use later

        linksToRemove[category] = elementWidth;
        counter += 1;
      } // Ensure the maxLinks does not become negative


      const max = maxLinks - Object.keys(linksToRemove).length < 0 ? 0 : maxLinks - Object.keys(linksToRemove).length; // Update the state

      setMaxLinks(max);
      setLinkWidths(_objectSpread({}, linkWidths, {}, linksToRemove));
    } else {
      // There is more room, see if any links can be brought back in
      let linksToAdd = 0;

      while (maxLinks + linksToAdd < categories.length && linksWidth < containerWidth) {
        const category = categories[maxLinks + linksToAdd].value;
        const elementWidth = linkWidths[category]; // If there is only one link in the More menu, calculate against the total container width,
        // otherwise calculate against the container less the width of the more button

        const targetWidth = maxLinks + linksToAdd + 1 >= categories.length ? width : containerWidth; // If the addition of a link is too large, stop checking

        if (linksWidth + elementWidth >= targetWidth) {
          break;
        }

        linksToAdd += 1;
        linksWidth += elementWidth; // always add
      }

      if (linksToAdd > 0) {
        // Update the state
        setMaxLinks(maxLinks + linksToAdd);
      }
    }
  }, [categories, linkWidths, linksRef, maxLinks, moreWidth]);
  React.useLayoutEffect(() => {
    if (!moreRef.current) return;
    setMoreWidth(outerWidth(moreRef.current)); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [moreRef.current, currentCategory]); // This effect must be defined after the checkLinks function
  // If the currently selected category changes or the more link width changes, be sure to check for any links to hide or show

  React.useEffect(() => {
    if (!linksRef.current) return;
    const {
      clientWidth
    } = linksRef.current;
    checkLinks({
      client: {
        width: clientWidth
      }
    }); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [moreRef.current, moreWidth, currentCategory]);
  return React.createElement(Measure, {
    client: true,
    innerRef: linksRef,
    onResize: checkLinks
  }, (_ref2) => {
    let {
      measureRef
    } = _ref2;
    return React.createElement(CategorySelectorComponent, {
      measureRef: measureRef,
      moreRef: moreRef,
      className: className,
      categories: categories,
      maxLinks: maxLinks,
      currentCategory: currentCategory,
      onSelect: onSelect,
      categoryProps: categoryProps
    });
  });
};

export default CategorySelector;
//# sourceMappingURL=CategorySelector.js.map