function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import AnimateHeight from 'react-animate-height'; // @ts-ignore flow import

import { RESIN_TAG_TARGET } from '../../common/variables';
import IconCaretDown from '../../icons/general/IconCaretDown';
import PlainButton from '../plain-button';
import { ButtonType } from '../button';
import { bdlGray50 } from '../../styles/variables';
import './Collapsible.scss';

class Collapsible extends React.PureComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "toggleVisibility", () => {
      const {
        onOpen,
        onClose
      } = this.props;
      this.setState(prevState => ({
        isOpen: !prevState.isOpen
      }), () => {
        const {
          isOpen
        } = this.state;

        if (isOpen && onOpen) {
          onOpen(this);
        } else if (!isOpen && onClose) {
          onClose(this);
        }
      });
    });

    this.state = {
      isOpen: props.isOpen
    };
  }

  render() {
    const {
      isOpen
    } = this.state;
    const {
      animationDuration,
      buttonProps = {},
      children,
      className,
      isBordered,
      hasStickyHeader,
      headerActionItems,
      title
    } = this.props;
    const sectionClassName = classNames('collapsible-card', {
      'is-open': isOpen
    }, {
      'is-bordered': isBordered
    }, className);
    const resinTagTarget = RESIN_TAG_TARGET;
    const modifiedButtonProps = omit(buttonProps, [resinTagTarget]);
    const interactionTarget = buttonProps[resinTagTarget];
    const buttonClassName = hasStickyHeader ? 'collapsible-card-header has-sticky-header' : 'collapsible-card-header';

    if (interactionTarget) {
      modifiedButtonProps[resinTagTarget] = "".concat(interactionTarget).concat(isOpen ? 'collapse' : 'expand');
    }

    return React.createElement("div", {
      className: sectionClassName
    }, React.createElement("div", {
      className: buttonClassName
    }, React.createElement(PlainButton, _extends({}, modifiedButtonProps, {
      "aria-expanded": isOpen,
      className: "collapsible-card-title",
      onClick: this.toggleVisibility,
      type: ButtonType.BUTTON
    }), title, React.createElement(IconCaretDown, {
      className: "collapsible-card-header-caret",
      color: bdlGray50,
      width: 8
    })), !!headerActionItems && React.createElement("span", {
      className: "bdl-Collapsible-actionItems"
    }, headerActionItems)), React.createElement(AnimateHeight, {
      duration: animationDuration,
      height: isOpen ? 'auto' : 0
    }, React.createElement("div", {
      className: "collapsible-card-content"
    }, children)));
  }

}

_defineProperty(Collapsible, "defaultProps", {
  buttonProps: {},
  className: '',
  isOpen: true,
  animationDuration: 100
});

export default Collapsible;
//# sourceMappingURL=Collapsible.js.map