function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { defineMessages, injectIntl, FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import noop from 'lodash/noop';
import range from 'lodash/range';
import uniqueId from 'lodash/uniqueId'; // @ts-ignore flow import

import { RESIN_TAG_TARGET } from '../../common/variables';
import AlertBadge16 from '../../icon/fill/AlertBadge16';
import Calendar16 from '../../icon/fill/Calendar16';
import ClearBadge16 from '../../icon/fill/ClearBadge16';
import AccessiblePikaday from './AccessiblePikaday';
import { ButtonType } from '../button';
import Label from '../label';
import PlainButton from '../plain-button';
import Tooltip, { TooltipPosition, TooltipTheme } from '../tooltip'; // @ts-ignore flow import

import { convertDateToUnixMidnightTime } from '../../utils/datetime';
import './DatePicker.scss';
const messages = defineMessages({
  previousMonth: {
    "id": "boxui.base.previousMonth",
    "defaultMessage": "Previous Month"
  },
  nextMonth: {
    "id": "boxui.base.nextMonth",
    "defaultMessage": "Next Month"
  },
  iconAlertText: {
    "id": "boxui.datePicker.iconAlertText",
    "defaultMessage": "Invalid Date"
  },
  dateClearButton: {
    "id": "boxui.datePicker.dateClearButton",
    "defaultMessage": "Clear Date"
  },
  chooseDate: {
    "id": "boxui.datePicker.chooseDate",
    "defaultMessage": "Choose Date"
  },
  dateInputRangeError: {
    "id": "boxui.datePicker.dateInputRangeError",
    "defaultMessage": "Please enter a date between {minLocaleDate} and {maxLocaleDate}"
  },
  dateInputMaxError: {
    "id": "boxui.datePicker.dateInputMaxError",
    "defaultMessage": "Please enter a date before {maxLocaleDate}"
  },
  dateInputMinError: {
    "id": "boxui.datePicker.dateInputMinError",
    "defaultMessage": "Please enter a date after {minLocaleDate}"
  }
});
const TOGGLE_DELAY_MS = 300;
const ENTER_KEY = 'Enter';
const ESCAPE_KEY = 'Escape';
const TAB_KEY = 'Tab';
const ISO_DATE_FORMAT_PATTERN = /^\d{4}-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])$/;
export let DateFormat;
/**
 * Converts date from being relative to GMT, to being relative to browser
 * timezone. E.g., Thu Jun 29 2017 00:00:00 GMT =>
 * Thu Jun 29 2017 00:00:00 GMT-0700 (PDT)
 * @param {Date} date UTC date
 * @returns {Date} date Local date
 */

(function (DateFormat) {
  DateFormat["ISO_STRING_DATE_FORMAT"] = "isoString";
  DateFormat["LOCALE_DATE_STRING_DATE_FORMAT"] = "localeDateString";
  DateFormat["UTC_TIME_DATE_FORMAT"] = "utcTime";
  DateFormat["UNIX_TIME_DATE_FORMAT"] = "unixTime";
  DateFormat["UTC_ISO_STRING_DATE_FORMAT"] = "utcISOString";
})(DateFormat || (DateFormat = {}));

function convertUTCToLocal(date) {
  const dateString = date.toUTCString(); // Remove ` GMT` from the timestamp string

  const dateStringWithoutTimeZone = dateString.slice(0, -4);
  return new Date(dateStringWithoutTimeZone);
}

function getFormattedDate(date, format) {
  if (!date) {
    return '';
  }

  let utcDate;

  switch (format) {
    case DateFormat.ISO_STRING_DATE_FORMAT:
      return date.toISOString();

    case DateFormat.LOCALE_DATE_STRING_DATE_FORMAT:
      return date.toLocaleDateString();

    case DateFormat.UTC_TIME_DATE_FORMAT:
      return convertDateToUnixMidnightTime(date);

    case DateFormat.UTC_ISO_STRING_DATE_FORMAT:
      utcDate = new Date(convertDateToUnixMidnightTime(date));
      return utcDate.toISOString();

    default:
      return date.getTime();
  }
}

const localesWhereWeekStartsOnSunday = ['en-US', 'en-CA', 'jp-JP'];

class DatePicker extends React.Component {
  constructor() {
    var _this;

    super(...arguments);
    _this = this;

    _defineProperty(this, "state", {
      isDateInputInvalid: false,
      showDateInputError: false
    });

    _defineProperty(this, "errorMessageID", uniqueId('errorMessage'));

    _defineProperty(this, "descriptionID", uniqueId('description'));

    _defineProperty(this, "onSelectHandler", function () {
      let date = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      const {
        onChange,
        isAccessible
      } = _this.props;
      const {
        isDateInputInvalid
      } = _this.state;

      if (onChange) {
        const formattedDate = _this.formatValue(date);

        onChange(date, formattedDate);
      }

      if (isAccessible) {
        if (_this.dateInputEl && _this.datePicker) {
          // Required because Pikaday instance is unbound
          // See https://github.com/Pikaday/Pikaday#usage
          _this.dateInputEl.value = _this.datePicker.toString();
        }

        if (_this.datePicker && _this.datePicker.isVisible()) {
          _this.datePicker.hide();

          _this.focusDatePicker();
        }
      }

      if (isDateInputInvalid) {
        _this.setState({
          isDateInputInvalid: false,
          showDateInputError: false
        });
      }
    });

    _defineProperty(this, "datePicker", null);

    _defineProperty(this, "canUseDateInputType", true);

    _defineProperty(this, "shouldStayClosed", false);

    _defineProperty(this, "focusDatePicker", () => {
      // This also opens the date picker when isAccessible is disabled
      if (this.dateInputEl) {
        this.dateInputEl.focus();
      }
    });

    _defineProperty(this, "getDateInputError", () => {
      const {
        intl,
        maxDate = null,
        minDate = null
      } = this.props;
      const {
        showDateInputError
      } = this.state;
      const {
        formatMessage
      } = intl;
      if (!showDateInputError) return '';
      let dateInputError = '';
      const maxLocaleDate = getFormattedDate(maxDate, DateFormat.LOCALE_DATE_STRING_DATE_FORMAT);
      const minLocaleDate = getFormattedDate(minDate, DateFormat.LOCALE_DATE_STRING_DATE_FORMAT);

      if (maxLocaleDate && minLocaleDate) {
        dateInputError = formatMessage(messages.dateInputRangeError, {
          maxLocaleDate,
          minLocaleDate
        });
      } else if (maxLocaleDate) {
        dateInputError = formatMessage(messages.dateInputMaxError, {
          maxLocaleDate
        });
      } else if (minLocaleDate) {
        dateInputError = formatMessage(messages.dateInputMinError, {
          minLocaleDate
        });
      }

      return dateInputError;
    });

    _defineProperty(this, "handleInputKeyDown", event => {
      const {
        isKeyboardInputAllowed,
        isTextInputAllowed,
        isAccessible
      } = this.props;

      if (!isKeyboardInputAllowed && this.datePicker && this.datePicker.isVisible()) {
        event.stopPropagation();
      } // Stops up/down arrow & spacebar from moving page scroll position since pikaday does not preventDefault correctly


      if (!(isTextInputAllowed || isAccessible) && event.key !== TAB_KEY) {
        event.preventDefault();
      }

      if ((isTextInputAllowed || isAccessible && !this.canUseDateInputType) && event.key === ENTER_KEY) {
        event.preventDefault();
      } // Stops enter & spacebar from opening up the browser's default date picker


      if (isAccessible && (event.key === ENTER_KEY || event.key === ' ')) {
        event.preventDefault();
      }

      if (event.key === ENTER_KEY || event.key === ESCAPE_KEY || event.key === ' ') {
        // Since pikaday auto-selects when you move the select box, enter/space don't do anything but close the date picker
        if (this.datePicker && this.datePicker.isVisible()) {
          this.datePicker.hide();
        }
      }
    });

    _defineProperty(this, "handleOnChange", event => {
      const {
        isAccessible,
        maxDate,
        minDate,
        onChange
      } = this.props;
      const {
        isDateInputInvalid
      } = this.state;

      if (!isAccessible || !this.canUseDateInputType) {
        return;
      }

      if (this.datePicker && this.datePicker.isVisible()) {
        event.stopPropagation();
      }

      const {
        value
      } = event.target;

      if (this.datePicker && value) {
        const parsedDate = this.parseDisplayDateType(value);

        if (parsedDate) {
          if (minDate && parsedDate < minDate || maxDate && parsedDate > maxDate) {
            this.datePicker.setDate(null);
            this.setState({
              isDateInputInvalid: true
            });
            return;
          } // Reset the error styling on valid date input


          if (isDateInputInvalid) {
            this.setState({
              isDateInputInvalid: false,
              showDateInputError: false
            });
          }
        } else {
          this.setState({
            isDateInputInvalid: true
          });
        } // Set date so Pikaday date picker value stays in sync with input


        this.datePicker.setDate(parsedDate, true);

        if (onChange) {
          const formattedDate = this.formatValue(parsedDate);
          onChange(parsedDate, formattedDate);
        }
      } else if (isDateInputInvalid) {
        this.setState({
          isDateInputInvalid: false,
          showDateInputError: false
        });
      }
    });

    _defineProperty(this, "handleInputBlur", event => {
      const {
        isAccessible,
        isTextInputAllowed,
        onBlur
      } = this.props;
      const {
        isDateInputInvalid
      } = this.state;
      const nextActiveElement = event.relatedTarget || document.activeElement; // This is mostly here to cancel out the pikaday hide() on blur

      if (this.datePicker && this.datePicker.isVisible() && nextActiveElement && nextActiveElement === this.datePickerButtonEl) {
        this.shouldStayClosed = true;
        setTimeout(() => {
          this.shouldStayClosed = false;
        }, TOGGLE_DELAY_MS);
      }

      if (onBlur) {
        onBlur(event);
      } // Since we fire parent onChange event if isTextInputAllowed,
      // fire it on blur if the user typed a correct date format


      let inputDate = null;

      if (this.dateInputEl) {
        let dateInputElVal = null;

        if (isAccessible && !this.canUseDateInputType) {
          dateInputElVal = this.parseDisplayDateType(this.dateInputEl.value);
        }

        inputDate = new Date(dateInputElVal || this.dateInputEl.value);
      }

      if ((isTextInputAllowed || isAccessible && !this.canUseDateInputType) && inputDate && inputDate.getDate()) {
        this.onSelectHandler(inputDate);
      }

      if (isAccessible && isDateInputInvalid) this.setState({
        showDateInputError: true
      });
    });

    _defineProperty(this, "handleButtonClick", event => {
      event.preventDefault();
      event.stopPropagation();
      const {
        isAccessible,
        isDisabled
      } = this.props;

      if (isAccessible) {
        if (isDisabled || !this.datePicker) {
          return;
        }

        if (this.datePicker.isVisible()) {
          this.datePicker.hide();
          this.focusDatePicker();
        } else {
          this.datePicker.show();
        }

        return;
      }

      if (!this.shouldStayClosed) {
        this.focusDatePicker();
      }
    });

    _defineProperty(this, "handleOnClick", event => {
      const {
        isAccessible
      } = this.props;

      if (isAccessible) {
        // Suppress Firefox default behavior: clicking on input type "date"
        // opens the browser date picker.
        event.preventDefault();
        event.stopPropagation();
      }
    });

    _defineProperty(this, "formatDisplay", date => {
      const {
        displayFormat,
        intl
      } = this.props;
      return date ? intl.formatDate(date, displayFormat) : '';
    });

    _defineProperty(this, "formatDisplayDateType", date => {
      // Input type "date" only accepts the format YYYY-MM-DD
      return date ? getFormattedDate(date, DateFormat.UTC_ISO_STRING_DATE_FORMAT).slice(0, 10) : '';
    });

    _defineProperty(this, "parseDisplayDateType", dateString => {
      if (dateString && ISO_DATE_FORMAT_PATTERN.test(dateString)) {
        // Calling new Date('YYYY-MM-DD') without 'T00:00:00' yields undesired results:
        // E.g. new Date('2017-06-01') => May 31 2017
        // E.g. new Date('2017-06-01T00:00:00') => June 01 2017
        // See https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/Date#parameters
        return new Date("".concat(dateString, "T00:00:00"));
      }

      return null;
    });

    _defineProperty(this, "formatValue", date => {
      const {
        dateFormat
      } = this.props;
      return dateFormat ? getFormattedDate(date, dateFormat) : '';
    });

    _defineProperty(this, "clearDate", event => {
      // Prevents the date picker from opening after clearing
      event.preventDefault();
      const {
        isAccessible
      } = this.props;

      if (this.datePicker) {
        this.datePicker.setDate(null);
      }

      this.onSelectHandler(null);

      if (isAccessible) {
        this.focusDatePicker();
      }
    });

    _defineProperty(this, "shouldUseAccessibleFallback", () => {
      const test = document.createElement('input');

      try {
        test.type = 'date';
      } catch (e) {} // no-op
      // If date input falls back to text input, show the fallback


      return test.type === 'text';
    });

    _defineProperty(this, "renderCalendarButton", () => {
      const {
        intl,
        isAccessible,
        isAlwaysVisible,
        isDisabled
      } = this.props;
      const {
        formatMessage
      } = intl;

      if (isAlwaysVisible) {
        return null;
      } // De-emphasizing the Pikaday date picker because it does not meet accessibility standards
      // Screenreaders & navigating via keyboard will no longer pick up on this element


      const accessibleAttrs = isAccessible ? {
        'aria-hidden': true,
        tabIndex: -1
      } : {};
      return React.createElement(PlainButton, _extends({
        "aria-label": formatMessage(messages.chooseDate),
        className: "date-picker-open-btn",
        getDOMRef: ref => {
          this.datePickerButtonEl = ref;
        },
        isDisabled: isDisabled,
        onClick: this.handleButtonClick,
        type: ButtonType.BUTTON
      }, accessibleAttrs), React.createElement(Calendar16, null));
    });
  }

  componentDidMount() {
    const {
      customInput,
      dateFormat,
      displayFormat,
      intl,
      isAccessible,
      isAlwaysVisible,
      isTextInputAllowed,
      maxDate,
      minDate,
      onChange,
      value,
      yearRange
    } = this.props;
    const {
      formatDate,
      formatMessage
    } = intl;
    const {
      nextMonth,
      previousMonth
    } = messages;
    let defaultValue = value;

    if (isAccessible && this.shouldUseAccessibleFallback()) {
      this.canUseDateInputType = false;
    } // When date format is utcTime, initial date needs to be converted from being relative to GMT to being
    // relative to browser timezone


    if (dateFormat === DateFormat.UTC_TIME_DATE_FORMAT && value) {
      defaultValue = convertUTCToLocal(value);

      if (onChange) {
        const formattedDate = this.formatValue(defaultValue);
        onChange(defaultValue, formattedDate);
      }
    } // Make sure the DST detection algorithm in browsers is up-to-date


    const year = new Date().getFullYear();
    const {
      timeZone
    } = displayFormat || {};
    const i18n = {
      previousMonth: formatMessage(previousMonth),
      nextMonth: formatMessage(nextMonth),
      months: range(12).map(month => formatDate(new Date(year, month, 15), {
        month: 'long',
        timeZone
      })),
      // weekdays must start with Sunday, so array of dates below is May 1st-8th, 2016
      weekdays: range(1, 8).map(date => formatDate(new Date(2016, 4, date), {
        weekday: 'long',
        timeZone
      })),
      weekdaysShort: range(1, 8).map(date => formatDate(new Date(2016, 4, date), {
        weekday: 'narrow',
        timeZone
      }))
    }; // If "bound" is true (default), the DatePicker will be appended at the end of the document, with absolute positioning
    // If "bound" is false, the DatePicker will be appended to the DOM right after the input, with relative positioning

    const datePickerConfig = {
      bound: !customInput,
      blurFieldOnSelect: false,
      // Available in pikaday > 1.5.1
      setDefaultDate: true,
      defaultDate: defaultValue === null ? undefined : defaultValue,
      field: this.dateInputEl,
      firstDay: localesWhereWeekStartsOnSunday.includes(intl.locale) ? 0 : 1,
      maxDate,
      minDate,
      position: 'bottom left',
      i18n,
      showDaysInNextAndPreviousMonths: true,
      onSelect: this.onSelectHandler,
      yearRange,
      toString: this.formatDisplay
    };

    if (isAccessible) {
      if (this.canUseDateInputType) {
        delete datePickerConfig.field;
        datePickerConfig.trigger = this.dateInputEl;
        datePickerConfig.accessibleFieldEl = this.dateInputEl;
        datePickerConfig.datePickerButtonEl = this.datePickerButtonEl;
      }

      datePickerConfig.parse = this.parseDisplayDateType;
      datePickerConfig.toString = this.formatDisplayDateType;
      datePickerConfig.keyboardInput = false;
    }

    this.datePicker = new AccessiblePikaday(datePickerConfig);

    if (isTextInputAllowed) {
      this.updateDateInputValue(this.formatDisplay(defaultValue));
    }

    if (isAlwaysVisible) {
      this.datePicker.show();
      this.datePicker.hide = noop;
    }
  } // eslint-disable-next-line camelcase


  UNSAFE_componentWillReceiveProps(nextProps) {
    if (!this.datePicker) return;
    const {
      value: nextValue = null,
      minDate: nextMinDate = null,
      maxDate: nextMaxDate = null
    } = nextProps;
    const {
      value,
      minDate,
      maxDate,
      isTextInputAllowed
    } = this.props;
    const selectedDate = this.datePicker && this.datePicker.getDate(); // only set date when props change

    if (nextValue && !value || !nextValue && value || nextValue && value && nextValue.getTime() !== value.getTime()) {
      this.datePicker.setDate(nextValue);
    } // If text input is allowed the dateInputEl will act as an uncontrolled input and
    // we need to set formatted value manually.


    if (isTextInputAllowed) {
      this.updateDateInputValue(this.formatDisplay(nextValue));
    }

    if (nextMinDate && !minDate || nextMinDate && minDate || nextMinDate && minDate && nextMinDate.getTime() !== minDate.getTime()) {
      this.datePicker.setMinDate(nextMinDate);

      if (selectedDate && selectedDate < nextMinDate) {
        this.datePicker.gotoDate(nextMinDate);
      }
    }

    if (nextMaxDate && !maxDate || !nextMaxDate && maxDate || nextMaxDate && maxDate && nextMaxDate.getTime() !== maxDate.getTime()) {
      this.datePicker.setMaxDate(nextMaxDate);

      if (selectedDate && nextMaxDate && selectedDate > nextMaxDate) {
        this.datePicker.gotoDate(nextMaxDate);
      }
    }
  }

  componentWillUnmount() {
    if (this.datePicker) {
      this.datePicker.destroy();
    }
  }

  updateDateInputValue(value) {
    if (this.dateInputEl) {
      this.dateInputEl.value = value;
    }
  }

  render() {
    const {
      className,
      customInput,
      description,
      error,
      errorTooltipPosition,
      hideLabel,
      hideOptionalLabel,
      inputProps,
      intl,
      isAccessible,
      isClearable,
      isDisabled,
      isRequired,
      isTextInputAllowed,
      label,
      maxDate,
      minDate,
      name,
      onFocus,
      placeholder,
      resinTarget,
      value
    } = this.props;
    const {
      isDateInputInvalid
    } = this.state;
    const {
      formatMessage
    } = intl;
    const errorMessage = error || this.getDateInputError();
    const hasError = !!errorMessage || isDateInputInvalid;
    const hasValue = !!value || isDateInputInvalid;
    const classes = classNames(className, 'date-picker-wrapper', {
      'show-clear-btn': isClearable && hasValue && !isDisabled,
      'show-error': hasError
    });
    const ariaAttrs = {
      'aria-invalid': hasError,
      'aria-required': isRequired,
      'aria-errormessage': this.errorMessageID,
      'aria-describedby': description ? this.descriptionID : undefined
    };
    const resinTargetAttr = resinTarget ? {
      [RESIN_TAG_TARGET]: resinTarget
    } : {};
    let valueAttr;

    if (isAccessible) {
      valueAttr = {
        defaultValue: this.formatDisplayDateType(value)
      };
    } else if (isTextInputAllowed) {
      valueAttr = {
        defaultValue: this.formatDisplay(value)
      };
    } else {
      valueAttr = {
        value: this.formatDisplay(value)
      };
    }

    let onChangeAttr;

    if (isAccessible && this.canUseDateInputType) {
      onChangeAttr = {
        onChange: this.handleOnChange
      };
    } else if (isTextInputAllowed || isAccessible && !this.canUseDateInputType) {
      onChangeAttr = {};
    } else {
      // Fixes prop type error about read-only field
      // Not adding readOnly so constraint validation works
      onChangeAttr = {
        onChange: noop
      };
    }

    let additionalAttrs;

    if (isAccessible && this.canUseDateInputType) {
      additionalAttrs = {
        max: this.formatDisplayDateType(maxDate) || '9999-12-31',
        min: this.formatDisplayDateType(minDate) || '0001-01-01'
      };
    } else if (isAccessible && !this.canUseDateInputType) {
      // "name" prop is required for pattern validation to be surfaced on form submit. See components/form-elements/form/Form.js
      // "title" prop is shown during constraint validation as a description of the pattern
      // See https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/pattern#usability
      additionalAttrs = {
        name,
        pattern: ISO_DATE_FORMAT_PATTERN.source,
        title: 'YYYY-MM-DD'
      };
    } else {
      additionalAttrs = {};
    }

    return React.createElement("div", {
      className: classes
    }, React.createElement("span", {
      className: "date-picker-icon-holder"
    }, React.createElement(Label, {
      hideLabel: hideLabel,
      showOptionalText: !hideOptionalLabel && !isRequired,
      text: label
    }, React.createElement(React.Fragment, null, !!description && React.createElement("div", {
      id: this.descriptionID,
      className: "date-picker-description"
    }, description), React.createElement(Tooltip, {
      className: "date-picker-error-tooltip",
      isShown: !!errorMessage,
      position: errorTooltipPosition,
      text: errorMessage || '',
      theme: TooltipTheme.ERROR
    }, customInput ? React.cloneElement(customInput, _objectSpread({
      disabled: isDisabled,
      ref: _ref => {
        this.dateInputEl = _ref;
      },
      required: isRequired
    }, resinTargetAttr, {}, ariaAttrs)) : React.createElement("input", _extends({
      ref: _ref2 => {
        this.dateInputEl = _ref2;
      },
      className: "date-picker-input",
      disabled: isDisabled,
      onBlur: this.handleInputBlur,
      onClick: this.handleOnClick,
      placeholder: placeholder || formatMessage(messages.chooseDate),
      required: isRequired,
      type: isAccessible && this.canUseDateInputType ? 'date' : 'text'
    }, onChangeAttr, {
      onFocus: onFocus,
      onKeyDown: this.handleInputKeyDown
    }, resinTargetAttr, ariaAttrs, inputProps, valueAttr, additionalAttrs))), React.createElement("span", {
      id: this.errorMessageID,
      className: "accessibility-hidden",
      role: "alert"
    }, errorMessage))), isClearable && hasValue && !isDisabled ? React.createElement(PlainButton, {
      "aria-label": formatMessage(messages.dateClearButton),
      className: "date-picker-clear-btn",
      onClick: this.clearDate,
      type: ButtonType.BUTTON
    }, React.createElement(ClearBadge16, null)) : null, hasError ? React.createElement(AlertBadge16, {
      className: "date-picker-icon-alert",
      title: React.createElement(FormattedMessage, messages.iconAlertText)
    }) : null, this.renderCalendarButton(), React.createElement("input", {
      className: "date-picker-unix-time-input",
      name: name,
      readOnly: true,
      type: "hidden",
      value: value ? this.formatValue(value) : ''
    })));
  }

}

_defineProperty(DatePicker, "defaultProps", {
  className: '',
  dateFormat: DateFormat.UNIX_TIME_DATE_FORMAT,
  displayFormat: {},
  error: '',
  errorTooltipPosition: TooltipPosition.BOTTOM_LEFT,
  inputProps: {},
  isClearable: true,
  isKeyboardInputAllowed: false,
  isTextInputAllowed: false,
  yearRange: 10
});

export { DatePicker as DatePickerBase };
export default injectIntl(DatePicker);
//# sourceMappingURL=DatePicker.js.map