import * as React from 'react';
import { IntlProvider } from 'react-intl';
import { State, Store } from '@sambego/storybook-state';
import { TooltipPosition } from '../tooltip';
import DatePicker from './DatePicker';
import notes from './DatePicker.stories.md';
import { bdlGray10 } from '../../styles/variables';
export const basic = () => {
  const MIN_TIME = new Date(0);
  const TODAY = new Date('July 18, 2018');
  const yearRange = [MIN_TIME.getFullYear(), TODAY.getFullYear()];
  const componentStore = new Store({
    date: new Date('July 9, 2018'),
    fromDate: null,
    toDate: null
  });
  return React.createElement(State, {
    store: componentStore
  }, state => React.createElement(IntlProvider, {
    locale: "en-US"
  }, React.createElement(DatePicker, {
    className: "date-picker-example",
    displayFormat: {
      day: 'numeric',
      month: 'long',
      year: 'numeric'
    },
    label: "Date",
    name: "datepicker",
    onChange: date => {
      componentStore.set({
        date
      });
    },
    placeholder: "Date",
    value: state.date,
    yearRange: yearRange
  })));
};
export const basicWithKeyboardInput = () => {
  const MIN_TIME = new Date(0);
  const TODAY = new Date('July 18, 2018');
  const yearRange = [MIN_TIME.getFullYear(), TODAY.getFullYear()];
  const componentStore = new Store({
    date: new Date('July 9, 2018'),
    fromDate: null,
    toDate: null
  });
  return React.createElement(State, {
    store: componentStore
  }, state => React.createElement(IntlProvider, {
    locale: "en-US"
  }, React.createElement(DatePicker, {
    className: "date-picker-example",
    displayFormat: {
      day: 'numeric',
      month: 'long',
      year: 'numeric'
    },
    isKeyboardInputAllowed: true,
    label: "Date",
    name: "datepicker",
    onChange: date => {
      componentStore.set({
        date
      });
    },
    placeholder: "Date",
    value: state.date,
    yearRange: yearRange
  })));
};
export const withDescription = () => React.createElement(IntlProvider, {
  locale: "en-US"
}, React.createElement(DatePicker, {
  placeholder: "Date",
  description: "Date of your birth",
  label: "Date Picker"
}));
export const manuallyEditable = () => React.createElement(IntlProvider, {
  locale: "en-US"
}, React.createElement(DatePicker, {
  isTextInputAllowed: true,
  placeholder: "Date",
  label: "Date Picker",
  value: new Date('September 27, 2019')
}));
export const manuallyEditableAndAccessible = () => React.createElement(IntlProvider, {
  locale: "en-US"
}, React.createElement(DatePicker, {
  isAccessible: true,
  placeholder: "Date",
  label: "Date Picker",
  value: new Date('August 10, 2021')
}));
export const withLimitedDateRange = () => {
  const maxDate = new Date('February 25, 2021');
  const sixDays = 1000 * 60 * 60 * 24 * 6;
  const minDate = new Date(maxDate.valueOf() - sixDays);
  const componentStore = new Store({
    date: maxDate,
    fromDate: null,
    toDate: null
  });
  return React.createElement(State, {
    store: componentStore
  }, state => React.createElement(IntlProvider, {
    locale: "en-US"
  }, React.createElement(DatePicker, {
    isTextInputAllowed: true,
    placeholder: "Date",
    label: "Date Picker",
    minDate: minDate,
    maxDate: maxDate,
    value: state.date
  })));
};
export const alwaysVisibleWithCustomInputField = () => {
  const componentStore = new Store({
    date: new Date('February 26, 2021'),
    fromDate: null,
    toDate: null
  });
  return React.createElement(State, {
    store: componentStore
  }, state => {
    const customInput = React.createElement("input", {
      style: {
        display: 'none'
      }
    });
    return React.createElement(IntlProvider, {
      locale: "en-US"
    }, React.createElement("div", {
      style: {
        display: 'flex',
        justifyContent: 'center'
      }
    }, React.createElement(DatePicker, {
      className: "date-picker-example",
      customInput: customInput,
      displayFormat: {
        day: 'numeric',
        month: 'short',
        year: 'numeric'
      },
      hideLabel: true,
      isAlwaysVisible: true,
      isClearable: false,
      label: "Date",
      name: "datepicker",
      onChange: date => {
        componentStore.set({
          date
        });
      },
      placeholder: "Date",
      value: state.date
    }), React.createElement("div", {
      style: {
        margin: '20px 30px',
        width: '400px'
      }
    }, React.createElement("p", null, "In this example, the DatePicker is bound to a custom hidden input field. The right panel retains the same state as the DatePicker, but is not contained within the DatePicker component."), React.createElement("div", {
      style: {
        position: 'relative'
      }
    }, React.createElement("label", {
      htmlFor: "date-picker-custom-input",
      style: {
        position: 'absolute',
        left: '10px',
        top: '6px',
        zIndex: 100
      }
    }, "Start Date"), React.createElement("input", {
      disabled: true,
      name: "date-picker-custom-input",
      style: {
        background: bdlGray10,
        border: 0,
        borderRadius: '4px',
        padding: '.5em .8em',
        width: '19em',
        height: '2.5em',
        top: 0,
        outline: 'none',
        textAlign: 'right'
      },
      value: state.date.toDateString()
    })))));
  });
};
export const disabledWithErrorMessage = () => React.createElement(IntlProvider, {
  locale: "en-US"
}, React.createElement(DatePicker, {
  isDisabled: true,
  error: "Error Message",
  placeholder: "Date",
  name: "datepicker",
  label: "Disabled Date Picker"
}));
export const customErrorTooltipPosition = () => React.createElement(IntlProvider, {
  locale: "en-US"
}, React.createElement(DatePicker, {
  error: "Error Message",
  errorTooltipPosition: TooltipPosition.MIDDLE_RIGHT,
  placeholder: "Date",
  name: "datepicker",
  label: "Disabled Date Picker"
}));
export const withRange = () => {
  const MAX_TIME = new Date('3000-01-01T00:00:00.000Z');
  const MIN_TIME = new Date(0);
  const TODAY = new Date();
  const componentStore = new Store({
    date: new Date(),
    fromDate: null,
    toDate: null
  });
  return React.createElement(State, {
    store: componentStore
  }, state => React.createElement(IntlProvider, {
    locale: "en-US"
  }, React.createElement("div", null, React.createElement(DatePicker, {
    className: "date-picker-example",
    displayFormat: {
      day: 'numeric',
      month: 'long',
      year: 'numeric'
    },
    hideOptionalLabel: true,
    label: "From Date",
    maxDate: state.toDate || MAX_TIME,
    name: "datepicker-from",
    onChange: date => {
      componentStore.set({
        fromDate: date
      });
    },
    placeholder: "Choose a Date",
    value: state.fromDate
  }), React.createElement(DatePicker, {
    className: "date-picker-example",
    displayFormat: {
      day: 'numeric',
      month: 'long',
      year: 'numeric'
    },
    hideOptionalLabel: true,
    label: "To Date",
    minDate: state.fromDate || MIN_TIME,
    maxDate: TODAY,
    name: "datepicker-to",
    onChange: date => {
      componentStore.set({
        toDate: date
      });
    },
    placeholder: "Choose a Date",
    value: state.toDate
  }))));
};
export const withRangeAndKeyboardInput = () => {
  const MAX_TIME = new Date('3000-01-01T00:00:00.000Z');
  const MIN_TIME = new Date(0);
  const TODAY = new Date();
  const componentStore = new Store({
    date: new Date(),
    fromDate: null,
    toDate: null
  });
  return React.createElement(State, {
    store: componentStore
  }, state => React.createElement(IntlProvider, {
    locale: "en-US"
  }, React.createElement("div", null, React.createElement(DatePicker, {
    className: "date-picker-example",
    displayFormat: {
      day: 'numeric',
      month: 'long',
      year: 'numeric'
    },
    hideOptionalLabel: true,
    isKeyboardInputAllowed: true,
    label: "From Date",
    maxDate: state.toDate || MAX_TIME,
    name: "datepicker-from",
    onChange: date => {
      componentStore.set({
        fromDate: date
      });
    },
    placeholder: "Choose a Date",
    value: state.fromDate
  }), React.createElement(DatePicker, {
    className: "date-picker-example",
    displayFormat: {
      day: 'numeric',
      month: 'long',
      year: 'numeric'
    },
    hideOptionalLabel: true,
    isKeyboardInputAllowed: true,
    label: "To Date",
    minDate: state.fromDate || MIN_TIME,
    maxDate: TODAY,
    name: "datepicker-to",
    onChange: date => {
      componentStore.set({
        toDate: date
      });
    },
    placeholder: "Choose a Date",
    value: state.toDate
  }))));
};
export default {
  title: 'Components/DatePicker',
  component: DatePicker,
  parameters: {
    notes
  }
};
//# sourceMappingURL=DatePicker.stories.js.map