function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import uniqueId from 'lodash/uniqueId';
import { Editor } from 'draft-js';
import 'draft-js/dist/Draft.css';
import Tooltip from '../tooltip';
import commonMessages from '../../common/messages';
import './DraftJSEditor.scss';

const OptionalFormattedMessage = () => React.createElement("span", {
  className: "bdl-Label-optional"
}, "(", React.createElement(FormattedMessage, commonMessages.optional), ")");

class DraftJSEditor extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "handleChange", editorState => {
      const {
        onChange
      } = this.props;
      onChange(editorState);
    });

    _defineProperty(this, "handleBlur", editorState => {
      const {
        onBlur
      } = this.props;
      onBlur(editorState);
    });

    _defineProperty(this, "handleReturn", event => {
      const {
        onReturn,
        inputProps
      } = this.props;

      if (onReturn && !inputProps['aria-activedescendant']) {
        // Return 'handled' tells DraftJS Editor to not handle return key event,
        // return 'not-handled' tells DraftJS Editor to continue handle the return key event.
        // We encapsulate this DraftJS Editor specific contract here, and use true/fase
        // to indicate whether to let DraftJS Editor handle return event or not in the upper level.
        return onReturn(event) ? 'handled' : 'not-handled';
      }

      return 'not-handled';
    });

    _defineProperty(this, "labelID", uniqueId('label'));

    _defineProperty(this, "descriptionID", uniqueId('description'));
  }

  render() {
    const {
      editorState,
      error,
      hideLabel,
      inputProps,
      isDisabled,
      isRequired,
      label,
      description,
      onFocus,
      placeholder
    } = this.props;
    const {
      handleBlur,
      handleChange
    } = this;
    const classes = classNames({
      'draft-js-editor': true,
      'is-disabled bdl-is-disabled': isDisabled,
      'show-error': !!error
    });
    let a11yProps = {};

    if (inputProps.role) {
      a11yProps = {
        ariaActiveDescendantID: inputProps['aria-activedescendant'],
        ariaAutoComplete: inputProps['aria-autocomplete'],
        ariaExpanded: inputProps['aria-expanded'],
        ariaOwneeID: inputProps['aria-owns'],
        ariaMultiline: true,
        role: 'textbox'
      };
    }

    return React.createElement("div", {
      className: classes
    }, React.createElement("span", {
      className: classNames('bdl-Label', {
        'accessibility-hidden': hideLabel
      }),
      id: this.labelID
    }, label, !isRequired && React.createElement(OptionalFormattedMessage, null)), React.createElement("span", {
      className: "accessibility-hidden screenreader-description",
      id: this.descriptionID
    }, description), React.createElement(Tooltip, {
      isShown: !!error,
      position: "bottom-left",
      text: error ? error.message : '',
      theme: "error"
    }, React.createElement("div", null, React.createElement(Editor, _extends({}, a11yProps, {
      ariaLabelledBy: this.labelID,
      ariaDescribedBy: this.descriptionID,
      editorState: editorState,
      handleReturn: this.handleReturn,
      onBlur: handleBlur,
      onChange: handleChange,
      onFocus: onFocus,
      placeholder: placeholder,
      readOnly: isDisabled,
      stripPastedStyles: true
    })))));
  }

}

_defineProperty(DraftJSEditor, "defaultProps", {
  inputProps: {},
  isRequired: false,
  isFocused: false
});

export default DraftJSEditor;
//# sourceMappingURL=DraftJSEditor.js.map