function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import uniqueId from 'lodash/uniqueId';
import Checkbox from '../checkbox/Checkbox';
import DraggableList from './DraggableList';
import DraggableListItem from './DraggableListItem';
import reorder from './draggable-list-utils/reorder';
import notes from './DraggableList.stories.md';

class DraggableListExamples extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      items: [],
      listId: ''
    });

    _defineProperty(this, "getItems", count => {
      return Array.from({
        length: count
      }, (v, k) => k).map(k => ({
        id: uniqueId('item_'),
        label: "item ".concat(k)
      }));
    });

    _defineProperty(this, "onDragEnd", (sourceIndex, destinationIndex) => {
      if (!destinationIndex) {
        return;
      }

      const items = reorder(this.state.items, sourceIndex, destinationIndex);
      this.setState({
        items
      });
    });
  }

  componentDidMount() {
    this.setState({
      items: this.getItems(10),
      listId: uniqueId()
    });
  }

  render() {
    const {
      isDraggableViaHandle
    } = this.props;
    const {
      items,
      listId
    } = this.state;
    return React.createElement(DraggableList, {
      className: "draggable-list-example-container",
      listId: listId,
      onDragEnd: this.onDragEnd
    }, items.map((item, index) => React.createElement(DraggableListItem, {
      key: "draggable-".concat(index),
      id: item.id,
      index: index,
      isDraggableViaHandle: isDraggableViaHandle
    }, React.createElement(Checkbox, {
      label: item.label,
      name: item.label
    }))));
  }

}

export const Example = () => React.createElement(DraggableListExamples, null);
export const ExampleIsDraggableViaHandle = () => React.createElement(DraggableListExamples, {
  isDraggableViaHandle: true
});
export default {
  title: 'Components/DraggableList',
  component: DraggableList,
  parameters: {
    notes
  }
};
//# sourceMappingURL=DraggableList.stories.js.map