function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import { EditorState } from 'draft-js';
import DatalistItem from '../../datalist-item';
import DraftJSEditor from '../../draft-js-editor';
import SelectorDropdown from '../../selector-dropdown';
import { addMention, defaultMentionTriggers, getActiveMentionForEditorState } from './utils';
import messages from './messages';
import './MentionSelector.scss';

const DefaultSelectorRow = (_ref) => {
  let {
    item = {}
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["item"]);

  return React.createElement(DatalistItem, rest, item.name, " ", React.createElement("span", {
    className: "dropdown-secondary-text"
  }, item.email));
};

const DefaultStartMentionMessage = () => React.createElement(FormattedMessage, messages.startMention);

const MentionStartState = (_ref2) => {
  let {
    message
  } = _ref2;
  return React.createElement("div", {
    role: "alert",
    className: "mention-start-state"
  }, message);
};

class DraftJSMentionSelector extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "handleMention", () => {
      const {
        onMention
      } = this.props;
      const {
        activeMention
      } = this.state;

      if (onMention) {
        onMention(activeMention ? activeMention.mentionString : '');
      }
    });

    _defineProperty(this, "handleContactSelected", index => {
      const {
        contacts
      } = this.props;
      this.addMention(contacts[index]);
      this.setState({
        activeMention: null,
        isFocused: true
      }, () => {
        this.handleMention();
      });
    });

    _defineProperty(this, "handleBlur", event => {
      const {
        onBlur
      } = this.props;
      this.setState({
        isFocused: false
      });

      if (onBlur) {
        onBlur(event);
      }
    });

    _defineProperty(this, "handleFocus", event => {
      const {
        onFocus
      } = this.props;
      this.setState({
        isFocused: true
      });

      if (onFocus) {
        onFocus(event);
      }
    });

    _defineProperty(this, "handleChange", nextEditorState => {
      const {
        onChange
      } = this.props;
      const activeMention = this.getActiveMentionForEditorState(nextEditorState);
      this.setState({
        activeMention
      }, () => {
        if (onChange) {
          onChange(nextEditorState);
        }

        if (activeMention && activeMention.mentionString) {
          this.handleMention();
        }
      });
    });

    _defineProperty(this, "shouldDisplayMentionLookup", () => {
      const {
        contacts
      } = this.props;
      const {
        activeMention
      } = this.state;
      return !!(activeMention && activeMention.mentionString && contacts.length);
    });

    const mentionTriggers = props.mentionTriggers.reduce((prev, current) => "".concat(prev, "\\").concat(current), '');
    this.state = {
      activeMention: null,
      isFocused: false,
      mentionPattern: new RegExp("([".concat(mentionTriggers, "])([^").concat(mentionTriggers, "]*)$"))
    };
  }
  /**
   * Lifecycle method that gets called immediately after an update
   * @param {object} lastProps Props the component is receiving
   * @returns {void}
   */


  componentDidUpdate(prevProps) {
    const {
      contacts: prevContacts
    } = prevProps;
    const {
      contacts: currentContacts
    } = this.props;
    const {
      activeMention
    } = this.state;

    if (activeMention !== null && !currentContacts.length && prevContacts.length !== currentContacts.length) {
      // if empty set of contacts get passed in, set active mention to null
      this.setState({
        activeMention: null
      });
    }
  }
  /**
   * Extracts the active mention from the editor state
   *
   * @param {EditorState} editorState
   * @returns {object}
   */


  getActiveMentionForEditorState(editorState) {
    const {
      mentionPattern
    } = this.state;
    return getActiveMentionForEditorState(editorState, mentionPattern);
  }
  /**
   * Called on each keypress when a mention is being composed
   * @returns {void}
   */


  /**
   * Inserts a selected mention into the editor
   * @param {object} mention The selected mention to insert
   */
  addMention(mention) {
    const {
      activeMention
    } = this.state;
    const {
      editorState
    } = this.props;
    const editorStateWithLink = addMention(editorState, activeMention, mention);
    this.setState({
      activeMention: null
    }, () => {
      this.handleChange(editorStateWithLink);
    });
  }
  /**
   * @returns {boolean}
   */


  render() {
    const {
      className,
      contacts,
      contactsLoaded,
      editorState,
      error,
      hideLabel,
      isDisabled,
      isRequired,
      label,
      description,
      onReturn,
      placeholder,
      selectorRow,
      startMentionMessage,
      onMention
    } = this.props;
    const {
      activeMention,
      isFocused
    } = this.state;
    const classes = classNames('mention-selector-wrapper', className);
    const showMentionStartState = !!(onMention && activeMention && !activeMention.mentionString && isFocused);
    const usersFoundMessage = this.shouldDisplayMentionLookup() ? _objectSpread({}, messages.usersFound, {
      values: {
        usersCount: contacts.length
      }
    }) : messages.noUsersFound;
    return React.createElement("div", {
      className: classes
    }, React.createElement(SelectorDropdown, {
      onSelect: this.handleContactSelected,
      selector: React.createElement(DraftJSEditor, {
        editorState: editorState,
        error: error,
        hideLabel: hideLabel,
        isDisabled: isDisabled,
        isFocused: isFocused,
        isRequired: isRequired,
        label: label,
        description: description,
        onBlur: this.handleBlur,
        onFocus: this.handleFocus,
        onChange: this.handleChange,
        onReturn: onReturn,
        placeholder: placeholder
      })
    }, this.shouldDisplayMentionLookup() ? contacts.map(contact => React.cloneElement(selectorRow, _objectSpread({}, selectorRow.props, {}, contact, {
      key: contact.id
    }))) : []), showMentionStartState ? React.createElement(MentionStartState, {
      message: startMentionMessage
    }) : null, contactsLoaded && React.createElement("span", {
      className: "accessibility-hidden",
      "data-testid": "accessibility-alert",
      role: "alert"
    }, React.createElement(FormattedMessage, usersFoundMessage)));
  }

}

_defineProperty(DraftJSMentionSelector, "defaultProps", {
  className: '',
  contacts: [],
  isDisabled: false,
  isRequired: false,
  mentionTriggers: defaultMentionTriggers,
  selectorRow: React.createElement(DefaultSelectorRow, null),
  startMentionMessage: React.createElement(DefaultStartMentionMessage, null)
});

export default DraftJSMentionSelector;
//# sourceMappingURL=DraftJSMentionSelectorCore.js.map