function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { CellMeasurer, CellMeasurerCache } from '@box/react-virtualized/dist/es/CellMeasurer';
import Table, { Column } from '@box/react-virtualized/dist/es/Table';
import getProp from 'lodash/get';
import GridViewSlot from './GridViewSlot';
import '@box/react-virtualized/styles.css';
import './GridView.scss';

class GridView extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "cache", new CellMeasurerCache({
      defaultHeight: 300,
      defaultWidth: 400,
      fixedWidth: true
    }));

    _defineProperty(this, "cellRenderer", (_ref) => {
      let {
        dataKey,
        parent,
        rowIndex
      } = _ref;
      const {
        columnCount,
        currentCollection,
        slotRenderer
      } = this.props;
      const count = getProp(currentCollection, 'items.length', 0);
      const contents = [];
      const startingIndex = rowIndex * columnCount;
      const maxSlotIndex = Math.min(startingIndex + columnCount, count);

      for (let slotIndex = startingIndex; slotIndex < maxSlotIndex; slotIndex += 1) {
        const {
          id,
          selected
        } = getProp(currentCollection, "items[".concat(slotIndex, "]")); // using item's id as key is important for renrendering.  React Virtualized Table rerenders
        // on every 1px scroll, so using improper key would lead to image flickering in each
        // card of the grid view when scrolling.

        contents.push(React.createElement(GridViewSlot, {
          key: id,
          selected: selected,
          slotIndex: slotIndex,
          slotRenderer: slotRenderer,
          slotWidth: "".concat((100 / columnCount).toFixed(4), "%")
        }));
      }

      return React.createElement(CellMeasurer, {
        key: dataKey,
        cache: this.cache,
        columnIndex: 0,
        parent: parent,
        rowIndex: rowIndex
      }, React.createElement("div", {
        className: "bdl-GridView-row"
      }, contents));
    });

    _defineProperty(this, "rowGetter", (_ref2) => {
      let {
        index
      } = _ref2;
      return index;
    });
  }

  componentDidUpdate(_ref3) {
    let {
      columnCount: prevColumnCount,
      width: prevWidth
    } = _ref3;
    const {
      columnCount,
      width
    } = this.props; // The React Virtualized Table must be notified whenever the heights of rows
    // could potentially change. If omitted, rows are sized
    // incorrectly resulting in gaps or content overlap.

    if (columnCount !== prevColumnCount || width !== prevWidth) {
      this.cache.clearAll();
      this.forceUpdate();
    }
  }

  render() {
    const {
      columnCount,
      currentCollection,
      height,
      scrollToRow = 0,
      width
    } = this.props;
    const count = getProp(currentCollection, 'items.length', 0);
    const rowCount = Math.ceil(count / columnCount);
    return React.createElement(Table, {
      className: "bdl-GridView",
      disableHeader: true,
      height: height,
      rowCount: rowCount,
      rowGetter: this.rowGetter,
      rowHeight: this.cache.rowHeight,
      width: width,
      gridClassName: "bdl-GridView-body",
      rowClassName: "bdl-GridView-tableRow",
      scrollToIndex: scrollToRow,
      sortDirection: "ASC"
    }, React.createElement(Column, {
      cellRenderer: this.cellRenderer,
      dataKey: "",
      flexGrow: 1,
      width: 400
    }));
  }

}

export default GridView;
//# sourceMappingURL=GridView.js.map