function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import commonMessages from '../../common/messages';
import { ModalActions } from '../modal';
import Button from '../button';
import PlainButton from '../plain-button';
import DropdownMenu, { MenuToggle } from '../dropdown-menu';
import { Menu, MenuItem } from '../menu';
import HotkeyFriendlyModal from './HotkeyFriendlyModal'; // eslint-disable-line import/no-cycle

import messages from './messages';
import './HotkeyHelpModal.scss';
const specialCharacters = {
  backspace: '\u232b',
  down: '\u2193',
  left: '\u2190',
  meta: '\u2318',
  right: '\u2192',
  up: '\u2191',
  enter: React.createElement(FormattedMessage, messages.enterKey),
  spacebar: React.createElement(FormattedMessage, messages.spacebarKey),
  shift: '\u21e7',
  ctrl: React.createElement(FormattedMessage, messages.ctrlKey),
  alt: React.createElement(FormattedMessage, messages.altKey),
  esc: React.createElement(FormattedMessage, messages.escKey)
};

class HotkeyHelpModal extends Component {
  constructor(props, context) {
    super(props);

    _defineProperty(this, "prettyPrintHotkey", hotkeyConfig => {
      const hotkeys = Array.isArray(hotkeyConfig.key) ? hotkeyConfig.key : [hotkeyConfig.key];
      return hotkeys.map(hotkey => hotkey.split(' ').reduce((prettyHotkey, combo, i) => {
        // Convert a "raw" combo to a "pretty" combo:
        // e.g. "shift+g" => [ <kbd>Shift</kbd>, '+', <kbd>G</kbd> ]
        const prettyCombo = combo.split('+').map(key => {
          // Convert special key characters into their respective icons or translated components:
          // e.g. "shift" => "Shift", "meta" => "⌘"
          if (key in specialCharacters) {
            return specialCharacters[key];
          } // If it's not a special character, just return the uppercased key:
          // e.g. "g" => "G"


          return key.length === 1 ? key.toUpperCase() : key;
        }).map((key, j) => React.createElement("kbd", {
          key: j
        }, key)); // If this hotkey is a sequence of keys, return a translated message to combine them:
        // e.g. "Shift+G Shift+A" => "Shift+G then Shift+A"

        return i === 0 ? prettyCombo : React.createElement(FormattedMessage, _extends({
          values: {
            key1: React.createElement("span", null, prettyHotkey),
            key2: React.createElement("span", null, prettyCombo)
          }
        }, messages.hotkeySequence));
      }, [])).reduce((finalHotkey, hotkey, i) => // For shortcuts with multiple hotkeys, separate each hotkey with a "/" joiner:
      // e.g. "Cmd+S Ctrl+S" => "Cmd+S / Ctrl+S"
      i === 0 ? [hotkey] : [...finalHotkey, ' / ', hotkey], []).map((element, i) => React.createElement("span", {
        key: i
      }, element));
    });

    _defineProperty(this, "renderHotkey", (hotkey, i) => React.createElement("li", {
      key: i,
      className: "hotkey-item"
    }, React.createElement("div", {
      className: "hotkey-description"
    }, hotkey.description), React.createElement("div", {
      className: "hotkey-key"
    }, this.prettyPrintHotkey(hotkey))));

    this.hotkeys = context.hotkeyLayer.getActiveHotkeys();
    this.types = context.hotkeyLayer.getActiveTypes();
    this.state = {
      currentType: this.types.length ? this.types[0] : null
    };
  }

  componentDidUpdate(_ref, _ref2) {
    let {
      isOpen: prevIsOpen
    } = _ref;
    let {
      currentType: prevType
    } = _ref2;
    const {
      isOpen
    } = this.props;

    if (!isOpen) {
      return;
    } // modal is being opened; refresh hotkeys


    if (!prevIsOpen && isOpen) {
      this.hotkeys = this.context.hotkeyLayer.getActiveHotkeys();
      this.types = this.context.hotkeyLayer.getActiveTypes();
    }

    if (!prevType) {
      this.setState({
        currentType: this.types.length ? this.types[0] : null
      });
    }
  }
  /**
   * Converts a "raw" hotkey to translated JSX version
   */


  renderDropdownMenu() {
    const {
      currentType
    } = this.state;

    if (!currentType) {
      return null;
    }

    return React.createElement("div", {
      className: "hotkey-dropdown"
    }, React.createElement(DropdownMenu, null, React.createElement(PlainButton, {
      className: "lnk",
      type: "button"
    }, React.createElement(MenuToggle, null, currentType)), React.createElement(Menu, null, this.types.map((hotkeyType, i) => React.createElement(MenuItem, {
      key: i,
      onClick: () => this.setState({
        currentType: hotkeyType
      })
    }, hotkeyType)))));
  }

  renderHotkeyList() {
    const {
      currentType
    } = this.state;

    if (!currentType) {
      return null;
    }

    const hotkeys = this.hotkeys[currentType];
    return React.createElement("ul", {
      className: "hotkey-list"
    }, hotkeys.map(this.renderHotkey));
  }

  render() {
    const {
      isOpen,
      onRequestClose
    } = this.props;
    const {
      currentType
    } = this.state;

    if (!currentType) {
      return null;
    }

    return React.createElement(HotkeyFriendlyModal, {
      className: "hotkey-modal",
      isOpen: isOpen,
      onRequestClose: onRequestClose,
      title: React.createElement(FormattedMessage, messages.hotkeyModalTitle)
    }, this.renderDropdownMenu(), this.renderHotkeyList(), React.createElement(ModalActions, null, React.createElement(Button, {
      onClick: onRequestClose
    }, React.createElement(FormattedMessage, commonMessages.cancel))));
  }

}

_defineProperty(HotkeyHelpModal, "propTypes", {
  isOpen: PropTypes.bool,
  onRequestClose: PropTypes.func.isRequired
});

_defineProperty(HotkeyHelpModal, "contextTypes", {
  hotkeyLayer: PropTypes.object
});

export default HotkeyHelpModal;
//# sourceMappingURL=HotkeyHelpModal.js.map