function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { toQuery, useMediaQuery as _useMediaQuery } from 'react-responsive';
import { ANY_HOVER, ANY_POINTER_COARSE, ANY_POINTER_FINE, HOVER, HOVER_TYPE, POINTER_COARSE, POINTER_FINE, POINTER_TYPE, SIZE_LARGE, SIZE_MEDIUM, SIZE_SMALL, VIEW_SIZE_TYPE } from './constants';

const getPointerCapabilities = (isFine, isCoarse) => {
  if (!isFine && !isCoarse) return POINTER_TYPE.none;
  if (isFine) return POINTER_TYPE.fine;
  return POINTER_TYPE.coarse;
};

const getViewDimensions = () => {
  return {
    viewWidth: window.innerWidth,
    viewHeight: window.innerHeight
  };
};
/**
 * Formats the media query either as a MediaQuery object or string
 * @param query
 * @returns {string}
 */


function formatQuery(query) {
  return typeof query === 'string' ? query : toQuery(query);
}
/**
 * Executes media query
 * @param query
 * @param onQueryChange
 * @returns {boolean}
 */


function useQuery(query, onQueryChange) {
  return _useMediaQuery({
    query: formatQuery(query)
  }, null, onQueryChange);
}
/**
 * Determines device capabilities for hover and pointer features
 * @returns {{anyPointer: *, hover: (string), pointer: *, anyHover: (string)}}
 */


function useDeviceCapabilities() {
  const isHover = useQuery(HOVER);
  const isAnyHover = useQuery(ANY_HOVER);
  const anyHover = isAnyHover ? HOVER_TYPE.hover : HOVER_TYPE.none;
  const hover = isHover ? HOVER_TYPE.hover : HOVER_TYPE.none;
  const pointer = getPointerCapabilities(useQuery(POINTER_FINE), useQuery(POINTER_COARSE));
  const anyPointer = getPointerCapabilities(useQuery(ANY_POINTER_FINE), useQuery(ANY_POINTER_COARSE));
  const isTouchDevice = hover === HOVER_TYPE.none && pointer === POINTER_TYPE.coarse;
  return {
    anyHover,
    hover,
    anyPointer,
    pointer,
    isTouchDevice
  };
}
/**
 * Determines device size using media queries
 * @returns {string}
 */


function useDeviceSize() {
  const isSmall = useQuery(SIZE_SMALL);
  const isMedium = useQuery(SIZE_MEDIUM);
  const isLarge = useQuery(SIZE_LARGE);
  if (isSmall) return VIEW_SIZE_TYPE.small;
  if (isMedium) return VIEW_SIZE_TYPE.medium;
  if (isLarge) return VIEW_SIZE_TYPE.large;
  return VIEW_SIZE_TYPE.xlarge;
}

function useMediaQuery() {
  const deviceCapabilities = useDeviceCapabilities();
  const deviceSize = useDeviceSize();
  const viewDimensions = getViewDimensions();
  return _objectSpread({}, deviceCapabilities, {}, viewDimensions, {
    size: deviceSize
  });
}

export default useMediaQuery;
//# sourceMappingURL=useMediaQuery.js.map