function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import debounce from 'lodash/debounce';
import './SubmenuItem.scss';
import Arrow16 from '../../icon/fill/Arrow16';
const SUBMENU_LEFT_ALIGNED_CLASS = 'is-left-aligned';
const SUBMENU_BOTTOM_ALIGNED_CLASS = 'is-bottom-aligned';
const SUBMENU_RIGHT_BOTTOM_ALIGNED_CLASS = 'is-right-bottom-aligned';

/**
 * A menu-item component which triggers open a submenu
 *
 * @NOTE: Nested submenus are NOT currently supported, switching
 * focus with arrow keys in the subsubmenu is not working properly.
 */
class SubmenuItem extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isSubmenuOpen: false,
      submenuFocusIndex: null
    });

    _defineProperty(this, "getMenuAlignmentClasses", () => {
      if (!this.submenuTriggerEl || !this.submenuEl) {
        return {};
      }

      const {
        rightBoundaryElement,
        bottomBoundaryElement
      } = this.props;
      const submenuElBounding = this.submenuEl.getBoundingClientRect();
      const submenuTriggerElBounding = this.submenuTriggerEl.getBoundingClientRect();
      const rightBoundaryElementBounding = rightBoundaryElement ? rightBoundaryElement.getBoundingClientRect() : {
        right: window.innerWidth
      };
      const bottomBoundaryElementBounding = bottomBoundaryElement ? bottomBoundaryElement.getBoundingClientRect() : {
        bottom: window.innerHeight
      };
      const isLeftAligned = submenuTriggerElBounding.right + submenuElBounding.width > rightBoundaryElementBounding.right;
      const isBottomAligned = submenuTriggerElBounding.top + submenuElBounding.height > bottomBoundaryElementBounding.bottom;
      const isRightBottomAligned = submenuTriggerElBounding.bottom + submenuElBounding.height > bottomBoundaryElementBounding.bottom;
      return {
        [SUBMENU_LEFT_ALIGNED_CLASS]: isLeftAligned,
        [SUBMENU_BOTTOM_ALIGNED_CLASS]: isBottomAligned,
        [SUBMENU_RIGHT_BOTTOM_ALIGNED_CLASS]: isRightBottomAligned // Used only in medium-screen viewport sizes

      };
    });

    _defineProperty(this, "handleMenuItemClick", event => {
      const {
        isDisabled,
        onClick
      } = this.props; // If aria-disabled is passed as a prop, we should ignore clicks on this menu item

      if (isDisabled) {
        event.stopPropagation();
        event.preventDefault();
        return;
      }

      if (onClick) {
        onClick(event);
      } // If event target is triggering submenu element, do not propagate to close menu


      if (this.submenuEl && !this.submenuEl.contains(event.target)) {
        event.stopPropagation();
        event.preventDefault();
      }
    });

    _defineProperty(this, "handleKeyDown", event => {
      switch (event.key) {
        case ' ':
        case 'Enter':
        case 'ArrowRight':
          event.stopPropagation();
          event.preventDefault();
          this.openSubmenuAndFocus();
          break;

        default:
          break;
      }
    });

    _defineProperty(this, "closeSubmenu", debounce(() => {
      this.setState({
        isSubmenuOpen: false
      });
    }, 50));

    _defineProperty(this, "closeSubmenuAndFocusTrigger", isKeyboardEvent => {
      this.closeSubmenu();

      if (this.submenuTriggerEl && isKeyboardEvent) {
        this.submenuTriggerEl.focus();
      }
    });

    _defineProperty(this, "openSubmenu", () => {
      this.closeSubmenu.cancel();
      const {
        onOpen
      } = this.props;

      if (onOpen) {
        onOpen();
      }

      this.setState({
        isSubmenuOpen: true,
        submenuFocusIndex: null
      });
    });

    _defineProperty(this, "openSubmenuAndFocus", () => {
      const {
        onOpen
      } = this.props;

      if (onOpen) {
        onOpen();
      }

      this.setState({
        isSubmenuOpen: true,
        submenuFocusIndex: 0
      });
    });
  }

  render() {
    const _this$props = this.props,
          {
      children,
      className,
      isDisabled
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["children", "className", "isDisabled"]);

    const {
      isSubmenuOpen,
      submenuFocusIndex
    } = this.state;
    const elements = React.Children.toArray(children);
    const submenuTriggerContent = elements[0];
    const submenu = elements[1];

    if (elements.length !== 2 || !submenuTriggerContent || !submenu) {
      throw new Error('SubmenuItem must have exactly two children, a trigger component and a <Menu>');
    }

    const chevron = React.createElement(Arrow16, {
      className: "menu-item-arrow",
      width: 12,
      height: 12
    });

    const menuItemProps = _objectSpread({}, omit(rest, ['bottomBoundaryElement', 'onClick', 'onOpen', 'rightBoundaryElement', 'role', 'tabIndex']), {
      'aria-disabled': isDisabled ? 'true' : undefined,
      'aria-expanded': isSubmenuOpen ? 'true' : 'false',
      'aria-haspopup': 'true',
      className: classNames('menu-item', 'submenu-target', className),
      onClick: this.handleMenuItemClick,
      onMouseLeave: this.closeSubmenu,
      onMouseEnter: this.openSubmenu,
      onKeyDown: this.handleKeyDown,
      ref: _ref => {
        this.submenuTriggerEl = _ref;
      },
      role: 'menuitem',
      tabIndex: -1
    });

    const submenuProps = {
      className: classNames(submenu.props.className, 'submenu', this.getMenuAlignmentClasses()),
      initialFocusIndex: submenuFocusIndex,
      // Hide the menu instead of unmounting it. Otherwise onMouseLeave won't work.
      isHidden: !isSubmenuOpen,
      isSubmenu: true,
      onClose: this.closeSubmenuAndFocusTrigger,
      setRef: ref => {
        this.submenuEl = ref;
      }
    };
    return React.createElement("li", menuItemProps, submenuTriggerContent, chevron, React.cloneElement(submenu, submenuProps));
  }

}

export default SubmenuItem;
//# sourceMappingURL=SubmenuItem.js.map