function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import tabbable from 'tabbable';
import omit from 'lodash/omit';
import FocusTrap from '../focus-trap';
import LoadingIndicator from '../loading-indicator';
import Portal from '../portal';
import ModalDialog from './ModalDialog';
import './Modal.scss';

class Modal extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "onKeyDown", event => {
      const {
        isOpen,
        onRequestClose
      } = this.props;

      if (isOpen && onRequestClose && event.key === 'Escape') {
        event.stopPropagation();
        onRequestClose(event);
      }
    });

    _defineProperty(this, "onBackdropClick", event => {
      const {
        onRequestClose,
        onBackdropClick
      } = this.props;

      if (onBackdropClick) {
        onBackdropClick(event);
      } else if (onRequestClose) {
        onRequestClose(event);
      }
    });

    _defineProperty(this, "onModalOpen", () => {
      setTimeout(() => {
        const {
          focusElementSelector
        } = this.props;
        const focusElementSelectorTrimmed = focusElementSelector && focusElementSelector.trim();

        if (focusElementSelectorTrimmed) {
          this.focusElement(focusElementSelectorTrimmed);
        } else {
          this.focusFirstUsefulElement();
        }
      }, 0);
    });

    _defineProperty(this, "focusFirstUsefulElement", () => {
      if (!this.dialog) {
        return;
      }

      const tabbableEls = tabbable(this.dialog);

      if (tabbableEls.length > 1) {
        tabbableEls[1].focus();
      } else if (tabbableEls.length > 0) {
        tabbableEls[0].focus();
      }
    });

    _defineProperty(this, "focusElement", elementSelector => {
      if (!this.dialog) {
        return;
      }

      const el = this.dialog.querySelector(elementSelector);

      if (el) {
        el.focus();
      } else {
        throw new Error("Could not find element matching selector ".concat(elementSelector, " to focus on."));
      }
    });
  }

  componentDidMount() {
    const {
      isOpen
    } = this.props;

    if (isOpen) {
      this.onModalOpen();
    }
  }

  componentDidUpdate(prevProps) {
    const {
      isLoading,
      isOpen
    } = this.props; // Set focus if modal is transitioning from closed -> open and/or loading -> not loading

    if ((!prevProps.isOpen || prevProps.isLoading) && isOpen && !isLoading) {
      this.onModalOpen();
    }
  }
  /**
   * Call props.onRequestClose when escape is pressed
   * @param {SyntheticKeyboardEvent} event
   */


  render() {
    const _this$props = this.props,
          {
      className,
      isLoading,
      isOpen,
      onRequestClose,
      shouldNotUsePortal,
      style
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["className", "isLoading", "isOpen", "onRequestClose", "shouldNotUsePortal", "style"]);

    if (!isOpen) {
      return null;
    }

    const bodyOverrideStyle = "\n            body {\n                overflow:hidden;\n            }\n        "; // used `omit` here to prevent certain key/value pairs from going into the spread on `ModalDialog`

    const modalProps = omit(rest, ['onBackdropClick', 'focusElementSelector']);
    const WrapperComponent = shouldNotUsePortal ? 'div' : Portal; // Render a style tag to prevent body from scrolling as long as the Modal is open

    return React.createElement(WrapperComponent, {
      className: classNames('modal', className),
      onKeyDown: this.onKeyDown,
      tabIndex: "-1"
    }, React.createElement("div", {
      className: "modal-backdrop",
      onClick: this.onBackdropClick,
      style: style.backdrop
    }), React.createElement(FocusTrap, {
      className: "modal-dialog-container"
    }, isLoading ? React.createElement(LoadingIndicator, {
      size: "large"
    }) : React.createElement(ModalDialog, _extends({
      modalRef: modalEl => {
        // This callback gets passed through as a regular prop since
        // ModalDialog is wrapped in a HOC
        this.dialog = modalEl;
      },
      onRequestClose: onRequestClose,
      style: style.dialog
    }, modalProps))), React.createElement("style", {
      type: "text/css"
    }, bodyOverrideStyle));
  }

}

_defineProperty(Modal, "defaultProps", {
  style: {
    backdrop: {},
    dialog: {}
  }
});

export default Modal;
//# sourceMappingURL=Modal.js.map