function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import uniqueId from 'lodash/uniqueId';
import { defineMessages, injectIntl } from 'react-intl';
import IconBack from '../../icon/fill/Arrow16';
import IconClose from '../../icon/fill/X16';
const ALERT_TYPE = 'alert';
const DIALOG_TYPE = 'dialog';
const messages = defineMessages({
  backModalText: {
    "id": "boxui.modalDialog.backModalText",
    "defaultMessage": "Back"
  },
  closeModalText: {
    "id": "boxui.modalDialog.closeModalText",
    "defaultMessage": "Close Modal"
  }
});

class ModalDialog extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "onBackButtonClick", event => {
      const {
        onRequestBack
      } = this.props;

      if (onRequestBack) {
        onRequestBack(event);
      }
    });

    _defineProperty(this, "onCloseButtonClick", event => {
      const {
        onRequestClose
      } = this.props;

      if (onRequestClose) {
        onRequestClose(event);
      }
    });

    _defineProperty(this, "modalID", uniqueId('modal'));
  }

  /**
   * Renders a button if onRequestBack is passed in
   * @return {ReactElement|null} - Returns the button, or null if the button shouldn't be rendered
   */
  renderBackButton() {
    const {
      intl
    } = this.props;
    const {
      formatMessage
    } = intl;
    return React.createElement("button", {
      "aria-label": formatMessage(messages.backModalText),
      className: "modal-back-button",
      "data-testid": "modal-back-button",
      onClick: this.onBackButtonClick,
      type: "button"
    }, React.createElement(IconBack, {
      height: 18,
      width: 18
    }));
  }
  /**
   * Renders a button if onRequestClose is passed in
   * @return {ReactElement|null} - Returns the button, or null if the button shouldn't be rendered
   */


  renderCloseButton() {
    const {
      closeButtonProps,
      intl
    } = this.props;
    const {
      formatMessage
    } = intl;
    return (// eslint-disable-next-line react/button-has-type
      React.createElement("button", _extends({}, closeButtonProps, {
        "aria-label": formatMessage(messages.closeModalText),
        className: "modal-close-button",
        onClick: this.onCloseButtonClick
      }), React.createElement(IconClose, {
        color: "#909090",
        height: 18,
        width: 18
      }))
    );
  }

  renderContent() {
    const {
      children,
      type
    } = this.props;

    if (type !== ALERT_TYPE) {
      return React.createElement("div", {
        className: "modal-content"
      }, children);
    }

    const elements = React.Children.toArray(children);

    if (elements.length !== 2) {
      throw new Error('Alert modal must have exactly two children: A message and <ModalActions>');
    }

    return React.createElement("div", {
      className: "modal-content"
    }, React.createElement("p", {
      id: "".concat(this.modalID, "-desc")
    }, elements[0]), elements[1]);
  }

  render() {
    const _this$props = this.props,
          {
      className,
      modalRef,
      onRequestBack,
      onRequestClose,
      title,
      type // Useful for resin tagging, and other misc tags such as a11y

    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["className", "modalRef", "onRequestBack", "onRequestClose", "title", "type"]);

    const isAlertType = type === ALERT_TYPE;
    const divProps = omit(rest, ['children', 'closeButtonProps', 'onRequestClose', 'intl']);
    divProps.role = isAlertType ? 'alertdialog' : 'dialog';
    divProps['aria-modal'] = true;
    divProps['aria-labelledby'] = "".concat(this.modalID, "-label");

    if (isAlertType) {
      divProps['aria-describedby'] = "".concat(this.modalID, "-desc");
    }

    return React.createElement("div", _extends({
      ref: modalRef,
      className: classNames('modal-dialog', className)
    }, divProps), React.createElement("div", {
      className: "modal-header-container"
    }, React.createElement("div", {
      className: "modal-header"
    }, onRequestBack && this.renderBackButton(), React.createElement("h2", {
      className: "modal-title",
      id: "".concat(this.modalID, "-label")
    }, title)), onRequestClose && this.renderCloseButton()), this.renderContent());
  }

}

_defineProperty(ModalDialog, "defaultProps", {
  type: DIALOG_TYPE,
  closeButtonProps: {}
});

export { ModalDialog as ModalDialogBase };
export default injectIntl(ModalDialog);
//# sourceMappingURL=ModalDialog.js.map