function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { defineMessages, injectIntl } from 'react-intl';
import classNames from 'classnames';
import InfoBadge16 from '../../icon/line/InfoBadge16';
import CircleCheck16 from '../../icon/line/CircleCheck16';
import TriangleAlert16 from '../../icon/line/TriangleAlert16';
import XBadge16 from '../../icon/line/XBadge16';
import X16 from '../../icon/fill/X16';
import './Notification.scss'; // @NOTE: We can't import these constants from ./constant.js because `react-docgen`
// can't handle imported variables appear in propTypes
// see https://github.com/reactjs/react-docgen/issues/33

const DURATION_SHORT = 'short';
const DURATION_LONG = 'long';
const OVERFLOW_WRAP = 'wrap';
const TYPE_DEFAULT = 'default';
const TYPE_INFO = 'info';
const TYPE_WARN = 'warn';
const TYPE_ERROR = 'error';
const DURATION_TIMES = {
  [DURATION_SHORT]: 5000,
  [DURATION_LONG]: 10000
};
const ICON_RENDERER = {
  [TYPE_DEFAULT]: () => React.createElement(InfoBadge16, null),
  [TYPE_ERROR]: () => React.createElement(XBadge16, null),
  [TYPE_INFO]: () => React.createElement(CircleCheck16, null),
  [TYPE_WARN]: () => React.createElement(TriangleAlert16, null)
};
const messages = defineMessages({
  clearNotificationButtonText: {
    "id": "boxui.notification.clearNotification",
    "defaultMessage": "Clear Notification"
  }
});

class Notification extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "onClose", event => {
      const {
        onClose
      } = this.props;

      if (this.timeout) {
        clearTimeout(this.timeout);
      }

      if (onClose) {
        onClose(event);
      }
    });
  }

  componentDidMount() {
    const {
      duration,
      onClose
    } = this.props;
    this.timeout = duration && onClose ? setTimeout(onClose, DURATION_TIMES[duration]) : null;
  }

  getChildren() {
    const {
      children
    } = this.props;
    return typeof children === 'string' ? React.createElement("span", null, children) : children;
  }

  render() {
    const contents = this.getChildren();
    const {
      intl,
      type,
      overflow
    } = this.props;
    const {
      formatMessage
    } = intl;
    const classes = classNames('notification', type, overflow);
    return React.createElement("div", {
      className: classes
    }, React.cloneElement(ICON_RENDERER[type](), {
      color: '#fff',
      height: 20,
      width: 20
    }), contents, React.createElement("button", {
      "aria-label": formatMessage(messages.clearNotificationButtonText),
      className: "close-btn",
      onClick: this.onClose,
      type: "button"
    }, React.createElement(X16, null)));
  }

}

_defineProperty(Notification, "defaultProps", {
  overflow: OVERFLOW_WRAP,
  type: TYPE_DEFAULT
});

export default injectIntl(Notification);
//# sourceMappingURL=Notification.js.map