import * as React from 'react';
import { IntlProvider } from 'react-intl';
import { State, Store } from '@sambego/storybook-state';
import Button from '../../button/Button';
import PrimaryButton from '../../primary-button/PrimaryButton';
import Notification from '../Notification';
import NotificationsWrapper from '../NotificationsWrapper';
import notes from './NotificationsWrapper.stories.md';
export const example = () => {
  const DATE = new Date('May 13, 2002 23:15:30').toTimeString();
  const componentStore = new Store({
    id: 0,
    notifications: new Map()
  });

  const closeNotification = id => {
    const notifications = componentStore.get('notifications');
    notifications.delete(id);
    componentStore.set({
      notifications
    });
  };

  const addNotification = (duration, type) => {
    const id = componentStore.get('id');
    const notifications = componentStore.get('notifications');
    const notification = React.createElement(Notification, {
      key: id,
      duration: duration,
      onClose: () => closeNotification(id),
      type: type
    }, React.createElement("span", null, "Hello world! I was made at ", DATE), React.createElement(Button, null, "Okay"));
    componentStore.set({
      notifications: notifications.set(id, notification),
      id: id + 1
    });
  };

  return React.createElement(State, {
    store: componentStore
  }, state => React.createElement(IntlProvider, {
    locale: "en"
  }, React.createElement("div", null, React.createElement(NotificationsWrapper, null, [...state.notifications.values()]), React.createElement(Button, {
    onClick: () => addNotification('short', 'info')
  }, "Display timed notification"), React.createElement(PrimaryButton, {
    onClick: () => addNotification(undefined, 'warn')
  }, "Display persistent notification"))));
};
export default {
  title: 'Components/Notifications/NotificationsWrapper',
  component: NotificationsWrapper,
  parameters: {
    notes
  }
};
//# sourceMappingURL=NotificationsWrapper.stories.js.map