function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import uniqueId from 'lodash/uniqueId';
import { List } from 'immutable';
import Tooltip from '../tooltip';
import { KEYS } from '../../constants';
import RoundPill from './RoundPill';
import Pill from './Pill';
import SuggestedPillsRow from './SuggestedPillsRow';

function stopDefaultEvent(event) {
  event.preventDefault();
  event.stopPropagation();
}

class PillSelectorBase extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isFocused: false,
      selectedIndex: -1
    });

    _defineProperty(this, "getNumSelected", () => {
      const {
        selectedOptions
      } = this.props;
      return typeof selectedOptions.size === 'number' ? selectedOptions.size : selectedOptions.length;
    });

    _defineProperty(this, "getPillsByKey", key => {
      const {
        selectedOptions
      } = this.props;
      return selectedOptions.map(option => option[key]);
    });

    _defineProperty(this, "handleClick", () => {
      this.inputEl.focus();
    });

    _defineProperty(this, "handleFocus", () => {
      this.setState({
        isFocused: true
      });
    });

    _defineProperty(this, "handleBlur", () => {
      this.setState({
        isFocused: false
      });
    });

    _defineProperty(this, "handleKeyDown", event => {
      const inputValue = this.inputEl.value;
      const numPills = this.getNumSelected();
      const {
        selectedIndex
      } = this.state;

      switch (event.key) {
        case KEYS.backspace:
          {
            let index = -1;

            if (selectedIndex >= 0) {
              // remove selected pill
              index = selectedIndex;
              this.resetSelectedIndex();
              this.inputEl.focus();
            } else if (inputValue === '') {
              // remove last pill
              index = numPills - 1;
            }

            if (index >= 0) {
              const {
                onRemove,
                selectedOptions
              } = this.props;
              const selectedOption = // $FlowFixMe
              typeof selectedOptions.get === 'function' ? selectedOptions.get(index) : selectedOptions[index];
              onRemove(selectedOption, index);
              stopDefaultEvent(event);
            }

            break;
          }

        case KEYS.arrowLeft:
          if (selectedIndex >= 0) {
            // select previous pill
            this.setState({
              selectedIndex: Math.max(selectedIndex - 1, 0)
            });
            stopDefaultEvent(event);
          } else if (inputValue === '' && numPills > 0) {
            // select last pill
            this.hiddenEl.focus();
            this.setState({
              selectedIndex: numPills - 1
            });
            stopDefaultEvent(event);
          }

          break;

        case KEYS.arrowRight:
          {
            if (selectedIndex >= 0) {
              const index = selectedIndex + 1;

              if (index >= numPills) {
                // deselect last pill
                this.resetSelectedIndex();
                this.inputEl.focus();
              } else {
                // select next pill
                this.setState({
                  selectedIndex: index
                });
              }

              stopDefaultEvent(event);
            }

            break;
          }
        // no default
      }
    });

    _defineProperty(this, "errorMessageID", uniqueId('errorMessage'));

    _defineProperty(this, "hiddenRef", hiddenEl => {
      if (hiddenEl) {
        this.hiddenEl = hiddenEl;
      }
    });

    _defineProperty(this, "resetSelectedIndex", () => {
      if (this.state.selectedIndex !== -1) {
        this.setState({
          selectedIndex: -1
        });
      }
    });
  }

  render() {
    const {
      isFocused,
      selectedIndex
    } = this.state;

    const _this$props = this.props,
          {
      allowInvalidPills,
      className,
      disabled,
      error,
      errorTooltipPosition,
      getPillClassName,
      getPillImageUrl,
      inputProps,
      isInputDisabled,
      isInputFocusedNextLine,
      onInput,
      onRemove,
      onSuggestedPillAdd,
      placeholder,
      innerRef,
      selectedOptions,
      showAvatars,
      showRoundedPills,
      suggestedPillsData,
      suggestedPillsFilter,
      suggestedPillsTitle,
      validator
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["allowInvalidPills", "className", "disabled", "error", "errorTooltipPosition", "getPillClassName", "getPillImageUrl", "inputProps", "isInputDisabled", "isInputFocusedNextLine", "onInput", "onRemove", "onSuggestedPillAdd", "placeholder", "innerRef", "selectedOptions", "showAvatars", "showRoundedPills", "suggestedPillsData", "suggestedPillsFilter", "suggestedPillsTitle", "validator"]);

    const suggestedPillsEnabled = suggestedPillsData && suggestedPillsData.length > 0;
    const hasError = !!error;
    const classes = classNames('bdl-PillSelector', 'pill-selector-input-wrapper', {
      'is-disabled': disabled,
      'bdl-is-disabled': disabled,
      'is-focused': isFocused,
      'show-error': hasError,
      'pill-selector-suggestions-enabled': suggestedPillsEnabled,
      'bdl-PillSelector--suggestionsEnabled': suggestedPillsEnabled
    });
    const ariaAttrs = {
      'aria-invalid': hasError,
      'aria-errormessage': this.errorMessageID,
      'aria-describedby': this.errorMessageID
    };
    return React.createElement(Tooltip, {
      isShown: hasError,
      text: error || '',
      position: errorTooltipPosition,
      theme: "error"
    }, React.createElement("span", {
      className: classes,
      onBlur: this.handleBlur,
      onClick: this.handleClick,
      onFocus: this.handleFocus,
      onKeyDown: this.handleKeyDown,
      ref: innerRef
    }, showRoundedPills ? selectedOptions.map((option, index) => {
      return React.createElement(RoundPill, {
        className: getPillClassName ? getPillClassName(option) : undefined,
        getPillImageUrl: getPillImageUrl,
        isValid: allowInvalidPills ? validator(option) : true,
        isDisabled: disabled,
        isSelected: index === selectedIndex,
        key: option.value,
        onRemove: onRemove.bind(this, option, index) // $FlowFixMe option.text is for backwards compatibility
        ,
        text: option.displayText || option.text,
        showAvatar: showAvatars,
        id: option.id,
        hasWarning: option.hasWarning,
        isExternal: option.isExternalUser
      });
    }) : selectedOptions.map((option, index) => {
      // TODO: This and associated types will be removed once all views are updates with round pills.
      return React.createElement(Pill, {
        isValid: allowInvalidPills ? validator(option) : true,
        isDisabled: disabled,
        isSelected: index === selectedIndex,
        key: option.value,
        onRemove: onRemove.bind(this, option, index) // $FlowFixMe option.text is for backwards compatibility
        ,
        text: option.displayText || option.text
      });
    }), React.createElement("span", {
      "aria-hidden": "true",
      className: "accessibility-hidden",
      onBlur: this.resetSelectedIndex,
      ref: this.hiddenRef,
      tabIndex: -1,
      "data-testid": "pill-selection-helper"
    }), React.createElement("textarea", _extends({}, ariaAttrs, rest, inputProps, {
      autoComplete: "off",
      className: classNames('bdl-PillSelector-input', 'pill-selector-input', className, {
        'bdl-PillSelector-input--nextLine': isInputFocusedNextLine
      }),
      disabled: disabled || isInputDisabled,
      onInput: onInput,
      placeholder: this.getNumSelected() === 0 ? placeholder : '',
      ref: input => {
        this.inputEl = input;
      }
    })), React.createElement(SuggestedPillsRow, {
      onSuggestedPillAdd: onSuggestedPillAdd,
      selectedPillsValues: this.getPillsByKey('value'),
      suggestedPillsFilter: suggestedPillsFilter,
      suggestedPillsData: suggestedPillsData,
      title: suggestedPillsTitle
    }), React.createElement("span", {
      id: this.errorMessageID,
      className: "accessibility-hidden",
      role: "alert"
    }, error)));
  }

}

_defineProperty(PillSelectorBase, "defaultProps", {
  allowInvalidPills: false,
  disabled: false,
  error: '',
  errorTooltipPosition: 'bottom-left',
  inputProps: {},
  placeholder: '',
  selectedOptions: [],
  validator: () => true
});

export { PillSelectorBase };
const PillSelector = React.forwardRef((props, ref) => React.createElement(PillSelectorBase, _extends({}, props, {
  innerRef: ref
})));
PillSelector.displayName = 'PillSelector';
export default PillSelector;
//# sourceMappingURL=PillSelector.js.map