function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import { List } from 'immutable';
import noop from 'lodash/noop';
import parseCSV from '../../utils/parseCSV';
import Label from '../label';
import SelectorDropdown from '../selector-dropdown';
import PillSelector from './PillSelector';
import './PillSelectorDropdown.scss';

class PillSelectorDropdown extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      inputValue: '',
      isInCompositionMode: false
    });

    _defineProperty(this, "parsePills", inputValue => {
      const {
        allowInvalidPills,
        parseItems,
        validator
      } = this.props;
      let pills = parseItems ? parseItems(inputValue) : parseCSV(inputValue);

      if (!pills) {
        return [];
      }

      if (!allowInvalidPills) {
        pills = pills.filter(pill => validator(pill));
      }

      const normalizedPills = pills.map(pill => typeof pill === 'string' ? {
        displayText: pill,
        text: pill,
        // deprecated, left for backwards compatibility
        value: pill
      } : pill);
      return normalizedPills;
    });

    _defineProperty(this, "addPillsFromInput", inputValue => {
      const {
        allowCustomPills,
        onPillCreate,
        onSelect,
        selectedOptions,
        shouldClearUnmatchedInput,
        validateForError
      } = this.props; // Do nothing if custom pills are not allowed

      if (!allowCustomPills) {
        return;
      } // Parse pills from input


      const pills = this.parsePills(inputValue); // "Select" the pills

      if (pills.length > 0) {
        onSelect(pills);
        onPillCreate(pills);
        this.resetInputValue();
      } else {
        if (validateForError && (inputValue !== '' || selectedOptions.length === 0)) {
          /**
           * If no pills were added, but an inputValue exists or
           * there are no pills selected, check for errors
           */
          validateForError(inputValue);
        }

        if (shouldClearUnmatchedInput) {
          this.resetInputValue();
        }
      }
    });

    _defineProperty(this, "handleBlur", event => {
      const {
        onBlur
      } = this.props;
      const {
        inputValue
      } = this.state;
      this.addPillsFromInput(inputValue);
      onBlur(event);
    });

    _defineProperty(this, "handleInput", event => {
      const {
        target
      } = event;
      const {
        value
      } = target;
      this.setState({
        inputValue: value
      });
      this.props.onInput(value, event);
    });

    _defineProperty(this, "handleEnter", event => {
      const {
        isInCompositionMode,
        inputValue
      } = this.state;

      if (!isInCompositionMode) {
        event.preventDefault();
        this.addPillsFromInput(inputValue);
      }
    });

    _defineProperty(this, "handlePaste", event => {
      event.preventDefault();
      const inputValue = event.clipboardData.getData('text');
      this.setState({
        inputValue
      });
      this.props.onInput(inputValue, event);
      this.addPillsFromInput(inputValue);
    });

    _defineProperty(this, "handleSelect", (index, event) => {
      const {
        onPillCreate,
        onSelect,
        selectorOptions
      } = this.props;
      const selectedOption = // $FlowFixMe
      typeof selectorOptions.get === 'function' ? selectorOptions.get(index) : selectorOptions[index];
      onSelect([selectedOption], event);
      onPillCreate([selectedOption]);
      this.handleInput({
        target: {
          value: ''
        }
      });
    });

    _defineProperty(this, "handleCompositionStart", () => {
      this.setState({
        isInCompositionMode: true
      });
    });

    _defineProperty(this, "handleCompositionEnd", () => {
      this.setState({
        isInCompositionMode: false
      });
    });

    _defineProperty(this, "resetInputValue", () => {
      const {
        onInput
      } = this.props;
      this.setState({
        inputValue: ''
      });
      onInput('');
    });
  }

  render() {
    const {
      allowInvalidPills,
      children,
      className,
      disabled,
      dividerIndex,
      dropdownScrollBoundarySelector,
      error,
      errorTooltipPosition,
      getPillClassName,
      getPillImageUrl,
      inputProps,
      isPositionDynamic,
      label,
      onRemove,
      onSuggestedPillAdd,
      overlayTitle,
      placeholder,
      selectedOptions,
      showAvatars,
      showRoundedPills,
      suggestedPillsData,
      suggestedPillsFilter,
      suggestedPillsTitle,
      shouldSetActiveItemOnOpen,
      validator
    } = this.props;
    const selectorDropdownElement = React.createElement(SelectorDropdown, {
      className: classNames('bdl-PillSelectorDropdown', 'pill-selector-wrapper', className),
      dividerIndex: dividerIndex,
      isPositionDynamic: isPositionDynamic,
      onEnter: this.handleEnter,
      onSelect: this.handleSelect,
      overlayTitle: overlayTitle,
      scrollBoundarySelector: dropdownScrollBoundarySelector,
      shouldSetActiveItemOnOpen: shouldSetActiveItemOnOpen,
      selector: React.createElement(PillSelector, _extends({
        onChange: noop // fix console error
        ,
        onCompositionEnd: this.handleCompositionEnd,
        onCompositionStart: this.handleCompositionStart
      }, inputProps, {
        allowInvalidPills: allowInvalidPills,
        disabled: disabled,
        error: error,
        errorTooltipPosition: errorTooltipPosition,
        getPillClassName: getPillClassName,
        getPillImageUrl: getPillImageUrl,
        onBlur: this.handleBlur,
        onInput: this.handleInput,
        onPaste: this.handlePaste,
        onRemove: onRemove,
        onSuggestedPillAdd: onSuggestedPillAdd,
        placeholder: placeholder,
        selectedOptions: selectedOptions,
        showAvatars: showAvatars && showRoundedPills,
        showRoundedPills: showRoundedPills,
        suggestedPillsData: suggestedPillsData,
        suggestedPillsFilter: suggestedPillsFilter,
        suggestedPillsTitle: suggestedPillsTitle,
        validator: validator,
        value: this.state.inputValue
      }))
    }, children);
    return label ? React.createElement(Label, {
      text: label
    }, selectorDropdownElement) : selectorDropdownElement;
  }

}

_defineProperty(PillSelectorDropdown, "defaultProps", {
  allowCustomPills: false,
  allowInvalidPills: false,
  disabled: false,
  error: '',
  inputProps: {},
  label: '',
  onBlur: noop,
  onPillCreate: noop,
  placeholder: '',
  selectedOptions: [],
  selectorOptions: [],
  shouldClearUnmatchedInput: false,
  shouldSetActiveItemOnOpen: false,
  validator: () => true
});

export default PillSelectorDropdown;
//# sourceMappingURL=PillSelectorDropdown.js.map