function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import uniqueId from 'lodash/uniqueId';
import TetherComponent from 'react-tether';
import './RadarAnimation.scss';
export let RadarAnimationPosition;

(function (RadarAnimationPosition) {
  RadarAnimationPosition["BOTTOM_CENTER"] = "bottom-center";
  RadarAnimationPosition["BOTTOM_LEFT"] = "bottom-left";
  RadarAnimationPosition["BOTTOM_RIGHT"] = "bottom-right";
  RadarAnimationPosition["MIDDLE_CENTER"] = "middle-center";
  RadarAnimationPosition["MIDDLE_LEFT"] = "middle-left";
  RadarAnimationPosition["MIDDLE_RIGHT"] = "middle-right";
  RadarAnimationPosition["TOP_CENTER"] = "top-center";
  RadarAnimationPosition["TOP_LEFT"] = "top-left";
  RadarAnimationPosition["TOP_RIGHT"] = "top-right";
})(RadarAnimationPosition || (RadarAnimationPosition = {}));

const positions = {
  [RadarAnimationPosition.BOTTOM_CENTER]: {
    attachment: 'top center',
    targetAttachment: 'bottom center'
  },
  [RadarAnimationPosition.BOTTOM_LEFT]: {
    attachment: 'top left',
    targetAttachment: 'bottom left'
  },
  [RadarAnimationPosition.BOTTOM_RIGHT]: {
    attachment: 'top right',
    targetAttachment: 'bottom right'
  },
  [RadarAnimationPosition.MIDDLE_CENTER]: {
    attachment: 'middle center',
    targetAttachment: 'middle center'
  },
  [RadarAnimationPosition.MIDDLE_LEFT]: {
    attachment: 'middle right',
    targetAttachment: 'middle left'
  },
  [RadarAnimationPosition.MIDDLE_RIGHT]: {
    attachment: 'middle left',
    targetAttachment: 'middle right'
  },
  [RadarAnimationPosition.TOP_CENTER]: {
    attachment: 'bottom center',
    targetAttachment: 'top center'
  },
  [RadarAnimationPosition.TOP_LEFT]: {
    attachment: 'bottom left',
    targetAttachment: 'top left'
  },
  [RadarAnimationPosition.TOP_RIGHT]: {
    attachment: 'bottom right',
    targetAttachment: 'top right'
  }
};

class RadarAnimation extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "tetherRef", React.createRef());

    _defineProperty(this, "radarAnimationID", uniqueId('radarAnimation'));

    _defineProperty(this, "position", () => {
      const {
        isShown
      } = this.props;

      if (this.tetherRef.current && isShown) {
        this.tetherRef.current.position();
      }
    });
  }

  render() {
    const _this$props = this.props,
          {
      children,
      className = '',
      constrainToScrollParent,
      constrainToWindow,
      position,
      isShown,
      offset,
      tetherElementClassName
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["children", "className", "constrainToScrollParent", "constrainToWindow", "position", "isShown", "offset", "tetherElementClassName"]);

    const constraints = [];

    if (constrainToScrollParent) {
      constraints.push({
        to: 'scrollParent',
        attachment: 'together'
      });
    }

    if (constrainToWindow) {
      constraints.push({
        to: 'window',
        attachment: 'together'
      });
    }

    const {
      attachment,
      targetAttachment
    } = positions[position];
    const child = React.Children.only(children);
    const referenceElement = React.cloneElement(child, {
      'aria-describedby': this.radarAnimationID
    }); // Typescript defs seem busted for older versions of react-tether

    const tetherProps = {
      attachment,
      classPrefix: 'radar-animation',
      constraints,
      targetAttachment
    };

    if (tetherElementClassName) {
      tetherProps.className = tetherElementClassName;
    }

    if (offset) {
      tetherProps.offset = offset;
    }

    return React.createElement(TetherComponent, _extends({
      ref: this.tetherRef
    }, tetherProps), referenceElement, isShown && React.createElement("div", _extends({
      className: "radar ".concat(className),
      id: this.radarAnimationID
    }, rest), React.createElement("div", {
      className: "radar-dot"
    }), React.createElement("div", {
      className: "radar-circle"
    })));
  }

}

_defineProperty(RadarAnimation, "defaultProps", {
  constrainToScrollParent: false,
  constrainToWindow: true,
  isShown: true,
  position: RadarAnimationPosition.MIDDLE_RIGHT
});

export default RadarAnimation;
//# sourceMappingURL=RadarAnimation.js.map