function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import noop from 'lodash/noop';
import throttle from 'lodash/throttle';
import './ScrollWrapper.scss';

class ScrollWrapper extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "state", {
      shouldShowTopScrollShadow: false,
      shouldShowBottomScrollShadow: false
    });

    _defineProperty(this, "componentDidMount", () => {
      const newState = this.getScrollShadowState();
      this.setState(newState);

      if (this.scrollRef) {
        this.scrollRef.addEventListener('transitionend', this.throttledOnContentScroll); // Apparently, flow only allows for one truthy check per command, so I have to either:
        // 1) duplicate this check per call, or
        // 2) nest if checks (_slightly more performant_)

        if (this.scrollRef) {
          this.observer.observe(this.scrollRef, {
            attributes: true,
            childlist: true,
            subtree: true
          });
        }
      }
    });

    _defineProperty(this, "onContentScroll", () => {
      const newState = this.getScrollShadowState();
      this.setState(newState);
    });

    _defineProperty(this, "getScrollShadowState", () => {
      const {
        scrollTop,
        scrollHeight,
        clientHeight
      } = this.scrollRef || {};
      const newState = {};

      if (scrollTop > 0 && scrollTop < scrollHeight - clientHeight) {
        newState.shouldShowTopScrollShadow = true;
        newState.shouldShowBottomScrollShadow = true;
      }

      if (scrollTop === 0) {
        newState.shouldShowTopScrollShadow = false;
      }

      if (scrollTop < scrollHeight - clientHeight) {
        newState.shouldShowBottomScrollShadow = true;
      }

      if (scrollTop === scrollHeight - clientHeight) {
        newState.shouldShowBottomScrollShadow = false;
      }

      return newState;
    });

    _defineProperty(this, "scrollRef", null);

    _defineProperty(this, "throttledOnContentScroll", throttle(this.onContentScroll, 100));

    this.observer = new MutationObserver(this.throttledOnContentScroll);
  }

  componentWillUnmount() {
    this.observer.disconnect();

    if (this.scrollRef) {
      this.scrollRef.removeEventListener('transitionend', this.throttledOnContentScroll);
    }
  }

  render() {
    const _this$props = this.props,
          {
      children,
      className = '',
      scrollRefFn,
      shadowSize
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["children", "className", "scrollRefFn", "shadowSize"]);

    const {
      shouldShowTopScrollShadow,
      shouldShowBottomScrollShadow
    } = this.state;
    const classes = classNames("scroll-container", className, {
      'is-showing-top-shadow': shouldShowTopScrollShadow,
      'is-showing-bottom-shadow': shouldShowBottomScrollShadow
    });
    return React.createElement("div", _extends({
      className: classes
    }, rest), React.createElement("div", {
      className: classNames('scroll-wrap-container', "style--".concat(shadowSize)),
      onScroll: this.throttledOnContentScroll,
      ref: el => {
        this.scrollRef = el;
        scrollRefFn(el);
      }
    }, children));
  }

}

_defineProperty(ScrollWrapper, "defaultProps", {
  scrollRefFn: noop,
  shadowSize: 'cover'
});

export default ScrollWrapper;
//# sourceMappingURL=ScrollWrapper.js.map