function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { injectIntl } from 'react-intl';
import classNames from 'classnames';
import omit from 'lodash/omit'; // $FlowFixMe

import SearchActions from './SearchActions'; // $FlowFixMe

import messages from './messages';
import './SearchForm.scss';

class SearchFormBase extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isEmpty: true
    });

    _defineProperty(this, "onClearHandler", event => {
      const {
        onChange,
        shouldPreventClearEventPropagation
      } = this.props;

      if (shouldPreventClearEventPropagation) {
        event.stopPropagation();
      }

      if (this.searchInput) {
        this.searchInput.value = '';
      }

      this.setState({
        isEmpty: true
      });

      if (onChange) {
        onChange('');
      }
    });

    _defineProperty(this, "onChangeHandler", (_ref) => {
      let {
        target
      } = _ref;
      const {
        value
      } = target;
      const {
        onChange
      } = this.props;
      this.setState({
        isEmpty: !value || !value.trim().length
      });

      if (onChange) {
        onChange(value);
      }
    });

    _defineProperty(this, "onSubmitHandler", event => {
      const {
        value
      } = event.target.elements[0];
      const {
        onSubmit
      } = this.props;

      if (onSubmit) {
        onSubmit(value, event);
      }
    });

    _defineProperty(this, "setInputRef", element => {
      this.searchInput = element;

      if (this.props.getSearchInput) {
        this.props.getSearchInput(this.searchInput);
      }
    });
  }

  static getDerivedStateFromProps(props) {
    const {
      value
    } = props;

    if (value && !!value.trim()) {
      return {
        isEmpty: true
      };
    }

    return null;
  }

  render() {
    const _this$props = this.props,
          {
      action,
      className,
      innerRef,
      intl,
      isLoading,
      method,
      name,
      queryParams,
      onSubmit,
      useClearButton
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["action", "className", "innerRef", "intl", "isLoading", "method", "name", "queryParams", "onSubmit", "useClearButton"]);

    const {
      isEmpty
    } = this.state;
    const inputProps = omit(rest, ['getSearchInput', 'onChange', 'onSubmit', 'required', 'shouldPreventClearEventPropagation']);
    const {
      formatMessage
    } = intl;
    const classes = classNames(className, 'search-input-container');
    const formClassNames = classNames('search-form', {
      'is-empty': isEmpty,
      'use-clear-button': useClearButton
    });
    const hiddenInputs = Object.keys(queryParams).map((param, index) => React.createElement("input", {
      key: index,
      name: param,
      type: "hidden",
      value: queryParams[param]
    })); // @NOTE Prevent errors from React about controlled inputs

    const onChangeStub = () => {};

    return React.createElement("div", {
      ref: innerRef,
      className: classes
    }, React.createElement("form", {
      action: action,
      className: formClassNames,
      method: method,
      onChange: this.onChangeHandler,
      onSubmit: this.onSubmitHandler,
      role: "search"
    }, React.createElement("input", _extends({
      ref: this.setInputRef,
      "aria-label": formatMessage(messages.searchLabel),
      autoComplete: "off",
      className: "search-input",
      name: name,
      onChange: onChangeStub,
      type: "search"
    }, inputProps)), React.createElement(SearchActions, {
      hasSubmitAction: !!onSubmit,
      isLoading: isLoading,
      loadingIndicatorProps: {
        className: 'search-form-loading-indicator'
      },
      onClear: this.onClearHandler
    }), hiddenInputs));
  }

}

_defineProperty(SearchFormBase, "defaultProps", {
  action: '',
  method: 'get',
  name: 'search',
  queryParams: {},
  useClearButton: false
});

const SearchFormBaseIntl = injectIntl(SearchFormBase);
export { SearchFormBaseIntl };
const SearchForm = React.forwardRef((props, ref) => React.createElement(SearchFormBaseIntl, _extends({}, props, {
  innerRef: ref
})));
SearchForm.displayName = 'SearchForm';
export default SearchForm;
//# sourceMappingURL=SearchForm.js.map