function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import range from 'lodash/range';
import * as React from 'react';
import SlideButton from './SlideButton';

class SlideNavigator extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "buttonElements", []);

    _defineProperty(this, "focusOnButtonElement", index => {
      if (index + 1 > this.buttonElements.length || index < 0) {
        return;
      }

      this.buttonElements[index].focus();
    });

    _defineProperty(this, "handleKeyDown", event => {
      const {
        numOptions,
        selectedIndex
      } = this.props;
      let nextIndex = null;

      switch (event.key) {
        case 'ArrowRight':
          nextIndex = (selectedIndex + 1) % numOptions;
          break;

        case 'ArrowLeft':
          nextIndex = (selectedIndex - 1 + numOptions) % numOptions;
          break;

        default:
          return;
      }

      this.handleSelection(nextIndex);
      event.preventDefault();
      event.stopPropagation();
    });

    _defineProperty(this, "handleSelection", index => {
      this.focusOnButtonElement(index);
      this.props.onSelection(index);
    });
  }

  render() {
    const {
      getButtonIdFromValue,
      getPanelIdFromValue,
      numOptions,
      onSelection,
      selectedIndex
    } = this.props;
    return React.createElement("nav", {
      className: "slide-navigator"
      /* eslint-disable jsx-a11y/no-noninteractive-element-to-interactive-role */
      ,
      onKeyDown: this.handleKeyDown,
      role: "tablist"
    }, range(numOptions).map((child, i) => React.createElement(SlideButton, {
      key: i,
      "aria-controls": getPanelIdFromValue(i),
      "aria-label": "slide".concat(i),
      buttonRef: buttonEl => {
        this.buttonElements[i] = buttonEl;
      },
      id: getButtonIdFromValue(i),
      isSelected: i === selectedIndex,
      onClick: () => onSelection(i),
      tabIndex: i === selectedIndex ? '0' : '-1'
    })));
  }

}

export default SlideNavigator;
//# sourceMappingURL=SlideNavigator.js.map