function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import TabViewPrimitive, { TAB_KEY, TAB_PANEL_ROLE } from './TabViewPrimitive';

class TabView extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "getActiveDocElement", () => document.activeElement);

    _defineProperty(this, "resetActiveTab", () => {
      this.setState({
        focusedIndex: this.props.defaultSelectedIndex,
        selectedIndex: this.props.defaultSelectedIndex
      });
    });

    _defineProperty(this, "resetFocusedTab", () => {
      this.setState({
        focusedIndex: this.state.selectedIndex
      });
    });

    _defineProperty(this, "handleOnTabSelect", selectedIndex => this.setState({
      selectedIndex
    }, () => {
      const {
        onTabSelect
      } = this.props;

      if (onTabSelect) {
        onTabSelect(this.state.selectedIndex);
      }
    }));

    _defineProperty(this, "handleOnTabFocus", index => this.setState({
      focusedIndex: index
    }));

    _defineProperty(this, "handleKeyUp", event => {
      const activeElement = this.getActiveDocElement();
      const isTabPanelFocused = activeElement && activeElement.getAttribute('role') === TAB_PANEL_ROLE;
      const isTabPanelFocusedWithTabKey = isTabPanelFocused && event.key === TAB_KEY;

      if (isTabPanelFocusedWithTabKey) {
        this.setState({
          showOutline: true
        });
      } else if (!isTabPanelFocused && this.state.showOutline) {
        this.setState({
          showOutline: false
        });
      }
    });

    this.state = {
      focusedIndex: props.defaultSelectedIndex,
      showOutline: false,
      selectedIndex: props.defaultSelectedIndex
    };
  }

  componentDidUpdate(prevProps) {
    const {
      defaultSelectedIndex
    } = this.props;

    if (prevProps.defaultSelectedIndex !== defaultSelectedIndex) {
      this.resetActiveTab();
    }
  }

  render() {
    const {
      children,
      className,
      isDynamic
    } = this.props;
    const {
      focusedIndex,
      selectedIndex,
      showOutline
    } = this.state;
    return React.createElement(TabViewPrimitive, {
      className: classNames(className, {
        'show-outline': showOutline
      }),
      focusedIndex: focusedIndex,
      isDynamic: isDynamic,
      onKeyUp: this.handleKeyUp,
      onTabFocus: this.handleOnTabFocus,
      onTabSelect: this.handleOnTabSelect,
      resetActiveTab: this.resetActiveTab,
      resetFocusedTab: this.resetFocusedTab,
      selectedIndex: selectedIndex
    }, children);
  }

}

_defineProperty(TabView, "defaultProps", {
  defaultSelectedIndex: 0,
  isDynamic: false
});

export default TabView;
//# sourceMappingURL=TabView.js.map