function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import uniqueId from 'lodash/uniqueId';
import IconPageBack from '../../icons/general/IconPageBack';
import IconPageForward from '../../icons/general/IconPageForward';
import LinkButton from '../link/LinkButton';
import './Tabs.scss';
export const TAB_KEY = 'Tab';
export const TAB_PANEL_ROLE = 'tabpanel';

class TabViewPrimitive extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "onClickTab", tabIndex => {
      const {
        onTabFocus,
        onTabSelect
      } = this.props;

      if (onTabSelect) {
        onTabSelect(tabIndex);
      }

      onTabFocus(tabIndex);
    });

    _defineProperty(this, "getLastElementsAnchorPoint", () => {
      if (this.tabsElements.length === 0) {
        return 0;
      }

      const lastTabElement = this.tabsElements[this.tabsElements.length - 1];
      return lastTabElement.offsetLeft + lastTabElement.offsetWidth;
    });

    _defineProperty(this, "getTabsContainerOffsetLeft", () => {
      if (!this.tabsContainer) {
        return 0;
      }

      const {
        tabsContainerOffsetLeft
      } = this.state;
      let viewportOffset = parseInt(tabsContainerOffsetLeft, 10) * -1;
      viewportOffset = viewportOffset || 0;
      return viewportOffset;
    });

    _defineProperty(this, "getTabsContainerWidth", () => this.tabsContainer ? parseInt(this.tabsContainer.offsetWidth, 10) : 0);

    _defineProperty(this, "scrollToTab", tabIndex => {
      if (!this.props.isDynamic || this.tabsContainer === null || this.tabsElements.length === 0 || tabIndex < 0 || tabIndex > this.tabsElements.length - 1) {
        return;
      }

      const tabElementOfInterest = this.tabsElements[tabIndex];
      const lastElementsAnchorPoint = this.getLastElementsAnchorPoint(); // if tabs don't overflow at all, no need to scroll

      const tabsContainerWidth = this.getTabsContainerWidth();

      if (lastElementsAnchorPoint <= tabsContainerWidth) {
        this.setState({
          tabsContainerOffsetLeft: 0
        });
        return;
      } // do not scroll any more if we will go past the rightmost anchor


      const newOffset = Math.min(lastElementsAnchorPoint - tabsContainerWidth, tabElementOfInterest.offsetLeft); // move the viewport

      const newViewportOffset = -1 * newOffset;
      this.setState({
        tabsContainerOffsetLeft: newViewportOffset
      });
    });

    _defineProperty(this, "isRightArrowVisible", () => {
      if (!this.tabsContainer) {
        return false;
      }

      const tabsContainerOffsetLeft = this.getTabsContainerOffsetLeft();
      const lastElementsAnchorPoint = this.getLastElementsAnchorPoint();
      const tabsContainerWidth = this.getTabsContainerWidth();
      return tabsContainerOffsetLeft + tabsContainerWidth < lastElementsAnchorPoint;
    });

    _defineProperty(this, "isLeftArrowVisible", () => {
      const {
        focusedIndex,
        selectedIndex
      } = this.props;
      const tabsContainerOffsetLeft = this.getTabsContainerOffsetLeft();
      return tabsContainerOffsetLeft !== 0 && (selectedIndex !== 0 || focusedIndex !== 0);
    });

    _defineProperty(this, "focusOnTabElement", focusedIndex => {
      if (focusedIndex + 1 > this.tabsElements.length || focusedIndex < 0) {
        return;
      }

      this.tabsElements[focusedIndex].focus();
    });

    _defineProperty(this, "tabsElements", []);

    _defineProperty(this, "tabsContainer", null);

    _defineProperty(this, "handleKeyDown", event => {
      const {
        children,
        focusedIndex,
        onTabFocus,
        resetFocusedTab,
        resetActiveTab
      } = this.props;
      const childrenCount = React.Children.count(children);

      switch (event.key) {
        case 'ArrowRight':
          onTabFocus(this.calculateNextIndex(focusedIndex, childrenCount));
          event.preventDefault();
          event.stopPropagation();
          break;

        case 'ArrowLeft':
          onTabFocus(this.calculatePrevIndex(focusedIndex, childrenCount));
          event.preventDefault();
          event.stopPropagation();
          break;

        case 'Escape':
          resetActiveTab();
          break;

        case TAB_KEY:
          resetFocusedTab();
          break;

        default:
          break;
      }
    });

    _defineProperty(this, "calculateNextIndex", (currentIndex, childrenCount) => (currentIndex + 1) % childrenCount);

    _defineProperty(this, "calculatePrevIndex", (currentIndex, childrenCount) => (currentIndex - 1 + childrenCount) % childrenCount);

    this.tabviewID = uniqueId('tabview');
    this.state = {
      tabsContainerOffsetLeft: 0
    };
  }

  componentDidMount() {
    const {
      isDynamic,
      focusedIndex
    } = this.props;

    if (isDynamic) {
      // set initial tabsContainerOffsetLeft state after first mounting
      this.scrollToTab(focusedIndex);
    }
  }

  componentDidUpdate(prevProps) {
    const {
      focusedIndex: prevFocusedIndex,
      selectedIndex: prevSelectedIndex
    } = prevProps;
    const {
      focusedIndex,
      selectedIndex
    } = this.props;

    if (this.props.isDynamic) {
      if (prevFocusedIndex !== focusedIndex) {
        this.scrollToTab(focusedIndex);
      } // update tabsContainerOffsetLeft state when receiving a new prop


      if (prevSelectedIndex !== selectedIndex) {
        this.scrollToTab(selectedIndex);
      }
    }

    if (prevFocusedIndex !== focusedIndex) {
      // have to focus after render otherwise, the focus will be lost
      this.focusOnTabElement(focusedIndex);
    }
  }

  /* eslint-disable jsx-a11y/no-noninteractive-element-to-interactive-role */
  renderTabs() {
    const {
      children,
      selectedIndex,
      isDynamic
    } = this.props;
    const {
      tabsContainerOffsetLeft
    } = this.state;
    const style = isDynamic ? {
      left: "".concat(tabsContainerOffsetLeft, "px")
    } : {};
    return React.createElement("div", {
      className: "tabs",
      role: "tablist",
      tabIndex: "0",
      ref: _ref2 => {
        this.tabsContainer = _ref2;
      },
      style: style,
      onKeyDown: !isDynamic ? this.handleKeyDown : null
    }, React.Children.map(children, (tab, i) => {
      const buttonProps = omit(tab.props, ['className', 'children', 'title']);
      const classes = classNames('btn-plain', 'tab', i === selectedIndex ? 'is-selected' : '');
      const ariaControls = "".concat(this.tabviewID, "-panel-").concat(i + 1);
      const ariaSelected = i === selectedIndex;
      const id = "".concat(this.tabviewID, "-tab-").concat(i + 1);
      const {
        href,
        component,
        refProp
      } = tab.props;
      const tabIndex = i === selectedIndex ? '0' : '-1';

      if (href) {
        return React.createElement(LinkButton, {
          className: classes,
          "aria-controls": ariaControls,
          "aria-selected": ariaSelected,
          id: id,
          role: "tab",
          href: href,
          linkRef: ref => {
            this.tabsElements[i] = ref;
          },
          refProp: refProp,
          tabIndex: tabIndex,
          to: href,
          component: component
        }, React.createElement("div", {
          className: "tab-title"
        }, tab.props.title), React.createElement("div", {
          className: "tab-underline"
        }));
      }

      return React.createElement("button", _extends({
        className: classes,
        "aria-controls": ariaControls,
        "aria-selected": ariaSelected,
        onClick: () => this.onClickTab(i),
        role: "tab",
        type: "button",
        id: id,
        ref: _ref => {
          this.tabsElements[i] = _ref;
        },
        tabIndex: tabIndex
      }, buttonProps), React.createElement("div", {
        className: "tab-title"
      }, tab.props.title), React.createElement("div", {
        className: "tab-underline"
      }));
    }));
  }
  /* eslint-enable jsx-a11y/no-noninteractive-element-to-interactive-role */


  renderDynamicTabs() {
    const {
      onTabFocus,
      focusedIndex
    } = this.props;
    return (// eslint-disable-next-line jsx-a11y/no-static-element-interactions
      React.createElement("div", {
        className: "dynamic-tabs-bar",
        onKeyDown: this.handleKeyDown
      }, React.createElement("button", {
        className: classNames('btn-plain svg-container left-arrow', {
          hidden: !this.isLeftArrowVisible()
        }),
        onClick: () => onTabFocus(focusedIndex - 1),
        type: "button",
        tabIndex: "-1"
      }, React.createElement(IconPageBack, null)), React.createElement("div", {
        className: "dynamic-tabs-wrapper"
      }, this.renderTabs()), React.createElement("button", {
        className: classNames('btn-plain svg-container right-arrow', {
          hidden: !this.isRightArrowVisible()
        }),
        onClick: () => onTabFocus(focusedIndex + 1),
        type: "button",
        tabIndex: "-1"
      }, React.createElement(IconPageForward, null)))
    );
  }

  render() {
    const {
      children,
      className = '',
      isDynamic = false,
      onKeyUp,
      selectedIndex
    } = this.props;
    return (// eslint-disable-next-line jsx-a11y/no-static-element-interactions
      React.createElement("div", {
        className: "tab-view ".concat(classNames(className, {
          'dynamic-tabs': isDynamic
        })),
        onKeyUp: onKeyUp
      }, !isDynamic ? this.renderTabs() : this.renderDynamicTabs(), React.createElement("div", {
        className: "tab-panels"
      }, React.Children.toArray(children).map((child, i) => React.createElement("div", {
        key: i,
        id: "".concat(this.tabviewID, "-panel-").concat(i),
        "aria-labelledby": "".concat(this.tabviewID, "-tab-").concat(i + 1),
        "aria-hidden": selectedIndex !== i,
        className: "tab-panel ".concat(i === selectedIndex ? 'is-selected' : ''),
        role: TAB_PANEL_ROLE
      }, child.props.children))))
    );
  }

}

export default TabViewPrimitive;
//# sourceMappingURL=TabViewPrimitive.js.map