function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import { FormattedMessage } from 'react-intl';
import messages from '../../common/messages';
import TextInput from '../text-input';
import Button from '../button';
import './TextInputWithCopyButton.scss';
const DEFAULT_SUCCESS_STATE_DURATION = 3000;
const defaultCopyText = React.createElement(FormattedMessage, messages.copy);
const defaultCopiedText = React.createElement(FormattedMessage, messages.copied);

class TextInputWithCopyButton extends React.PureComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "copySelectedText", () => document.execCommand('copy'));

    _defineProperty(this, "restoreCopyButton", () => {
      this.setState({
        copySuccess: false,
        buttonText: this.props.buttonDefaultText
      });
    });

    _defineProperty(this, "handleCopyButtonClick", () => {
      this.performAutofocus();
      this.copySelectedText();
      this.animateCopyButton();
    });

    _defineProperty(this, "handleFocus", event => {
      if (this.copyInputRef) {
        this.performAutofocus();
      }

      if (this.props.onFocus) {
        this.props.onFocus(event);
      }
    });

    _defineProperty(this, "handleCopyEvent", event => {
      const {
        disabled,
        onCopySuccess
      } = this.props;

      if (disabled) {
        event.preventDefault();
      } else {
        this.animateCopyButton();

        if (onCopySuccess) {
          onCopySuccess(event);
        }
      }
    });

    _defineProperty(this, "performAutofocus", () => {
      const {
        copyInputRef
      } = this;

      if (copyInputRef) {
        copyInputRef.select();
        copyInputRef.scrollLeft = 0;
      }
    });

    _defineProperty(this, "renderCopyButton", () => this.isCopyCommandSupported ? React.createElement(Button, _extends({
      isDisabled: this.props.disabled,
      onClick: this.handleCopyButtonClick,
      type: "button"
    }, this.props.buttonProps), this.state.buttonText) : null);

    this.isCopyCommandSupported = document.queryCommandSupported('copy');
    this.state = {
      copySuccess: false,
      buttonText: props.buttonDefaultText,
      hasFocused: false
    };
  }

  componentDidMount() {
    const {
      autofocus,
      value
    } = this.props;

    if (autofocus && value) {
      this.performAutofocus();
    }
  }

  componentDidUpdate() {
    const {
      autofocus,
      value,
      triggerCopyOnLoad
    } = this.props;
    const {
      copySuccess,
      hasFocused
    } = this.state; // if we've set focus before, and should auto focus on update, make sure to
    // focus after component update

    if (autofocus && value) {
      this.performAutofocus();
    }

    if (triggerCopyOnLoad && !copySuccess && !hasFocused) {
      this.animateCopyButton();
    }
  }

  componentWillUnmount() {
    this.clearCopySuccessTimeout();
  }

  animateCopyButton() {
    const {
      successStateDuration,
      buttonSuccessText
    } = this.props;
    this.clearCopySuccessTimeout();
    this.setState({
      copySuccess: true,
      buttonText: buttonSuccessText,
      hasFocused: true
    }, () => {
      this.copySuccessTimeout = setTimeout(() => {
        this.restoreCopyButton();
      }, successStateDuration);
    });
  }

  clearCopySuccessTimeout() {
    if (!this.copySuccessTimeout) {
      return;
    }

    clearTimeout(this.copySuccessTimeout);
    this.copySuccessTimeout = null;
  }

  render() {
    const _this$props = this.props,
          {
      additionalButtons,
      className
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["additionalButtons", "className"]);

    const {
      copySuccess
    } = this.state;
    const {
      isCopyCommandSupported
    } = this;
    const inputProps = omit(rest, ['autofocus', 'buttonDefaultText', 'buttonSuccessText', 'buttonProps', 'onCopySuccess', 'successStateDuration', 'triggerCopyOnLoad']);

    if (isCopyCommandSupported) {
      inputProps.inputRef = ref => {
        this.copyInputRef = ref;
      };
    }

    const wrapperClasses = classNames(className, {
      'copy-success': copySuccess,
      'text-input-with-copy-button-container': isCopyCommandSupported
    });
    const copyEvent = isCopyCommandSupported ? {
      onCopy: this.handleCopyEvent
    } : {};
    return React.createElement("div", _extends({
      className: wrapperClasses
    }, copyEvent), React.createElement(TextInput, _extends({}, inputProps, {
      onFocus: this.handleFocus
    })), additionalButtons, this.renderCopyButton());
  }

}

_defineProperty(TextInputWithCopyButton, "defaultProps", {
  buttonDefaultText: defaultCopyText,
  buttonProps: {},
  buttonSuccessText: defaultCopiedText,
  className: '',
  hideOptionalLabel: true,
  readOnly: true,
  successStateDuration: DEFAULT_SUCCESS_STATE_DURATION,
  type: 'text'
});

export default TextInputWithCopyButton;
//# sourceMappingURL=TextInputWithCopyButton.js.map