function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import getProp from 'lodash/get';
import { generatePath, matchPath } from 'react-router-dom';
import AnnotatorContext from './AnnotatorContext';
import { Action, Status } from './types';
const ANNOTATIONS_PATH = '/:sidebar/annotations/:fileVersionId/:annotationId?';
const defaultState = {
  action: null,
  activeAnnotationFileVersionId: null,
  activeAnnotationId: null,
  annotation: null,
  annotationReply: null,
  error: null,
  meta: null
};
export default function withAnnotations(WrappedComponent) {
  class ComponentWithAnnotations extends React.Component {
    constructor(props) {
      var _this;

      super(props);
      _this = this;

      _defineProperty(this, "annotator", null);

      _defineProperty(this, "emitActiveAnnotationChangeEvent", id => {
        const {
          annotator
        } = this;

        if (!annotator) {
          return;
        }

        annotator.emit('annotations_active_set', id);
      });

      _defineProperty(this, "emitAnnotationRemoveEvent", function (id) {
        let isStartEvent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
        const {
          annotator
        } = _this;

        if (!annotator) {
          return;
        } // Event name does not include "sidebar" namespace because of backwards compatibility with Preview


        const event = isStartEvent ? 'annotations_remove_start' : 'annotations_remove';
        annotator.emit(event, id);
      });

      _defineProperty(this, "emitAnnotationUpdateEvent", function (annotation) {
        let isStartEvent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
        const {
          annotator
        } = _this;

        if (!annotator) {
          return;
        }

        const event = isStartEvent ? 'sidebar.annotations_update_start' : 'sidebar.annotations_update';
        annotator.emit(event, annotation);
      });

      _defineProperty(this, "emitAnnotationReplyCreateEvent", function (reply, requestId, annotationId) {
        let isStartEvent = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
        const {
          annotator
        } = _this;

        if (!annotator) {
          return;
        }

        const event = isStartEvent ? 'sidebar.annotations_reply_create_start' : 'sidebar.annotations_reply_create';
        annotator.emit(event, {
          annotationId,
          reply,
          requestId
        });
      });

      _defineProperty(this, "emitAnnotationReplyDeleteEvent", function (id, annotationId) {
        let isStartEvent = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
        const {
          annotator
        } = _this;

        if (!annotator) {
          return;
        }

        const event = isStartEvent ? 'sidebar.annotations_reply_delete_start' : 'sidebar.annotations_reply_delete';
        annotator.emit(event, {
          annotationId,
          id
        });
      });

      _defineProperty(this, "emitAnnotationReplyUpdateEvent", function (reply, annotationId) {
        let isStartEvent = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
        const {
          annotator
        } = _this;

        if (!annotator) {
          return;
        }

        const event = isStartEvent ? 'sidebar.annotations_reply_update_start' : 'sidebar.annotations_reply_update';
        annotator.emit(event, {
          annotationId,
          reply
        });
      });

      _defineProperty(this, "handleAnnotationCreate", eventData => {
        const {
          annotation = null,
          error = null,
          meta = null
        } = eventData;
        const {
          onError
        } = this.props;

        if (onError && error) {
          onError(error, 'create_annotation_error', {
            showNotification: true
          });
        }

        this.setState(_objectSpread({}, this.state, {
          action: this.getAction(eventData),
          annotation,
          error,
          meta
        }));
      });

      _defineProperty(this, "handleAnnotationDelete", eventData => {
        const {
          annotation = null,
          error = null,
          meta = null
        } = eventData;
        this.setState({
          action: this.getDeleteAction(eventData),
          annotation,
          error,
          meta
        });
      });

      _defineProperty(this, "handleAnnotationUpdate", eventData => {
        const {
          annotation = null,
          error = null,
          meta = null
        } = eventData;
        this.setState({
          action: this.getUpdateAction(eventData),
          annotation,
          error,
          meta
        });
      });

      _defineProperty(this, "handleAnnotationReplyCreate", eventData => {
        const {
          annotation = null,
          annotationReply = null,
          error = null,
          meta = null
        } = eventData;
        this.setState({
          action: this.getReplyCreateAction(eventData),
          annotation,
          annotationReply,
          error,
          meta
        });
      });

      _defineProperty(this, "handleAnnotationReplyDelete", eventData => {
        const {
          annotation = null,
          annotationReply = null,
          error = null,
          meta = null
        } = eventData;
        this.setState({
          action: this.getReplyDeleteAction(eventData),
          annotation,
          annotationReply,
          error,
          meta
        });
      });

      _defineProperty(this, "handleAnnotationReplyUpdate", eventData => {
        const {
          annotation = null,
          annotationReply = null,
          error = null,
          meta = null
        } = eventData;
        this.setState({
          action: this.getReplyUpdateAction(eventData),
          annotation,
          annotationReply,
          error,
          meta
        });
      });

      _defineProperty(this, "handleActiveChange", (_ref) => {
        let {
          annotationId,
          fileVersionId
        } = _ref;
        this.setState({
          activeAnnotationFileVersionId: fileVersionId,
          activeAnnotationId: annotationId
        });
      });

      _defineProperty(this, "handleAnnotationFetchError", (_ref2) => {
        let {
          error
        } = _ref2;
        const {
          onError
        } = this.props;

        if (onError && error) {
          onError(error, 'fetch_annotations_error', {
            showNotification: true
          });
        }
      });

      _defineProperty(this, "handleAnnotator", annotator => {
        this.annotator = annotator;
        this.annotator.addListener('annotations_active_change', this.handleActiveChange);
        this.annotator.addListener('annotations_create', this.handleAnnotationCreate);
        this.annotator.addListener('annotations_delete', this.handleAnnotationDelete);
        this.annotator.addListener('annotations_fetch_error', this.handleAnnotationFetchError);
        this.annotator.addListener('annotations_update', this.handleAnnotationUpdate);
        this.annotator.addListener('annotations_reply_create', this.handleAnnotationReplyCreate);
        this.annotator.addListener('annotations_reply_delete', this.handleAnnotationReplyDelete);
        this.annotator.addListener('annotations_reply_update', this.handleAnnotationReplyUpdate);
      });

      _defineProperty(this, "handlePreviewDestroy", function () {
        let shouldReset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

        if (shouldReset) {
          _this.setState(defaultState);
        }

        if (_this.annotator) {
          _this.annotator.removeListener('annotations_active_change', _this.handleActiveChange);

          _this.annotator.removeListener('annotations_create', _this.handleAnnotationCreate);

          _this.annotator.removeListener('annotations_delete', _this.handleAnnotationDelete);

          _this.annotator.removeListener('annotations_fetch_error', _this.handleAnnotationFetchError);

          _this.annotator.removeListener('annotations_update', _this.handleAnnotationUpdate);

          _this.annotator.removeListener('annotations_reply_create', _this.handleAnnotationReplyCreate);

          _this.annotator.removeListener('annotations_reply_delete', _this.handleAnnotationReplyDelete);

          _this.annotator.removeListener('annotations_reply_update', _this.handleAnnotationReplyUpdate);
        }

        _this.annotator = null;
      });

      // Determine by url if there is already a deeply linked annotation
      const {
        location
      } = props;
      const match = this.getMatchPath(location);
      const activeAnnotationId = getProp(match, 'params.annotationId', null); // Seed the initial state with the activeAnnotationId if any from the location path

      this.state = _objectSpread({}, defaultState, {
        activeAnnotationId
      });
    }

    getAction(_ref3) {
      let {
        meta: {
          status
        },
        error
      } = _ref3;
      return status === Status.SUCCESS || error ? Action.CREATE_END : Action.CREATE_START;
    }

    getDeleteAction(_ref4) {
      let {
        meta: {
          status
        },
        error
      } = _ref4;
      return status === Status.SUCCESS || error ? Action.DELETE_END : Action.DELETE_START;
    }

    getUpdateAction(_ref5) {
      let {
        meta: {
          status
        },
        error
      } = _ref5;
      return status === Status.SUCCESS || error ? Action.UPDATE_END : Action.UPDATE_START;
    }

    getReplyCreateAction(_ref6) {
      let {
        meta: {
          status
        },
        error
      } = _ref6;
      return status === Status.SUCCESS || error ? Action.REPLY_CREATE_END : Action.REPLY_CREATE_START;
    }

    getReplyDeleteAction(_ref7) {
      let {
        meta: {
          status
        },
        error
      } = _ref7;
      return status === Status.SUCCESS || error ? Action.REPLY_DELETE_END : Action.REPLY_DELETE_START;
    }

    getReplyUpdateAction(_ref8) {
      let {
        meta: {
          status
        },
        error
      } = _ref8;
      return status === Status.SUCCESS || error ? Action.REPLY_UPDATE_END : Action.REPLY_UPDATE_START;
    }

    getAnnotationsPath(fileVersionId, annotationId) {
      if (!fileVersionId) {
        return '/activity';
      }

      return generatePath(ANNOTATIONS_PATH, {
        sidebar: 'activity',
        annotationId: annotationId || undefined,
        fileVersionId
      });
    }

    getMatchPath(location) {
      const pathname = getProp(location, 'pathname', '');
      return matchPath(pathname, {
        path: ANNOTATIONS_PATH,
        exact: true
      });
    }

    render() {
      return React.createElement(AnnotatorContext.Provider, {
        value: {
          emitActiveAnnotationChangeEvent: this.emitActiveAnnotationChangeEvent,
          emitAnnotationRemoveEvent: this.emitAnnotationRemoveEvent,
          emitAnnotationReplyCreateEvent: this.emitAnnotationReplyCreateEvent,
          emitAnnotationReplyDeleteEvent: this.emitAnnotationReplyDeleteEvent,
          emitAnnotationReplyUpdateEvent: this.emitAnnotationReplyUpdateEvent,
          emitAnnotationUpdateEvent: this.emitAnnotationUpdateEvent,
          getAnnotationsMatchPath: this.getMatchPath,
          getAnnotationsPath: this.getAnnotationsPath,
          state: this.state
        }
      }, React.createElement(WrappedComponent, _extends({}, this.props, {
        onAnnotator: this.handleAnnotator,
        onPreviewDestroy: this.handlePreviewDestroy
      })));
    }

  }

  const displayName = WrappedComponent.displayName || WrappedComponent.name || 'Component';
  ComponentWithAnnotations.displayName = "WithAnnotations(".concat(displayName, ")");
  return ComponentWithAnnotations;
}
//# sourceMappingURL=withAnnotations.js.map