/**
 * 
 * @file Function to render the date table cell
 * @author Box
 */
import React from 'react';
import { injectIntl, FormattedMessage } from 'react-intl';
import { isToday, isYesterday } from '../../../utils/datetime';
import messages from '../messages';
import './DateField.scss';
const DEFAULT_DATE_FORMAT = {
  weekday: 'short',
  month: 'short',
  year: 'numeric',
  day: 'numeric'
};

const DateField = (_ref) => {
  let {
    date,
    dateFormat = DEFAULT_DATE_FORMAT,
    omitCommas = false,
    intl,
    relative = true,
    capitalize = false
  } = _ref;
  const d = new Date(date);
  const isTodaysDate = isToday(d);
  const isYesterdaysDate = isYesterday(d);

  if (relative && (isTodaysDate || isYesterdaysDate)) {
    let Message = React.createElement(FormattedMessage, messages.today);

    if (isYesterdaysDate) {
      Message = React.createElement(FormattedMessage, messages.yesterday);
    }

    if (capitalize) {
      return React.createElement("span", {
        className: "be-date-capitalize"
      }, Message);
    }

    return Message;
  }

  let formattedDate = intl.formatDate(d, dateFormat);
  formattedDate = omitCommas ? formattedDate.replace(/,/g, '') : formattedDate;
  return formattedDate;
};

export default injectIntl(DateField);
//# sourceMappingURL=DateField.js.map