function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file HOC for drag drop
 * @author Box
 */
import React, { PureComponent } from 'react';
import { findDOMNode } from 'react-dom';
import classNames from 'classnames';

/* eslint-disable no-plusplus */
const makeDroppable = (_ref) => {
  let {
    dropValidator,
    onDrop
  } = _ref;
  return Wrapped => {
    var _class, _temp;

    return _temp = _class = class DroppableComponent extends PureComponent {
      /**
       * [constructor]
       *
       * @param {*} props
       * @return {DroppableComponent}
       */
      constructor(props) {
        super(props);

        _defineProperty(this, "removeEventListeners", element => {
          element.removeEventListener('dragenter', this.handleDragEnter);
          element.removeEventListener('dragover', this.handleDragOver);
          element.removeEventListener('dragleave', this.handleDragLeave);
          element.removeEventListener('drop', this.handleDrop);
        });

        _defineProperty(this, "bindDragDropHandlers", () => {
          const droppableEl = findDOMNode(this); // eslint-disable-line react/no-find-dom-node

          if (!droppableEl || !(droppableEl instanceof Element)) {
            return;
          } // add event listeners directly on the element


          droppableEl.addEventListener('dragenter', this.handleDragEnter);
          droppableEl.addEventListener('dragover', this.handleDragOver);
          droppableEl.addEventListener('dragleave', this.handleDragLeave);
          droppableEl.addEventListener('drop', this.handleDrop);
          this.droppableEl = droppableEl;
        });

        _defineProperty(this, "handleDragEnter", event => {
          // This allows onDrop to be fired
          event.preventDefault(); // Use this to track the number of drag enters and leaves.
          // This is used to normalize enters/leaves between parent/child elements
          // we only want to do things in dragenter when the counter === 1

          if (++this.enterLeaveCounter === 1) {
            const {
              dataTransfer
            } = event; // if we don't have a dropValidator, we just default canDrop to true

            const canDrop = dropValidator ? dropValidator(this.props, dataTransfer) : true;
            this.setState({
              isOver: true,
              canDrop
            });
          }
        });

        _defineProperty(this, "handleDragOver", event => {
          // This allows onDrop to be fired
          event.preventDefault();
          const {
            canDrop
          } = this.state;
          const {
            dataTransfer
          } = event;

          if (!dataTransfer) {
            return;
          }

          if (!canDrop) {
            dataTransfer.dropEffect = 'none';
          } else if (dataTransfer.effectAllowed) {
            // Set the drop effect if it was defined
            dataTransfer.dropEffect = dataTransfer.effectAllowed;
          }
        });

        _defineProperty(this, "handleDrop", event => {
          event.preventDefault(); // reset enterLeaveCounter

          this.enterLeaveCounter = 0;
          const {
            canDrop
          } = this.state;
          this.setState({
            canDrop: false,
            isDragging: false,
            isOver: false
          });

          if (canDrop && onDrop) {
            onDrop(event, this.props);
          }
        });

        _defineProperty(this, "handleDragLeave", event => {
          event.preventDefault(); // if enterLeaveCounter is zero, it means that we're actually leaving the item

          if (--this.enterLeaveCounter > 0) {
            return;
          }

          this.setState({
            canDrop: false,
            isDragging: false,
            isOver: false
          });
        });

        this.enterLeaveCounter = 0;
        this.state = {
          canDrop: false,
          isDragging: false,
          isOver: false
        };
      }
      /**
       * Adds event listeners once the component mounts
       * @inheritdoc
       */


      componentDidMount() {
        this.bindDragDropHandlers();
      }

      componentDidUpdate() {
        if (!this.droppableEl) {
          this.bindDragDropHandlers();
          return;
        } // eslint-disable-next-line react/no-find-dom-node


        if (findDOMNode(this) !== this.droppableEl) {
          this.removeEventListeners(this.droppableEl);
          this.bindDragDropHandlers();
        }
      }
      /**
       * Function that removes the drag and drop related event listeners on the input element
       *
       * @param {Element} element
       * @return {void}
       */


      /**
       * Removes event listeners when the component is going to unmount
       * @inheritdoc
       */
      componentWillUnmount() {
        if (!this.droppableEl || !(this.droppableEl instanceof Element)) {
          return;
        }

        this.removeEventListeners(this.droppableEl);
      }
      /**
       * Function that gets called when an item is dragged into the drop zone
       *
       * @param {SyntheticEvent} event - The dragenter event
       * @return {void}
       */


      /**
       * Renders the HOC
       *
       * @private
       * @inheritdoc
       * @return {Element}
       */
      render() {
        const _this$props = this.props,
              {
          className
        } = _this$props,
              rest = _objectWithoutProperties(_this$props, ["className"]);

        const {
          canDrop,
          isOver
        } = this.state;
        const classes = classNames(className, {
          'is-droppable': canDrop,
          'is-over': isOver
        });

        const mergedProps = _objectSpread({}, rest, {}, this.state, {
          className: classes
        });

        return React.createElement(Wrapped, mergedProps);
      }

    }, _defineProperty(_class, "defaultProps", {
      className: ''
    }), _temp;
  };
};

export default makeDroppable;
//# sourceMappingURL=makeDroppable.js.map