function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Error Boundary
 * @author Box
 */
import * as React from 'react';
import noop from 'lodash/noop';
import { ERROR_CODE_UNEXPECTED_EXCEPTION, IS_ERROR_DISPLAYED } from '../../../constants';
import DefaultError from './DefaultError';

class ErrorBoundary extends React.Component {
  constructor() {
    var _this;

    super(...arguments);
    _this = this;

    _defineProperty(this, "state", {});

    _defineProperty(this, "handleError", function (error, code) {
      let contextInfo = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      let origin = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : _this.props.errorOrigin;

      if (!error || !code || !origin) {
        return;
      }

      const elementsError = {
        type: 'error',
        code,
        message: error.message,
        origin,
        context_info: _objectSpread({
          [IS_ERROR_DISPLAYED]: true
        }, contextInfo)
      };

      _this.props.onError(elementsError);
    });
  }

  componentDidCatch(error, info) {
    this.setState({
      error
    }, () => {
      this.handleError(error, ERROR_CODE_UNEXPECTED_EXCEPTION, _objectSpread({}, info), this.props.errorOrigin);
    });
  }
  /**
   * Formats the error and emits it to the top level onError prop
   *
   * @param {Error} error - the error which occurred
   * @param {string} type - the error type to identify where the error occurred
   * @param {string} code - the error code to identify what error occurred
   * @param {Object} contextInfo - additional information which may be useful for the consumer of the error
   * @return {void}
   */


  render() {
    const _this$props = this.props,
          {
      children,
      errorComponent: ErrorComponent
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["children", "errorComponent"]);

    const {
      error
    } = this.state;

    if (error) {
      return React.createElement(ErrorComponent, {
        error: error
      });
    }

    return React.cloneElement(children, _objectSpread({}, rest, {
      onError: this.handleError
    }));
  }

}

_defineProperty(ErrorBoundary, "defaultProps", {
  errorComponent: DefaultError,
  onError: noop
});

export default ErrorBoundary;
//# sourceMappingURL=ErrorBoundary.js.map