/**
 * 
 * @file Header bar
 * @author Box
 */
import React from 'react';
import { injectIntl } from 'react-intl';
import Logo from './Logo';
import messages from '../messages';
import { VIEW_FOLDER, VIEW_SEARCH } from '../../../constants';
import './Header.scss';

// eslint-disable-next-line react/prop-types
const Header = (_ref) => {
  let {
    isHeaderLogoVisible = true,
    view,
    isSmall,
    searchQuery,
    onSearch,
    logoUrl,
    intl
  } = _ref;
  const {
    formatMessage
  } = intl;

  const search = (_ref2) => {
    let {
      currentTarget
    } = _ref2;
    return onSearch(currentTarget.value);
  };

  const searchMessage = formatMessage(messages.searchPlaceholder);
  const isFolder = view === VIEW_FOLDER;
  const isSearch = view === VIEW_SEARCH;
  return React.createElement("div", {
    className: "be-header"
  }, isHeaderLogoVisible && React.createElement(Logo, {
    isSmall: isSmall,
    url: logoUrl
  }), React.createElement("div", {
    className: "be-search"
  }, React.createElement("input", {
    "aria-label": searchMessage,
    "data-testid": "be-Header-searchInput",
    disabled: !isFolder && !isSearch,
    onChange: search,
    placeholder: searchMessage,
    type: "search",
    value: searchQuery
  })));
};

export { Header as HeaderBase };
export default injectIntl(Header);
//# sourceMappingURL=Header.js.map