function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import noop from 'lodash/noop';
import { v4 as uuidv4 } from 'uuid';
import { isMarkSupported } from '../../../utils/performance';
import { EVENT_DATA_READY, EVENT_JS_READY } from './constants';
import { METRIC_TYPE_PREVIEW, METRIC_TYPE_ELEMENTS_LOAD_METRIC } from '../../../constants';
const SESSION_ID = uuidv4();
const uniqueEvents = new Set();

class Logger extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "handlePreviewMetric", data => {
      const {
        onMetric
      } = this.props;
      onMetric(_objectSpread({}, data, {
        type: METRIC_TYPE_PREVIEW
      }));
    });

    _defineProperty(this, "handleDataReadyMetric", (data, uniqueId) => {
      if (!isMarkSupported) {
        return;
      }

      this.logUniqueMetric(METRIC_TYPE_ELEMENTS_LOAD_METRIC, EVENT_DATA_READY, data, uniqueId);
    });

    _defineProperty(this, "handleReadyMetric", data => {
      if (!isMarkSupported) {
        return;
      }

      const {
        startMarkName
      } = this.props;

      const metricData = _objectSpread({}, data, {
        startMarkName
      });

      this.logUniqueMetric(METRIC_TYPE_ELEMENTS_LOAD_METRIC, EVENT_JS_READY, metricData);
    });

    this.loggerProps = {
      onDataReadyMetric: this.handleDataReadyMetric,
      onPreviewMetric: this.handlePreviewMetric,
      onReadyMetric: this.handleReadyMetric
    };
  }

  get uniqueEvents() {
    return uniqueEvents;
  }

  get sessionId() {
    return SESSION_ID;
  }
  /**
   * Creates an event name meant for use with an event which is unique and meant to be logged only once
   *
   * @param {string} name - The event name
   * @param {string} [uniqueId] - an optional unique id
   * @returns {string} A string containing the component and event name and optional unique id
   */


  createEventName(name, uniqueId) {
    const {
      source
    } = this.props;
    const eventName = "".concat(source, "::").concat(name);
    return uniqueId ? "".concat(eventName, "::").concat(uniqueId) : eventName;
  }
  /**
   * Checks to see if the specified event for the component has already been fired.
   *
   * @param {string} component - the component name
   * @param {string} name - the event name
   * @returns {boolean} True if the event has already been fired
   */


  hasLoggedEvent(name) {
    return this.uniqueEvents.has(name);
  }
  /**
   * Invokes the provided metric logging callback.
   *
   * @param {string} type - the type of the event
   * @param {string} name - the name of the event
   * @param {Object} data  - the event data
   */


  logMetric(type, name, data) {
    const {
      onMetric,
      source
    } = this.props;

    const metric = _objectSpread({}, data, {
      component: source,
      name,
      timestamp: this.getTimestamp(),
      sessionId: this.sessionId,
      type
    });

    onMetric(metric);
  }
  /**
   * Logs a unique metric event. Prevents duplicate events from being logged in the session.
   *
   * @param {string} type - the type of the event
   * @param {string} name - the name of the event
   * @param {Object} data  - the event data
   * @param {string} [uniqueId] - an optional unique id
   * @returns {void}
   */


  logUniqueMetric(type, name, data, uniqueId) {
    const eventName = this.createEventName(name, uniqueId);

    if (this.hasLoggedEvent(eventName)) {
      return;
    }

    this.logMetric(type, name, data);
    this.uniqueEvents.add(eventName);
  }
  /**
   * Preview metric handler
   *
   * @param {Object} data - the metric data
   * @returns {void}
   */


  /**
   * Create an ISO Timestamp for right now.
   *
   * @returns {string}
   */
  getTimestamp() {
    return new Date().toISOString();
  }

  render() {
    const _this$props = this.props,
          {
      children,
      onMetric,
      startMarkName
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["children", "onMetric", "startMarkName"]);

    return React.cloneElement(children, _objectSpread({}, rest, {
      logger: this.loggerProps
    }));
  }

}

_defineProperty(Logger, "defaultProps", {
  onMetric: noop
});

export default Logger;
//# sourceMappingURL=Logger.js.map