function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file HOC to make popup-able Box UI Elements
 * @author Box
 */
import React, { PureComponent } from 'react';
import Modal from 'react-modal';
import noop from 'lodash/noop';
import omit from 'lodash/omit';
import { CLIENT_NAME_CONTENT_PICKER, CLIENT_NAME_CONTENT_UPLOADER } from '../../constants';

const makePopup = kit => Wrapped => {
  var _temp;

  return _temp = class Wrapper extends PureComponent {
    /**
     * [constructor]
     *
     * @param {*} props
     * @return {Wrapper}
     */
    constructor(props) {
      super(props);

      _defineProperty(this, "onClick", data => {
        const {
          onClick = noop
        } = this.props;
        this.close(onClick, data);
      });

      _defineProperty(this, "onClose", data => {
        const {
          onClose = noop
        } = this.props;
        this.close(onClose, data);
      });

      _defineProperty(this, "onCancel", data => {
        const {
          onCancel = noop
        } = this.props;
        this.close(onCancel, data);
      });

      _defineProperty(this, "onChoose", data => {
        const {
          onChoose = noop
        } = this.props;
        this.close(onChoose, data);
      });

      _defineProperty(this, "onButtonClick", () => {
        this.setState({
          isOpen: true
        });
      });

      this.state = {
        isOpen: false
      };
    }
    /**
     * Hides the modal and call the callback
     *
     * @param {Function} callback - function to call
     * @return {void}
     */


    close(callback, data) {
      this.setState({
        isOpen: false
      }, () => callback(data));
    }
    /**
     * Callback for clicking
     *
     * @param {*} data - any callback data
     * @return {void}
     */


    /**
     * Renders the component
     *
     * @return {void}
     */
    render() {
      const {
        isOpen
      } = this.state;

      const _this$props = this.props,
            {
        modal
      } = _this$props,
            rest = _objectWithoutProperties(_this$props, ["modal"]);

      const wrappedProps = omit(rest, ['onCancel', 'onChoose', 'onClose', 'modal']);
      const {
        buttonLabel = 'Missing modal.buttonLabel in options',
        buttonClassName = 'btn btn-primary',
        modalClassName = 'be-modal-wrapper-content',
        overlayClassName = 'be-modal-wrapper-overlay'
      } = modal;

      switch (kit) {
        case CLIENT_NAME_CONTENT_PICKER:
          wrappedProps.onCancel = this.onCancel;
          wrappedProps.onChoose = this.onChoose;
          break;

        case CLIENT_NAME_CONTENT_UPLOADER:
          wrappedProps.onClose = this.onClose;
          break;

        default:
          throw new Error('Unknown kit type');
      }

      return React.createElement("div", null, React.createElement("button", {
        className: buttonClassName,
        onClick: this.onButtonClick,
        type: "button"
      }, buttonLabel), React.createElement(Modal, {
        className: modalClassName,
        contentLabel: kit,
        isOpen: isOpen,
        overlayClassName: overlayClassName
      }, React.createElement(Wrapped, wrappedProps)));
    }

  }, _temp;
};

export default makePopup;
//# sourceMappingURL=makePopup.js.map