function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file HOC to make responsive Box UI Elements
 * @author Box
 */
import * as React from 'react';
import debounce from 'lodash/debounce';
import Measure from 'react-measure';
import classNames from 'classnames';
import { CLASS_IS_MEDIUM, CLASS_IS_SMALL, CLASS_IS_TOUCH, SIZE_LARGE, SIZE_MEDIUM, SIZE_SMALL, SIZE_VERY_LARGE } from '../../constants';
const CROSS_OVER_WIDTH_SMALL = 700;
const CROSS_OVER_WIDTH_MEDIUM = 1000;
const CROSS_OVER_WIDTH_LARGE = 1500;
const HAS_TOUCH = !!('ontouchstart' in window || window.DocumentTouch && document instanceof window.DocumentTouch);

function makeResponsive(Wrapped) {
  var _class, _temp;

  return _temp = _class = class extends React.PureComponent {
    /**
     * [constructor]
     *
     * @param {*} data
     * @return {void}
     */
    constructor(props) {
      super(props);

      _defineProperty(this, "onResize", debounce((_ref) => {
        let {
          bounds: {
            width
          }
        } = _ref;
        this.setState({
          size: this.getSize(width)
        });
      }, 500));

      _defineProperty(this, "innerRef", el => {
        this.innerElement = el;
      });

      _defineProperty(this, "getInnerElement", () => this.innerElement);

      this.state = {
        size: props.size || this.getSize(window.innerWidth)
      };
    }
    /**
     * Calculates the new size
     *
     * @private
     * @param {Component} react component
     * @return {void}
     */


    getSize(width) {
      let size = SIZE_VERY_LARGE;

      if (width <= CROSS_OVER_WIDTH_SMALL) {
        size = SIZE_SMALL;
      } else if (width <= CROSS_OVER_WIDTH_MEDIUM) {
        size = SIZE_MEDIUM;
      } else if (width <= CROSS_OVER_WIDTH_LARGE) {
        size = SIZE_LARGE;
      }

      return size;
    }
    /**
     * Resizing function
     *
     * @private
     * @param {Component} react component
     * @return {void}
     */


    /**
     * Renders the Box UI Element
     *
     * @private
     * @inheritdoc
     * @return {Element}
     */
    render() {
      const _this$props = this.props,
            {
        isTouch,
        size,
        className,
        componentRef
      } = _this$props,
            rest = _objectWithoutProperties(_this$props, ["isTouch", "size", "className", "componentRef"]);

      let isLarge = size === SIZE_LARGE;
      let isMedium = size === SIZE_MEDIUM;
      let isSmall = size === SIZE_SMALL;
      let isVeryLarge = size === SIZE_VERY_LARGE;
      const isResponsive = !isSmall && !isLarge && !isMedium && !isVeryLarge;

      if ([isSmall, isMedium, isLarge, isVeryLarge].filter(item => item).length > 1) {
        throw new Error('Box UI Element cannot be small or medium or large or very large at the same time');
      }

      if (!isResponsive) {
        return React.createElement(Wrapped, _extends({
          ref: componentRef,
          className: className,
          isLarge: isLarge,
          isMedium: isMedium,
          isSmall: isSmall,
          isTouch: isTouch,
          isVeryLarge: isVeryLarge
        }, rest));
      }

      const {
        size: sizeFromState
      } = this.state;
      isSmall = sizeFromState === SIZE_SMALL;
      isMedium = sizeFromState === SIZE_MEDIUM;
      isLarge = sizeFromState === SIZE_LARGE;
      isVeryLarge = sizeFromState === SIZE_VERY_LARGE;
      const styleClassName = classNames({
        [CLASS_IS_SMALL]: isSmall,
        [CLASS_IS_MEDIUM]: isMedium,
        [CLASS_IS_TOUCH]: isTouch
      }, className);
      return React.createElement(Measure, {
        bounds: true,
        innerRef: this.innerRef,
        onResize: this.onResize
      }, (_ref2) => {
        let {
          measureRef
        } = _ref2;
        return React.createElement(Wrapped, _extends({
          ref: componentRef,
          className: styleClassName,
          getInnerRef: this.getInnerElement,
          isLarge: isLarge,
          isMedium: isMedium,
          isSmall: isSmall,
          isTouch: isTouch,
          isVeryLarge: isVeryLarge,
          measureRef: measureRef
        }, rest));
      });
    }

  }, _defineProperty(_class, "defaultProps", {
    className: '',
    isTouch: HAS_TOUCH
  }), _temp;
}

export default makeResponsive;
//# sourceMappingURL=makeResponsive.js.map