function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Progress Bar component
 * @author Box
 */
import React, { PureComponent } from 'react';
import './ProgressBar.scss';

class ProgressBar extends PureComponent {
  /**
   * [constructor]
   *
   * @return {ProgressBar}
   */
  constructor(props) {
    super(props);

    _defineProperty(this, "startProgress", () => {
      const {
        percent
      } = this.state;

      if (percent === 0) {
        this.interval = setInterval(this.incrementProgress, 100);
      } else if (percent === 100) {
        // Timeout helps transition of hiding the bar to finish
        this.timeout = setTimeout(this.resetProgress, 600);
      }
    });

    _defineProperty(this, "incrementProgress", () => {
      const {
        percent
      } = this.state;
      this.setState({
        percent: percent + 2 / (percent || 1)
      });
    });

    _defineProperty(this, "resetProgress", () => {
      this.setState(ProgressBar.defaultProps);
    });

    const {
      percent: _percent
    } = props;
    this.state = {
      percent: _percent
    };
  }
  /**
   * Clears any timeouts and intervals
   *
   * @return {void}
   */


  clearTimeoutAndInterval() {
    clearInterval(this.interval);
    clearTimeout(this.timeout);
  }
  /**
   * Starts progress on mount
   */


  componentDidMount() {
    this.startProgress();
  }
  /**
   * Updates state from new props
   *
   * @return {void}
   */


  componentDidUpdate(prevProps) {
    const {
      percent
    } = this.props;

    if (prevProps.percent !== percent) {
      this.clearTimeoutAndInterval();
      this.setState({
        percent
      }, this.startProgress);
    }
  }
  /**
   * Clears time out
   *
   * @return {void}
   */


  componentWillUnmount() {
    this.clearTimeoutAndInterval();
  }
  /**
   * Increaments the progress or resets it
   * depending upon the edge conditions.
   *
   * @return {void}
   */


  /**
   * Renders the progress bar
   *
   * @return {void}
   */
  render() {
    const {
      percent
    } = this.state;
    const containerStyle = {
      opacity: percent > 0 && percent < 100 ? 1 : 0,
      transitionDelay: percent > 0 && percent < 100 ? '0' : '0.4s'
    };
    return React.createElement("div", {
      className: "be-progress-container",
      style: containerStyle
    }, React.createElement("div", {
      className: "be-progress",
      style: {
        width: "".concat(percent, "%")
      }
    }));
  }

}

_defineProperty(ProgressBar, "defaultProps", {
  percent: 0
});

export default ProgressBar;
//# sourceMappingURL=ProgressBar.js.map