/**
 * 
 * @file Content Explorer Delete Confirmation Dialog
 * @author Box
 */
import React from 'react';
import { injectIntl } from 'react-intl';
import messages from '../messages';
import { ACCESS_NONE, ACCESS_OPEN, ACCESS_COLLAB, ACCESS_COMPANY } from '../../../constants';
import './ShareAccessSelect.scss';

const ShareAccessSelect = (_ref) => {
  let {
    className,
    canSetShareAccess,
    onChange,
    item,
    intl
  } = _ref;
  const {
    allowed_shared_link_access_levels: allowedSharedAccessLevels,
    permissions,
    shared_link: sharedLink
  } = item;

  if (!allowedSharedAccessLevels) {
    return React.createElement("span", null);
  }

  const {
    access = ACCESS_NONE
  } = sharedLink || {};
  const {
    can_set_share_access: allowShareAccessChange
  } = permissions || {};

  const changeHandler = (_ref2) => {
    let {
      target
    } = _ref2;
    return onChange(target.value, item);
  };

  const allowOpen = allowedSharedAccessLevels.indexOf(ACCESS_OPEN) > -1;
  const allowCollab = allowedSharedAccessLevels.indexOf(ACCESS_COLLAB) > -1;
  const allowCompany = allowedSharedAccessLevels.indexOf(ACCESS_COMPANY) > -1;
  const allowed = canSetShareAccess && allowShareAccessChange && (allowOpen || allowCompany || allowCollab);

  if (!allowed) {
    return React.createElement("span", null);
  }
  /* eslint-disable jsx-a11y/no-onchange */


  return React.createElement("select", {
    className: "be-share-access-select ".concat(className),
    onChange: changeHandler,
    value: access
  }, allowOpen ? React.createElement("option", {
    value: ACCESS_OPEN
  }, intl.formatMessage(messages.shareAccessOpen)) : null, allowCollab ? React.createElement("option", {
    value: ACCESS_COLLAB
  }, intl.formatMessage(messages.shareAccessCollab)) : null, allowCompany ? React.createElement("option", {
    value: ACCESS_COMPANY
  }, intl.formatMessage(messages.shareAccessCompany)) : null, React.createElement("option", {
    value: ACCESS_NONE
  }, access === ACCESS_NONE ? intl.formatMessage(messages.shareAccessNone) : intl.formatMessage(messages.shareAccessRemove)));
};

export default injectIntl(ShareAccessSelect);
//# sourceMappingURL=ShareAccessSelect.js.map