/**
 * 
 * @file Content sub header component
 * @author Box
 */
import React from 'react';
import Sort from './Sort';
import Add from './Add';
import GridViewSlider from '../../../components/grid-view/GridViewSlider';
import ViewModeChangeButton from './ViewModeChangeButton';
import { VIEW_FOLDER, VIEW_MODE_GRID } from '../../../constants';
import './SubHeaderRight.scss';

const SubHeaderRight = (_ref) => {
  let {
    canCreateNewFolder,
    canUpload,
    currentCollection,
    gridColumnCount,
    gridMaxColumns,
    gridMinColumns,
    maxGridColumnCountForWidth,
    onCreate,
    onGridViewSliderChange,
    onSortChange,
    onUpload,
    onViewModeChange,
    view,
    viewMode
  } = _ref;
  const {
    sortBy,
    sortDirection,
    items = []
  } = currentCollection;
  const hasGridView = !!gridColumnCount;
  const hasItems = items.length > 0;
  const isFolder = view === VIEW_FOLDER;
  const showSort = isFolder && hasItems;
  const showAdd = (!!canUpload || !!canCreateNewFolder) && isFolder;
  return React.createElement("div", {
    className: "be-sub-header-right"
  }, hasItems && viewMode === VIEW_MODE_GRID && React.createElement(GridViewSlider, {
    columnCount: gridColumnCount,
    gridMaxColumns: gridMaxColumns,
    gridMinColumns: gridMinColumns,
    maxColumnCount: maxGridColumnCountForWidth,
    onChange: onGridViewSliderChange
  }), hasItems && hasGridView && React.createElement(ViewModeChangeButton, {
    viewMode: viewMode,
    onViewModeChange: onViewModeChange
  }), showSort && !!sortBy && !!sortDirection && React.createElement(Sort, {
    onSortChange: onSortChange,
    sortBy: sortBy,
    sortDirection: sortDirection
  }), showAdd && React.createElement(Add, {
    isDisabled: !isFolder,
    onCreate: onCreate,
    onUpload: onUpload,
    showCreate: canCreateNewFolder,
    showUpload: canUpload
  }));
};

export default SubHeaderRight;
//# sourceMappingURL=SubHeaderRight.js.map