function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Content Explorer Component
 * @author Box
 */
import 'regenerator-runtime/runtime';
import React, { Component } from 'react';
import classNames from 'classnames';
import cloneDeep from 'lodash/cloneDeep';
import debounce from 'lodash/debounce';
import flow from 'lodash/flow';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import uniqueid from 'lodash/uniqueId';
import CreateFolderDialog from '../common/create-folder-dialog';
import UploadDialog from '../common/upload-dialog';
import Header from '../common/header';
import Pagination from '../../features/pagination';
import SubHeader from '../common/sub-header/SubHeader';
import makeResponsive from '../common/makeResponsive';
import openUrlInsideIframe from '../../utils/iframe';
import Internationalize from '../common/Internationalize';
import API from '../../api';
import MetadataQueryAPIHelper from '../../features/metadata-based-view/MetadataQueryAPIHelper';
import Footer from './Footer';
import PreviewDialog from './PreviewDialog';
import ShareDialog from './ShareDialog';
import RenameDialog from './RenameDialog';
import DeleteConfirmationDialog from './DeleteConfirmationDialog';
import Content from './Content';
import isThumbnailReady from './utils';
import { isFocusableElement, isInputElement, focus } from '../../utils/dom';
import { FILE_SHARED_LINK_FIELDS_TO_FETCH } from '../../utils/fields';
import CONTENT_EXPLORER_FOLDER_FIELDS_TO_FETCH from './constants';
import LocalStore from '../../utils/LocalStore';
import { withFeatureConsumer, withFeatureProvider } from '../common/feature-checking';
import { DEFAULT_HOSTNAME_UPLOAD, DEFAULT_HOSTNAME_API, DEFAULT_HOSTNAME_APP, DEFAULT_HOSTNAME_STATIC, DEFAULT_SEARCH_DEBOUNCE, SORT_ASC, FIELD_NAME, FIELD_PERMISSIONS_CAN_SHARE, FIELD_SHARED_LINK, DEFAULT_ROOT, VIEW_SEARCH, VIEW_FOLDER, VIEW_ERROR, VIEW_RECENTS, VIEW_METADATA, VIEW_MODE_LIST, TYPE_FILE, TYPE_WEBLINK, TYPE_FOLDER, CLIENT_NAME_CONTENT_EXPLORER, DEFAULT_PAGE_NUMBER, DEFAULT_PAGE_SIZE, DEFAULT_VIEW_FILES, DEFAULT_VIEW_RECENTS, DEFAULT_VIEW_METADATA, ERROR_CODE_ITEM_NAME_INVALID, ERROR_CODE_ITEM_NAME_TOO_LONG, TYPED_ID_FOLDER_PREFIX, VIEW_MODE_GRID } from '../../constants';
import '../common/fonts.scss';
import '../common/base.scss';
import '../common/modal.scss';
import './ContentExplorer.scss';
const GRID_VIEW_MAX_COLUMNS = 7;
const GRID_VIEW_MIN_COLUMNS = 1;
const localStoreViewMode = 'bce.defaultViewMode';

class ContentExplorer extends Component {
  // Keeps track of very 1st load

  /**
   * [constructor]
   *
   * @private
   * @return {ContentExplorer}
   */
  constructor(props) {
    var _this;

    super(props);
    _this = this;

    _defineProperty(this, "firstLoad", true);

    _defineProperty(this, "store", new LocalStore());

    _defineProperty(this, "showMetadataQueryResultsSuccessCallback", metadataQueryCollection => {
      const {
        nextMarker
      } = metadataQueryCollection;
      const {
        currentCollection,
        currentPageNumber,
        markers
      } = this.state;
      const cloneMarkers = [...markers];

      if (nextMarker) {
        cloneMarkers[currentPageNumber + 1] = nextMarker;
      }

      this.setState({
        currentCollection: _objectSpread({}, currentCollection, {}, metadataQueryCollection, {
          percentLoaded: 100
        }),
        markers: cloneMarkers
      });
    });

    _defineProperty(this, "errorCallback", error => {
      this.setState({
        view: VIEW_ERROR
      });
      /* eslint-disable no-console */

      console.error(error);
      /* eslint-enable no-console */
    });

    _defineProperty(this, "refreshCollection", () => {
      const {
        currentCollection: {
          id
        },
        view,
        searchQuery
      } = this.state;

      if (view === VIEW_FOLDER && id) {
        this.fetchFolder(id, false);
      } else if (view === VIEW_RECENTS) {
        this.showRecents(false);
      } else if (view === VIEW_SEARCH && searchQuery) {
        this.search(searchQuery);
      } else if (view === VIEW_METADATA) {
        this.showMetadataQueryResults();
      } else {
        throw new Error('Cannot refresh incompatible view!');
      }
    });

    _defineProperty(this, "fetchFolder", function (id) {
      let triggerNavigationEvent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      const {
        rootFolderId
      } = _this.props;
      const {
        currentCollection: {
          id: currentId
        },
        currentOffset,
        currentPageSize: limit,
        searchQuery = '',
        sortBy,
        sortDirection
      } = _this.state;
      const folderId = typeof id === 'string' ? id : rootFolderId;
      const hasFolderChanged = currentId && currentId !== folderId;
      const hasSearchQuery = !!searchQuery.trim().length;
      const offset = hasFolderChanged || hasSearchQuery ? 0 : currentOffset; // Reset offset on folder or mode change
      // If we are navigating around, aka not first load
      // then reset the focus to the root so that after
      // the collection loads the activeElement is not the
      // button that was clicked to fetch the folder

      if (!_this.firstLoad) {
        _this.rootElement.focus();
      } // Reset search state, the view and show busy indicator


      _this.setState({
        searchQuery: '',
        view: VIEW_FOLDER,
        currentCollection: _this.currentUnloadedCollection(),
        currentOffset: offset
      }); // Fetch the folder using folder API


      _this.api.getFolderAPI().getFolder(folderId, limit, offset, sortBy, sortDirection, collection => {
        _this.fetchFolderSuccessCallback(collection, triggerNavigationEvent);
      }, _this.errorCallback, {
        fields: CONTENT_EXPLORER_FOLDER_FIELDS_TO_FETCH,
        forceFetch: true
      });
    });

    _defineProperty(this, "onItemClick", item => {
      // If the id was passed in, just use that
      if (typeof item === 'string') {
        this.fetchFolder(item);
        return;
      }

      const {
        id,
        type
      } = item;
      const {
        isTouch
      } = this.props;

      if (type === TYPE_FOLDER) {
        this.fetchFolder(id);
        return;
      }

      if (isTouch) {
        return;
      }

      this.preview(item);
    });

    _defineProperty(this, "searchSuccessCallback", collection => {
      const {
        selected
      } = this.state; // Close any open modals

      this.closeModals();
      this.updateCollection(collection, selected);
    });

    _defineProperty(this, "debouncedSearch", debounce((id, query) => {
      const {
        currentOffset,
        currentPageSize
      } = this.state;
      this.api.getSearchAPI().search(id, query, currentPageSize, currentOffset, this.searchSuccessCallback, this.errorCallback, {
        fields: CONTENT_EXPLORER_FOLDER_FIELDS_TO_FETCH,
        forceFetch: true
      });
    }, DEFAULT_SEARCH_DEBOUNCE));

    _defineProperty(this, "search", query => {
      const {
        rootFolderId
      } = this.props;
      const {
        currentCollection: {
          id
        },
        currentOffset,
        searchQuery
      } = this.state;
      const folderId = typeof id === 'string' ? id : rootFolderId;
      const trimmedQuery = query.trim();

      if (!query) {
        // Cancel the debounce so we don't search on a previous query
        this.debouncedSearch.cancel(); // Query was cleared out, load the prior folder
        // The prior folder is always the parent folder for search

        this.setState({
          currentOffset: 0
        }, () => {
          this.fetchFolder(folderId, false);
        });
        return;
      }

      if (!trimmedQuery) {
        // Query now only has bunch of spaces
        // do nothing and but update prior state
        this.setState({
          searchQuery: query
        });
        return;
      }

      this.setState({
        currentCollection: this.currentUnloadedCollection(),
        currentOffset: trimmedQuery === searchQuery ? currentOffset : 0,
        searchQuery: query,
        selected: undefined,
        view: VIEW_SEARCH
      });
      this.debouncedSearch(folderId, query);
    });

    _defineProperty(this, "upload", () => {
      const {
        currentCollection: {
          id,
          permissions
        }
      } = this.state;
      const {
        canUpload
      } = this.props;

      if (!canUpload || !id || !permissions) {
        return;
      }

      const {
        can_upload
      } = permissions;

      if (!can_upload) {
        return;
      }

      this.setState({
        isUploadModalOpen: true
      });
    });

    _defineProperty(this, "uploadSuccessHandler", () => {
      const {
        currentCollection: {
          id
        }
      } = this.state;
      this.fetchFolder(id, false);
    });

    _defineProperty(this, "changeShareAccess", access => {
      const {
        selected
      } = this.state;
      const {
        canSetShareAccess
      } = this.props;

      if (!selected || !canSetShareAccess) {
        return;
      }

      const {
        permissions,
        type
      } = selected;

      if (!permissions || !type) {
        return;
      }

      const {
        can_set_share_access
      } = permissions;

      if (!can_set_share_access) {
        return;
      }

      this.setState({
        isLoading: true
      });
      this.api.getAPI(type).share(selected, access, updatedItem => {
        this.setState({
          isLoading: false
        });
        this.select(updatedItem);
      });
    });

    _defineProperty(this, "sort", (sortBy, sortDirection) => {
      const {
        currentCollection: {
          id
        }
      } = this.state;

      if (id) {
        this.setState({
          sortBy,
          sortDirection
        }, this.refreshCollection);
      }
    });

    _defineProperty(this, "attemptThumbnailGeneration", async item => {
      const entries = getProp(item, 'representations.entries');
      const representation = getProp(entries, '[0]');

      if (representation) {
        const updatedRepresentation = await this.api.getFileAPI(false).generateRepresentation(representation);

        if (updatedRepresentation !== representation) {
          this.updateItemInCollection(_objectSpread({}, cloneDeep(item), {
            representations: {
              entries: [updatedRepresentation, ...entries.slice(1)]
            }
          }));
        }
      }
    });

    _defineProperty(this, "updateItemInCollection", newItem => {
      const {
        currentCollection
      } = this.state;
      const {
        items = []
      } = currentCollection;

      const newCollection = _objectSpread({}, currentCollection);

      newCollection.items = items.map(item => item.id === newItem.id ? newItem : item);
      this.setState({
        currentCollection: newCollection
      });
    });

    _defineProperty(this, "select", function (item) {
      let callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : noop;
      const {
        selected,
        currentCollection
      } = _this.state;
      const {
        items = []
      } = currentCollection;
      const {
        onSelect
      } = _this.props;

      if (item === selected) {
        callback(item);
        return;
      }

      const selectedItem = _objectSpread({}, item, {
        selected: true
      });

      _this.updateCollection(currentCollection, selectedItem, () => {
        onSelect(cloneDeep([selectedItem]));
        callback(selectedItem);
      });

      const focusedRow = items.findIndex(i => i.id === item.id);

      _this.setState({
        focusedRow
      });
    });

    _defineProperty(this, "preview", item => {
      const {
        type,
        url
      } = item;

      if (type === TYPE_WEBLINK) {
        window.open(url);
        return;
      }

      this.select(item, this.previewCallback);
    });

    _defineProperty(this, "previewCallback", () => {
      const {
        selected
      } = this.state;
      const {
        canPreview
      } = this.props;

      if (!selected || !canPreview) {
        return;
      }

      const {
        permissions
      } = selected;

      if (!permissions) {
        return;
      }

      const {
        can_preview
      } = permissions;

      if (!can_preview) {
        return;
      }

      this.setState({
        isPreviewModalOpen: true
      });
    });

    _defineProperty(this, "download", item => {
      this.select(item, this.downloadCallback);
    });

    _defineProperty(this, "downloadCallback", () => {
      const {
        selected
      } = this.state;
      const {
        canDownload,
        onDownload
      } = this.props;

      if (!selected || !canDownload) {
        return;
      }

      const {
        id,
        permissions
      } = selected;

      if (!id || !permissions) {
        return;
      }

      const {
        can_download
      } = permissions;

      if (!can_download) {
        return;
      }

      const openUrl = url => {
        openUrlInsideIframe(url);
        onDownload(cloneDeep([selected]));
      };

      const {
        type
      } = selected;

      if (type === TYPE_FILE) {
        this.api.getFileAPI().getDownloadUrl(id, selected, openUrl, noop);
      }
    });

    _defineProperty(this, "delete", item => {
      this.select(item, this.deleteCallback);
    });

    _defineProperty(this, "deleteCallback", () => {
      const {
        selected,
        isDeleteModalOpen
      } = this.state;
      const {
        canDelete,
        onDelete
      } = this.props;

      if (!selected || !canDelete) {
        return;
      }

      const {
        id,
        permissions,
        parent,
        type
      } = selected;

      if (!id || !permissions || !parent || !type) {
        return;
      }

      const {
        id: parentId
      } = parent;
      const {
        can_delete
      } = permissions;

      if (!can_delete || !parentId) {
        return;
      }

      if (!isDeleteModalOpen) {
        this.setState({
          isDeleteModalOpen: true
        });
        return;
      }

      this.setState({
        isLoading: true
      });
      this.api.getAPI(type).deleteItem(selected, () => {
        onDelete(cloneDeep([selected]));
        this.refreshCollection();
      }, () => {
        this.refreshCollection();
      });
    });

    _defineProperty(this, "rename", item => {
      this.select(item, this.renameCallback);
    });

    _defineProperty(this, "renameCallback", (nameWithoutExt, extension) => {
      const {
        selected,
        isRenameModalOpen
      } = this.state;
      const {
        canRename,
        onRename
      } = this.props;

      if (!selected || !canRename) {
        return;
      }

      const {
        id,
        permissions,
        type
      } = selected;

      if (!id || !permissions || !type) {
        return;
      }

      const {
        can_rename
      } = permissions;

      if (!can_rename) {
        return;
      }

      if (!isRenameModalOpen || !nameWithoutExt) {
        this.setState({
          isRenameModalOpen: true,
          errorCode: ''
        });
        return;
      }

      const name = "".concat(nameWithoutExt).concat(extension);

      if (!nameWithoutExt.trim()) {
        this.setState({
          errorCode: ERROR_CODE_ITEM_NAME_INVALID,
          isLoading: false
        });
        return;
      }

      this.setState({
        isLoading: true
      });
      this.api.getAPI(type).rename(selected, name.trim(), updatedItem => {
        this.setState({
          isRenameModalOpen: false
        });
        this.refreshCollection();
        this.select(updatedItem);
        onRename(cloneDeep(selected));
      }, (_ref) => {
        let {
          code
        } = _ref;
        this.setState({
          errorCode: code,
          isLoading: false
        });
      });
    });

    _defineProperty(this, "createFolder", () => {
      this.createFolderCallback();
    });

    _defineProperty(this, "createFolderCallback", name => {
      const {
        isCreateFolderModalOpen,
        currentCollection
      } = this.state;
      const {
        canCreateNewFolder,
        onCreate
      } = this.props;

      if (!canCreateNewFolder) {
        return;
      }

      const {
        id,
        permissions
      } = currentCollection;

      if (!id || !permissions) {
        return;
      }

      const {
        can_upload
      } = permissions;

      if (!can_upload) {
        return;
      }

      if (!isCreateFolderModalOpen || !name) {
        this.setState({
          isCreateFolderModalOpen: true,
          errorCode: ''
        });
        return;
      }

      if (!name.trim()) {
        this.setState({
          errorCode: ERROR_CODE_ITEM_NAME_INVALID,
          isLoading: false
        });
        return;
      }

      if (name.length > 255) {
        this.setState({
          errorCode: ERROR_CODE_ITEM_NAME_TOO_LONG,
          isLoading: false
        });
        return;
      }

      this.setState({
        isLoading: true
      });
      this.api.getFolderAPI().create(id, name.trim(), item => {
        this.refreshCollection();
        this.select(item);
        onCreate(cloneDeep(item));
      }, (_ref2) => {
        let {
          code
        } = _ref2;
        this.setState({
          errorCode: code,
          isLoading: false
        });
      });
    });

    _defineProperty(this, "share", item => {
      this.select(item, this.shareCallback);
    });

    _defineProperty(this, "fetchSharedLinkInfo", item => {
      const {
        id,
        type
      } = item;

      switch (type) {
        case TYPE_FOLDER:
          this.api.getFolderAPI().getFolderFields(id, this.handleSharedLinkSuccess, noop, {
            fields: FILE_SHARED_LINK_FIELDS_TO_FETCH
          });
          break;

        case TYPE_FILE:
          this.api.getFileAPI().getFile(id, this.handleSharedLinkSuccess, noop, {
            fields: FILE_SHARED_LINK_FIELDS_TO_FETCH
          });
          break;

        case TYPE_WEBLINK:
          this.api.getWebLinkAPI().getWeblink(id, this.handleSharedLinkSuccess, noop, {
            fields: FILE_SHARED_LINK_FIELDS_TO_FETCH
          });
          break;

        default:
          throw new Error('Unknown Type');
      }
    });

    _defineProperty(this, "handleSharedLinkSuccess", async item => {
      const {
        currentCollection
      } = this.state;
      let updatedItem = item; // if there is no shared link, create one with enterprise default access

      if (!item[FIELD_SHARED_LINK] && getProp(item, FIELD_PERMISSIONS_CAN_SHARE, false)) {
        // $FlowFixMe
        await this.api.getAPI(item.type).share(item, undefined, sharedItem => {
          updatedItem = sharedItem;
        });
      }

      this.updateCollection(currentCollection, updatedItem, () => this.setState({
        isShareModalOpen: true
      }));
    });

    _defineProperty(this, "shareCallback", () => {
      const {
        selected
      } = this.state;
      const {
        canShare
      } = this.props;

      if (!selected || !canShare) {
        return;
      }

      const {
        permissions,
        type
      } = selected;

      if (!permissions || !type) {
        return;
      }

      const {
        can_share
      } = permissions;

      if (!can_share) {
        return;
      }

      this.fetchSharedLinkInfo(selected);
    });

    _defineProperty(this, "tableRef", table => {
      this.table = table;
    });

    _defineProperty(this, "closeModals", () => {
      const {
        focusedRow
      } = this.state;
      this.setState({
        isLoading: false,
        isDeleteModalOpen: false,
        isRenameModalOpen: false,
        isCreateFolderModalOpen: false,
        isShareModalOpen: false,
        isUploadModalOpen: false,
        isPreviewModalOpen: false
      });
      const {
        selected,
        currentCollection: {
          items = []
        }
      } = this.state;

      if (selected && items.length > 0) {
        focus(this.rootElement, ".bce-item-row-".concat(focusedRow));
      }
    });

    _defineProperty(this, "isFocusOnItem", () => {
      var _document$activeEleme;

      const focusedElementClassList = (_document$activeEleme = document.activeElement) === null || _document$activeEleme === void 0 ? void 0 : _document$activeEleme.classList;
      return focusedElementClassList && focusedElementClassList.contains('be-item-label');
    });

    _defineProperty(this, "onKeyDown", event => {
      if (isInputElement(event.target)) {
        return;
      }

      const {
        rootFolderId
      } = this.props;
      const key = event.key.toLowerCase();

      switch (key) {
        case '/':
          focus(this.rootElement, '.be-search input[type="search"]', false);
          event.preventDefault();
          break;

        case 'arrowdown':
          if (this.getViewMode() === VIEW_MODE_GRID) {
            if (!this.isFocusOnItem()) {
              focus(this.rootElement, '.be-item-name .be-item-label', false);
              event.preventDefault();
            }
          } else {
            focus(this.rootElement, '.bce-item-row', false);
            this.setState({
              focusedRow: 0
            });
            event.preventDefault();
          }

          break;

        case 'g':
          break;

        case 'b':
          if (this.globalModifier) {
            focus(this.rootElement, '.be-breadcrumb button', false);
            event.preventDefault();
          }

          break;

        case 'f':
          if (this.globalModifier) {
            this.fetchFolder(rootFolderId);
            event.preventDefault();
          }

          break;

        case 'u':
          if (this.globalModifier) {
            this.upload();
            event.preventDefault();
          }

          break;

        case 'r':
          if (this.globalModifier) {
            this.showRecents();
            event.preventDefault();
          }

          break;

        case 'n':
          if (this.globalModifier) {
            this.createFolder();
            event.preventDefault();
          }

          break;

        default:
          this.globalModifier = false;
          return;
      }

      this.globalModifier = key === 'g';
    });

    _defineProperty(this, "paginate", newOffset => {
      this.setState({
        currentOffset: newOffset
      }, this.refreshCollection);
    });

    _defineProperty(this, "markerBasedPaginate", newOffset => {
      const {
        currentPageNumber
      } = this.state;
      this.setState({
        currentPageNumber: currentPageNumber + newOffset // newOffset could be negative

      }, this.refreshCollection);
    });

    _defineProperty(this, "getViewMode", () => this.store.getItem(localStoreViewMode) || VIEW_MODE_LIST);

    _defineProperty(this, "getMaxNumberOfGridViewColumnsForWidth", () => {
      const {
        isSmall,
        isMedium,
        isLarge
      } = this.props;
      let maxWidthColumns = GRID_VIEW_MAX_COLUMNS;

      if (isSmall) {
        maxWidthColumns = 1;
      } else if (isMedium) {
        maxWidthColumns = 3;
      } else if (isLarge) {
        maxWidthColumns = 5;
      }

      return maxWidthColumns;
    });

    _defineProperty(this, "changeViewMode", viewMode => {
      this.store.setItem(localStoreViewMode, viewMode);
      this.forceUpdate();
    });

    _defineProperty(this, "onGridViewSliderChange", sliderValue => {
      // need to do this calculation since lowest value of grid view slider
      // means highest number of columns
      const gridColumnCount = GRID_VIEW_MAX_COLUMNS - sliderValue + 1;
      this.setState({
        gridColumnCount
      });
    });

    _defineProperty(this, "updateMetadata", (item, field, oldValue, newValue) => {
      this.metadataQueryAPIHelper.updateMetadata(item, field, oldValue, newValue, () => {
        this.updateMetadataSuccessCallback(item, field, newValue);
      }, this.errorCallback);
    });

    _defineProperty(this, "updateMetadataSuccessCallback", (item, field, newValue) => {
      const {
        currentCollection
      } = this.state;
      const {
        items = [],
        nextMarker
      } = currentCollection;
      const updatedItems = items.map(collectionItem => {
        const clonedItem = cloneDeep(collectionItem);

        if (item.id === clonedItem.id) {
          const fields = getProp(clonedItem, 'metadata.enterprise.fields', []);
          fields.forEach(itemField => {
            if (itemField.key.split('.').pop() === field) {
              itemField.value = newValue; // set updated metadata value to correct item in currentCollection
            }
          });
        }

        return clonedItem;
      });
      this.setState({
        currentCollection: {
          items: updatedItems,
          nextMarker,
          percentLoaded: 100
        }
      });
    });

    const {
      apiHost,
      initialPage,
      initialPageSize,
      language,
      requestInterceptor,
      responseInterceptor,
      rootFolderId: _rootFolderId,
      sharedLink,
      sharedLinkPassword,
      sortBy: _sortBy,
      sortDirection: _sortDirection,
      token,
      uploadHost
    } = props;
    this.api = new API({
      apiHost,
      clientName: CLIENT_NAME_CONTENT_EXPLORER,
      id: "".concat(TYPED_ID_FOLDER_PREFIX).concat(_rootFolderId),
      language,
      requestInterceptor,
      responseInterceptor,
      sharedLink,
      sharedLinkPassword,
      token,
      uploadHost
    });
    this.id = uniqueid('bce_');
    this.state = {
      currentCollection: {},
      currentOffset: initialPageSize * (initialPage - 1),
      currentPageSize: initialPageSize,
      currentPageNumber: 0,
      errorCode: '',
      focusedRow: 0,
      gridColumnCount: 4,
      isCreateFolderModalOpen: false,
      isDeleteModalOpen: false,
      isLoading: false,
      isPreviewModalOpen: false,
      isRenameModalOpen: false,
      isShareModalOpen: false,
      isUploadModalOpen: false,
      markers: [],
      rootName: '',
      searchQuery: '',
      sortBy: _sortBy,
      sortDirection: _sortDirection,
      view: VIEW_FOLDER
    };
  }
  /**
   * Destroys api instances
   *
   * @private
   * @return {void}
   */


  clearCache() {
    this.api.destroy(true);
  }
  /**
   * Cleanup
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentWillUnmount() {
    this.clearCache();
  }
  /**
   * Fetches the root folder on load
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentDidMount() {
    const {
      currentFolderId,
      defaultView
    } = this.props;
    this.rootElement = document.getElementById(this.id);
    this.appElement = this.rootElement.firstElementChild;

    switch (defaultView) {
      case DEFAULT_VIEW_RECENTS:
        this.showRecents();
        break;

      case DEFAULT_VIEW_METADATA:
        this.showMetadataQueryResults();
        break;

      default:
        this.fetchFolder(currentFolderId);
    }
  }
  /**
   * Fetches the current folder if different
   * from what was already fetched before.
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentDidUpdate(_ref3, prevState) {
    let {
      currentFolderId: prevFolderId
    } = _ref3;
    const {
      currentFolderId
    } = this.props;
    const {
      currentCollection: {
        id
      }
    } = prevState;

    if (prevFolderId === currentFolderId) {
      return;
    }

    if (typeof currentFolderId === 'string' && id !== currentFolderId) {
      this.fetchFolder(currentFolderId);
    }
  }
  /**
   * Metadata queries success callback
   *
   * @private
   * @param {Object} metadataQueryCollection - Metadata query response collection
   * @return {void}
   */


  /**
   * Queries metadata_queries/execute API and fetches the result
   *
   * @private
   * @return {void}
   */
  showMetadataQueryResults() {
    const {
      metadataQuery = {}
    } = this.props;
    const {
      currentPageNumber,
      markers
    } = this.state;
    const metadataQueryClone = cloneDeep(metadataQuery);

    if (currentPageNumber === 0) {
      // Preserve the marker as part of the original query
      markers[currentPageNumber] = metadataQueryClone.marker;
    }

    if (typeof markers[currentPageNumber] === 'string') {
      // Set marker to the query to get next set of results
      metadataQueryClone.marker = markers[currentPageNumber];
    }

    if (typeof metadataQueryClone.limit !== 'number') {
      // Set limit to the query for pagination support
      metadataQueryClone.limit = DEFAULT_PAGE_SIZE;
    } // Reset search state, the view and show busy indicator


    this.setState({
      searchQuery: '',
      currentCollection: this.currentUnloadedCollection(),
      view: VIEW_METADATA
    });
    this.metadataQueryAPIHelper = new MetadataQueryAPIHelper(this.api);
    this.metadataQueryAPIHelper.fetchMetadataQueryResults(metadataQueryClone, this.showMetadataQueryResultsSuccessCallback, this.errorCallback);
  }
  /**
   * Resets the collection so that the loading bar starts showing
   *
   * @private
   * @return {Collection}
   */


  currentUnloadedCollection() {
    const {
      currentCollection
    } = this.state;
    return _extends(currentCollection, {
      percentLoaded: 0
    });
  }
  /**
   * Network error callback
   *
   * @private
   * @param {Error} error error object
   * @return {void}
   */


  /**
   * Focuses the grid and fires navigate event
   *
   * @private
   * @return {void}
   */
  finishNavigation() {
    const {
      autoFocus
    } = this.props;
    const {
      currentCollection: {
        percentLoaded
      }
    } = this.state; // If loading for the very first time, only allow focus if autoFocus is true

    if (this.firstLoad && !autoFocus) {
      this.firstLoad = false;
      return;
    } // Don't focus the grid until its loaded and user is not already on an interactable element


    if (percentLoaded === 100 && !isFocusableElement(document.activeElement)) {
      focus(this.rootElement, '.bce-item-row');
      this.setState({
        focusedRow: 0
      });
    }

    this.firstLoad = false;
  }
  /**
   * Refreshing the item collection depending upon the view.
   * Navigation event is prevented.
   *
   * @private
   * @return {void}
   */


  /**
   * Folder fetch success callback
   *
   * @private
   * @param {Object} collection - item collection object
   * @param {Boolean|void} triggerNavigationEvent - To trigger navigate event and focus grid
   * @return {void}
   */
  fetchFolderSuccessCallback(collection, triggerNavigationEvent) {
    const {
      onNavigate,
      rootFolderId
    } = this.props;
    const {
      boxItem,
      id,
      name
    } = collection;
    const {
      selected
    } = this.state;
    const rootName = id === rootFolderId ? name : ''; // Close any open modals

    this.closeModals();
    this.updateCollection(collection, selected, () => {
      if (triggerNavigationEvent) {
        // Fire folder navigation event
        this.setState({
          rootName
        }, this.finishNavigation);

        if (boxItem) {
          onNavigate(cloneDeep(boxItem));
        }
      } else {
        this.setState({
          rootName
        });
      }
    });
  }
  /**
   * Fetches a folder, defaults to fetching root folder
   *
   * @private
   * @param {string|void} [id] folder id
   * @param {Boolean|void} [triggerNavigationEvent] To trigger navigate event
   * @return {void}
   */


  /**
   * Recents fetch success callback
   *
   * @private
   * @param {Object} collection item collection object
   * @param {Boolean} triggerNavigationEvent - To trigger navigate event
   * @return {void}
   */
  recentsSuccessCallback(collection, triggerNavigationEvent) {
    if (triggerNavigationEvent) {
      this.updateCollection(collection, undefined, this.finishNavigation);
    } else {
      this.updateCollection(collection);
    }
  }
  /**
   * Shows recents.
   *
   * @private
   * @param {Boolean|void} [triggerNavigationEvent] To trigger navigate event
   * @return {void}
   */


  showRecents() {
    let triggerNavigationEvent = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    const {
      rootFolderId
    } = this.props; // Reset search state, the view and show busy indicator

    this.setState({
      searchQuery: '',
      view: VIEW_RECENTS,
      currentCollection: this.currentUnloadedCollection(),
      currentOffset: 0
    }); // Fetch the folder using folder API

    this.api.getRecentsAPI().recents(rootFolderId, collection => {
      this.recentsSuccessCallback(collection, triggerNavigationEvent);
    }, this.errorCallback, {
      fields: CONTENT_EXPLORER_FOLDER_FIELDS_TO_FETCH,
      forceFetch: true
    });
  }
  /**
   * Uploads
   *
   * @private
   * @param {File} file dom file object
   * @return {void}
   */


  /**
   * Sets state with currentCollection updated to have items.selected properties
   * set according to the given selected param. Also updates the selected item in the
   * currentCollection. selectedItem will be set to the selected state
   * item if it is in currentCollection, otherwise it will be set to undefined.
   *
   * @private
   * @param {Collection} collection - collection that needs to be updated
   * @param {Object} [selectedItem] - The item that should be selected in that collection (if present)
   * @param {Function} [callback] - callback function that should be called after setState occurs
   * @return {void}
   */
  async updateCollection(collection, selectedItem) {
    let callback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : noop;
    const newCollection = cloneDeep(collection);
    const {
      items = []
    } = newCollection;
    const fileAPI = this.api.getFileAPI(false);
    const selectedId = selectedItem ? selectedItem.id : null;
    let newSelectedItem;
    const itemThumbnails = await Promise.all(items.map(item => {
      return item.type === TYPE_FILE ? fileAPI.getThumbnailUrl(item) : null;
    }));
    newCollection.items = items.map((item, index) => {
      const isSelected = item.id === selectedId;
      const currentItem = isSelected ? selectedItem : item;
      const thumbnailUrl = itemThumbnails[index];

      const newItem = _objectSpread({}, currentItem, {
        selected: isSelected,
        thumbnailUrl
      });

      if (item.type === TYPE_FILE && thumbnailUrl && !isThumbnailReady(newItem)) {
        this.attemptThumbnailGeneration(newItem);
      } // Only if selectedItem is in the current collection do we want to set selected state


      if (isSelected) {
        newSelectedItem = newItem;
      }

      return newItem;
    });
    this.setState({
      currentCollection: newCollection,
      selected: newSelectedItem
    }, callback);
  }
  /**
   * Attempts to generate a thumbnail for the given item and assigns the
   * item its thumbnail url if successful
   *
   * @param {BoxItem} item - item to generate thumbnail for
   * @return {Promise<void>}
   */


  /**
   * Renders the file picker
   *
   * @private
   * @inheritdoc
   * @return {Element}
   */
  render() {
    const {
      apiHost,
      appHost,
      canCreateNewFolder,
      canDelete,
      canDownload,
      canPreview,
      canRename,
      canSetShareAccess,
      canShare,
      canUpload,
      className,
      contentPreviewProps,
      contentUploaderProps,
      defaultView,
      isMedium,
      isSmall,
      isTouch,
      language,
      logoUrl,
      measureRef,
      messages,
      fieldsToShow,
      onDownload,
      onPreview,
      onUpload,
      requestInterceptor,
      responseInterceptor,
      rootFolderId,
      sharedLink,
      sharedLinkPassword,
      staticHost,
      staticPath,
      previewLibraryVersion,
      token,
      uploadHost
    } = this.props;
    const {
      currentCollection,
      currentPageNumber,
      currentPageSize,
      errorCode,
      focusedRow,
      gridColumnCount,
      isCreateFolderModalOpen,
      isDeleteModalOpen,
      isLoading,
      isPreviewModalOpen,
      isRenameModalOpen,
      isShareModalOpen,
      isUploadModalOpen,
      markers,
      rootName,
      searchQuery,
      selected,
      view
    } = this.state;
    const {
      id,
      offset,
      permissions,
      totalCount
    } = currentCollection;
    const {
      can_upload
    } = permissions || {};
    const styleClassName = classNames('be bce', className);
    const allowUpload = canUpload && !!can_upload;
    const allowCreate = canCreateNewFolder && !!can_upload;
    const isDefaultViewMetadata = defaultView === DEFAULT_VIEW_METADATA;
    const isErrorView = view === VIEW_ERROR;
    const viewMode = this.getViewMode();
    const maxGridColumnCount = this.getMaxNumberOfGridViewColumnsForWidth();
    const hasNextMarker = !!markers[currentPageNumber + 1];
    const hasPreviousMarker = currentPageNumber === 1 || !!markers[currentPageNumber - 1];
    /* eslint-disable jsx-a11y/no-static-element-interactions */

    /* eslint-disable jsx-a11y/no-noninteractive-tabindex */

    return React.createElement(Internationalize, {
      language: language,
      messages: messages
    }, React.createElement("div", {
      id: this.id,
      className: styleClassName,
      ref: measureRef,
      "data-testid": "content-explorer"
    }, React.createElement("div", {
      className: "be-app-element",
      onKeyDown: this.onKeyDown,
      tabIndex: 0
    }, !isDefaultViewMetadata && React.createElement(React.Fragment, null, React.createElement(Header, {
      view: view,
      isSmall: isSmall,
      searchQuery: searchQuery,
      logoUrl: logoUrl,
      onSearch: this.search
    }), React.createElement(SubHeader, {
      view: view,
      viewMode: viewMode,
      rootId: rootFolderId,
      isSmall: isSmall,
      rootName: rootName,
      currentCollection: currentCollection,
      canUpload: allowUpload,
      canCreateNewFolder: allowCreate,
      gridColumnCount: gridColumnCount,
      gridMaxColumns: GRID_VIEW_MAX_COLUMNS,
      gridMinColumns: GRID_VIEW_MIN_COLUMNS,
      maxGridColumnCountForWidth: maxGridColumnCount,
      onUpload: this.upload,
      onCreate: this.createFolder,
      onGridViewSliderChange: this.onGridViewSliderChange,
      onItemClick: this.fetchFolder,
      onSortChange: this.sort,
      onViewModeChange: this.changeViewMode
    })), React.createElement(Content, {
      canDelete: canDelete,
      canDownload: canDownload,
      canPreview: canPreview,
      canRename: canRename,
      canShare: canShare,
      currentCollection: currentCollection,
      focusedRow: focusedRow,
      gridColumnCount: Math.min(gridColumnCount, maxGridColumnCount),
      isMedium: isMedium,
      isSmall: isSmall,
      isTouch: isTouch,
      fieldsToShow: fieldsToShow,
      onItemClick: this.onItemClick,
      onItemDelete: this.delete,
      onItemDownload: this.download,
      onItemPreview: this.preview,
      onItemRename: this.rename,
      onItemSelect: this.select,
      onItemShare: this.share,
      onMetadataUpdate: this.updateMetadata,
      onSortChange: this.sort,
      rootElement: this.rootElement,
      rootId: rootFolderId,
      selected: selected,
      tableRef: this.tableRef,
      view: view,
      viewMode: viewMode
    }), !isErrorView && React.createElement(Footer, null, React.createElement(Pagination, {
      hasNextMarker: hasNextMarker,
      hasPrevMarker: hasPreviousMarker,
      offset: offset,
      onOffsetChange: this.paginate,
      pageSize: currentPageSize,
      totalCount: totalCount,
      onMarkerBasedPageChange: this.markerBasedPaginate
    }))), allowUpload && !!this.appElement ? React.createElement(UploadDialog, {
      isOpen: isUploadModalOpen,
      currentFolderId: id,
      token: token,
      sharedLink: sharedLink,
      sharedLinkPassword: sharedLinkPassword,
      apiHost: apiHost,
      uploadHost: uploadHost,
      onClose: this.uploadSuccessHandler,
      parentElement: this.rootElement,
      appElement: this.appElement,
      onUpload: onUpload,
      contentUploaderProps: contentUploaderProps,
      requestInterceptor: requestInterceptor,
      responseInterceptor: responseInterceptor
    }) : null, allowCreate && !!this.appElement ? React.createElement(CreateFolderDialog, {
      isOpen: isCreateFolderModalOpen,
      onCreate: this.createFolderCallback,
      onCancel: this.closeModals,
      isLoading: isLoading,
      errorCode: errorCode,
      parentElement: this.rootElement,
      appElement: this.appElement
    }) : null, canDelete && selected && !!this.appElement ? React.createElement(DeleteConfirmationDialog, {
      isOpen: isDeleteModalOpen,
      onDelete: this.deleteCallback,
      onCancel: this.closeModals,
      item: selected,
      isLoading: isLoading,
      parentElement: this.rootElement,
      appElement: this.appElement
    }) : null, canRename && selected && !!this.appElement ? React.createElement(RenameDialog, {
      isOpen: isRenameModalOpen,
      onRename: this.renameCallback,
      onCancel: this.closeModals,
      item: selected,
      isLoading: isLoading,
      errorCode: errorCode,
      parentElement: this.rootElement,
      appElement: this.appElement
    }) : null, canShare && selected && !!this.appElement ? React.createElement(ShareDialog, {
      isOpen: isShareModalOpen,
      canSetShareAccess: canSetShareAccess,
      onShareAccessChange: this.changeShareAccess,
      onCancel: this.refreshCollection,
      item: selected,
      isLoading: isLoading,
      parentElement: this.rootElement,
      appElement: this.appElement
    }) : null, canPreview && selected && !!this.appElement ? React.createElement(PreviewDialog, {
      isOpen: isPreviewModalOpen,
      isTouch: isTouch,
      onCancel: this.closeModals,
      item: selected,
      currentCollection: cloneDeep(currentCollection),
      token: token,
      parentElement: this.rootElement,
      appElement: this.appElement,
      onPreview: onPreview,
      onDownload: onDownload,
      canDownload: canDownload,
      cache: this.api.getCache(),
      apiHost: apiHost,
      appHost: appHost,
      staticHost: staticHost,
      staticPath: staticPath,
      previewLibraryVersion: previewLibraryVersion,
      sharedLink: sharedLink,
      sharedLinkPassword: sharedLinkPassword,
      contentPreviewProps: contentPreviewProps,
      requestInterceptor: requestInterceptor,
      responseInterceptor: responseInterceptor
    }) : null));
    /* eslint-enable jsx-a11y/no-static-element-interactions */

    /* eslint-enable jsx-a11y/no-noninteractive-tabindex */
  }

}

_defineProperty(ContentExplorer, "defaultProps", {
  rootFolderId: DEFAULT_ROOT,
  sortBy: FIELD_NAME,
  sortDirection: SORT_ASC,
  canDownload: true,
  canDelete: true,
  canUpload: true,
  canRename: true,
  canShare: true,
  canPreview: true,
  canSetShareAccess: true,
  canCreateNewFolder: true,
  autoFocus: false,
  apiHost: DEFAULT_HOSTNAME_API,
  appHost: DEFAULT_HOSTNAME_APP,
  staticHost: DEFAULT_HOSTNAME_STATIC,
  uploadHost: DEFAULT_HOSTNAME_UPLOAD,
  className: '',
  onDelete: noop,
  onDownload: noop,
  onPreview: noop,
  onRename: noop,
  onCreate: noop,
  onSelect: noop,
  onUpload: noop,
  onNavigate: noop,
  defaultView: DEFAULT_VIEW_FILES,
  initialPage: DEFAULT_PAGE_NUMBER,
  initialPageSize: DEFAULT_PAGE_SIZE,
  contentPreviewProps: {
    contentSidebarProps: {}
  },
  contentUploaderProps: {}
});

export { ContentExplorer as ContentExplorerComponent };
export default flow([makeResponsive, withFeatureConsumer, withFeatureProvider])(ContentExplorer);
//# sourceMappingURL=ContentExplorer.js.map