import React from 'react';
import { FormattedMessage, injectIntl } from 'react-intl';
import Button from '../../components/button/Button';
import DropdownMenu from '../../components/dropdown-menu/DropdownMenu';
import Menu from '../../components/menu/Menu';
import MenuItem from '../../components/menu/MenuItem';
import Browser from '../../utils/Browser';
import IconEllipsis from '../../icons/general/IconEllipsis';
import { bdlGray } from '../../styles/variables';
import messages from '../common/messages';
import { PERMISSION_CAN_DOWNLOAD, PERMISSION_CAN_RENAME, PERMISSION_CAN_DELETE, PERMISSION_CAN_SHARE, PERMISSION_CAN_PREVIEW, TYPE_FILE, TYPE_WEBLINK } from '../../constants';
import './MoreOptionsCell.scss';

const MoreOptions = (_ref) => {
  let {
    canPreview,
    canShare,
    canDownload,
    canDelete,
    canRename,
    onItemSelect,
    onItemDelete,
    onItemDownload,
    onItemRename,
    onItemShare,
    onItemPreview,
    intl,
    isSmall,
    item
  } = _ref;

  const onFocus = () => onItemSelect(item);

  const onDelete = () => onItemDelete(item);

  const onDownload = () => onItemDownload(item);

  const onRename = () => onItemRename(item);

  const onShare = () => onItemShare(item);

  const onPreview = () => onItemPreview(item);

  const {
    permissions,
    type
  } = item;

  if (!permissions) {
    return React.createElement("span", null);
  }

  const allowPreview = type === TYPE_FILE && canPreview && permissions[PERMISSION_CAN_PREVIEW];
  const allowOpen = type === TYPE_WEBLINK;
  const allowDelete = canDelete && permissions[PERMISSION_CAN_DELETE];
  const allowShare = canShare && permissions[PERMISSION_CAN_SHARE];
  const allowRename = canRename && permissions[PERMISSION_CAN_RENAME];
  const allowDownload = canDownload && permissions[PERMISSION_CAN_DOWNLOAD] && type === TYPE_FILE && Browser.canDownload();
  const allowed = allowDelete || allowRename || allowDownload || allowPreview || allowShare || allowOpen;

  if (!allowed) {
    return React.createElement("span", null);
  }

  return React.createElement("div", {
    className: "bce-more-options"
  }, React.createElement(DropdownMenu, {
    constrainToScrollParent: true,
    isRightAligned: true
  }, React.createElement(Button, {
    "aria-label": intl.formatMessage(messages.moreOptions),
    className: "bce-btn-more-options",
    "data-testid": "bce-btn-more-options",
    onFocus: onFocus,
    type: "button"
  }, React.createElement(IconEllipsis, {
    color: bdlGray,
    height: 10,
    width: 16
  })), React.createElement(Menu, null, allowPreview && React.createElement(MenuItem, {
    onClick: onPreview
  }, React.createElement(FormattedMessage, messages.preview)), allowOpen && React.createElement(MenuItem, {
    onClick: onPreview
  }, React.createElement(FormattedMessage, messages.open)), allowDelete && React.createElement(MenuItem, {
    onClick: onDelete
  }, React.createElement(FormattedMessage, messages.delete)), allowDownload && React.createElement(MenuItem, {
    onClick: onDownload
  }, React.createElement(FormattedMessage, messages.download)), allowRename && React.createElement(MenuItem, {
    onClick: onRename
  }, React.createElement(FormattedMessage, messages.rename)), allowShare && React.createElement(MenuItem, {
    onClick: onShare
  }, React.createElement(FormattedMessage, messages.share)))), allowShare && !isSmall && React.createElement(Button, {
    onClick: onShare,
    onFocus: onFocus,
    type: "button"
  }, React.createElement(FormattedMessage, messages.share)));
};

export default injectIntl(MoreOptions);
//# sourceMappingURL=MoreOptions.js.map