function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Open With Component
 * @author Box
 */
import React, { PureComponent } from 'react';
import classNames from 'classnames';
import uniqueid from 'lodash/uniqueId';
import noop from 'lodash/noop';
import { FormattedMessage } from 'react-intl';
import queryString from 'query-string';
import Internationalize from '../common/Internationalize';
import messages from '../common/messages';
import { withErrorBoundary } from '../common/error-boundary';
import API from '../../api';
import IntegrationPortalContainer from './IntegrationPortalContainer';
import OpenWithDropdownMenu from './OpenWithDropdownMenu';
import BoxToolsInstallMessage from './BoxToolsInstallMessage';
import OpenWithButton from './OpenWithButton';
import OpenWithFallbackButton from './OpenWithFallbackButton';
import ExecuteForm from './ExecuteForm';
import '../common/base.scss';
import './ContentOpenWith.scss';
import { BOX_EDIT_INTEGRATION_ID, BOX_EDIT_SFC_INTEGRATION_ID, CLIENT_NAME_OPEN_WITH, DEFAULT_HOSTNAME_API, ERROR_CODE_EXECUTE_INTEGRATION, HTTP_GET, HTTP_POST, ORIGIN_OPEN_WITH, TYPE_FILE, TYPE_FOLDER } from '../../constants';
const UNSUPPORTED_INVOCATION_METHOD_TYPE = 'Integration invocation using this HTTP method type is not supported';
const BLACKLISTED_ERROR_MESSAGE_KEY = 'boxToolsBlacklistedError';
const BOX_TOOLS_INSTALL_ERROR_MESSAGE_KEY = 'boxToolsInstallErrorMessage';
const GENERIC_EXECUTE_MESSAGE_KEY = 'executeIntegrationOpenWithErrorHeader';
const AUTH_CODE = 'auth_code';

class ContentOpenWith extends PureComponent {
  /**
   * [constructor]
   *
   * @private
   * @return {ContentOpenWith}
   */
  constructor(props) {
    super(props);

    _defineProperty(this, "initialState", {
      isDropdownOpen: false,
      integrations: null,
      isLoading: true,
      fetchError: null,
      executePostData: null,
      shouldRenderErrorIntegrationPortal: false,
      shouldRenderLoadingIntegrationPortal: false
    });

    _defineProperty(this, "fetchOpenWithSuccessHandler", async integrations => {
      const {
        boxToolsName,
        boxToolsInstallUrl
      } = this.props;
      const boxEditIntegration = integrations.find((_ref) => {
        let {
          appIntegrationId
        } = _ref;
        return this.isBoxEditIntegration(appIntegrationId);
      });

      if (boxEditIntegration && !boxEditIntegration.isDisabled) {
        try {
          const {
            extension
          } = await this.getIntegrationFileExtension();
          boxEditIntegration.extension = extension; // If Box Edit is present and enabled, we need to set its ability to locally open the given file
          // No-op if these checks are successful

          await this.isBoxEditAvailable();
          await this.canOpenExtensionWithBoxEdit(boxEditIntegration);
        } catch (error) {
          const errorMessageObject = messages[error.message] || messages[GENERIC_EXECUTE_MESSAGE_KEY];
          let formattedErrorMessage = React.createElement(FormattedMessage, errorMessageObject);

          if (error.message === BOX_TOOLS_INSTALL_ERROR_MESSAGE_KEY) {
            formattedErrorMessage = React.createElement(BoxToolsInstallMessage, {
              boxToolsInstallUrl: boxToolsInstallUrl,
              boxToolsName: boxToolsName
            });
          }

          boxEditIntegration.disabledReasons.push(formattedErrorMessage);
          boxEditIntegration.isDisabled = true;
        }
      }

      this.setState({
        integrations,
        isLoading: false
      });
    });

    _defineProperty(this, "getIntegrationFileExtension", () => {
      const {
        fileId
      } = this.props;
      return new Promise((resolve, reject) => {
        this.api.getFileAPI().getFileExtension(fileId, resolve, () => reject(new Error(GENERIC_EXECUTE_MESSAGE_KEY)));
      });
    });

    _defineProperty(this, "isBoxEditAvailable", () => {
      return this.api.getBoxEditAPI().checkBoxEditAvailability().catch(() => {
        throw new Error(BOX_TOOLS_INSTALL_ERROR_MESSAGE_KEY);
      });
    });

    _defineProperty(this, "canOpenExtensionWithBoxEdit", (_ref2) => {
      let {
        extension = ''
      } = _ref2;
      return this.api.getBoxEditAPI().getAppForExtension(extension).catch(() => {
        throw new Error(BLACKLISTED_ERROR_MESSAGE_KEY);
      });
    });

    _defineProperty(this, "fetchErrorHandler", (error, code) => {
      this.props.onError(error, code, {
        error
      });
      this.setState({
        fetchError: error,
        isLoading: false
      });
    });

    _defineProperty(this, "onIntegrationClick", (_ref3) => {
      let {
        appIntegrationId,
        displayName
      } = _ref3;
      const {
        fileId
      } = this.props;
      const isBoxEditIntegration = this.isBoxEditIntegration(appIntegrationId);
      this.api.getAppIntegrationsAPI(false).execute(appIntegrationId, fileId, this.executeIntegrationSuccessHandler.bind(this, appIntegrationId), isBoxEditIntegration ? this.executeBoxEditErrorHandler : this.executeIntegrationErrorHandler);

      if (isBoxEditIntegration) {
        // No window management is required when using Box Edit.
        return;
      } // These window features will open the new window directly on top of the current window at the same


      const windowFeatures = "left=".concat(window.screenX, ",top=").concat(window.screenY, ",height=").concat(window.outerHeight, ",width=").concat(window.innerWidth, ",toolbar=0"); // window.open() is immediately invoked to avoid popup-blockers
      // The name is included to be the target of a form if the integration is a POST integration.
      // A uniqueid is used to force the browser to open a new tab every time, while still allowing
      // a form to reference a given tab.

      this.integrationWindow = this.window.open('', "".concat(uniqueid(appIntegrationId)), windowFeatures);
      this.integrationWindow.document.title = displayName;
      this.integrationWindow.onunload = this.cleanupIntegrationWindow;
      this.setState({
        shouldRenderLoadingIntegrationPortal: true,
        shouldRenderErrorIntegrationPortal: false
      });
    });

    _defineProperty(this, "cleanupIntegrationWindow", () => {
      this.setState({
        shouldRenderLoadingIntegrationPortal: false,
        shouldRenderErrorIntegrationPortal: false
      });
    });

    _defineProperty(this, "executeIntegrationSuccessHandler", (integrationId, executeData) => {
      if (this.isBoxEditIntegration(integrationId)) {
        this.executeBoxEditSuccessHandler(integrationId, executeData);
      } else {
        this.executeOnlineIntegrationSuccessHandler(executeData);
      }

      this.onExecute(integrationId);
    });

    _defineProperty(this, "executeOnlineIntegrationSuccessHandler", executeData => {
      const {
        method,
        url
      } = executeData;

      switch (method) {
        case HTTP_POST:
          this.setState({
            executePostData: executeData
          });
          break;

        case HTTP_GET:
          if (!this.integrationWindow) {
            return;
          } // Prevents abuse of window.opener
          // see here for more details: https://mathiasbynens.github.io/rel-noopener/


          this.integrationWindow.location = url;
          this.integrationWindow.opener = null;
          break;

        default:
          this.executeIntegrationErrorHandler(Error(UNSUPPORTED_INVOCATION_METHOD_TYPE), ERROR_CODE_EXECUTE_INTEGRATION);
      }

      this.integrationWindow = null;
    });

    _defineProperty(this, "executeBoxEditSuccessHandler", (integrationId, _ref4) => {
      let {
        url
      } = _ref4;
      const {
        fileId,
        token,
        onError
      } = this.props;
      const queryParams = queryString.parse(url);
      const authCode = queryParams[AUTH_CODE];
      const isFileScoped = this.isBoxEditSFCIntegration(integrationId);
      this.api.getBoxEditAPI().openFile(fileId, {
        data: {
          auth_code: authCode,
          token,
          token_scope: isFileScoped ? TYPE_FILE : TYPE_FOLDER
        }
      }).catch(error => {
        onError(error, ERROR_CODE_EXECUTE_INTEGRATION, {
          error
        });
      });
    });

    _defineProperty(this, "onExecuteFormSubmit", () => {
      this.setState({
        executePostData: null
      });
    });

    _defineProperty(this, "executeIntegrationErrorHandler", (error, code) => {
      this.props.onError(error, code, {
        error
      }); // eslint-disable-next-line no-console

      console.error(error);
      this.setState({
        shouldRenderLoadingIntegrationPortal: false,
        shouldRenderErrorIntegrationPortal: true
      });
    });

    _defineProperty(this, "executeBoxEditErrorHandler", error => {
      this.props.onError(error); // eslint-disable-next-line no-console

      console.error(error);
    });

    const {
      token: _token,
      apiHost,
      clientName,
      language,
      requestInterceptor,
      responseInterceptor
    } = props;
    this.id = uniqueid('bcow_');
    this.api = new API({
      apiHost,
      clientName,
      language,
      requestInterceptor,
      responseInterceptor,
      token: _token
    }); // Clone initial state to allow for state reset on new files

    this.state = _objectSpread({}, this.initialState);
  }
  /**
   * Destroys api instances with caches
   *
   * @private
   * @return {void}
   */


  clearCache() {
    this.api.destroy(true);
  }
  /**
   * Cleanup
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentWillUnmount() {
    // Don't destroy the cache while unmounting
    this.api.destroy(false);
  }
  /**
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentDidMount() {
    const {
      fileId
    } = this.props;

    if (!fileId) {
      return;
    }

    this.window = window;
    this.fetchOpenWithData();
  }
  /**
   * After component updates, re-fetch Open With data if appropriate.
   *
   * @return {void}
   */


  componentDidUpdate(prevProps) {
    const {
      fileId: currentFileId
    } = this.props;
    const {
      fileId: previousFileId
    } = prevProps;

    if (!currentFileId) {
      return;
    }

    if (currentFileId !== previousFileId) {
      this.setState(_objectSpread({}, this.initialState));
      this.fetchOpenWithData();
    }
  }
  /**
   * Checks if a given integration is a Box Edit integration.
   *
   * @param {string} [integrationId] - The integration ID
   * @return {boolean}
   */


  isBoxEditIntegration(integrationId) {
    return integrationId === BOX_EDIT_INTEGRATION_ID || this.isBoxEditSFCIntegration(integrationId);
  }
  /**
   * Checks if a given integration is a Box Edit integration.
   *
   * @param {string} [integrationId] - The integration ID
   * @return {boolean}
   */


  isBoxEditSFCIntegration(integrationId) {
    return integrationId === BOX_EDIT_SFC_INTEGRATION_ID;
  }
  /**
   * Fetches Open With data.
   *
   * @return {void}
   */


  fetchOpenWithData() {
    const {
      fileId
    } = this.props;
    this.api.getOpenWithAPI(false).getOpenWithIntegrations(fileId, this.fetchOpenWithSuccessHandler, this.fetchErrorHandler);
  }
  /**
   * Fetch app integrations info needed to render.
   *
   * @param {OpenWithIntegrations} integrations - The available Open With integrations
   * @return {void}
   */


  /**
   * Calls the onExecute prop
   *
   * @private
   * @param {string} integrationID - The integration that was executed
   * @return {void}
   */
  onExecute(integrationID) {
    this.props.onExecute(integrationID);
    this.setState({
      shouldRenderLoadingIntegrationPortal: false
    });
  }
  /**
   * Handles execution related errors
   *
   * @private
   * @param {Error} error - Error object
   * @return {void}
   */


  /**
   * Gets a display integration, if available, for the Open With button
   *
   * @private
   * @return {?Integration}
   */
  getDisplayIntegration() {
    const {
      integrations
    } = this.state; // We only consider an integration a display integration if is the only integration in our state

    return Array.isArray(integrations) && integrations.length === 1 ? integrations[0] : null;
  }
  /**
   * Render the Open With element
   *
   * @private
   * @inheritdoc
   * @return {Element}
   */


  render() {
    const {
      language,
      messages: intlMessages,
      dropdownAlignment
    } = this.props;
    const {
      fetchError,
      isLoading,
      integrations,
      executePostData,
      shouldRenderLoadingIntegrationPortal,
      shouldRenderErrorIntegrationPortal
    } = this.state;
    const className = classNames('be bcow', this.props.className);
    const displayIntegration = this.getDisplayIntegration();
    const numIntegrations = integrations ? integrations.length : 0;
    return React.createElement(Internationalize, {
      language: language,
      messages: intlMessages
    }, React.createElement("div", {
      className: className,
      "data-testid": "bcow-content",
      id: this.id
    }, numIntegrations <= 1 ? React.createElement(OpenWithButton, {
      displayIntegration: displayIntegration,
      error: fetchError,
      isLoading: isLoading,
      onClick: this.onIntegrationClick
    }) : React.createElement(OpenWithDropdownMenu, {
      dropdownAlignment: dropdownAlignment,
      integrations: integrations,
      onClick: this.onIntegrationClick
    }), (shouldRenderLoadingIntegrationPortal || shouldRenderErrorIntegrationPortal) && React.createElement(IntegrationPortalContainer, {
      hasError: shouldRenderErrorIntegrationPortal,
      integrationWindow: this.integrationWindow
    }), executePostData && React.createElement(ExecuteForm, {
      executePostData: executePostData,
      id: this.id,
      onSubmit: this.onExecuteFormSubmit,
      windowName: this.integrationWindow && this.integrationWindow.name
    })));
  }

}

_defineProperty(ContentOpenWith, "defaultProps", {
  apiHost: DEFAULT_HOSTNAME_API,
  className: '',
  clientName: CLIENT_NAME_OPEN_WITH,
  onExecute: noop,
  onError: noop
});

export { ContentOpenWith as ContentOpenWithComponent };
export default withErrorBoundary(ORIGIN_OPEN_WITH, OpenWithFallbackButton)(ContentOpenWith);
//# sourceMappingURL=ContentOpenWith.js.map