function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * 
 * @file Open With button
 * @author Box
 */
import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import noop from 'lodash/noop';
import Button from '../../components/button/Button';
import IconOpenWith from '../../icons/general/IconOpenWith';
import Tooltip from '../common/Tooltip';
import messages from '../common/messages';
import OpenWithButtonContents from './OpenWithButtonContents';
import utils from './openWithUtils';
import { CLASS_INTEGRATION_ICON, OPEN_WITH_BUTTON_ICON_SIZE } from '../../constants';
import getIcon from './IconFileMap';

/**
 * Gets the tooltip text for the ContentOpenWith button
 *
 * @private
 * @return {?(string | Element)} the tooltip message
 */
export const getTooltip = function getTooltip(displayDescription, isLoading, error) {
  let disabledReasons = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];

  if (isLoading) {
    return null;
  }

  let message = React.createElement(FormattedMessage, messages.emptyOpenWithDescription);

  if (disabledReasons.length > 0) {
    [message] = disabledReasons;
  } else if (error) {
    message = React.createElement(FormattedMessage, messages.errorOpenWithDescription);
  } else if (displayDescription) {
    message = displayDescription;
  }

  return message;
};

const OpenWithButton = (_ref) => {
  let {
    error,
    onClick: _onClick = noop,
    displayIntegration,
    isLoading
  } = _ref;
  const {
    displayName,
    isDisabled: isDisplayIntegrationDisabled,
    extension,
    disabledReasons,
    displayDescription
  } = displayIntegration || {};
  const isDisabled = !!isDisplayIntegrationDisabled || !displayName;
  const Icon = displayName ? getIcon(displayName) : IconOpenWith;
  const tooltipDisplayProps = utils.isDisabledBecauseBoxToolsIsNotInstalled(displayIntegration) ? {
    isShown: true,
    showCloseButton: true
  } : {};
  return React.createElement(Tooltip, _extends({
    className: "bcow-tooltip",
    position: "bottom-center",
    text: getTooltip(displayDescription, isLoading, error, disabledReasons)
  }, tooltipDisplayProps), React.createElement(Button, {
    "data-testid": "singleintegrationbutton",
    isDisabled: isDisabled,
    onClick: () => displayIntegration ? _onClick(displayIntegration) : noop
  }, React.createElement(OpenWithButtonContents, null, React.createElement(Icon, {
    className: CLASS_INTEGRATION_ICON,
    dimension: OPEN_WITH_BUTTON_ICON_SIZE,
    extension: extension,
    height: OPEN_WITH_BUTTON_ICON_SIZE,
    width: OPEN_WITH_BUTTON_ICON_SIZE
  }))));
};

export default OpenWithButton;
//# sourceMappingURL=OpenWithButton.js.map