/**
 * 
 * @file File picker header and list component
 * @author Box
 */
import React from 'react';
import EmptyState from '../common/empty-state';
import ProgressBar from '../common/progress-bar';
import ItemList from './ItemList';
import { VIEW_ERROR, VIEW_SELECTED } from '../../constants';
import './Content.scss';

/**
 * Determines if we should show the empty state
 *
 * @param {string} view the current view
 * @param {Object} currentCollection the current collection
 * @return {boolean} empty or not
 */
function isEmpty(view, currentCollection) {
  const {
    items = []
  } = currentCollection;
  return view === VIEW_ERROR || items.length === 0;
}

const Content = (_ref) => {
  let {
    view,
    rootId,
    isSmall,
    rootElement,
    focusedRow,
    hasHitSelectionLimit,
    selectableType,
    currentCollection,
    tableRef,
    canSetShareAccess,
    isSingleSelect,
    onItemClick,
    onItemSelect,
    onShareAccessChange,
    onFocusChange,
    extensionsWhitelist
  } = _ref;
  return React.createElement("div", {
    className: "bcp-content"
  }, view === VIEW_ERROR || view === VIEW_SELECTED ? null : React.createElement(ProgressBar, {
    percent: currentCollection.percentLoaded
  }), isEmpty(view, currentCollection) ? React.createElement(EmptyState, {
    view: view,
    isLoading: currentCollection.percentLoaded !== 100
  }) : React.createElement(ItemList, {
    view: view,
    rootId: rootId,
    isSmall: isSmall,
    rootElement: rootElement,
    focusedRow: focusedRow,
    currentCollection: currentCollection,
    tableRef: tableRef,
    canSetShareAccess: canSetShareAccess,
    hasHitSelectionLimit: hasHitSelectionLimit,
    isSingleSelect: isSingleSelect,
    selectableType: selectableType,
    onItemSelect: onItemSelect,
    onItemClick: onItemClick,
    onFocusChange: onFocusChange,
    onShareAccessChange: onShareAccessChange,
    extensionsWhitelist: extensionsWhitelist
  }));
};

export default Content;
//# sourceMappingURL=Content.js.map