/**
 * 
 * @file Preview Navigation
 * @author Box
 */
import * as React from 'react';
import { injectIntl } from 'react-intl';
import { Route } from 'react-router-dom';
import IconNavigateLeft from '../../icons/general/IconNavigateLeft';
import IconNavigateRight from '../../icons/general/IconNavigateRight';
import PlainButton from '../../components/plain-button/PlainButton';
import messages from '../common/messages';

const PreviewNavigation = (_ref) => {
  let {
    collection = [],
    currentIndex,
    intl,
    onNavigateLeft,
    onNavigateRight
  } = _ref;
  const hasLeftNavigation = collection.length > 1 && currentIndex > 0 && currentIndex < collection.length;
  const hasRightNavigation = collection.length > 1 && currentIndex > -1 && currentIndex < collection.length - 1;

  if (!hasLeftNavigation && !hasRightNavigation) {
    return null;
  }

  return React.createElement(Route, {
    path: ['/:activeTab/:deeplink', '/']
  }, (_ref2) => {
    let {
      match,
      history
    } = _ref2;
    return React.createElement(React.Fragment, null, hasLeftNavigation && React.createElement(PlainButton, {
      className: "bcpr-navigate-left",
      onClick: () => {
        if (match.params.deeplink) {
          history.push("/".concat(match.params.activeTab));
        }

        onNavigateLeft();
      },
      title: intl.formatMessage(messages.previousFile),
      type: "button"
    }, React.createElement(IconNavigateLeft, null)), hasRightNavigation && React.createElement(PlainButton, {
      className: "bcpr-navigate-right",
      onClick: () => {
        if (match.params.deeplink) {
          history.push("/".concat(match.params.activeTab));
        }

        onNavigateRight();
      },
      title: intl.formatMessage(messages.nextFile),
      type: "button"
    }, React.createElement(IconNavigateRight, null)));
  });
};

export { PreviewNavigation as PreviewNavigationComponent };
export default injectIntl(PreviewNavigation);
//# sourceMappingURL=PreviewNavigation.js.map