function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import API from '../../api';
import Notification from '../../components/notification/Notification';
import { DURATION_SHORT, TYPE_ERROR, TYPE_INFO } from '../../components/notification/constants';
import NotificationsWrapper from '../../components/notification/NotificationsWrapper';
import useSharedLink from './hooks/useSharedLink';
import { convertCollab, convertCollabsRequest, convertCollabsResponse, convertGroupContactsResponse, convertItemResponse, convertSharedLinkPermissions, convertSharedLinkSettings, convertUserContactsResponse, USM_TO_API_ACCESS_LEVEL_MAP } from '../../features/unified-share-modal/utils/convertData';
import useAvatars from './hooks/useAvatars';
import useCollaborators from './hooks/useCollaborators';
import useContacts from './hooks/useContacts';
import useInvites from './hooks/useInvites';
import contentSharingMessages from './messages';

function SharingNotification(_ref) {
  let {
    accessLevel,
    api,
    closeComponent,
    closeSettings,
    collaboratorsList,
    currentUserID,
    getContacts,
    isDownloadAvailable,
    itemID,
    itemType,
    ownerEmail,
    ownerID,
    permissions,
    sendInvites,
    serverURL,
    setChangeSharedLinkAccessLevel,
    setChangeSharedLinkPermissionLevel,
    setGetContacts,
    setCollaboratorsList,
    setIsLoading,
    setItem,
    setOnAddLink,
    setOnRemoveLink,
    setOnSubmitSettings,
    setSendInvites,
    setSharedLink
  } = _ref;
  const [notifications, setNotifications] = React.useState({});
  const [notificationID, setNotificationID] = React.useState(0); // Close a notification

  const handleNotificationClose = React.useCallback(id => {
    const updatedNotifications = _objectSpread({}, notifications);

    delete updatedNotifications[id];
    setNotifications(updatedNotifications);
  }, [notifications]); // Create a notification

  const createNotification = React.useCallback((notificationType, message) => {
    const updatedNotifications = _objectSpread({}, notifications);

    if (updatedNotifications[notificationID]) {
      return;
    }

    updatedNotifications[notificationID] = React.createElement(Notification, {
      key: notificationID,
      duration: DURATION_SHORT,
      onClose: () => handleNotificationClose(notificationID),
      type: notificationType
    }, React.createElement("span", null, React.createElement(FormattedMessage, message)));
    setNotifications(updatedNotifications);
    setNotificationID(notificationID + 1);
  }, [handleNotificationClose, notificationID, notifications]); // Handle successful PUT requests to /files or /folders

  const _handleUpdateSharedLinkSuccess = itemData => {
    const {
      item: updatedItem,
      sharedLink: updatedSharedLink
    } = convertItemResponse(itemData);
    setItem(prevItem => _objectSpread({}, prevItem, {}, updatedItem));
    setSharedLink(prevSharedLink => {
      return _objectSpread({}, prevSharedLink, {}, updatedSharedLink);
    }); // merge new shared link data with current shared link data
  };
  /**
   * Handle a successful shared link removal request.
   *
   * Most of the data for the shared link will be removed, with the exception of the "canInvite", "serverURL"
   * and "enterpriseName" properties, both of which are still necessary for rendering the form-only version of ContentSharing.
   * We retain "serverURL" and "enterpriseName" from the previous shared link, to avoid having to make another call to the Users API.
   *
   * @param {ContentSharingItemAPIResponse} itemData
   */


  const _handleRemoveSharedLinkSuccess = itemData => {
    const {
      item: updatedItem,
      sharedLink: updatedSharedLink
    } = convertItemResponse(itemData);
    setItem(prevItem => _objectSpread({}, prevItem, {}, updatedItem));
    setSharedLink(prevSharedLink => {
      return _objectSpread({}, updatedSharedLink, {
        serverURL: prevSharedLink ? prevSharedLink.serverURL : '',
        enterpriseName: prevSharedLink && prevSharedLink.enterpriseName ? prevSharedLink.enterpriseName : ''
      });
    });
  }; // Generate shared link CRUD functions for the item


  const {
    changeSharedLinkAccessLevel,
    changeSharedLinkPermissionLevel,
    onAddLink,
    onRemoveLink,
    onSubmitSettings
  } = useSharedLink(api, itemID, itemType, permissions, accessLevel, {
    handleUpdateSharedLinkError: () => {
      createNotification(TYPE_ERROR, contentSharingMessages.sharedLinkUpdateError);
      setIsLoading(false);
      closeSettings();
    },
    handleUpdateSharedLinkSuccess: itemData => {
      createNotification(TYPE_INFO, contentSharingMessages.sharedLinkSettingsUpdateSuccess);

      _handleUpdateSharedLinkSuccess(itemData);

      setIsLoading(false);
      closeSettings();
    },
    handleRemoveSharedLinkError: () => {
      createNotification(TYPE_ERROR, contentSharingMessages.sharedLinkUpdateError);
      setIsLoading(false);
      closeComponent(); // if this function is provided, it will close the modal
    },
    handleRemoveSharedLinkSuccess: itemData => {
      createNotification(TYPE_INFO, contentSharingMessages.sharedLinkRemovalSuccess);

      _handleRemoveSharedLinkSuccess(itemData);

      setIsLoading(false);
      closeComponent();
    },
    setIsLoading,
    transformAccess: newAccessLevel => USM_TO_API_ACCESS_LEVEL_MAP[newAccessLevel],
    transformPermissions: newSharedLinkPermissionLevel => convertSharedLinkPermissions(newSharedLinkPermissionLevel),
    transformSettings: (settings, access) => convertSharedLinkSettings(settings, access, isDownloadAvailable, serverURL)
  });
  setChangeSharedLinkAccessLevel(() => changeSharedLinkAccessLevel);
  setChangeSharedLinkPermissionLevel(() => changeSharedLinkPermissionLevel);
  setOnAddLink(() => onAddLink);
  setOnRemoveLink(() => onRemoveLink);
  setOnSubmitSettings(() => onSubmitSettings); // Set the collaborators list

  const collaboratorsListFromAPI = useCollaborators(api, itemID, itemType, {
    handleError: () => createNotification(TYPE_ERROR, contentSharingMessages.collaboratorsLoadingError)
  });
  const avatarsFromAPI = useAvatars(api, itemID, collaboratorsListFromAPI);

  if (collaboratorsListFromAPI && avatarsFromAPI && !collaboratorsList) {
    setCollaboratorsList(convertCollabsResponse(collaboratorsListFromAPI, avatarsFromAPI, ownerEmail, currentUserID === ownerID));
  } // Set the getContacts function


  const getContactsFn = useContacts(api, itemID, {
    handleError: () => createNotification(TYPE_ERROR, contentSharingMessages.getContactsError),
    transformGroups: data => convertGroupContactsResponse(data),
    transformUsers: data => convertUserContactsResponse(data, currentUserID)
  });

  if (getContactsFn && !getContacts) {
    setGetContacts(() => getContactsFn);
  } // Set the sendInvites function


  const sendInvitesFn = useInvites(api, itemID, itemType, {
    handleSuccess: response => {
      createNotification(TYPE_INFO, contentSharingMessages.sendInvitesSuccess);
      setIsLoading(false);
      setCollaboratorsList(prevList => {
        const newList = prevList ? _objectSpread({}, prevList) : {
          collaborators: []
        };
        const newCollab = convertCollab({
          collab: response,
          ownerEmail,
          isCurrentUserOwner: currentUserID === ownerID
        });

        if (newCollab) {
          newList.collaborators.push(newCollab);
        }

        return newList;
      });
      closeComponent();
    },
    handleError: () => {
      createNotification(TYPE_ERROR, contentSharingMessages.sendInvitesError);
      setIsLoading(false);
      closeComponent();
    },
    setIsLoading,
    transformRequest: data => convertCollabsRequest(data, collaboratorsList)
  });

  if (sendInvitesFn && !sendInvites) {
    setSendInvites(() => sendInvitesFn);
  }

  return React.createElement(NotificationsWrapper, null, React.createElement(React.Fragment, null, [...Object.values(notifications)]));
}

export default SharingNotification;
//# sourceMappingURL=SharingNotification.js.map