function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Activity feed sidebar component
 * @author Box
 */
import * as React from 'react';
import classNames from 'classnames';
import debounce from 'lodash/debounce';
import flow from 'lodash/flow';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import uniqueId from 'lodash/uniqueId';
import { FormattedMessage } from 'react-intl';
import { generatePath } from 'react-router-dom';
import ActivityFeed from './activity-feed';
import AddTaskButton from './AddTaskButton';
import API from '../../api';
import messages from '../common/messages';
import SidebarContent from './SidebarContent';
import { WithAnnotatorContextProps, withAnnotatorContext } from '../common/annotator-context';
import { EVENT_DATA_READY, EVENT_JS_READY } from '../common/logger/constants';
import { getBadUserError } from '../../utils/error';
import { mark } from '../../utils/performance';
import { withAPIContext } from '../common/api-context';
import { withErrorBoundary } from '../common/error-boundary';
import { withFeatureConsumer, isFeatureEnabled } from '../common/feature-checking';
import { withLogger } from '../common/logger';
import { withRouterAndRef } from '../common/routing';
import ActivitySidebarFilter from './ActivitySidebarFilter';
import { ACTIVITY_FILTER_OPTION_ALL, ACTIVITY_FILTER_OPTION_RESOLVED, ACTIVITY_FILTER_OPTION_TASKS, ACTIVITY_FILTER_OPTION_UNRESOLVED, DEFAULT_COLLAB_DEBOUNCE, ERROR_CODE_FETCH_ACTIVITY, FEED_ITEM_TYPE_ANNOTATION, FEED_ITEM_TYPE_COMMENT, FEED_ITEM_TYPE_TASK, FEED_ITEM_TYPE_VERSION, ORIGIN_ACTIVITY_SIDEBAR, SIDEBAR_VIEW_ACTIVITY, TASK_COMPLETION_RULE_ALL } from '../../constants';
import './ActivitySidebar.scss';
export const activityFeedInlineError = {
  inlineError: {
    title: messages.errorOccured,
    content: messages.activityFeedItemApiError
  }
};
const MARK_NAME_DATA_LOADING = "".concat(ORIGIN_ACTIVITY_SIDEBAR, "_data_loading");
const MARK_NAME_DATA_READY = "".concat(ORIGIN_ACTIVITY_SIDEBAR, "_").concat(EVENT_DATA_READY);
const MARK_NAME_JS_READY = "".concat(ORIGIN_ACTIVITY_SIDEBAR, "_").concat(EVENT_JS_READY);
mark(MARK_NAME_JS_READY);

class ActivitySidebar extends React.PureComponent {
  constructor(props) {
    var _this;

    super(props);
    _this = this;

    _defineProperty(this, "handleAnnotationDelete", (_ref) => {
      let {
        id,
        permissions
      } = _ref;
      const {
        api,
        emitAnnotationRemoveEvent,
        file
      } = this.props;
      emitAnnotationRemoveEvent(id, true);
      api.getFeedAPI(false).deleteAnnotation(file, id, permissions, this.deleteAnnotationSuccess.bind(this, id), this.feedErrorCallback);
      this.fetchFeedItems();
    });

    _defineProperty(this, "handleAnnotationEdit", (_ref2) => {
      let {
        id,
        text,
        permissions
      } = _ref2;
      const {
        api,
        emitAnnotationUpdateEvent,
        file
      } = this.props;
      emitAnnotationUpdateEvent({
        id,
        description: {
          message: text
        }
      }, true);
      api.getFeedAPI(false).updateAnnotation(file, id, text, undefined, permissions, annotation => {
        emitAnnotationUpdateEvent(annotation);
        this.feedSuccessCallback();
      }, this.feedErrorCallback);
      this.fetchFeedItems();
    });

    _defineProperty(this, "handleAnnotationStatusChange", (_ref3) => {
      let {
        id,
        permissions,
        status
      } = _ref3;
      const {
        api,
        emitAnnotationUpdateEvent,
        file
      } = this.props;
      emitAnnotationUpdateEvent({
        id,
        status
      }, true);
      api.getFeedAPI(false).updateAnnotation(file, id, undefined, status, permissions, annotation => {
        emitAnnotationUpdateEvent(annotation);
        this.feedSuccessCallback();
      }, this.feedErrorCallback);
      this.fetchFeedItems();
    });

    _defineProperty(this, "feedSuccessCallback", () => {
      this.fetchFeedItems();
    });

    _defineProperty(this, "feedErrorCallback", (e, code, contextInfo) => {
      this.errorCallback(e, code, contextInfo);
      this.fetchFeedItems();
    });

    _defineProperty(this, "createTask", (message, assignees, taskType, dueAt, completionRule, onSuccess, onError) => {
      const {
        api,
        currentUser,
        file
      } = this.props;

      if (!currentUser) {
        throw getBadUserError();
      }

      const errorCallback = (e, code, contextInfo) => {
        if (onError) {
          onError(e, code, contextInfo);
        }

        this.feedErrorCallback(e, code, contextInfo);
      };

      const successCallback = () => {
        if (onSuccess) {
          onSuccess();
        }

        this.feedSuccessCallback();
      };

      api.getFeedAPI(false).createTaskNew(file, currentUser, message, assignees, taskType, dueAt, completionRule, successCallback, errorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "deleteTask", task => {
      const {
        file,
        api,
        onTaskDelete
      } = this.props;
      api.getFeedAPI(false).deleteTaskNew(file, task, taskId => {
        this.feedSuccessCallback();
        onTaskDelete(taskId);
      }, this.feedErrorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "updateTask", (task, onSuccess, onError) => {
      const {
        api,
        file,
        onTaskUpdate
      } = this.props;

      const errorCallback = (e, code) => {
        if (onError) {
          onError(e, code);
        }

        this.feedErrorCallback(e, code);
      };

      const successCallback = () => {
        this.feedSuccessCallback();

        if (onSuccess) {
          onSuccess();
        }

        onTaskUpdate();
      };

      api.getFeedAPI(false).updateTaskNew(file, task, successCallback, errorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "updateTaskAssignment", (taskId, taskAssignmentId, status) => {
      const {
        api,
        currentUser = {},
        file,
        onTaskAssignmentUpdate
      } = this.props;

      const successCallback = () => {
        this.feedSuccessCallback();
        onTaskAssignmentUpdate(taskId, taskAssignmentId, status, currentUser.id);
      };

      api.getFeedAPI(false).updateTaskCollaborator(file, taskId, taskAssignmentId, status, successCallback, this.feedErrorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "deleteComment", (_ref4) => {
      let {
        id,
        permissions
      } = _ref4;
      const {
        api,
        file,
        hasReplies,
        onCommentDelete
      } = this.props;

      const successCallback = comment => {
        this.feedSuccessCallback();
        onCommentDelete(comment);
      };

      if (hasReplies) {
        api.getFeedAPI(false).deleteThreadedComment(file, id, permissions, successCallback, this.feedErrorCallback);
      } else {
        api.getFeedAPI(false).deleteComment(file, id, permissions, successCallback, this.feedErrorCallback);
      } // need to load the pending item


      this.fetchFeedItems();
    });

    _defineProperty(this, "deleteReply", (_ref5) => {
      let {
        id,
        parentId,
        permissions
      } = _ref5;
      const {
        api,
        emitAnnotationReplyDeleteEvent,
        file
      } = this.props;
      emitAnnotationReplyDeleteEvent(id, parentId, true);
      api.getFeedAPI(false).deleteReply(file, id, parentId, permissions, this.deleteReplySuccessCallback.bind(this, id, parentId), this.feedErrorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "deleteReplySuccessCallback", (id, parentId) => {
      const {
        emitAnnotationReplyDeleteEvent
      } = this.props;
      this.feedSuccessCallback();
      emitAnnotationReplyDeleteEvent(id, parentId);
    });

    _defineProperty(this, "updateComment", (id, text, status, hasMention, permissions, onSuccess, onError) => {
      const {
        api,
        file,
        hasReplies,
        onCommentUpdate
      } = this.props;

      const errorCallback = (e, code) => {
        if (onError) {
          onError(e, code);
        }

        this.feedErrorCallback(e, code);
      };

      const successCallback = () => {
        this.feedSuccessCallback();

        if (onSuccess) {
          onSuccess();
        }

        onCommentUpdate();
      };

      if (hasReplies) {
        api.getFeedAPI(false).updateThreadedComment(file, id, text, status, permissions, successCallback, errorCallback);
      } else {
        api.getFeedAPI(false).updateComment(file, id, text || '', hasMention, permissions, successCallback, errorCallback);
      } // need to load the pending item


      this.fetchFeedItems();
    });

    _defineProperty(this, "updateReply", (id, parentId, text, permissions, onSuccess, onError) => {
      const {
        api,
        emitAnnotationReplyUpdateEvent,
        file
      } = this.props;
      emitAnnotationReplyUpdateEvent({
        id,
        tagged_message: text
      }, parentId, true);
      api.getFeedAPI(false).updateReply(file, id, parentId, text, permissions, this.updateReplySuccessCallback.bind(this, parentId, onSuccess), (error, code) => {
        if (onError) {
          onError(error, code);
        }

        this.feedErrorCallback(error, code);
      }); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "updateReplies", (id, replies) => {
      const {
        activeFeedEntryId,
        api,
        file,
        history
      } = this.props;
      const {
        feedItems
      } = this.state;

      if (!feedItems) {
        return;
      }

      const feedAPI = api.getFeedAPI(false);
      feedAPI.file = file; // Detect if replies are being hidden and activeFeedEntryId belongs to a reply
      // that is in currently being updated parent, in order to disable active item

      if (activeFeedEntryId && replies.length === 1 && feedItems.some(item => item.id === id && item === this.getCommentFeedItemByReplyId(feedItems, activeFeedEntryId))) {
        history.replace(this.getActiveCommentPath());
      }

      feedAPI.updateFeedItem({
        replies
      }, id);
      this.fetchFeedItems();
    });

    _defineProperty(this, "updateReplySuccessCallback", (parentId, onSuccess, reply) => {
      const {
        emitAnnotationReplyUpdateEvent
      } = this.props;
      this.feedSuccessCallback();
      emitAnnotationReplyUpdateEvent(reply, parentId);

      if (onSuccess) {
        onSuccess();
      }
    });

    _defineProperty(this, "createComment", (text, hasMention) => {
      const {
        api,
        currentUser,
        file,
        hasReplies,
        onCommentCreate
      } = this.props;

      if (!currentUser) {
        throw getBadUserError();
      }

      const successCallback = comment => {
        onCommentCreate(comment);
        this.feedSuccessCallback();
      };

      if (hasReplies) {
        api.getFeedAPI(false).createThreadedComment(file, currentUser, text, successCallback, this.feedErrorCallback);
      } else {
        api.getFeedAPI(false).createComment(file, currentUser, text, hasMention, successCallback, this.feedErrorCallback);
      } // need to load the pending item


      this.fetchFeedItems();
    });

    _defineProperty(this, "createReply", (parentId, parentType, text) => {
      const {
        api,
        currentUser,
        emitAnnotationReplyCreateEvent,
        file
      } = this.props;

      if (!currentUser) {
        throw getBadUserError();
      }

      const eventRequestId = uniqueId('comment_');
      emitAnnotationReplyCreateEvent({
        tagged_message: text
      }, eventRequestId, parentId, true);
      api.getFeedAPI(false).createReply(file, currentUser, parentId, parentType, text, this.createReplySuccessCallback.bind(this, eventRequestId, parentId), this.feedErrorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "createReplySuccessCallback", (eventRequestId, parentId, reply) => {
      const {
        emitAnnotationReplyCreateEvent
      } = this.props;
      this.feedSuccessCallback();
      emitAnnotationReplyCreateEvent(reply, eventRequestId, parentId);
    });

    _defineProperty(this, "deleteAppActivity", (_ref6) => {
      let {
        id
      } = _ref6;
      const {
        api,
        file
      } = this.props;
      api.getFeedAPI(false).deleteAppActivity(file, id, this.feedSuccessCallback, this.feedErrorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "fetchRepliesForFeedItems", feedItems => {
      const {
        activeFeedEntryId
      } = this.props;

      if (!activeFeedEntryId) {
        return;
      }

      this.getActiveFeedEntryData(feedItems).then((_ref7) => {
        let {
          id,
          type
        } = _ref7;

        if (!id || !type || this.isActiveEntryInFeed(feedItems, activeFeedEntryId) || !this.isItemTypeComment(type)) {
          return Promise.resolve(feedItems);
        }

        const parentType = type === FEED_ITEM_TYPE_COMMENT ? FEED_ITEM_TYPE_COMMENT : FEED_ITEM_TYPE_ANNOTATION;
        return this.getFeedItemsWithReplies(feedItems, id, parentType);
      }).then(updatedItems => this.fetchFeedItemsSuccessCallback(updatedItems)).catch(error => this.fetchFeedItemsErrorCallback(feedItems, [error]));
    });

    _defineProperty(this, "fetchFeedItemsSuccessCallback", feedItems => {
      const {
        file: {
          id: fileId
        },
        logger
      } = this.props;
      mark(MARK_NAME_DATA_READY); // Only emit metric if has >1 activity feed items (there should always at least be the current version)

      if (feedItems.length > 1) {
        logger.onDataReadyMetric({
          endMarkName: MARK_NAME_DATA_READY,
          startMarkName: MARK_NAME_DATA_LOADING
        }, fileId);
      }

      this.setState({
        feedItems,
        activityFeedError: undefined
      });
    });

    _defineProperty(this, "fetchFeedItemsErrorCallback", (feedItems, errors) => {
      const {
        onError
      } = this.props;
      this.setState({
        feedItems,
        activityFeedError: activityFeedInlineError
      });

      if (Array.isArray(errors) && errors.length) {
        onError(new Error('Fetch feed items error'), ERROR_CODE_FETCH_ACTIVITY, {
          showNotification: true,
          errors: errors.map((_ref8) => {
            let {
              code
            } = _ref8;
            return code;
          })
        });
      }
    });

    _defineProperty(this, "getCommentFeedItemWithReplies", (feedItem, replies) => _objectSpread({}, feedItem, {
      replies
    }));

    _defineProperty(this, "getFeedItemsWithReplies", (feedItems, id, type) => {
      const {
        api,
        file
      } = this.props;
      return new Promise((resolve, reject) => {
        if (!id || !type) {
          resolve(feedItems);
          return;
        }

        api.getFeedAPI(false).fetchReplies(file, id, type, replies => {
          const updatedFeedItems = feedItems.map(item => {
            if (item.id === id && this.isItemTypeComment(item.type)) {
              if (item.type === FEED_ITEM_TYPE_ANNOTATION) {
                return this.getCommentFeedItemWithReplies(item, replies);
              }

              if (item.type === FEED_ITEM_TYPE_COMMENT) {
                return this.getCommentFeedItemWithReplies(item, replies);
              }
            }

            return item;
          });
          resolve(updatedFeedItems);
        }, error => {
          reject(error);
        });
      });
    });

    _defineProperty(this, "errorCallback", function (error, code) {
      let contextInfo = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      /* eslint-disable no-console */
      console.error(error);
      /* eslint-enable no-console */
      // eslint-disable-next-line react/prop-types

      _this.props.onError(error, code, contextInfo);
    });

    _defineProperty(this, "getApproverContactsSuccessCallback", collaborators => {
      const {
        entries
      } = collaborators;
      this.setState({
        approverSelectorContacts: entries
      });
    });

    _defineProperty(this, "getMentionContactsSuccessCallback", collaborators => {
      const {
        entries
      } = collaborators;
      this.setState({
        contactsLoaded: false
      }, () => this.setState({
        contactsLoaded: true,
        mentionSelectorContacts: entries
      }));
    });

    _defineProperty(this, "getApprover", debounce(searchStr => {
      const {
        file,
        api
      } = this.props;
      api.getFileCollaboratorsAPI(false).getCollaboratorsWithQuery(file.id, this.getApproverContactsSuccessCallback, this.errorCallback, searchStr, {
        includeGroups: true
      });
    }, DEFAULT_COLLAB_DEBOUNCE));

    _defineProperty(this, "getMention", debounce(searchStr => {
      const {
        file,
        api
      } = this.props;
      api.getFileCollaboratorsAPI(false).getCollaboratorsWithQuery(file.id, this.getMentionContactsSuccessCallback, this.errorCallback, searchStr);
    }, DEFAULT_COLLAB_DEBOUNCE));

    _defineProperty(this, "getFocusableFeedItemById", (feedItems, itemId) => {
      if (!itemId) {
        return undefined;
      }

      return feedItems.find((_ref9) => {
        let {
          id,
          type
        } = _ref9;
        return id === itemId && this.isItemTypeFocusable(type);
      });
    });

    _defineProperty(this, "getCommentFeedItemByReplyId", (feedItems, replyId) => {
      if (!replyId) {
        return undefined;
      }

      return feedItems.find(item => {
        if (item.type !== FEED_ITEM_TYPE_ANNOTATION && item.type !== FEED_ITEM_TYPE_COMMENT || !item.replies) {
          return false;
        }

        return item.replies.some((_ref10) => {
          let {
            id
          } = _ref10;
          return id === replyId;
        });
      });
    });

    _defineProperty(this, "isActiveEntryInFeed", (feedItems, itemId) => !!(this.getFocusableFeedItemById(feedItems, itemId) || this.getCommentFeedItemByReplyId(feedItems, itemId)));

    _defineProperty(this, "isItemTypeFocusable", type => type === FEED_ITEM_TYPE_ANNOTATION || type === FEED_ITEM_TYPE_COMMENT || type === FEED_ITEM_TYPE_TASK);

    _defineProperty(this, "isItemTypeComment", type => type === FEED_ITEM_TYPE_ANNOTATION || type === FEED_ITEM_TYPE_COMMENT);

    _defineProperty(this, "getActiveFeedEntryData", feedItems => {
      const {
        activeFeedEntryId,
        activeFeedEntryType,
        api,
        file
      } = this.props;
      return new Promise((resolve, reject) => {
        if (!activeFeedEntryId || !activeFeedEntryType || !this.isItemTypeFocusable(activeFeedEntryType)) {
          resolve({});
          return;
        } // Check if the active entry is a first level Feed item


        const firstLevelItem = this.getFocusableFeedItemById(feedItems, activeFeedEntryId);

        if (firstLevelItem) {
          const {
            id,
            type
          } = firstLevelItem;
          resolve({
            id,
            type
          });
          return;
        } // Check if the active entry is within replies of any first level Feed items


        const firstLevelItemWithActiveReply = this.getCommentFeedItemByReplyId(feedItems, activeFeedEntryId);

        if (firstLevelItemWithActiveReply) {
          const {
            id,
            type
          } = firstLevelItemWithActiveReply;
          resolve({
            id,
            type
          });
          return;
        } // If the active entry could not be found within feed items, it's most likely a reply that
        // is not yet visible in feed and we need to fetch its data in order to find parent


        api.getFeedAPI(false).fetchThreadedComment(file, activeFeedEntryId, (_ref11) => {
          let {
            parent
          } = _ref11;
          const parentItem = this.getFocusableFeedItemById(feedItems, parent === null || parent === void 0 ? void 0 : parent.id);
          const {
            id,
            type
          } = parentItem || {};
          resolve({
            id,
            type
          });
        }, error => {
          if (error.status === 404) {
            resolve({});
          } else {
            reject(error);
          }
        });
      });
    });

    _defineProperty(this, "getReplies", (id, type) => {
      const {
        api,
        file
      } = this.props;
      api.getFeedAPI(false).fetchReplies(file, id, type, this.feedSuccessCallback, this.feedErrorCallback); // need to load the pending item

      this.fetchFeedItems();
    });

    _defineProperty(this, "getAvatarUrl", async userId => {
      const {
        file,
        api
      } = this.props;
      return api.getUsersAPI(false).getAvatarUrlWithAccessToken(userId, file.id);
    });

    _defineProperty(this, "handleAnnotationSelect", annotation => {
      const {
        file_version,
        id: nextActiveAnnotationId
      } = annotation;
      const {
        emitActiveAnnotationChangeEvent,
        file,
        getAnnotationsMatchPath,
        getAnnotationsPath,
        history,
        location,
        onAnnotationSelect
      } = this.props;
      const annotationFileVersionId = getProp(file_version, 'id');
      const currentFileVersionId = getProp(file, 'file_version.id');
      const match = getAnnotationsMatchPath(location);
      const selectedFileVersionId = getProp(match, 'params.fileVersionId', currentFileVersionId);
      emitActiveAnnotationChangeEvent(nextActiveAnnotationId);

      if (annotationFileVersionId && annotationFileVersionId !== selectedFileVersionId) {
        history.push(getAnnotationsPath(annotationFileVersionId, nextActiveAnnotationId));
      }

      onAnnotationSelect(annotation);
    });

    _defineProperty(this, "handleItemsFiltered", status => {
      const {
        onFilterChange
      } = this.props;
      this.setState({
        feedItemsStatusFilter: status
      });
      onFilterChange(status);
    });

    _defineProperty(this, "getFilteredFeedItems", () => {
      const {
        feedItems,
        feedItemsStatusFilter
      } = this.state;

      if (!feedItems || !feedItemsStatusFilter || feedItemsStatusFilter === ACTIVITY_FILTER_OPTION_ALL) {
        return feedItems;
      } // Filter is completed on two properties (status and type) because filtering on comments (resolved vs. unresolved)
      // requires looking at item status to see if it is open or resolved. To filter all tasks, we need to look at the
      // item type. Item type is also used to keep versions in the feed. Task also has a status but it's status will be
      // "NOT_STARTED" or "COMPLETED" so it will not conflict with comment's status.


      return feedItems.filter(item => {
        return item.status === feedItemsStatusFilter || item.type === FEED_ITEM_TYPE_VERSION || item.type === feedItemsStatusFilter;
      });
    });

    _defineProperty(this, "onTaskModalClose", () => {
      this.setState({
        approverSelectorContacts: []
      });
    });

    _defineProperty(this, "renderAddTaskButton", () => {
      const {
        isDisabled,
        hasTasks
      } = this.props;
      const {
        approverSelectorContacts
      } = this.state;
      const {
        getApprover,
        getAvatarUrl,
        createTask,
        onTaskModalClose
      } = this;

      if (!hasTasks) {
        return null;
      }

      return React.createElement(AddTaskButton, {
        isDisabled: isDisabled,
        onTaskModalClose: onTaskModalClose,
        taskFormProps: {
          approvers: [],
          approverSelectorContacts,
          completionRule: TASK_COMPLETION_RULE_ALL,
          createTask,
          getApproverWithQuery: getApprover,
          getAvatarUrl,
          id: '',
          message: ''
        }
      });
    });

    _defineProperty(this, "renderActivitySidebarFilter", () => {
      const {
        features,
        hasTasks
      } = this.props;
      const {
        feedItemsStatusFilter
      } = this.state;
      const shouldShowActivityFeedFilter = isFeatureEnabled(features, 'activityFeed.filter.enabled');
      const shouldShowAdditionalFilterOptions = isFeatureEnabled(features, 'activityFeed.newThreadedReplies.enabled');

      if (!shouldShowActivityFeedFilter) {
        return null;
      }

      const activityFilterOptions = [ACTIVITY_FILTER_OPTION_ALL, ACTIVITY_FILTER_OPTION_UNRESOLVED];

      if (shouldShowAdditionalFilterOptions) {
        // Determine which filter options to show based on what activity types are available in current context
        activityFilterOptions.push(ACTIVITY_FILTER_OPTION_RESOLVED);

        if (hasTasks) {
          activityFilterOptions.push(ACTIVITY_FILTER_OPTION_TASKS);
        }
      }

      return React.createElement(ActivitySidebarFilter, {
        activityFilterOptions: activityFilterOptions,
        feedItemType: feedItemsStatusFilter,
        onFeedItemTypeClick: selectedStatus => {
          this.handleItemsFiltered(selectedStatus);
        }
      });
    });

    _defineProperty(this, "renderActions", () => React.createElement(React.Fragment, null, this.renderActivitySidebarFilter(), this.renderAddTaskButton()));

    _defineProperty(this, "renderTitle", () => {
      const {
        features
      } = this.props;
      const shouldHideTitle = isFeatureEnabled(features, 'activityFeed.filter.enabled');

      if (shouldHideTitle) {
        return null;
      }

      return React.createElement(FormattedMessage, messages.sidebarActivityTitle);
    });

    // eslint-disable-next-line react/prop-types
    const {
      logger: _logger
    } = this.props;
    mark(MARK_NAME_DATA_LOADING);

    _logger.onReadyMetric({
      endMarkName: MARK_NAME_JS_READY
    });

    this.state = {};
  }

  componentDidMount() {
    this.fetchFeedItems(true);
  }

  deleteAnnotationSuccess(id) {
    const {
      emitAnnotationRemoveEvent
    } = this.props;
    this.feedSuccessCallback();
    emitAnnotationRemoveEvent(id);
  }
  /**
   * Success callback for fetching feed items
   */


  /**
   * Fetches the feed items for the sidebar
   *
   * @param {boolean} shouldRefreshCache true if the cache should be refreshed
   * @param {boolean} shouldDestroy true if the api factory should be destroyed
   */
  fetchFeedItems() {
    let shouldRefreshCache = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
    let shouldDestroy = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    const {
      activeFeedEntryId,
      activeFeedEntryType,
      api,
      file,
      features,
      hasReplies: shouldShowReplies,
      hasTasks: shouldShowTasks,
      hasVersions: shouldShowVersions
    } = this.props;
    const shouldFetchReplies = shouldRefreshCache && shouldShowReplies && activeFeedEntryId && activeFeedEntryType === FEED_ITEM_TYPE_COMMENT;
    const shouldShowAppActivity = isFeatureEnabled(features, 'activityFeed.appActivity.enabled');
    const shouldShowAnnotations = isFeatureEnabled(features, 'activityFeed.annotations.enabled');
    const shouldUseUAA = isFeatureEnabled(features, 'activityFeed.uaaIntegration.enabled');
    api.getFeedAPI(shouldDestroy).feedItems(file, shouldRefreshCache, shouldFetchReplies ? this.fetchRepliesForFeedItems : this.fetchFeedItemsSuccessCallback, this.fetchFeedItemsErrorCallback, this.errorCallback, {
      shouldShowAnnotations,
      shouldShowAppActivity,
      shouldShowReplies,
      shouldShowTasks,
      shouldShowVersions,
      shouldUseUAA
    });
  }

  getActiveCommentPath(commentId) {
    if (!commentId) {
      return '/activity';
    }

    return generatePath('/:sidebar/comments/:commentId?', {
      sidebar: 'activity',
      commentId
    });
  }
  /**
   * Fetches replies (comments) of a comment or annotation
   *
   * @param {string} id - id of the feed item
   * @param {CommentFeedItemType} type - type of the feed item
   * @return {void}
   */


  refresh() {
    let shouldRefreshCache = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    this.fetchFeedItems(shouldRefreshCache);
  }

  render() {
    const {
      activeFeedEntryId,
      activeFeedEntryType,
      currentUser,
      currentUserError,
      elementId,
      features,
      file,
      hasReplies,
      hasVersions,
      isDisabled = false,
      onVersionHistoryClick,
      getUserProfileUrl,
      onTaskView
    } = this.props;
    const {
      activityFeedError,
      approverSelectorContacts,
      contactsLoaded,
      mentionSelectorContacts
    } = this.state;
    const isNewThreadedRepliesEnabled = isFeatureEnabled(features, 'activityFeed.newThreadedReplies.enabled');
    const shouldUseUAA = isFeatureEnabled(features, 'activityFeed.uaaIntegration.enabled');
    return React.createElement(SidebarContent, {
      actions: this.renderActions(),
      className: classNames('bcs-activity', {
        'bcs-activity--full': hasReplies
      }),
      elementId: elementId,
      sidebarView: SIDEBAR_VIEW_ACTIVITY,
      title: this.renderTitle()
    }, React.createElement(ActivityFeed, {
      activeFeedEntryId: activeFeedEntryId,
      activeFeedEntryType: activeFeedEntryType,
      activityFeedError: activityFeedError,
      approverSelectorContacts: approverSelectorContacts,
      currentUser: currentUser,
      currentUserError: currentUserError,
      feedItems: this.getFilteredFeedItems(),
      file: file,
      getApproverWithQuery: this.getApprover,
      getAvatarUrl: this.getAvatarUrl,
      getMentionWithQuery: this.getMention,
      getUserProfileUrl: getUserProfileUrl,
      hasNewThreadedReplies: isNewThreadedRepliesEnabled,
      hasReplies: hasReplies,
      hasVersions: hasVersions,
      isDisabled: isDisabled,
      mentionSelectorContacts: mentionSelectorContacts,
      contactsLoaded: contactsLoaded,
      onAnnotationDelete: this.handleAnnotationDelete,
      onAnnotationEdit: this.handleAnnotationEdit,
      onAnnotationSelect: this.handleAnnotationSelect,
      onAnnotationStatusChange: this.handleAnnotationStatusChange,
      onAppActivityDelete: this.deleteAppActivity,
      onCommentCreate: this.createComment,
      onCommentDelete: this.deleteComment,
      onCommentUpdate: this.updateComment,
      onHideReplies: this.updateReplies,
      onReplyCreate: this.createReply,
      onReplyDelete: this.deleteReply,
      onReplyUpdate: this.updateReply,
      onShowReplies: this.getReplies,
      onTaskAssignmentUpdate: this.updateTaskAssignment,
      onTaskCreate: this.createTask,
      onTaskDelete: this.deleteTask,
      onTaskModalClose: this.onTaskModalClose,
      onTaskUpdate: this.updateTask,
      onTaskView: onTaskView,
      onVersionHistoryClick: onVersionHistoryClick,
      shouldUseUAA: shouldUseUAA
    }));
  }

}

_defineProperty(ActivitySidebar, "defaultProps", {
  annotatorState: {},
  emitActiveAnnotationChangeEvent: noop,
  emitAnnotationRemoveEvent: noop,
  emitAnnotationReplyCreateEvent: noop,
  emitAnnotationReplyDeleteEvent: noop,
  emitAnnotationReplyUpdateEvent: noop,
  emitAnnotationUpdateEvent: noop,
  getAnnotationsMatchPath: noop,
  getAnnotationsPath: noop,
  hasReplies: false,
  hasTasks: true,
  hasVersions: true,
  isDisabled: false,
  onAnnotationSelect: noop,
  onCommentCreate: noop,
  onCommentDelete: noop,
  onCommentUpdate: noop,
  onFilterChange: noop,
  onTaskAssignmentUpdate: noop,
  onTaskCreate: noop,
  onTaskDelete: noop,
  onTaskUpdate: noop,
  onVersionChange: noop,
  onVersionHistoryClick: noop
});

export { ActivitySidebar as ActivitySidebarComponent };
export default flow([withLogger(ORIGIN_ACTIVITY_SIDEBAR), withErrorBoundary(ORIGIN_ACTIVITY_SIDEBAR), withAPIContext, withFeatureConsumer, withAnnotatorContext, withRouterAndRef])(ActivitySidebar);
//# sourceMappingURL=ActivitySidebar.js.map