function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Content Sidebar Container
 * @author Box
 */
import 'regenerator-runtime/runtime';
import * as React from 'react';
import noop from 'lodash/noop';
import flow from 'lodash/flow';
import API from '../../api';
import APIContext from '../common/api-context';
import Internationalize from '../common/Internationalize';
import Sidebar from './Sidebar';
import NavRouter from '../common/nav-router';
import SidebarUtils from './SidebarUtils';
import { DEFAULT_HOSTNAME_API, CLIENT_NAME_CONTENT_SIDEBAR, ORIGIN_CONTENT_SIDEBAR } from '../../constants';
import { EVENT_JS_READY } from '../common/logger/constants';
import { mark } from '../../utils/performance';
import { SIDEBAR_FIELDS_TO_FETCH } from '../../utils/fields';
import { withErrorBoundary } from '../common/error-boundary';
import { withFeatureProvider } from '../common/feature-checking';
import { withLogger } from '../common/logger';
import '../common/fonts.scss';
import '../common/base.scss';
import '../common/modal.scss';
import './ContentSidebar.scss';
const MARK_NAME_JS_READY = "".concat(ORIGIN_CONTENT_SIDEBAR, "_").concat(EVENT_JS_READY);
mark(MARK_NAME_JS_READY);

class ContentSidebar extends React.Component {
  /**
   * [constructor]
   *
   * @private
   * @return {ContentSidebar}
   */
  constructor(props) {
    super(props);

    _defineProperty(this, "state", {
      isLoading: true
    });

    _defineProperty(this, "errorCallback", (error, code) => {
      /* eslint-disable no-console */
      console.error(error);
      /* eslint-enable no-console */

      /* eslint-disable react/prop-types */

      this.props.onError(error, code, {
        error
      });
      /* eslint-enable react/prop-types */
    });

    _defineProperty(this, "fetchMetadataSuccessCallback", (_ref) => {
      let {
        editors
      } = _ref;
      this.setState({
        metadataEditors: editors
      });
    });

    _defineProperty(this, "fetchFileSuccessCallback", file => {
      const {
        onFetchFileSuccess
      } = this.props;
      !!onFetchFileSuccess && onFetchFileSuccess();
      this.setState({
        file,
        isLoading: false
      }, this.fetchMetadata);
    });

    const {
      apiHost,
      cache,
      clientName,
      language,
      requestInterceptor,
      responseInterceptor,
      sharedLink,
      sharedLinkPassword,
      token
    } = props;
    this.api = new API({
      apiHost,
      cache,
      clientName,
      language,
      requestInterceptor,
      responseInterceptor,
      sharedLink,
      sharedLinkPassword,
      token
    });
    /* eslint-disable react/prop-types */

    const {
      logger
    } = props;
    logger.onReadyMetric({
      endMarkName: MARK_NAME_JS_READY
    });
    /* eslint-enable react/prop-types */
  }
  /**
   * Destroys api instances with caches
   *
   * @private
   * @return {void}
   */


  clearCache() {
    this.api.destroy(true);
  }
  /**
   * Cleanup
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentWillUnmount() {
    // Don't destroy the cache while unmounting
    this.api.destroy(false);
  }
  /**
   * Fetches the file data on load
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentDidMount() {
    this.fetchFile();
  }
  /**
   * Fetches new file data on update
   *
   * @private
   * @inheritdoc
   * @return {void}
   */


  componentDidUpdate(prevProps) {
    const {
      fileId
    } = this.props;
    const {
      fileId: prevFileId
    } = prevProps;

    if (fileId !== prevFileId) {
      this.fetchFile();
    }
  }
  /**
   * Network error callback
   *
   * @private
   * @param {Error} error - Error object
   * @param {string} code - error code
   * @return {void}
   */


  /**
   * Fetches file metadata editors if required
   *
   * @private
   * @return {void}
   */
  fetchMetadata() {
    const {
      file
    } = this.state;
    const {
      metadataSidebarProps
    } = this.props;
    const {
      isFeatureEnabled = true
    } = metadataSidebarProps; // Only fetch metadata if we think that the file may have metadata on it
    // but currently the metadata feature is turned off. Use case of this would be a free
    // user who doesn't have the metadata feature but is collabed on a file from a user
    // who added metadata on the file. If the feature is enabled we always end up showing
    // the metadata sidebar irrespective of there being any existing metadata or not.

    const canHaveMetadataSidebar = !isFeatureEnabled && SidebarUtils.canHaveMetadataSidebar(this.props);

    if (canHaveMetadataSidebar) {
      this.api.getMetadataAPI(false).getMetadata(file, this.fetchMetadataSuccessCallback, noop, isFeatureEnabled);
    }
  }
  /**
   * File fetch success callback that sets the file and sidebar visibility.
   * Also makes an optional request to fetch metadata editors
   *
   * @private
   * @param {Object} file - Box file
   * @return {void}
   */


  /**
   * Fetches a file
   *
   * @private
   * @param {Object|void} [fetchOptions] - Fetch options
   * @return {void}
   */
  fetchFile() {
    let fetchOptions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    const {
      fileId
    } = this.props;
    this.setState({
      isLoading: true
    });

    if (fileId && SidebarUtils.canHaveSidebar(this.props)) {
      this.api.getFileAPI().getFile(fileId, this.fetchFileSuccessCallback, this.errorCallback, _objectSpread({}, fetchOptions, {
        fields: SIDEBAR_FIELDS_TO_FETCH
      }));
    }
  }
  /**
   * Refreshes the sidebar panel
   * @returns {void}
   */


  refresh() {
    if (this.sidebarRef) {
      this.sidebarRef.refresh();
    }
  }
  /**
   * Renders the sidebar
   *
   * @private
   * @inheritdoc
   * @return {Element}
   */


  render() {
    const {
      activitySidebarProps,
      additionalTabs,
      className,
      currentUser,
      defaultView,
      detailsSidebarProps,
      docGenSidebarProps,
      fileId,
      getPreview,
      getViewer,
      hasAdditionalTabs,
      hasActivityFeed,
      hasMetadata,
      hasNav,
      hasSkills,
      hasVersions,
      history,
      isDefaultOpen,
      language,
      messages,
      metadataSidebarProps,
      onAnnotationSelect,
      onVersionChange,
      onVersionHistoryClick,
      versionsSidebarProps
    } = this.props;
    const {
      file,
      isLoading,
      metadataEditors
    } = this.state;
    const initialPath = defaultView.charAt(0) === '/' ? defaultView : "/".concat(defaultView);

    if (!file || !fileId || !SidebarUtils.shouldRenderSidebar(this.props, file, metadataEditors)) {
      return null;
    }

    return React.createElement(Internationalize, {
      language: language,
      messages: messages
    }, React.createElement(APIContext.Provider, {
      value: this.api
    }, React.createElement(NavRouter, {
      history: history,
      initialEntries: [initialPath]
    }, React.createElement(Sidebar, {
      activitySidebarProps: activitySidebarProps,
      additionalTabs: additionalTabs,
      className: className,
      currentUser: currentUser,
      detailsSidebarProps: detailsSidebarProps,
      docGenSidebarProps: docGenSidebarProps,
      file: file,
      fileId: fileId,
      getPreview: getPreview,
      getViewer: getViewer,
      hasActivityFeed: hasActivityFeed,
      hasAdditionalTabs: hasAdditionalTabs,
      hasNav: hasNav,
      hasMetadata: hasMetadata,
      hasSkills: hasSkills,
      hasVersions: hasVersions,
      isDefaultOpen: isDefaultOpen,
      isLoading: isLoading,
      metadataEditors: metadataEditors,
      metadataSidebarProps: metadataSidebarProps,
      onAnnotationSelect: onAnnotationSelect,
      onVersionChange: onVersionChange,
      onVersionHistoryClick: onVersionHistoryClick,
      versionsSidebarProps: versionsSidebarProps,
      wrappedComponentRef: ref => {
        this.sidebarRef = ref;
      }
    }))));
  }

}

_defineProperty(ContentSidebar, "defaultProps", {
  activitySidebarProps: {},
  apiHost: DEFAULT_HOSTNAME_API,
  className: '',
  clientName: CLIENT_NAME_CONTENT_SIDEBAR,
  defaultView: '',
  detailsSidebarProps: {},
  docGenSidebarProps: {
    enabled: false
  },
  getPreview: noop,
  getViewer: noop,
  hasActivityFeed: false,
  hasAdditionalTabs: false,
  hasMetadata: false,
  hasNav: true,
  hasSkills: false,
  isDefaultOpen: true,
  metadataSidebarProps: {}
});

export { ContentSidebar as ContentSidebarComponent };
export default flow([withFeatureProvider, withLogger(ORIGIN_CONTENT_SIDEBAR), withErrorBoundary(ORIGIN_CONTENT_SIDEBAR)])(ContentSidebar);
//# sourceMappingURL=ContentSidebar.js.map