function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Details sidebar component
 * @author Box
 */
import React from 'react';
import flow from 'lodash/flow';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import { FormattedMessage } from 'react-intl';
import API from '../../api';
import messages from '../common/messages';
import SidebarAccessStats from './SidebarAccessStats';
import SidebarClassification from './SidebarClassification'; // $FlowFixMe typescript component

import SidebarContentInsights from './SidebarContentInsights';
import SidebarContent from './SidebarContent';
import SidebarFileProperties from './SidebarFileProperties';
import SidebarNotices from './SidebarNotices';
import SidebarSection from './SidebarSection';
import SidebarVersions from './SidebarVersions';
import { EVENT_JS_READY } from '../common/logger/constants';
import { getBadItemError } from '../../utils/error';
import { mark } from '../../utils/performance';
import { SECTION_TARGETS } from '../common/interactionTargets';
import { SIDEBAR_FIELDS_TO_FETCH } from '../../utils/fields';
import { withAPIContext } from '../common/api-context';
import { withErrorBoundary } from '../common/error-boundary';
import { withLogger } from '../common/logger';
import { HTTP_STATUS_CODE_FORBIDDEN, ORIGIN_DETAILS_SIDEBAR, IS_ERROR_DISPLAYED, SIDEBAR_VIEW_DETAILS } from '../../constants';
import './DetailsSidebar.scss';
const MARK_NAME_JS_READY = "".concat(ORIGIN_DETAILS_SIDEBAR, "_").concat(EVENT_JS_READY);
mark(MARK_NAME_JS_READY);

class DetailsSidebar extends React.PureComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "descriptionChangeSuccessCallback", file => {
      this.setState({
        file,
        fileError: undefined
      });
    });

    _defineProperty(this, "fetchFileSuccessCallback", file => {
      this.setState({
        file,
        fileError: undefined
      });
    });

    _defineProperty(this, "fetchFileErrorCallback", (e, code) => {
      // TODO: handle the error properly (probably with maskError) once files call split out
      this.setState({
        file: undefined
      });
      this.props.onError(e, code, {
        e
      });
    });

    _defineProperty(this, "descriptionChangeErrorCallback", file => {
      // Reset the state back to the original description since the API call failed
      this.setState({
        file,
        fileError: {
          inlineError: {
            title: messages.fileDescriptionInlineErrorTitleMessage,
            content: messages.defaultInlineErrorContentMessage
          }
        }
      });
    });

    _defineProperty(this, "onDescriptionChange", newDescription => {
      const {
        api
      } = this.props;
      const {
        file
      } = this.state;

      if (!file) {
        throw getBadItemError();
      }

      const {
        description
      } = file;

      if (newDescription === description) {
        return;
      }

      api.getFileAPI().setFileDescription(file, newDescription, this.descriptionChangeSuccessCallback, this.descriptionChangeErrorCallback);
    });

    _defineProperty(this, "fetchAccessStatsErrorCallback", (e, code) => {
      if (!this.props.hasAccessStats) {
        return;
      }

      const isForbidden = getProp(e, 'status') === HTTP_STATUS_CODE_FORBIDDEN;
      let accessStatsError;

      if (isForbidden) {
        accessStatsError = {
          error: messages.fileAccessStatsPermissionsError
        };
      } else {
        accessStatsError = {
          maskError: {
            errorHeader: messages.fileAccessStatsErrorHeaderMessage,
            errorSubHeader: messages.defaultErrorMaskSubHeaderMessage
          }
        };
      }

      this.setState({
        isLoadingAccessStats: false,
        accessStats: undefined,
        accessStatsError
      });
      this.props.onError(e, code, {
        e,
        [IS_ERROR_DISPLAYED]: !isForbidden
      });
    });

    _defineProperty(this, "fetchAccessStatsSuccessCallback", accessStats => {
      if (!this.props.hasAccessStats) {
        return;
      }

      this.setState({
        accessStats,
        accessStatsError: undefined,
        isLoadingAccessStats: false
      });
    });

    this.state = {
      isLoadingAccessStats: false
    };
    const {
      logger
    } = this.props;
    logger.onReadyMetric({
      endMarkName: MARK_NAME_JS_READY
    });
  }

  componentDidMount() {
    const {
      hasAccessStats,
      hasContentInsights,
      fetchContentInsights
    } = this.props;
    this.fetchFile();

    if (hasAccessStats) {
      this.fetchAccessStats();
    }

    if (hasContentInsights && fetchContentInsights) {
      fetchContentInsights();
    }
  }

  componentDidUpdate(_ref) {
    let {
      hasAccessStats: prevHasAccessStats,
      hasContentInsights: prevHasContentInsights
    } = _ref;
    const {
      hasAccessStats,
      hasContentInsights,
      fetchContentInsights
    } = this.props; // Component visibility props such as hasAccessStats can sometimes be flipped after an async call

    const hasAccessStatsChanged = prevHasAccessStats !== hasAccessStats;
    const hasContentInsightsChanged = prevHasContentInsights !== hasContentInsights;

    if (hasAccessStatsChanged) {
      if (hasAccessStats) {
        this.fetchAccessStats();
      } else {
        this.setState({
          isLoadingAccessStats: false,
          accessStats: undefined,
          accessStatsError: undefined
        });
      }
    }

    if (hasContentInsightsChanged && hasContentInsights && fetchContentInsights) {
      fetchContentInsights();
    }
  }
  /**
   * File description update callback
   *
   * @private
   * @param {BoxItem} file - Updated file object
   * @return {void}
   */


  /**
   * Fetches a file with the fields needed for details sidebar
   *
   * @param {Function} successCallback - the success callback
   * @param {Function} errorCallback - the error callback
   * @return {void}
   */
  fetchFile() {
    let successCallback = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.fetchFileSuccessCallback;
    let errorCallback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.fetchFileErrorCallback;
    const {
      api,
      fileId
    } = this.props;
    api.getFileAPI().getFile(fileId, successCallback, errorCallback, {
      fields: SIDEBAR_FIELDS_TO_FETCH // TODO: replace this with DETAILS_SIDEBAR_FIELDS_TO_FETCH as we do not need all the sidebar fields

    });
  }
  /**
   * Handles a successful file fetch
   *
   * @param {Object} file - the box file
   * @return {void}
   */


  /**
   * Fetches the access stats for a file
   *
   * @private
   * @return {void}
   */
  fetchAccessStats() {
    const {
      api,
      fileId
    } = this.props;
    const {
      isLoadingAccessStats
    } = this.state;

    if (isLoadingAccessStats) {
      return;
    }

    this.setState({
      isLoadingAccessStats: true
    });
    api.getFileAccessStatsAPI(false).getFileAccessStats(fileId, this.fetchAccessStatsSuccessCallback, this.fetchAccessStatsErrorCallback);
  }

  refresh() {
    this.fetchAccessStats();
  }

  render() {
    const {
      classification,
      contentInsights,
      elementId,
      hasProperties,
      hasNotices,
      hasAccessStats,
      hasClassification,
      hasContentInsights,
      hasRetentionPolicy,
      hasVersions,
      onAccessStatsClick,
      onVersionHistoryClick,
      onClassificationClick,
      onContentInsightsClick,
      onRetentionPolicyExtendClick,
      retentionPolicy
    } = this.props;
    const {
      accessStats,
      accessStatsError,
      file,
      fileError,
      isLoadingAccessStats
    } = this.state; // TODO: Add loading indicator and handle errors once file call is split out

    return React.createElement(SidebarContent, {
      className: "bcs-details",
      elementId: elementId,
      sidebarView: SIDEBAR_VIEW_DETAILS,
      title: React.createElement(FormattedMessage, messages.sidebarDetailsTitle)
    }, file && hasNotices && React.createElement("div", {
      className: "bcs-DetailsSidebar-notices"
    }, React.createElement(SidebarNotices, {
      file: file
    })), file && hasClassification && React.createElement(SidebarClassification, {
      classification: classification,
      file: file,
      onEdit: onClassificationClick
    }), file && hasAccessStats && React.createElement(SidebarAccessStats, _extends({
      accessStats: accessStats,
      file: file,
      onAccessStatsClick: onAccessStatsClick
    }, accessStatsError)), file && hasContentInsights && React.createElement(SidebarContentInsights, {
      contentInsights: contentInsights,
      onContentInsightsClick: onContentInsightsClick
    }), file && hasProperties && React.createElement(SidebarSection, {
      interactionTarget: SECTION_TARGETS.FILE_PROPERTIES,
      title: React.createElement(FormattedMessage, messages.sidebarProperties)
    }, hasVersions && React.createElement(SidebarVersions, {
      file: file,
      onVersionHistoryClick: onVersionHistoryClick
    }), React.createElement(SidebarFileProperties, _extends({
      file: file,
      onDescriptionChange: this.onDescriptionChange
    }, fileError, {
      hasRetentionPolicy: hasRetentionPolicy,
      isLoading: isLoadingAccessStats,
      onRetentionPolicyExtendClick: onRetentionPolicyExtendClick,
      retentionPolicy: retentionPolicy
    }))));
  }

}

_defineProperty(DetailsSidebar, "defaultProps", {
  hasNotices: false,
  hasProperties: false,
  hasAccessStats: false,
  hasClassification: false,
  hasRetentionPolicy: false,
  hasVersions: false,
  onError: noop
});

export { DetailsSidebar as DetailsSidebarComponent };
export default flow([withLogger(ORIGIN_DETAILS_SIDEBAR), withErrorBoundary(ORIGIN_DETAILS_SIDEBAR), withAPIContext])(DetailsSidebar);
//# sourceMappingURL=DetailsSidebar.js.map