function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Metadata sidebar component
 * @author Box
 */
import * as React from 'react';
import flow from 'lodash/flow';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import { FormattedMessage } from 'react-intl';
import API from '../../api';
import EmptyContent from '../../features/metadata-instance-editor/EmptyContent';
import InlineError from '../../components/inline-error/InlineError';
import Instances from '../../features/metadata-instance-editor/Instances';
import LoadingIndicator from '../../components/loading-indicator/LoadingIndicator';
import LoadingIndicatorWrapper from '../../components/loading-indicator/LoadingIndicatorWrapper';
import messages from '../common/messages';
import SidebarContent from './SidebarContent';
import TemplateDropdown from '../../features/metadata-instance-editor/TemplateDropdown';
import { normalizeTemplates } from '../../features/metadata-instance-editor/metadataUtil';
import { EVENT_JS_READY } from '../common/logger/constants';
import { isUserCorrectableError } from '../../utils/error';
import { mark } from '../../utils/performance';
import { withAPIContext } from '../common/api-context';
import { withErrorBoundary } from '../common/error-boundary';
import { withLogger } from '../common/logger';
import { FIELD_IS_EXTERNALLY_OWNED, FIELD_PERMISSIONS, FIELD_PERMISSIONS_CAN_UPLOAD, IS_ERROR_DISPLAYED, ORIGIN_METADATA_SIDEBAR, SIDEBAR_VIEW_METADATA } from '../../constants';
import './MetadataSidebar.scss';
const MARK_NAME_JS_READY = "".concat(ORIGIN_METADATA_SIDEBAR, "_").concat(EVENT_JS_READY);
mark(MARK_NAME_JS_READY);

class MetadataSidebar extends React.PureComponent {
  constructor(props) {
    var _this;

    super(props);
    _this = this;

    _defineProperty(this, "state", {
      isLoading: false
    });

    _defineProperty(this, "onApiError", function (error, code) {
      let newState = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      const {
        onError
      } = _this.props;
      const {
        status
      } = error;
      const isValidError = isUserCorrectableError(status);

      _this.setState(_objectSpread({
        error: messages.sidebarMetadataEditingErrorContent,
        isLoading: false
      }, newState));

      onError(error, code, {
        error,
        [IS_ERROR_DISPLAYED]: isValidError
      });
    });

    _defineProperty(this, "onRemove", id => {
      const {
        api
      } = this.props;
      const {
        file
      } = this.state;
      const editor = this.getEditor(id);

      if (!editor || !file) {
        return;
      }

      api.getMetadataAPI(false).deleteMetadata(file, editor.template, () => this.onRemoveSuccessHandler(editor), this.onApiError);
    });

    _defineProperty(this, "onAddSuccessHandler", editor => {
      const {
        editors = []
      } = this.state;
      const clone = editors.slice(0);
      clone.push(editor);
      this.setState({
        editors: clone,
        isLoading: false
      });
    });

    _defineProperty(this, "onAdd", template => {
      const {
        api
      } = this.props;
      const {
        file
      } = this.state;

      if (!file) {
        return;
      }

      this.setState({
        isLoading: true
      });
      api.getMetadataAPI(false).createMetadata(file, template, this.onAddSuccessHandler, this.onApiError);
    });

    _defineProperty(this, "onSave", (id, ops) => {
      const {
        api
      } = this.props;
      const {
        file
      } = this.state;
      const oldEditor = this.getEditor(id);

      if (!oldEditor || !file) {
        return;
      }

      api.getMetadataAPI(false).updateMetadata(file, oldEditor.template, ops, newEditor => {
        this.replaceEditor(oldEditor, newEditor);
      }, (error, code) => {
        this.onSaveErrorHandler(oldEditor, error, code);
      });
    });

    _defineProperty(this, "onModification", (id, isDirty) => {
      const oldEditor = this.getEditor(id);

      if (!oldEditor) {
        return;
      }

      const newEditor = _objectSpread({}, oldEditor, {
        isDirty
      }); // shallow clone suffices for isDirty setting


      this.replaceEditor(oldEditor, newEditor);
    });

    _defineProperty(this, "fetchMetadataErrorCallback", (e, code) => {
      this.onApiError(e, code, {
        editors: undefined,
        error: messages.sidebarMetadataFetchingErrorContent,
        templates: undefined
      });
    });

    _defineProperty(this, "fetchMetadataSuccessCallback", (_ref) => {
      let {
        editors,
        templates
      } = _ref;
      const {
        selectedTemplateKey,
        templateFilters
      } = this.props;
      this.setState({
        editors: editors.slice(0),
        // cloned for potential editing
        error: undefined,
        isLoading: false,
        templates: normalizeTemplates(templates, selectedTemplateKey, templateFilters)
      });
    });

    _defineProperty(this, "fetchFileErrorCallback", (e, code) => {
      this.onApiError(e, code, {
        error: messages.sidebarFileFetchingErrorContent,
        file: undefined
      });
    });

    _defineProperty(this, "fetchFileSuccessCallback", file => {
      const {
        file: currentFile
      } = this.state;
      const currentCanUpload = getProp(currentFile, FIELD_PERMISSIONS_CAN_UPLOAD, false);
      const newCanUpload = getProp(file, FIELD_PERMISSIONS_CAN_UPLOAD, false);
      const shouldFetchMetadata = !currentFile || currentCanUpload !== newCanUpload;
      const callback = shouldFetchMetadata ? this.fetchMetadata : noop;
      this.setState({
        file
      }, callback);
    });

    const {
      logger
    } = this.props;
    logger.onReadyMetric({
      endMarkName: MARK_NAME_JS_READY
    });
  }

  componentDidMount() {
    this.fetchFile();
  }
  /**
   * Common error callback
   *
   * @param {Error} error - API error
   * @param {string} code - error code
   * @param {Object} [newState] - optional state to set
   * @return {void}
   */


  /**
   * Checks upload permission
   *
   * @return {boolean} - true if metadata can be edited
   */
  canEdit() {
    const {
      file
    } = this.state;
    return getProp(file, FIELD_PERMISSIONS_CAN_UPLOAD, false);
  }
  /**
   * Finds the editor we are editing
   *
   * @param {number} id - instance id
   * @return {Object} editor instance
   */


  getEditor(id) {
    const {
      editors = []
    } = this.state;
    return editors.find((_ref2) => {
      let {
        instance
      } = _ref2;
      return instance.id === id;
    });
  }
  /**
   * Instance remove success handler
   *
   * @param {Object} editor - the editor to remove
   * @return {void}
   */


  onRemoveSuccessHandler(editor) {
    const {
      editors = []
    } = this.state;
    const clone = editors.slice(0);
    clone.splice(editors.indexOf(editor), 1);
    this.setState({
      editors: clone
    });
  }
  /**
   * Instance remove handler
   *
   * @param {string} id - instance id
   * @return {void}
   */


  /**
   * Instance save success handler
   *
   * @param {Object} oldEditor - prior editor
   * @param {Object} newEditor - updated editor
   * @return {void}
   */
  replaceEditor(oldEditor, newEditor) {
    const {
      editors = []
    } = this.state;
    const clone = editors.slice(0);
    clone.splice(editors.indexOf(oldEditor), 1, newEditor);
    this.setState({
      editors: clone
    });
  }
  /**
   * Instance save error handler
   *
   * @param {Object} oldEditor - prior editor
   * @param {Object} error - api error
   * @param {string} code - error code
   * @return {void}
   */


  onSaveErrorHandler(oldEditor, error, code) {
    const clone = _objectSpread({}, oldEditor, {
      hasError: true
    }); // shallow clone suffices for hasError setting


    this.replaceEditor(oldEditor, clone);
    this.onApiError(error, code);
  }
  /**
   * Instance save handler
   *
   * @param {string} id - instance id
   * @param {Array} ops - json patch ops
   * @return {void}
   */


  /**
   * Fetches the metadata editors
   *
   * @return {void}
   */
  fetchMetadata() {
    const {
      api,
      isFeatureEnabled
    } = this.props;
    const {
      file
    } = this.state;

    if (!file) {
      return;
    }

    api.getMetadataAPI(false).getMetadata(file, this.fetchMetadataSuccessCallback, this.fetchMetadataErrorCallback, isFeatureEnabled, {
      refreshCache: true
    });
  }
  /**
   * Handles a failed file fetch
   *
   * @private
   * @param {Error} e - API error
   * @param {string} code - error code
   * @return {void}
   */


  /**
   * Fetches a file with the fields needed for metadata sidebar
   *
   * @return {void}
   */
  fetchFile() {
    const {
      api,
      fileId
    } = this.props;
    api.getFileAPI().getFile(fileId, this.fetchFileSuccessCallback, this.fetchFileErrorCallback, {
      fields: [FIELD_IS_EXTERNALLY_OWNED, FIELD_PERMISSIONS],
      refreshCache: true // see implications in file success callback

    });
  }

  refresh() {
    this.fetchMetadata();
  }

  render() {
    const {
      editors,
      file,
      error,
      isLoading,
      templates
    } = this.state;
    const {
      elementId,
      selectedTemplateKey
    } = this.props;
    const showEditor = !!file && !!templates && !!editors;
    const showLoadingIndicator = !error && !showEditor;
    const canEdit = this.canEdit();
    const showTemplateDropdown = showEditor && canEdit;
    const showEmptyContent = showEditor && editors.length === 0;
    return React.createElement(SidebarContent, {
      actions: showTemplateDropdown ? React.createElement(TemplateDropdown, {
        hasTemplates: templates && templates.length !== 0,
        isDropdownBusy: false,
        onAdd: this.onAdd // $FlowFixMe checked via showTemplateDropdown & showEditor
        ,
        templates: templates // $FlowFixMe checked via showTemplateDropdown & showEditor
        ,
        usedTemplates: editors.map(editor => editor.template)
      }) : null,
      className: "bcs-metadata",
      elementId: elementId,
      sidebarView: SIDEBAR_VIEW_METADATA,
      title: React.createElement(FormattedMessage, messages.sidebarMetadataTitle)
    }, error && React.createElement(InlineError, {
      title: React.createElement(FormattedMessage, messages.error)
    }, React.createElement(FormattedMessage, error)), showLoadingIndicator && React.createElement(LoadingIndicator, null), showEditor && React.createElement(LoadingIndicatorWrapper, {
      className: "metadata-instance-editor",
      isLoading: isLoading
    }, showEmptyContent ? React.createElement(EmptyContent, {
      canAdd: canEdit
    }) : React.createElement(Instances, {
      editors: editors,
      onModification: this.onModification,
      onRemove: this.onRemove,
      onSave: this.onSave,
      selectedTemplateKey: selectedTemplateKey
    })));
  }

}

_defineProperty(MetadataSidebar, "defaultProps", {
  isFeatureEnabled: true
});

export { MetadataSidebar as MetadataSidebarComponent };
export default flow([withLogger(ORIGIN_METADATA_SIDEBAR), withErrorBoundary(ORIGIN_METADATA_SIDEBAR), withAPIContext])(MetadataSidebar);
//# sourceMappingURL=MetadataSidebar.js.map