/**
 * 
 * @file Preview sidebar nav component
 * @author Box
 */
import * as React from 'react';
import { injectIntl } from 'react-intl';
import AdditionalTabs from './additional-tabs';
import IconChatRound from '../../icons/general/IconChatRound';
import IconDocInfo from '../../icons/general/IconDocInfo';
import IconMagicWand from '../../icons/general/IconMagicWand';
import IconMetadataThick from '../../icons/general/IconMetadataThick';
import SidebarNavButton from './SidebarNavButton';
import SidebarNavSign from './SidebarNavSign';
import SidebarNavTablist from './SidebarNavTablist';
import SidebarToggle from './SidebarToggle';
import Tag16 from '../../icon/fill/Tag16';
import messages from '../common/messages';
import { SIDEBAR_NAV_TARGETS } from '../common/interactionTargets';
import { SIDEBAR_VIEW_DOCGEN, SIDEBAR_VIEW_ACTIVITY, SIDEBAR_VIEW_DETAILS, SIDEBAR_VIEW_METADATA, SIDEBAR_VIEW_SKILLS } from '../../constants';
import { useFeatureConfig } from '../common/feature-checking';
import './SidebarNav.scss';

const SidebarNav = (_ref) => {
  let {
    additionalTabs,
    elementId,
    fileId,
    hasActivity,
    hasAdditionalTabs,
    hasDetails,
    hasMetadata,
    hasSkills,
    hasDocGen = false,
    intl,
    isOpen,
    onNavigate
  } = _ref;
  const {
    enabled: hasBoxSign
  } = useFeatureConfig('boxSign');
  return React.createElement("div", {
    className: "bcs-SidebarNav",
    "aria-label": intl.formatMessage(messages.sidebarNavLabel)
  }, React.createElement("div", {
    className: "bcs-SidebarNav-tabs"
  }, React.createElement(SidebarNavTablist, {
    elementId: elementId,
    isOpen: isOpen,
    onNavigate: onNavigate
  }, hasActivity && React.createElement(SidebarNavButton, {
    "data-resin-target": SIDEBAR_NAV_TARGETS.ACTIVITY,
    "data-testid": "sidebaractivity",
    sidebarView: SIDEBAR_VIEW_ACTIVITY,
    tooltip: intl.formatMessage(messages.sidebarActivityTitle)
  }, React.createElement(IconChatRound, null)), hasDetails && React.createElement(SidebarNavButton, {
    "data-resin-target": SIDEBAR_NAV_TARGETS.DETAILS,
    "data-testid": "sidebardetails",
    sidebarView: SIDEBAR_VIEW_DETAILS,
    tooltip: intl.formatMessage(messages.sidebarDetailsTitle)
  }, React.createElement(IconDocInfo, null)), hasSkills && React.createElement(SidebarNavButton, {
    "data-resin-target": SIDEBAR_NAV_TARGETS.SKILLS,
    "data-testid": "sidebarskills",
    sidebarView: SIDEBAR_VIEW_SKILLS,
    tooltip: intl.formatMessage(messages.sidebarSkillsTitle)
  }, React.createElement(IconMagicWand, null)), hasMetadata && React.createElement(SidebarNavButton, {
    "data-resin-target": SIDEBAR_NAV_TARGETS.METADATA,
    "data-testid": "sidebarmetadata",
    sidebarView: SIDEBAR_VIEW_METADATA,
    tooltip: intl.formatMessage(messages.sidebarMetadataTitle)
  }, React.createElement(IconMetadataThick, null)), hasDocGen && React.createElement(SidebarNavButton, {
    "data-resin-target": SIDEBAR_NAV_TARGETS.DOCGEN,
    sidebarView: SIDEBAR_VIEW_DOCGEN,
    tooltip: intl.formatMessage(messages.sidebarDocGenTooltip)
  }, React.createElement(Tag16, {
    className: "bcs-SidebarNav-icon"
  }))), hasBoxSign && React.createElement("div", {
    className: "bcs-SidebarNav-secondary"
  }, React.createElement(SidebarNavSign, null)), hasAdditionalTabs && React.createElement("div", {
    className: "bcs-SidebarNav-overflow"
  }, React.createElement(AdditionalTabs, {
    key: fileId,
    tabs: additionalTabs
  }))), React.createElement("div", {
    className: "bcs-SidebarNav-footer"
  }, React.createElement(SidebarToggle, {
    isOpen: isOpen
  })));
};

export default injectIntl(SidebarNav);
//# sourceMappingURL=SidebarNav.js.map