/**
 * 
 * @file Preview sidebar nav button component
 * @author Box
 */
import * as React from 'react';
import { Route } from 'react-router-dom';
import NavButton from '../common/nav-button';
import Tooltip from '../../components/tooltip/Tooltip';
import './SidebarNavButton.scss';
const SidebarNavButton = React.forwardRef((props, ref) => {
  const {
    'data-resin-target': dataResinTarget,
    'data-testid': dataTestId,
    children,
    elementId = '',
    isOpen,
    sidebarView,
    tooltip
  } = props;
  const sidebarPath = "/".concat(sidebarView);
  return React.createElement(Route, {
    path: sidebarPath
  }, (_ref) => {
    let {
      match
    } = _ref;
    const isMatch = !!match;

    const isActive = () => isMatch && !!isOpen;

    const isActiveValue = isActive();
    const isExactMatch = isMatch && match.isExact;
    const id = "".concat(elementId).concat(elementId === '' ? '' : '_').concat(sidebarView);
    return React.createElement(Tooltip, {
      position: "middle-left",
      text: tooltip,
      isTabbable: false
    }, React.createElement(NavButton, {
      activeClassName: "bcs-is-selected",
      "aria-selected": isActiveValue,
      "aria-controls": "".concat(id, "-content"),
      "aria-label": tooltip,
      className: "bcs-NavButton",
      "data-resin-target": dataResinTarget,
      "data-testid": dataTestId,
      getDOMRef: ref,
      id: id,
      isActive: isActive,
      replace: isExactMatch,
      role: "tab",
      tabIndex: isActiveValue ? '0' : '-1',
      to: {
        pathname: sidebarPath,
        state: {
          open: true
        }
      },
      type: "button"
    }, children));
  });
});
export default SidebarNavButton;
//# sourceMappingURL=SidebarNavButton.js.map