function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Content Sidebar Panels component
 * @author Box
 */
import * as React from 'react';
import flow from 'lodash/flow';
import { matchPath, Redirect, Route, Switch } from 'react-router-dom';
import SidebarUtils from './SidebarUtils';
import withSidebarAnnotations from './withSidebarAnnotations';
import { withAnnotatorContext } from '../common/annotator-context';
import { withAPIContext } from '../common/api-context';
import { withRouterAndRef } from '../common/routing';
import { ORIGIN_ACTIVITY_SIDEBAR, ORIGIN_DETAILS_SIDEBAR, ORIGIN_DOCGEN_SIDEBAR, ORIGIN_METADATA_SIDEBAR, ORIGIN_SKILLS_SIDEBAR, ORIGIN_VERSIONS_SIDEBAR, SIDEBAR_VIEW_ACTIVITY, SIDEBAR_VIEW_DETAILS, SIDEBAR_VIEW_METADATA, SIDEBAR_VIEW_SKILLS, SIDEBAR_VIEW_VERSIONS, SIDEBAR_VIEW_DOCGEN } from '../../constants';
// TODO: place into code splitting logic
const BASE_EVENT_NAME = '_JS_LOADING';
const MARK_NAME_JS_LOADING_DETAILS = "".concat(ORIGIN_DETAILS_SIDEBAR).concat(BASE_EVENT_NAME);
const MARK_NAME_JS_LOADING_ACTIVITY = "".concat(ORIGIN_ACTIVITY_SIDEBAR).concat(BASE_EVENT_NAME);
const MARK_NAME_JS_LOADING_SKILLS = "".concat(ORIGIN_SKILLS_SIDEBAR).concat(BASE_EVENT_NAME);
const MARK_NAME_JS_LOADING_METADATA = "".concat(ORIGIN_METADATA_SIDEBAR).concat(BASE_EVENT_NAME);
const MARK_NAME_JS_LOADING_DOCGEN = "".concat(ORIGIN_DOCGEN_SIDEBAR).concat(BASE_EVENT_NAME);
const MARK_NAME_JS_LOADING_VERSIONS = "".concat(ORIGIN_VERSIONS_SIDEBAR).concat(BASE_EVENT_NAME);
const URL_TO_FEED_ITEM_TYPE = {
  annotations: 'annotation',
  comments: 'comment',
  tasks: 'task'
};
const LoadableDetailsSidebar = SidebarUtils.getAsyncSidebarContent(SIDEBAR_VIEW_DETAILS, MARK_NAME_JS_LOADING_DETAILS);
const LoadableActivitySidebar = SidebarUtils.getAsyncSidebarContent(SIDEBAR_VIEW_ACTIVITY, MARK_NAME_JS_LOADING_ACTIVITY);
const LoadableSkillsSidebar = SidebarUtils.getAsyncSidebarContent(SIDEBAR_VIEW_SKILLS, MARK_NAME_JS_LOADING_SKILLS);
const LoadableMetadataSidebar = SidebarUtils.getAsyncSidebarContent(SIDEBAR_VIEW_METADATA, MARK_NAME_JS_LOADING_METADATA);
const LoadableDocGenSidebar = SidebarUtils.getAsyncSidebarContent(SIDEBAR_VIEW_DOCGEN, MARK_NAME_JS_LOADING_DOCGEN);
const LoadableVersionsSidebar = SidebarUtils.getAsyncSidebarContent(SIDEBAR_VIEW_VERSIONS, MARK_NAME_JS_LOADING_VERSIONS);
const SIDEBAR_PATH_VERSIONS = '/:sidebar(activity|details)/versions/:versionId?';

class SidebarPanels extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "activitySidebar", React.createRef());

    _defineProperty(this, "detailsSidebar", React.createRef());

    _defineProperty(this, "metadataSidebar", React.createRef());

    _defineProperty(this, "state", {
      isInitialized: false
    });

    _defineProperty(this, "versionsSidebar", React.createRef());

    _defineProperty(this, "getVersionsMatchPath", location => {
      const {
        pathname
      } = location;
      return matchPath(pathname, SIDEBAR_PATH_VERSIONS);
    });
  }

  componentDidMount() {
    this.setState({
      isInitialized: true
    });
  }

  componentDidUpdate(prevProps) {
    const {
      location,
      onVersionChange
    } = this.props;
    const {
      location: prevLocation
    } = prevProps; // Reset the current version id if the wrapping versions route is no longer active

    if (onVersionChange && this.getVersionsMatchPath(prevLocation) && !this.getVersionsMatchPath(location)) {
      onVersionChange(null);
    }
  }

  /**
   * Refreshes the contents of the active sidebar
   * @returns {void}
   */
  refresh() {
    let shouldRefreshCache = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    const {
      current: activitySidebar
    } = this.activitySidebar;
    const {
      current: detailsSidebar
    } = this.detailsSidebar;
    const {
      current: metadataSidebar
    } = this.metadataSidebar;
    const {
      current: versionsSidebar
    } = this.versionsSidebar;

    if (activitySidebar) {
      activitySidebar.refresh(shouldRefreshCache);
    }

    if (detailsSidebar) {
      detailsSidebar.refresh();
    }

    if (metadataSidebar) {
      metadataSidebar.refresh();
    }

    if (versionsSidebar) {
      versionsSidebar.refresh();
    }
  }

  render() {
    const {
      activitySidebarProps,
      currentUser,
      currentUserError,
      detailsSidebarProps,
      docGenSidebarProps,
      elementId,
      file,
      fileId,
      getPreview,
      getViewer,
      hasActivity,
      hasDetails,
      hasDocGen,
      hasMetadata,
      hasSkills,
      hasVersions,
      isOpen,
      metadataSidebarProps,
      onAnnotationSelect,
      onVersionChange,
      onVersionHistoryClick,
      versionsSidebarProps
    } = this.props;
    const {
      isInitialized
    } = this.state;

    if (!isOpen || !hasActivity && !hasDetails && !hasMetadata && !hasSkills && !hasVersions) {
      return null;
    }

    return React.createElement(Switch, null, hasSkills && React.createElement(Route, {
      exact: true,
      path: "/".concat(SIDEBAR_VIEW_SKILLS),
      render: () => React.createElement(LoadableSkillsSidebar, {
        elementId: elementId,
        key: file.id,
        file: file,
        getPreview: getPreview,
        getViewer: getViewer,
        hasSidebarInitialized: isInitialized,
        startMarkName: MARK_NAME_JS_LOADING_SKILLS
      })
    }), hasActivity && React.createElement(Route, {
      exact: true,
      path: ["/".concat(SIDEBAR_VIEW_ACTIVITY), "/".concat(SIDEBAR_VIEW_ACTIVITY, "/:activeFeedEntryType(annotations)/:fileVersionId/:activeFeedEntryId?"), "/".concat(SIDEBAR_VIEW_ACTIVITY, "/:activeFeedEntryType(comments|tasks)/:activeFeedEntryId?")],
      render: (_ref) => {
        let {
          match
        } = _ref;
        const matchEntryType = match.params.activeFeedEntryType;
        const activeFeedEntryType = matchEntryType ? URL_TO_FEED_ITEM_TYPE[matchEntryType] : undefined;
        return React.createElement(LoadableActivitySidebar, _extends({
          elementId: elementId,
          currentUser: currentUser,
          currentUserError: currentUserError,
          file: file,
          hasSidebarInitialized: isInitialized,
          onAnnotationSelect: onAnnotationSelect,
          onVersionChange: onVersionChange,
          onVersionHistoryClick: onVersionHistoryClick,
          ref: this.activitySidebar,
          startMarkName: MARK_NAME_JS_LOADING_ACTIVITY,
          activeFeedEntryId: match.params.activeFeedEntryId,
          activeFeedEntryType: match.params.activeFeedEntryId && activeFeedEntryType
        }, activitySidebarProps));
      }
    }), hasDetails && React.createElement(Route, {
      exact: true,
      path: "/".concat(SIDEBAR_VIEW_DETAILS),
      render: () => React.createElement(LoadableDetailsSidebar, _extends({
        elementId: elementId,
        fileId: fileId,
        hasSidebarInitialized: isInitialized,
        key: fileId,
        hasVersions: hasVersions,
        onVersionHistoryClick: onVersionHistoryClick,
        ref: this.detailsSidebar,
        startMarkName: MARK_NAME_JS_LOADING_DETAILS
      }, detailsSidebarProps))
    }), hasMetadata && React.createElement(Route, {
      exact: true,
      path: "/".concat(SIDEBAR_VIEW_METADATA),
      render: () => React.createElement(LoadableMetadataSidebar, _extends({
        elementId: elementId,
        fileId: fileId,
        hasSidebarInitialized: isInitialized,
        ref: this.metadataSidebar,
        startMarkName: MARK_NAME_JS_LOADING_METADATA
      }, metadataSidebarProps))
    }), hasDocGen && React.createElement(Route, {
      exact: true,
      path: "/".concat(SIDEBAR_VIEW_DOCGEN),
      render: () => React.createElement(LoadableDocGenSidebar, _extends({
        hasSidebarInitialized: isInitialized,
        startMarkName: MARK_NAME_JS_LOADING_DOCGEN
      }, docGenSidebarProps))
    }), hasVersions && React.createElement(Route, {
      path: SIDEBAR_PATH_VERSIONS,
      render: (_ref2) => {
        let {
          match
        } = _ref2;
        return React.createElement(LoadableVersionsSidebar, _extends({
          fileId: fileId,
          hasSidebarInitialized: isInitialized,
          key: fileId,
          onVersionChange: onVersionChange,
          parentName: match.params.sidebar,
          ref: this.versionsSidebar,
          versionId: match.params.versionId
        }, versionsSidebarProps));
      }
    }), React.createElement(Route, {
      render: () => {
        let redirect = '';

        if (hasDocGen) {
          redirect = SIDEBAR_VIEW_DOCGEN;
        } else if (hasSkills) {
          redirect = SIDEBAR_VIEW_SKILLS;
        } else if (hasActivity) {
          redirect = SIDEBAR_VIEW_ACTIVITY;
        } else if (hasDetails) {
          redirect = SIDEBAR_VIEW_DETAILS;
        } else if (hasMetadata) {
          redirect = SIDEBAR_VIEW_METADATA;
        }

        return React.createElement(Redirect, {
          to: {
            pathname: "/".concat(redirect),
            state: {
              silent: true
            }
          }
        });
      }
    }));
  }

}

export { SidebarPanels as SidebarPanelsComponent };
export default flow([withSidebarAnnotations, withAPIContext, withAnnotatorContext, withRouterAndRef])(SidebarPanels);
//# sourceMappingURL=SidebarPanels.js.map