function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Skills sidebar component
 * @author Box
 */
import * as React from 'react';
import flow from 'lodash/flow';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import { FormattedMessage } from 'react-intl';
import API from '../../api';
import LoadingIndicator from '../../components/loading-indicator/LoadingIndicator';
import messages from '../common/messages';
import SidebarContent from './SidebarContent';
import SidebarSkills from './skills/SidebarSkills';
import { EVENT_JS_READY } from '../common/logger/constants';
import { mark } from '../../utils/performance';
import { withAPIContext } from '../common/api-context';
import { withErrorBoundary } from '../common/error-boundary';
import { withLogger } from '../common/logger';
import { FIELD_PERMISSIONS_CAN_UPLOAD, SKILLS_TRANSCRIPT, ORIGIN_SKILLS_SIDEBAR, SIDEBAR_VIEW_SKILLS } from '../../constants';
import './SkillsSidebar.scss';
const MARK_NAME_JS_READY = "".concat(ORIGIN_SKILLS_SIDEBAR, "_").concat(EVENT_JS_READY);
mark(MARK_NAME_JS_READY);

class SkillsSidebar extends React.PureComponent {
  constructor(props) {
    var _this;

    super(props);
    _this = this;

    _defineProperty(this, "state", {
      errors: {}
    });

    _defineProperty(this, "fetchSkillsSuccessCallback", cards => {
      this.updatePreviewTranscript(cards);
      this.setState({
        cards
      });
    });

    _defineProperty(this, "updatePreviewTranscript", cards => {
      const {
        getPreview,
        getViewer
      } = this.props;
      const preview = getPreview ? getPreview() : null;
      const viewer = getViewer ? getViewer() : null;
      const transcriptCard = cards.find(card => card.skill_card_type === SKILLS_TRANSCRIPT);

      if (!transcriptCard || !preview) {
        return;
      }

      if (!viewer) {
        preview.addListener('load', (_ref) => {
          let {
            viewer: loadedViewer
          } = _ref;

          if (typeof loadedViewer.loadAutoGeneratedCaptions === 'function') {
            loadedViewer.loadAutoGeneratedCaptions(transcriptCard);
          }
        });
      } else if (typeof viewer.loadAutoGeneratedCaptions === 'function') {
        viewer.loadAutoGeneratedCaptions(transcriptCard);
      }
    });

    _defineProperty(this, "onSaveSuccessHandler", (index, updatedCards) => {
      const {
        errors
      } = this.state;

      const clone = _objectSpread({}, errors);

      delete clone[index];
      this.updatePreviewTranscript(updatedCards);
      this.setState({
        cards: updatedCards,
        errors: clone
      });
    });

    _defineProperty(this, "onSaveErrorHandler", index => {
      const {
        errors
      } = this.state;

      const clone = _objectSpread({}, errors);

      clone[index] = true;
      this.setState({
        errors: clone
      });
    });

    _defineProperty(this, "onSave", function (index) {
      let removes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
      let adds = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
      let replaces = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
      const {
        api,
        file
      } = _this.props;
      const {
        cards = []
      } = _this.state;
      const card = cards[index];
      const path = "/cards/".concat(index);
      const ops = [];
      const canEdit = getProp(file, FIELD_PERMISSIONS_CAN_UPLOAD, false);

      if (!canEdit || !card) {
        return;
      }

      if (Array.isArray(replaces)) {
        replaces.forEach((_ref2) => {
          let {
            replaced,
            replacement
          } = _ref2;
          const idx = card.entries.findIndex(entry => entry === replaced);

          if (idx > -1) {
            ops.push({
              op: 'replace',
              path: "".concat(path, "/entries/").concat(idx),
              value: replacement
            });
          }
        });
      }

      if (Array.isArray(removes)) {
        const deletes = [];
        removes.forEach(removed => {
          const idx = card.entries.findIndex(entry => entry === removed);

          if (idx > -1) {
            deletes.push(idx);
          }
        }); // To maintain metadata index positions, removes should be
        // done is reverse order with largest index being removed first.
        // Remove operations are atomic and don't happen in batch.

        deletes.sort((a, b) => b - a) // number sort in descending order
        .forEach(idx => {
          ops.push({
            op: 'remove',
            path: "".concat(path, "/entries/").concat(idx)
          });
        });
      }

      if (Array.isArray(adds)) {
        adds.forEach(added => {
          ops.push({
            op: 'add',
            path: "".concat(path, "/entries/-"),
            value: added
          });
        });
      } // If no ops, don't proceed


      if (ops.length === 0) {
        return;
      } // Add test ops before any other ops


      ops.splice(0, 0, {
        op: 'test',
        path,
        value: card
      });
      api.getMetadataAPI(false).updateSkills(file, ops, updatedCards => {
        _this.onSaveSuccessHandler(index, updatedCards);
      }, () => {
        _this.onSaveErrorHandler(index);
      });
    });

    const {
      logger
    } = this.props;
    logger.onReadyMetric({
      endMarkName: MARK_NAME_JS_READY
    });
  }

  componentDidMount() {
    const {
      api,
      file
    } = this.props;
    api.getMetadataAPI(false).getSkills(file, this.fetchSkillsSuccessCallback, noop);
  }

  componentDidUpdate(_ref3) {
    let {
      refreshIdentity: prevRefreshIdentity
    } = _ref3;
    const {
      api,
      file,
      refreshIdentity
    } = this.props;

    if (refreshIdentity !== prevRefreshIdentity) {
      api.getMetadataAPI(false).getSkills(file, this.fetchSkillsSuccessCallback, noop);
    }
  }
  /**
   * Handles skills fetch success
   *
   * @private
   * @param {Array<SkillCard>} cards - Skills cards
   * @return {void}
   */


  render() {
    const {
      file,
      getViewer,
      elementId
    } = this.props;
    const {
      cards,
      errors
    } = this.state;
    return React.createElement(SidebarContent, {
      className: "bcs-skills",
      elementId: elementId,
      sidebarView: SIDEBAR_VIEW_SKILLS,
      title: React.createElement(FormattedMessage, messages.sidebarSkillsTitle)
    }, cards ? React.createElement(SidebarSkills, {
      cards: cards,
      errors: errors,
      file: file,
      getViewer: getViewer,
      onSkillChange: this.onSave
    }) : React.createElement(LoadingIndicator, null));
  }

}

export { SkillsSidebar as SkillsSidebarComponent };
export default flow([withLogger(ORIGIN_SKILLS_SIDEBAR), withErrorBoundary(ORIGIN_SKILLS_SIDEBAR), withAPIContext])(SkillsSidebar);
//# sourceMappingURL=SkillsSidebar.js.map