function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file avatar component
 * @author Box
 */
import * as React from 'react';
import AvatarComponent from '../../../components/avatar';

class Avatar extends React.PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      avatarUrl: null
    });

    _defineProperty(this, "isMounted", false);

    _defineProperty(this, "getAvatarUrlHandler", avatarUrl => {
      if (this.isMounted) {
        this.setState({
          avatarUrl
        });
      }
    });
  }

  /**
   * Gets the avatar URL for the user from the getAvatarUrl prop
   *
   * @return {Promise<?string>} Promise which resolve with the avatar url string
   */
  getAvatarUrl() {
    const {
      user = {},
      getAvatarUrl
    } = this.props;
    const {
      avatar_url = null,
      id
    } = user;
    const avatarPromise = id && getAvatarUrl ? getAvatarUrl("".concat(id)) : Promise.resolve(avatar_url);
    return avatarPromise.then(this.getAvatarUrlHandler);
  }

  componentDidMount() {
    this.isMounted = true;
    this.getAvatarUrl();
  }

  componentWillUnmount() {
    this.isMounted = false;
  }

  render() {
    const {
      badgeIcon,
      className,
      user
    } = this.props;
    const {
      avatarUrl
    } = this.state;
    const {
      id,
      name
    } = user;
    return React.createElement(AvatarComponent, {
      avatarUrl: avatarUrl,
      badgeIcon: badgeIcon,
      className: className,
      id: id,
      name: name
    });
  }

}

export default Avatar;
//# sourceMappingURL=Avatar.js.map