function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Active state component for Activity Feed
 */
import * as React from 'react';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import ActivityThread from './ActivityThread';
import ActivityItem from './ActivityItem';
import AppActivity from '../app-activity';
import AnnotationActivity from '../annotations';
import Comment from '../comment';
import TaskNew from '../task-new';
import Version, { CollapsedVersion } from '../version';
import withErrorHandling from '../../withErrorHandling';
import { BaseComment } from '../comment/BaseComment';
import { FEED_ITEM_TYPE_ANNOTATION, FEED_ITEM_TYPE_APP_ACTIVITY, FEED_ITEM_TYPE_COMMENT, FEED_ITEM_TYPE_TASK, FEED_ITEM_TYPE_VERSION } from '../../../../constants';
import AnnotationActivityLinkProvider from './AnnotationActivityLinkProvider';

const ActiveState = (_ref) => {
  let {
    activeFeedItem,
    activeFeedItemRef,
    approverSelectorContacts,
    currentFileVersionId,
    currentUser,
    getApproverWithQuery,
    getAvatarUrl,
    getMentionWithQuery,
    getUserProfileUrl,
    hasNewThreadedReplies = false,
    hasReplies = false,
    hasVersions,
    items,
    mentionSelectorContacts,
    onAnnotationDelete,
    onAnnotationEdit,
    onAnnotationSelect,
    onAnnotationStatusChange,
    onAppActivityDelete,
    onCommentDelete,
    onCommentEdit,
    onCommentSelect = noop,
    onHideReplies: _onHideReplies = noop,
    onReplyCreate: _onReplyCreate = noop,
    onReplyDelete = noop,
    onReplyUpdate = noop,
    onShowReplies: _onShowReplies = noop,
    onTaskAssignmentUpdate,
    onTaskDelete,
    onTaskEdit,
    onTaskModalClose,
    onTaskView,
    onVersionInfo,
    shouldUseUAA,
    translations
  } = _ref;

  const onCommentSelectHandler = itemId => isSelected => {
    onCommentSelect(isSelected ? itemId : null);
  };

  const onHideRepliesHandler = parentId => lastReply => {
    _onHideReplies(parentId, [lastReply]);
  };

  const onReplyCreateHandler = (parentId, parentType) => text => {
    _onReplyCreate(parentId, parentType, text);
  };

  const onReplyDeleteHandler = parentId => options => {
    onReplyDelete(_objectSpread({}, options, {
      parentId
    }));
  };

  const onReplyUpdateHandler = parentId => (id, text, status, hasMention, permissions, onSuccess, onError) => {
    onReplyUpdate(id, parentId, text, permissions, onSuccess, onError);
  };

  const onShowRepliesHandler = (id, type) => () => {
    _onShowReplies(id, type);
  };

  const onCommentStatusChangeHandler = props => {
    if (onCommentEdit) {
      onCommentEdit(_objectSpread({
        hasMention: false
      }, props));
    }
  };

  const hasMultipleVersions = item => item.versions || shouldUseUAA && item.version_start !== item.version_end;

  return React.createElement("ul", {
    className: "bcs-activity-feed-active-state"
  }, items.map(item => {
    var _ref2, _item$description;

    const isFocused = item === activeFeedItem;
    const refValue = isFocused ? activeFeedItemRef : undefined;
    const itemFileVersionId = getProp(item, 'file_version.id');
    const replyProps = {
      hasReplies,
      onReplySelect: onCommentSelectHandler(item.id)
    };

    const commentAndAnnotationCommonProps = _objectSpread({}, item, {}, replyProps, {
      currentUser,
      getAvatarUrl,
      getMentionWithQuery,
      getUserProfileUrl,
      mentionSelectorContacts,
      onHideReplies: shownReplies => _onHideReplies(item.id, shownReplies),
      onSelect: onCommentSelectHandler(item.id),
      permissions: {
        can_delete: getProp(item.permissions, 'can_delete', false),
        can_edit: getProp(item.permissions, 'can_edit', false),
        can_reply: getProp(item.permissions, 'can_reply', false),
        can_resolve: getProp(item.permissions, 'can_resolve', false)
      },
      // TODO: legitimate, pre-existing typing issue that was previously undetected
      // $FlowFixMe
      repliesTotalCount: item.total_reply_count,
      translations
    });

    switch (item.type) {
      case FEED_ITEM_TYPE_COMMENT:
        return React.createElement(ActivityItem, {
          key: item.type + item.id,
          "data-testid": "comment",
          isFocused: isFocused,
          isHoverable: true,
          hasNewThreadedReplies: hasNewThreadedReplies,
          ref: refValue
        }, hasNewThreadedReplies ? // TODO: legitimate, pre-existing typing issue that was previously undetected
        // Conflict between BoxCommentPermissions and BoxTaskPermissions
        // $FlowFixMe
        React.createElement(BaseComment, _extends({}, commentAndAnnotationCommonProps, {
          onDelete: onCommentDelete,
          onCommentEdit: onCommentEdit,
          onReplyCreate: reply => _onReplyCreate(item.id, FEED_ITEM_TYPE_COMMENT, reply),
          onReplyDelete: onReplyDeleteHandler(item.id),
          onShowReplies: () => _onShowReplies(item.id, FEED_ITEM_TYPE_COMMENT),
          onStatusChange: onCommentStatusChangeHandler
        })) : React.createElement(ActivityThread, {
          "data-testid": "activity-thread",
          currentUser: currentUser,
          getAvatarUrl: getAvatarUrl,
          getMentionWithQuery: getMentionWithQuery,
          getUserProfileUrl: getUserProfileUrl,
          hasNewThreadedReplies: hasNewThreadedReplies,
          hasReplies: hasReplies,
          isPending: item.isPending,
          isRepliesLoading: item.isRepliesLoading,
          mentionSelectorContacts: mentionSelectorContacts,
          onHideReplies: onHideRepliesHandler(item.id),
          onReplyCreate: onReplyCreateHandler(item.id, item.type),
          onReplyDelete: onReplyDeleteHandler(item.id),
          onReplyEdit: onReplyUpdateHandler(item.id),
          onReplySelect: onCommentSelectHandler(item.id),
          onShowReplies: onShowRepliesHandler(item.id, item.type),
          repliesTotalCount: item.total_reply_count,
          replies: item.replies,
          translations: translations
        }, React.createElement(Comment, _extends({}, item, {
          currentUser: currentUser,
          getAvatarUrl: getAvatarUrl,
          getMentionWithQuery: getMentionWithQuery,
          getUserProfileUrl: getUserProfileUrl,
          mentionSelectorContacts: mentionSelectorContacts,
          onDelete: onCommentDelete,
          onEdit: onCommentEdit,
          onSelect: onCommentSelectHandler(item.id),
          permissions: {
            can_delete: getProp(item.permissions, 'can_delete', false),
            can_edit: getProp(item.permissions, 'can_edit', false),
            can_reply: getProp(item.permissions, 'can_reply', false),
            can_resolve: getProp(item.permissions, 'can_resolve', false)
          },
          translations: translations
        }))));

      case FEED_ITEM_TYPE_TASK:
        return React.createElement(ActivityItem, {
          key: item.type + item.id,
          className: "bcs-activity-feed-task-new",
          "data-testid": "task",
          isFocused: isFocused,
          ref: refValue
        }, React.createElement(TaskNew, _extends({}, item, {
          approverSelectorContacts: approverSelectorContacts,
          currentUser: currentUser,
          getApproverWithQuery: getApproverWithQuery,
          getAvatarUrl: getAvatarUrl,
          getUserProfileUrl: getUserProfileUrl,
          onAssignmentUpdate: onTaskAssignmentUpdate,
          onDelete: onTaskDelete,
          onEdit: onTaskEdit,
          onView: onTaskView,
          onModalClose: onTaskModalClose,
          shouldUseUAA: shouldUseUAA,
          translations: translations
        })));

      case FEED_ITEM_TYPE_VERSION:
        return React.createElement(ActivityItem, {
          key: item.type + item.id,
          className: "bcs-version-item",
          "data-testid": "version"
        }, hasMultipleVersions(item) ? // $FlowFixMe
        React.createElement(CollapsedVersion, _extends({}, item, {
          onInfo: onVersionInfo,
          shouldUseUAA: shouldUseUAA
        })) : // $FlowFixMe
        React.createElement(Version, _extends({}, item, {
          onInfo: onVersionInfo,
          shouldUseUAA: shouldUseUAA
        })));

      case FEED_ITEM_TYPE_APP_ACTIVITY:
        return React.createElement(ActivityItem, {
          key: item.type + item.id,
          className: "bcs-activity-feed-app-activity",
          "data-testid": "app-activity"
        }, React.createElement(AppActivity, _extends({
          currentUser: currentUser,
          onDelete: onAppActivityDelete
        }, item)));

      case FEED_ITEM_TYPE_ANNOTATION:
        return React.createElement(ActivityItem, {
          key: item.type + item.id,
          className: "bcs-activity-feed-annotation-activity",
          "data-testid": "annotation-activity",
          isHoverable: true,
          hasNewThreadedReplies: hasNewThreadedReplies,
          isFocused: isFocused,
          ref: refValue
        }, hasNewThreadedReplies && onAnnotationSelect ? // TODO: legitimate, pre-existing typing issue that was previously undetected
        // Conflict between BoxCommentPermissions and BoxTaskPermissions
        // $FlowFixMe
        React.createElement(BaseComment, _extends({}, commentAndAnnotationCommonProps, {
          annotationActivityLink: React.createElement(AnnotationActivityLinkProvider, {
            item: item,
            onSelect: onAnnotationSelect,
            isCurrentVersion: currentFileVersionId === itemFileVersionId
          }),
          onAnnotationEdit: onAnnotationEdit,
          onCommentEdit: onCommentEdit,
          onDelete: onAnnotationDelete,
          onStatusChange: onAnnotationStatusChange,
          onReplyCreate: reply => _onReplyCreate(item.id, FEED_ITEM_TYPE_ANNOTATION, reply),
          onShowReplies: () => _onShowReplies(item.id, FEED_ITEM_TYPE_ANNOTATION),
          tagged_message: (_ref2 = (_item$description = item.description) === null || _item$description === void 0 ? void 0 : _item$description.message) !== null && _ref2 !== void 0 ? _ref2 : ''
        })) : React.createElement(ActivityThread, {
          "data-testid": "activity-thread",
          currentUser: currentUser,
          getAvatarUrl: getAvatarUrl,
          getMentionWithQuery: getMentionWithQuery,
          getUserProfileUrl: getUserProfileUrl,
          hasNewThreadedReplies: hasNewThreadedReplies,
          hasReplies: hasReplies,
          isPending: item.isPending,
          isRepliesLoading: item.isRepliesLoading,
          mentionSelectorContacts: mentionSelectorContacts,
          onHideReplies: onHideRepliesHandler(item.id),
          onReplyCreate: onReplyCreateHandler(item.id, item.type),
          onReplyDelete: onReplyDeleteHandler(item.id),
          onReplyEdit: onReplyUpdateHandler(item.id),
          onReplySelect: onCommentSelectHandler(item.id),
          onShowReplies: onShowRepliesHandler(item.id, item.type),
          repliesTotalCount: item.total_reply_count,
          replies: item.replies,
          translations: translations
        }, React.createElement(AnnotationActivity, {
          currentUser: currentUser,
          getAvatarUrl: getAvatarUrl,
          getUserProfileUrl: getUserProfileUrl,
          getMentionWithQuery: getMentionWithQuery,
          hasVersions: hasVersions,
          isCurrentVersion: currentFileVersionId === itemFileVersionId,
          item: item,
          mentionSelectorContacts: mentionSelectorContacts,
          onEdit: onAnnotationEdit,
          onDelete: onAnnotationDelete,
          onSelect: onAnnotationSelect,
          onStatusChange: onAnnotationStatusChange
        })));

      default:
        return null;
    }
  }));
};

export { ActiveState as ActiveStateComponent };
export default withErrorHandling(ActiveState);
//# sourceMappingURL=ActiveState.js.map