function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Component for Activity feed
 */
import * as React from 'react';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import throttle from 'lodash/throttle';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import ActiveState from './ActiveState';
import CommentForm from '../comment-form';
import EmptyState from './EmptyState';
import InlineError from '../../../../components/inline-error/InlineError';
import LoadingIndicator from '../../../../components/loading-indicator/LoadingIndicator';
import messages from './messages';
import { collapseFeedState, ItemTypes } from './activityFeedUtils';
import { FEED_ITEM_TYPE_ANNOTATION, FEED_ITEM_TYPE_COMMENT, FEED_ITEM_TYPE_TASK, PERMISSION_CAN_CREATE_ANNOTATIONS } from '../../../../constants';
import { scrollIntoView } from '../../../../utils/dom';
import './ActivityFeed.scss';

class ActivityFeed extends React.Component {
  constructor() {
    var _this;

    super(...arguments);
    _this = this;

    _defineProperty(this, "state", {
      isScrolled: false,
      isInputOpen: false,
      selectedItemId: null
    });

    _defineProperty(this, "activeFeedItemRef", React.createRef());

    _defineProperty(this, "isEmpty", function () {
      let {
        feedItems,
        shouldUseUAA
      } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _this.props;

      if (feedItems === undefined) {
        return false;
      }

      return feedItems.length === 0 || !shouldUseUAA && feedItems.length === 1 && feedItems[0].type === ItemTypes.fileVersion || !!shouldUseUAA && feedItems.length === 1 && feedItems[0].type === ItemTypes.fileVersion && feedItems[0].version_start === 1 && feedItems[0].version_end === 1;
    });

    _defineProperty(this, "hasLoaded", (prevCurrentUser, prevFeedItems) => {
      const {
        currentUser,
        feedItems
      } = this.props;
      return currentUser !== undefined && feedItems !== undefined && (!prevCurrentUser || !prevFeedItems);
    });

    _defineProperty(this, "resetFeedScroll", () => {
      if (this.feedContainer) {
        this.feedContainer.scrollTop = this.feedContainer.scrollHeight;
      }
    });

    _defineProperty(this, "handleFeedScroll", event => {
      const {
        target
      } = event;

      if (target instanceof Element) {
        const {
          scrollTop
        } = target;
        this.setState({
          isScrolled: scrollTop > 0
        });
      }
    });

    _defineProperty(this, "throttledFeedScroll", throttle(this.handleFeedScroll, 100));

    _defineProperty(this, "onKeyDown", event => {
      const {
        nativeEvent
      } = event;
      nativeEvent.stopImmediatePropagation();
    });

    _defineProperty(this, "commentFormFocusHandler", () => {
      this.resetFeedScroll();
      this.setState({
        isInputOpen: true
      });
    });

    _defineProperty(this, "commentFormCancelHandler", () => this.setState({
      isInputOpen: false
    }));

    _defineProperty(this, "commentFormSubmitHandler", () => this.setState({
      isInputOpen: false
    }));

    _defineProperty(this, "onCommentCreate", (_ref) => {
      let {
        text,
        hasMention
      } = _ref;
      const {
        onCommentCreate = noop
      } = this.props;
      onCommentCreate(text, hasMention);
      this.commentFormSubmitHandler();
    });

    _defineProperty(this, "onTaskCreate", (_ref2) => {
      let {
        text,
        assignees,
        dueAt
      } = _ref2;
      const {
        onTaskCreate = noop
      } = this.props;
      onTaskCreate(text, assignees, dueAt);
      this.commentFormSubmitHandler();
    });

    _defineProperty(this, "openVersionHistoryPopup", data => {
      const versionInfoHandler = this.props.onVersionHistoryClick || noop;
      versionInfoHandler(data);
    });

    _defineProperty(this, "setSelectedItem", itemId => {
      const {
        hasReplies
      } = this.props;

      if (!hasReplies) {
        return;
      }

      this.setState({
        selectedItemId: itemId
      });
    });

    _defineProperty(this, "isFeedItemActive", (_ref3) => {
      let {
        id,
        type
      } = _ref3;
      const {
        activeFeedEntryId,
        activeFeedEntryType
      } = this.props;
      const {
        selectedItemId
      } = this.state;
      const isSelected = selectedItemId === id;
      return selectedItemId ? isSelected : id === activeFeedEntryId && type === activeFeedEntryType;
    });

    _defineProperty(this, "isCommentFeedItemActive", item => {
      const {
        activeFeedEntryId
      } = this.props;
      const {
        replies
      } = item;
      const isActive = this.isFeedItemActive(item);
      return isActive || !!replies && replies.some(reply => reply.id === activeFeedEntryId);
    });
  }

  componentDidMount() {
    this.resetFeedScroll();
  }

  componentDidUpdate(prevProps, prevState) {
    const {
      activeFeedEntryId: prevActiveFeedEntryId,
      currentUser: prevCurrentUser,
      feedItems: prevFeedItems
    } = prevProps;
    const {
      feedItems: currFeedItems,
      activeFeedEntryId
    } = this.props;
    const {
      isInputOpen: prevIsInputOpen
    } = prevState;
    const {
      isInputOpen: currIsInputOpen
    } = this.state;
    const hasLoaded = this.hasLoaded(prevCurrentUser, prevFeedItems);
    const hasMoreItems = prevFeedItems && currFeedItems && prevFeedItems.length < currFeedItems.length;
    const didLoadFeedItems = prevFeedItems === undefined && currFeedItems !== undefined;
    const hasInputOpened = currIsInputOpen !== prevIsInputOpen;
    const hasActiveFeedEntryIdChanged = activeFeedEntryId !== prevActiveFeedEntryId;

    if ((hasLoaded || hasMoreItems || didLoadFeedItems || hasInputOpened) && activeFeedEntryId === undefined) {
      this.resetFeedScroll();
    }

    if (didLoadFeedItems || hasActiveFeedEntryIdChanged) {
      this.scrollToActiveFeedItemOrErrorMessage();
    }
  }

  scrollToActiveFeedItemOrErrorMessage() {
    const {
      current: activeFeedItemRef
    } = this.activeFeedItemRef;
    const {
      activeFeedEntryId
    } = this.props; // if there is no active item, do not scroll

    if (!activeFeedEntryId) {
      return;
    } // if there was supposed to be an active feed item but the feed item does not exist
    // scroll to the bottom to show the inline error message


    if (activeFeedItemRef === null) {
      this.resetFeedScroll();
      return;
    }

    scrollIntoView(activeFeedItemRef);
  }
  /**
   * Detects whether or not the empty state should be shown.
   * @param {object} currentUser - The user that is logged into the account
   * @param {object} feedItems - Items in the activity feed
   */


  render() {
    const {
      activeFeedEntryType,
      activityFeedError,
      approverSelectorContacts,
      currentUser,
      feedItems,
      file,
      getApproverWithQuery,
      getAvatarUrl,
      getMentionWithQuery,
      getUserProfileUrl,
      hasNewThreadedReplies,
      hasReplies,
      hasVersions,
      isDisabled,
      mentionSelectorContacts,
      contactsLoaded,
      onAnnotationDelete,
      onAnnotationEdit,
      onAnnotationSelect,
      onAnnotationStatusChange,
      onAppActivityDelete,
      onCommentCreate,
      onCommentDelete,
      onCommentUpdate,
      onHideReplies,
      onReplyCreate,
      onReplyDelete,
      onReplyUpdate,
      onShowReplies,
      onTaskAssignmentUpdate,
      onTaskDelete,
      onTaskModalClose,
      onTaskUpdate,
      onTaskView,
      onVersionHistoryClick,
      shouldUseUAA,
      translations
    } = this.props;
    const {
      isInputOpen,
      isScrolled
    } = this.state;
    const currentFileVersionId = getProp(file, 'file_version.id');
    const hasAnnotationCreatePermission = getProp(file, ['permissions', PERMISSION_CAN_CREATE_ANNOTATIONS], false);
    const hasCommentPermission = getProp(file, 'permissions.can_comment', false);
    const showCommentForm = !!(currentUser && hasCommentPermission && onCommentCreate && feedItems);
    const isEmpty = this.isEmpty(this.props);
    const isLoading = !this.hasLoaded();
    const activeFeedItem = Array.isArray(feedItems) && feedItems.find(item => {
      switch (item.type) {
        case FEED_ITEM_TYPE_ANNOTATION:
          return this.isCommentFeedItemActive(item);

        case FEED_ITEM_TYPE_COMMENT:
          return this.isCommentFeedItemActive(item);

        case FEED_ITEM_TYPE_TASK:
          return this.isFeedItemActive(item);

        default:
          return false;
      }
    });
    const errorMessageByEntryType = {
      annotation: messages.annotationMissingError,
      comment: messages.commentMissingError,
      task: messages.taskMissingError
    };
    const inlineFeedItemErrorMessage = activeFeedEntryType ? errorMessageByEntryType[activeFeedEntryType] : undefined;
    const isInlineFeedItemErrorVisible = !isLoading && activeFeedEntryType && !activeFeedItem;
    return (// eslint-disable-next-line jsx-a11y/no-static-element-interactions
      React.createElement("div", {
        className: classNames('bcs-activity-feed', {
          'bcs-is-scrolled': isScrolled
        }),
        "data-testid": isScrolled ? 'activityfeedscrolled' : 'activityfeed',
        onKeyDown: this.onKeyDown
      }, React.createElement("div", {
        ref: _ref4 => {
          this.feedContainer = _ref4;
        },
        className: "bcs-activity-feed-items-container",
        onScroll: this.throttledFeedScroll
      }, isLoading && React.createElement("div", {
        className: "bcs-activity-feed-loading-state"
      }, React.createElement(LoadingIndicator, null)), isEmpty && !isLoading && React.createElement(EmptyState, {
        showAnnotationMessage: hasAnnotationCreatePermission,
        showCommentMessage: showCommentForm
      }), !isEmpty && !isLoading && React.createElement(ActiveState, _extends({}, activityFeedError, {
        activeFeedItem: activeFeedItem,
        activeFeedItemRef: this.activeFeedItemRef,
        approverSelectorContacts: approverSelectorContacts,
        currentFileVersionId: currentFileVersionId,
        currentUser: currentUser,
        getApproverWithQuery: getApproverWithQuery,
        getAvatarUrl: getAvatarUrl,
        getMentionWithQuery: getMentionWithQuery,
        getUserProfileUrl: getUserProfileUrl,
        hasNewThreadedReplies: hasNewThreadedReplies,
        hasReplies: hasReplies,
        hasVersions: hasVersions,
        isDisabled: isDisabled,
        items: collapseFeedState(feedItems),
        mentionSelectorContacts: mentionSelectorContacts,
        onAnnotationDelete: onAnnotationDelete,
        onAnnotationEdit: onAnnotationEdit,
        onAnnotationSelect: onAnnotationSelect,
        onAnnotationStatusChange: onAnnotationStatusChange,
        onAppActivityDelete: onAppActivityDelete,
        onCommentDelete: hasCommentPermission ? onCommentDelete : noop,
        onCommentEdit: hasCommentPermission && onCommentUpdate ? props => {
          onCommentUpdate(props.id, props.text, props.status, props.hasMention, props.permissions, props.onSuccess, props.onError);
        } : noop,
        onCommentSelect: this.setSelectedItem,
        onHideReplies: onHideReplies,
        onReplyCreate: hasCommentPermission ? onReplyCreate : noop,
        onReplyDelete: hasCommentPermission ? onReplyDelete : noop,
        onReplyUpdate: hasCommentPermission ? onReplyUpdate : noop,
        onShowReplies: onShowReplies,
        onTaskAssignmentUpdate: onTaskAssignmentUpdate,
        onTaskDelete: onTaskDelete,
        onTaskEdit: onTaskUpdate,
        onTaskModalClose: onTaskModalClose,
        onTaskView: onTaskView,
        onVersionInfo: onVersionHistoryClick ? this.openVersionHistoryPopup : null,
        shouldUseUAA: shouldUseUAA,
        translations: translations
      })), isInlineFeedItemErrorVisible && inlineFeedItemErrorMessage && React.createElement(InlineError, {
        title: React.createElement(FormattedMessage, messages.feedInlineErrorTitle),
        className: "bcs-feedItemInlineError"
      }, React.createElement(FormattedMessage, inlineFeedItemErrorMessage))), showCommentForm ? React.createElement(CommentForm, {
        onSubmit: this.resetFeedScroll,
        isDisabled: isDisabled,
        mentionSelectorContacts: mentionSelectorContacts,
        contactsLoaded: contactsLoaded,
        className: classNames('bcs-activity-feed-comment-input', {
          'bcs-is-disabled': isDisabled
        }),
        createComment: hasCommentPermission ? this.onCommentCreate : noop,
        getMentionWithQuery: getMentionWithQuery,
        isOpen: isInputOpen // $FlowFixMe
        ,
        user: currentUser,
        onCancel: this.commentFormCancelHandler,
        onFocus: this.commentFormFocusHandler,
        getAvatarUrl: getAvatarUrl
      }) : null)
    );
  }

}

export default ActivityFeed;
//# sourceMappingURL=ActivityFeed.js.map