function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import noop from 'lodash/noop';
import PlainButton from '../../../../components/plain-button';
import ActivityThreadReplies from './ActivityThreadReplies';
import ActivityThreadReplyForm from './ActivityThreadReplyForm';
import messages from './messages';
import './ActivityThread.scss';

const ActivityThread = (_ref) => {
  let {
    children,
    currentUser,
    getAvatarUrl,
    getMentionWithQuery,
    getUserProfileUrl,
    hasNewThreadedReplies = false,
    hasReplies,
    isAlwaysExpanded = false,
    isPending,
    isRepliesLoading,
    mentionSelectorContacts,
    onHideReplies = noop,
    onReplyCreate,
    onReplyDelete = noop,
    onReplyEdit = noop,
    onReplySelect = noop,
    onShowReplies = noop,
    replies = [],
    repliesTotalCount = 0,
    translations
  } = _ref;
  const {
    length: repliesLength
  } = replies;
  const repliesToLoadCount = Math.max(repliesTotalCount - repliesLength, 0);

  const onHideRepliesHandler = () => {
    if (repliesLength) {
      onHideReplies(replies[repliesLength - 1]);
    }
  };

  const handleFormFocusOrShow = () => {
    onReplySelect(true);
  };

  const handleFormHide = () => {
    onReplySelect(false);
  };

  const renderButton = () => {
    if (isAlwaysExpanded || isRepliesLoading) {
      return null;
    }

    if (repliesTotalCount > repliesLength) {
      return React.createElement(PlainButton, {
        className: "bcs-ActivityThread-toggle",
        onClick: onShowReplies,
        type: "button",
        "data-testid": "activity-thread-button"
      }, React.createElement(FormattedMessage, _extends({
        values: {
          repliesToLoadCount
        }
      }, messages.showReplies)));
    }

    if (repliesTotalCount > 1 && repliesTotalCount === repliesLength) {
      return React.createElement(PlainButton, {
        className: "bcs-ActivityThread-toggle",
        onClick: onHideRepliesHandler,
        type: "button",
        "data-testid": "activity-thread-button"
      }, React.createElement(FormattedMessage, messages.hideReplies));
    }

    return null;
  };

  if (!hasReplies) {
    return children;
  }

  return React.createElement("div", {
    className: "bcs-ActivityThread",
    "data-testid": "activity-thread"
  }, React.createElement("div", {
    className: "bcs-ActivityThread-selectWrapper"
  }, React.createElement("div", {
    className: "bcs-ActivityThread-content"
  }, children, renderButton(), repliesTotalCount > 0 && repliesLength > 0 && React.createElement(ActivityThreadReplies, {
    currentUser: currentUser,
    getAvatarUrl: getAvatarUrl,
    getMentionWithQuery: getMentionWithQuery,
    getUserProfileUrl: getUserProfileUrl,
    hasNewThreadedReplies: hasNewThreadedReplies,
    isRepliesLoading: isRepliesLoading,
    mentionSelectorContacts: mentionSelectorContacts,
    onDelete: onReplyDelete,
    onEdit: onReplyEdit,
    onSelect: onReplySelect,
    replies: replies,
    translations: translations
  })), onReplyCreate && React.createElement(ActivityThreadReplyForm, {
    getMentionWithQuery: getMentionWithQuery,
    isDisabled: isPending,
    mentionSelectorContacts: mentionSelectorContacts,
    onFocus: handleFormFocusOrShow,
    onHide: handleFormHide,
    onShow: handleFormFocusOrShow,
    onReplyCreate: onReplyCreate
  })));
};

export default ActivityThread;
//# sourceMappingURL=ActivityThread.js.map