function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import uniqueId from 'lodash/uniqueId';
import commonMessages from '../../../common/messages';
import { annotationErrors, commentsErrors } from './errors';
import API from '../../../../api/APIFactory';
import useRepliesAPI from './useRepliesAPI';
import { useAnnotatorEvents } from '../../../common/annotator-context';
import useAnnotationAPI from './useAnnotationAPI';

const normalizeReplies = repliesArray => {
  if (!repliesArray) {
    return {};
  }

  return repliesArray.reduce((prevValues, reply) => {
    return _objectSpread({}, prevValues, {
      [reply.id]: reply
    });
  }, {});
};

const denormalizeReplies = repliesMap => {
  return Object.keys(repliesMap).map(key => repliesMap[key]);
};

const useAnnotationThread = (_ref) => {
  let {
    annotationId,
    api,
    currentUser,
    errorCallback,
    eventEmitter,
    file,
    onAnnotationCreate,
    target
  } = _ref;
  const [annotation, setAnnotation] = React.useState();
  const [replies, setReplies] = React.useState({});
  const [error, setError] = React.useState();
  const [isLoading, setIsLoading] = React.useState(false);
  const {
    file_version: {
      id: fileVersionId
    } = {},
    id: fileId,
    permissions: filePermissions = {}
  } = file;

  const updateOrCreateReplyItem = (replyId, updatedReplyValues) => {
    setReplies(prevReplies => _objectSpread({}, prevReplies, {
      [replyId]: _objectSpread({}, prevReplies[replyId], {}, updatedReplyValues)
    }));
  };

  const removeReplyItem = replyId => {
    setReplies(prevReplies => {
      const newReplies = _objectSpread({}, prevReplies);

      delete newReplies[replyId];
      return newReplies;
    });
  };

  const addPendingReply = (baseReply, requestId) => {
    const date = new Date().toISOString();

    const pendingReply = _objectSpread({
      created_at: date,
      created_by: currentUser,
      id: requestId,
      isPending: true,
      modified_at: date
    }, baseReply);

    updateOrCreateReplyItem(requestId, pendingReply);
  };

  const isCurrentAnnotation = id => annotationId === id;

  const handleAnnotationUpdateStartEvent = updatedAnnotation => {
    if (!isCurrentAnnotation(updatedAnnotation.id) || !annotation) {
      return;
    }

    setAnnotation(prevAnnotation => _objectSpread({}, prevAnnotation, {}, updatedAnnotation, {
      isPending: true
    }));
  };

  const handleAnnotationUpdateEndEvent = updatedAnnotation => {
    if (!isCurrentAnnotation(updatedAnnotation.id) || !annotation) {
      return;
    }

    setAnnotation(prevAnnotation => _objectSpread({}, prevAnnotation, {}, updatedAnnotation, {
      isPending: false
    }));
  };

  const handleAnnotationDeleteStartEvent = originAnnotationId => {
    if (!isCurrentAnnotation(originAnnotationId) || !annotation) {
      return;
    }

    setAnnotation(prevAnnotation => _objectSpread({}, prevAnnotation, {
      isPending: true
    }));
  };

  const handleAnnotationReplyAddStartEvent = (_ref2) => {
    let {
      annotationId: originAnnotationId,
      reply,
      requestId
    } = _ref2;

    if (!isCurrentAnnotation(originAnnotationId)) {
      return;
    }

    addPendingReply(reply, requestId);
  };

  const handleAnnotationReplyAddEndEvent = (_ref3) => {
    let {
      annotationId: originAnnotationId,
      reply,
      requestId
    } = _ref3;

    if (!isCurrentAnnotation(originAnnotationId)) {
      return;
    }

    updateOrCreateReplyItem(requestId, _objectSpread({}, reply, {
      isPending: false
    }));
  };

  const handleAnnotationReplyUpdateStart = (_ref4) => {
    let {
      annotationId: originAnnotationId,
      reply
    } = _ref4;

    if (!isCurrentAnnotation(originAnnotationId)) {
      return;
    }

    updateOrCreateReplyItem(reply.id, _objectSpread({}, reply, {
      isPending: true
    }));
  };

  const handleAnnotationReplyUpdateEnd = (_ref5) => {
    let {
      annotationId: originAnnotationId,
      reply
    } = _ref5;

    if (!isCurrentAnnotation(originAnnotationId)) {
      return;
    }

    updateOrCreateReplyItem(reply.id, _objectSpread({}, reply, {
      isPending: false
    }));
  };

  const handleAnnotationReplyDeleteStart = (_ref6) => {
    let {
      annotationId: originAnnotationId,
      id: replyId
    } = _ref6;

    if (!isCurrentAnnotation(originAnnotationId)) {
      return;
    }

    updateOrCreateReplyItem(replyId, {
      isPending: true
    });
  };

  const handleAnnotationReplyDeleteEnd = (_ref7) => {
    let {
      annotationId: originAnnotationId,
      id: replyId
    } = _ref7;

    if (!isCurrentAnnotation(originAnnotationId)) {
      return;
    }

    removeReplyItem(replyId);
  };

  const {
    emitAddAnnotationEndEvent,
    emitAddAnnotationReplyEndEvent,
    emitAddAnnotationReplyStartEvent,
    emitAddAnnotationStartEvent,
    emitAnnotationActiveChangeEvent,
    emitDeleteAnnotationEndEvent,
    emitDeleteAnnotationReplyEndEvent,
    emitDeleteAnnotationReplyStartEvent,
    emitDeleteAnnotationStartEvent,
    emitUpdateAnnotationEndEvent,
    emitUpdateAnnotationReplyEndEvent,
    emitUpdateAnnotationReplyStartEvent,
    emitUpdateAnnotationStartEvent
  } = useAnnotatorEvents({
    eventEmitter,
    onAnnotationDeleteStart: handleAnnotationDeleteStartEvent,
    onAnnotationReplyAddEnd: handleAnnotationReplyAddEndEvent,
    onAnnotationReplyAddStart: handleAnnotationReplyAddStartEvent,
    onAnnotationReplyUpdateEnd: handleAnnotationReplyUpdateEnd,
    onAnnotationReplyUpdateStart: handleAnnotationReplyUpdateStart,
    onAnnotationUpdateEnd: handleAnnotationUpdateEndEvent,
    onAnnotationUpdateStart: handleAnnotationUpdateStartEvent,
    onAnnotationReplyDeleteEnd: handleAnnotationReplyDeleteEnd,
    onAnnotationReplyDeleteStart: handleAnnotationReplyDeleteStart
  });

  const handleUpdateAnnotation = updatedValues => {
    setAnnotation(prevAnnotation => _objectSpread({}, prevAnnotation, {}, updatedValues));
  };

  const annotationErrorCallback = React.useCallback((e, code) => {
    setIsLoading(false);
    setError({
      title: commonMessages.errorOccured,
      message: annotationErrors[code] || annotationErrors.default
    });
    errorCallback(e, code, {
      error: e
    });
  }, [errorCallback]);
  const {
    handleCreate,
    handleDelete,
    handleEdit,
    handleFetch,
    handleStatusChange
  } = useAnnotationAPI({
    api,
    file,
    errorCallback: annotationErrorCallback
  });
  const replyErrorCallback = React.useCallback((replyId, e, code) => {
    updateOrCreateReplyItem(replyId, {
      error: {
        title: commonMessages.errorOccured,
        message: commentsErrors[code] || commentsErrors.default
      }
    });
    errorCallback(e, code, {
      error: e
    });
  }, [errorCallback]);
  const {
    createReply,
    deleteReply,
    editReply
  } = useRepliesAPI({
    annotationId,
    api,
    errorCallback: replyErrorCallback,
    fileId,
    filePermissions
  });

  const handleAnnotationCreate = text => {
    setIsLoading(true);
    const requestId = uniqueId('annotation_');

    const successCallback = newAnnotation => {
      setIsLoading(false);
      emitAddAnnotationEndEvent(newAnnotation, requestId);
      onAnnotationCreate(newAnnotation);
    };

    const payload = {
      description: {
        message: text
      },
      target
    };
    emitAddAnnotationStartEvent(payload, requestId);
    handleCreate({
      payload,
      successCallback
    });
  };

  const handleAnnotationDelete = (_ref8) => {
    let {
      id,
      permissions
    } = _ref8;

    const annotationDeleteSuccessCallback = () => {
      emitDeleteAnnotationEndEvent(id);
    };

    setAnnotation(prevAnnotation => _objectSpread({}, prevAnnotation, {
      isPending: true
    }));
    emitDeleteAnnotationStartEvent(id);
    handleDelete({
      id,
      permissions,
      successCallback: annotationDeleteSuccessCallback
    });
  };

  const onAnnotationEditSuccessCallback = updatedAnnotation => {
    handleUpdateAnnotation(_objectSpread({}, updatedAnnotation, {
      isPending: false
    }));
    emitUpdateAnnotationEndEvent(updatedAnnotation);
  };

  const handleAnnotationEdit = (_ref9) => {
    let {
      id,
      text,
      permissions
    } = _ref9;
    setAnnotation(prevAnnotation => _objectSpread({}, prevAnnotation, {
      isPending: true
    }));
    emitUpdateAnnotationStartEvent({
      id,
      description: {
        message: text
      }
    });
    handleEdit({
      id,
      text: text !== null && text !== void 0 ? text : '',
      permissions,
      successCallback: onAnnotationEditSuccessCallback
    });
  };

  const handleAnnotationStatusChange = (_ref10) => {
    let {
      id,
      permissions,
      status
    } = _ref10;
    setAnnotation(prevAnnotation => _objectSpread({}, prevAnnotation, {
      isPending: true
    }));
    handleStatusChange({
      id,
      status,
      permissions,
      successCallback: onAnnotationEditSuccessCallback
    });
  };

  const handleReplyCreate = message => {
    const requestId = uniqueId('reply_');
    const replyData = {
      tagged_message: message,
      type: 'comment'
    };

    const successCallback = comment => {
      updateOrCreateReplyItem(requestId, _objectSpread({}, comment, {
        isPending: false
      }));
      emitAddAnnotationReplyEndEvent(comment, annotationId, requestId);
    };

    addPendingReply(replyData, requestId);
    emitAddAnnotationReplyStartEvent(replyData, annotationId, requestId);
    createReply({
      message,
      requestId,
      successCallback
    });
  };

  const handleReplyEdit = (replyId, message, status, hasMention, permissions) => {
    const updates = {
      id: replyId,
      tagged_message: message
    };

    const successCallback = comment => {
      updateOrCreateReplyItem(comment.id, _objectSpread({}, comment, {
        isPending: false
      }));
      emitUpdateAnnotationReplyEndEvent(comment, annotationId);
    };

    updateOrCreateReplyItem(replyId, {
      message,
      isPending: true
    });
    emitUpdateAnnotationReplyStartEvent(updates, annotationId);
    editReply({
      id: replyId,
      message,
      permissions,
      successCallback
    });
  };

  const handleReplyDelete = (_ref11) => {
    let {
      id,
      permissions
    } = _ref11;
    updateOrCreateReplyItem(id, {
      isPending: true
    });
    emitDeleteAnnotationReplyStartEvent(id, annotationId);

    const successCallback = () => {
      removeReplyItem(id);
      emitDeleteAnnotationReplyEndEvent(id, annotationId);
    };

    deleteReply({
      id,
      permissions,
      successCallback
    });
  };

  React.useEffect(() => {
    if (!annotationId || isLoading || annotation && annotation.id === annotationId) {
      return;
    }

    setIsLoading(true);
    handleFetch({
      id: annotationId,
      successCallback: (_ref12) => {
        let {
          replies: fetchedReplies
        } = _ref12,
            normalizedAnnotation = _objectWithoutProperties(_ref12, ["replies"]);

        setAnnotation(_objectSpread({}, normalizedAnnotation));
        setReplies(normalizeReplies(fetchedReplies));
        setError(undefined);
        setIsLoading(false);
        emitAnnotationActiveChangeEvent(normalizedAnnotation.id, fileVersionId);
      }
    });
  }, [annotation, annotationId, emitAnnotationActiveChangeEvent, fileVersionId, handleFetch, isLoading]);
  return {
    annotation,
    error,
    isLoading,
    replies: denormalizeReplies(replies),
    annotationActions: {
      handleAnnotationCreate,
      handleAnnotationDelete,
      handleAnnotationEdit,
      handleAnnotationStatusChange
    },
    repliesActions: {
      handleReplyCreate,
      handleReplyEdit,
      handleReplyDelete
    }
  };
};

export default useAnnotationThread;
//# sourceMappingURL=useAnnotationThread.js.map