function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import TetherComponent from 'react-tether';
import ActivityError from '../common/activity-error';
import ActivityMessage from '../common/activity-message';
import ActivityStatus from '../common/activity-status';
import ActivityTimestamp from '../common/activity-timestamp';
import AnnotationActivityLink from './AnnotationActivityLink';
import AnnotationActivityMenu from './AnnotationActivityMenu';
import Avatar from '../Avatar';
import CommentForm from '../comment-form/CommentForm';
import DeleteConfirmation from '../common/delete-confirmation';
import Media from '../../../../components/media';
import messages from './messages';
import SelectableActivityCard from '../SelectableActivityCard';
import UserLink from '../common/user-link';
import { ACTIVITY_TARGETS } from '../../../common/interactionTargets';
import { COMMENT_STATUS_RESOLVED, PLACEHOLDER_USER } from '../../../../constants';
import IconAnnotation from '../../../../icons/two-toned/IconAnnotation';
import './AnnotationActivity.scss';

const AnnotationActivity = (_ref) => {
  let {
    currentUser,
    item,
    getAvatarUrl,
    getMentionWithQuery,
    getUserProfileUrl,
    hasVersions,
    isCurrentVersion,
    mentionSelectorContacts,
    onDelete = noop,
    onEdit = noop,
    onSelect = noop,
    onStatusChange = noop
  } = _ref;
  const [isConfirmingDelete, setIsConfirmingDelete] = React.useState(false);
  const [isEditing, setIsEditing] = React.useState(false);
  const [isMenuOpen, setIsMenuOpen] = React.useState(false);
  const {
    created_at,
    created_by,
    description,
    error,
    file_version,
    id,
    isPending,
    modified_at,
    permissions = {},
    status,
    target
  } = item;
  const {
    can_delete: canDelete,
    can_edit: canEdit,
    can_resolve: canResolve
  } = permissions;
  const isEdited = modified_at !== undefined && modified_at !== created_at;
  const isFileVersionUnavailable = file_version === null;
  const isCardDisabled = !!error || isConfirmingDelete || isMenuOpen || isEditing || isFileVersionUnavailable;
  const isMenuVisible = (canDelete || canEdit || canResolve) && !isPending;
  const isResolved = status === COMMENT_STATUS_RESOLVED;

  const handleDelete = () => setIsConfirmingDelete(true);

  const handleDeleteCancel = () => setIsConfirmingDelete(false);

  const handleDeleteConfirm = () => {
    setIsConfirmingDelete(false);
    onDelete({
      id,
      permissions
    });
  };

  const handleEdit = () => setIsEditing(true);

  const handleFormCancel = () => setIsEditing(false);

  const handleFormSubmit = (_ref2) => {
    let {
      text
    } = _ref2;
    setIsEditing(false);
    onEdit({
      id,
      text,
      permissions
    });
  };

  const handleMenuClose = () => setIsMenuOpen(false);

  const handleMenuOpen = () => setIsMenuOpen(true);

  const handleMouseDown = event => {
    if (isCardDisabled) {
      return;
    } // Prevents document event handlers from executing because box-annotations relies on
    // detecting mouse events on the document outside of annotation targets to determine when to
    // deselect annotations


    event.stopPropagation();
  };

  const handleSelect = () => onSelect(item);

  const handleStatusChange = newStatus => onStatusChange({
    id,
    status: newStatus,
    permissions
  });

  const createdAtTimestamp = new Date(created_at).getTime();
  const createdByUser = created_by || PLACEHOLDER_USER;
  const linkMessage = isCurrentVersion ? messages.annotationActivityPageItem : messages.annotationActivityVersionLink;
  const linkValue = isCurrentVersion ? target.location.value : getProp(file_version, 'version_number');
  const message = description && description.message || '';
  const activityLinkMessage = isFileVersionUnavailable ? messages.annotationActivityVersionUnavailable : _objectSpread({}, linkMessage, {
    values: {
      number: linkValue
    }
  });
  const tetherProps = {
    attachment: 'top right',
    className: 'bcs-AnnotationActivity-deleteConfirmationModal',
    constraints: [{
      to: 'scrollParent',
      attachment: 'together'
    }],
    targetAttachment: 'bottom right'
  };
  return React.createElement(React.Fragment, null, React.createElement(SelectableActivityCard, {
    className: "bcs-AnnotationActivity",
    "data-resin-feature": "annotations",
    "data-resin-iscurrent": isCurrentVersion,
    "data-resin-itemid": id,
    "data-resin-target": "annotationButton",
    isDisabled: isCardDisabled,
    onMouseDown: handleMouseDown,
    onSelect: handleSelect
  }, React.createElement(Media, {
    className: classNames('bcs-AnnotationActivity-media', {
      'bcs-is-pending': isPending || error
    })
  }, React.createElement(Media.Figure, {
    className: "bcs-AnnotationActivity-avatar"
  }, React.createElement(Avatar, {
    getAvatarUrl: getAvatarUrl,
    user: createdByUser,
    badgeIcon: React.createElement(IconAnnotation, null)
  })), React.createElement(Media.Body, null, React.createElement("div", {
    className: "bcs-AnnotationActivity-headline"
  }, React.createElement(UserLink, {
    "data-resin-target": ACTIVITY_TARGETS.PROFILE,
    getUserProfileUrl: getUserProfileUrl,
    id: createdByUser.id,
    name: createdByUser.name
  })), React.createElement("div", {
    className: "bcs-AnnotationActivity-timestamp"
  }, React.createElement(ActivityTimestamp, {
    date: createdAtTimestamp
  }), hasVersions && React.createElement(AnnotationActivityLink, {
    className: "bcs-AnnotationActivity-link",
    "data-resin-target": "annotationLink",
    id: id,
    isDisabled: isFileVersionUnavailable,
    message: activityLinkMessage,
    onClick: handleSelect
  })), React.createElement(ActivityStatus, {
    status: status
  }), isEditing && currentUser ? React.createElement(CommentForm, {
    className: "bcs-AnnotationActivity-editor",
    entityId: id,
    getAvatarUrl: getAvatarUrl,
    getMentionWithQuery: getMentionWithQuery,
    isEditing: isEditing,
    isOpen: isEditing,
    mentionSelectorContacts: mentionSelectorContacts,
    onCancel: handleFormCancel,
    updateComment: handleFormSubmit,
    user: currentUser,
    tagged_message: message
  }) : React.createElement(ActivityMessage, {
    getUserProfileUrl: getUserProfileUrl,
    id: id,
    isEdited: isEdited && !isResolved,
    tagged_message: message
  }))), error ? React.createElement(ActivityError, error) : null), React.createElement(TetherComponent, tetherProps, isMenuVisible && React.createElement(AnnotationActivityMenu, {
    canDelete: canDelete,
    canEdit: canEdit,
    canResolve: canResolve,
    className: "bcs-AnnotationActivity-menu",
    id: id,
    isDisabled: isConfirmingDelete,
    status: status,
    onDelete: handleDelete,
    onEdit: handleEdit,
    onMenuClose: handleMenuClose,
    onMenuOpen: handleMenuOpen,
    onStatusChange: handleStatusChange
  }), isConfirmingDelete && React.createElement(DeleteConfirmation, {
    "data-resin-component": ACTIVITY_TARGETS.ANNOTATION_OPTIONS,
    isOpen: isConfirmingDelete,
    message: messages.annotationActivityDeletePrompt,
    onDeleteCancel: handleDeleteCancel,
    onDeleteConfirm: handleDeleteConfirm
  })));
};

export default AnnotationActivity;
//# sourceMappingURL=AnnotationActivity.js.map