function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file AppActivity component
 */
import * as React from 'react';
import classNames from 'classnames';
import getProp from 'lodash/get';
import noop from 'lodash/noop';
import TetherComponent from 'react-tether';
import { FormattedMessage, injectIntl } from 'react-intl';
import ActivityCard from '../ActivityCard';
import ActivityTimestamp from '../common/activity-timestamp';
import DeleteConfirmation from '../common/delete-confirmation';
import IconTrash from '../../../../icons/general/IconTrash';
import Media from '../../../../components/media';
import messages from './messages';
import { bdlGray80 } from '../../../../styles/variables';
import { Link } from '../../../../components/link';
import { MenuItem } from '../../../../components/menu';
import './AppActivity.scss';

function mapActivityNodes(node) {
  const {
    dataset = {},
    href = '#',
    tagName,
    textContent
  } = node;

  switch (tagName) {
    case 'A':
      return React.createElement(Link, {
        href: href,
        "data-resin-target": dataset.resinTarget,
        "data-resin-action": dataset.resinAction,
        key: "app_actvity_link_".concat(href),
        rel: "roreferrer noopener",
        className: "bcs-AppActivity-link",
        target: "_blank"
      }, textContent);

    default:
      return textContent;
  }
}

class AppActivity extends React.PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "parser", new DOMParser());

    _defineProperty(this, "state", {
      isConfirmingDelete: false
    });

    _defineProperty(this, "handleDeleteCancel", () => {
      this.setState({
        isConfirmingDelete: false
      });
    });

    _defineProperty(this, "handleDeleteClick", () => {
      this.setState({
        isConfirmingDelete: true
      });
    });

    _defineProperty(this, "handleDeleteConfirm", () => {
      const {
        id,
        onDelete,
        permissions
      } = this.props;
      onDelete({
        id,
        permissions
      });
    });

    _defineProperty(this, "parseActivity", () => {
      const {
        rendered_text: renderedText
      } = this.props;
      const doc = this.parser.parseFromString(renderedText, 'text/html');

      if (!doc) {
        return [];
      }

      const childNodes = getProp(doc, 'body.childNodes', []);
      return Array.from(childNodes);
    });
  }

  render() {
    const {
      activity_template: {
        id: templateId
      },
      app: {
        name,
        icon_url
      },
      created_at: createdAt,
      created_by: createdBy,
      currentUser,
      error,
      intl,
      isPending,
      permissions
    } = this.props;
    const canDelete = getProp(permissions, 'can_delete', false) || currentUser && currentUser.id === createdBy.id;
    const createdAtTimestamp = new Date(createdAt).getTime();
    const isMenuVisible = canDelete && !isPending;
    const {
      isConfirmingDelete
    } = this.state;
    return React.createElement(ActivityCard, {
      className: "bcs-AppActivity",
      "data-resin-target": "loaded",
      "data-resin-feature": "appActivityCard".concat(templateId)
    }, React.createElement(Media, {
      className: classNames({
        'bcs-is-pending': isPending || error
      })
    }, React.createElement(Media.Figure, null, React.createElement("img", {
      className: "bcs-AppActivity-icon",
      alt: intl.formatMessage(messages.appActivityAltIcon, {
        appActivityName: name
      }),
      src: icon_url
    })), React.createElement(Media.Body, {
      className: "bcs-AppActivity-body"
    }, isMenuVisible && React.createElement(TetherComponent, {
      attachment: "top right",
      className: "bcs-AppActivity-confirm",
      constraints: [{
        to: 'scrollParent',
        attachment: 'together'
      }],
      targetAttachment: "bottom right"
    }, React.createElement(Media.Menu, {
      isDisabled: isConfirmingDelete
    }, React.createElement(MenuItem, {
      onClick: this.handleDeleteClick
    }, React.createElement(IconTrash, {
      color: bdlGray80
    }), React.createElement(FormattedMessage, messages.appActivityDeleteMenuItem))), isConfirmingDelete && React.createElement(DeleteConfirmation, {
      isOpen: isConfirmingDelete,
      message: messages.appActivityDeletePrompt,
      onDeleteCancel: this.handleDeleteCancel,
      onDeleteConfirm: this.handleDeleteConfirm
    })), React.createElement("figcaption", {
      className: "bcs-AppActivity-headline"
    }, name), React.createElement("div", null, React.createElement(ActivityTimestamp, {
      date: createdAtTimestamp
    })), this.parseActivity().map(mapActivityNodes))));
  }

}

_defineProperty(AppActivity, "defaultProps", {
  onDelete: noop,
  permissions: {}
});

export default injectIntl(AppActivity);
//# sourceMappingURL=AppActivity.js.map