function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Component for Approval comment form
 */
import * as React from 'react';
import noop from 'lodash/noop';
import classNames from 'classnames';
import { EditorState } from 'draft-js';
import { FormattedMessage, injectIntl } from 'react-intl';
import Avatar from '../Avatar';
import CommentFormControls from './CommentFormControls';
import DraftJSMentionSelector, { createMentionSelectorState, getFormattedCommentText } from '../../../../components/form-elements/draft-js-mention-selector';
import Form from '../../../../components/form-elements/form/Form';
import Media from '../../../../components/media';
import messages from './messages';
import './CommentForm.scss';

const getEditorState = (shouldFocusOnOpen, message) => shouldFocusOnOpen ? EditorState.moveFocusToEnd(createMentionSelectorState(message)) : createMentionSelectorState(message);

class CommentForm extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      commentEditorState: getEditorState(this.props.shouldFocusOnOpen, this.props.tagged_message)
    });

    _defineProperty(this, "onFormValidSubmitHandler", () => {
      const {
        createComment = noop,
        updateComment = noop,
        onSubmit,
        entityId
      } = this.props;
      const {
        text,
        hasMention
      } = this.getFormattedCommentText();

      if (!text) {
        return;
      }

      if (entityId) {
        updateComment({
          id: entityId,
          text,
          hasMention
        });
      } else {
        createComment({
          text,
          hasMention
        });
      }

      if (onSubmit) {
        onSubmit();
      }

      this.setState({
        commentEditorState: getEditorState(false)
      });
    });

    _defineProperty(this, "onMentionSelectorChangeHandler", nextEditorState => this.setState({
      commentEditorState: nextEditorState
    }));

    _defineProperty(this, "getFormattedCommentText", () => {
      const {
        commentEditorState
      } = this.state;
      return getFormattedCommentText(commentEditorState);
    });
  }

  componentDidUpdate(_ref) {
    let {
      isOpen: prevIsOpen
    } = _ref;
    const {
      isOpen
    } = this.props;

    if (isOpen !== prevIsOpen && !isOpen) {
      this.setState({
        commentEditorState: getEditorState(false)
      });
    }
  }

  render() {
    const {
      className,
      getMentionWithQuery,
      intl: {
        formatMessage
      },
      isDisabled,
      isOpen,
      mentionSelectorContacts = [],
      contactsLoaded,
      onCancel,
      onFocus,
      user,
      isEditing,
      tagged_message,
      getAvatarUrl,
      showTip = true,
      placeholder = formatMessage(messages.commentWrite)
    } = this.props;
    const {
      commentEditorState
    } = this.state;
    const inputContainerClassNames = classNames('bcs-CommentForm', className, {
      'bcs-is-open': isOpen
    });
    return React.createElement(Media, {
      className: inputContainerClassNames
    }, !isEditing && !!user && React.createElement(Media.Figure, {
      className: "bcs-CommentForm-avatar"
    }, React.createElement(Avatar, {
      getAvatarUrl: getAvatarUrl,
      user: user
    })), React.createElement(Media.Body, {
      className: "bcs-CommentForm-body",
      "data-testid": "bcs-CommentForm-body"
    }, React.createElement(Form, {
      onValidSubmit: this.onFormValidSubmitHandler
    }, React.createElement(DraftJSMentionSelector, {
      className: "bcs-CommentForm-input",
      contacts: isOpen ? mentionSelectorContacts : [],
      contactsLoaded: contactsLoaded,
      editorState: commentEditorState,
      hideLabel: true,
      isDisabled: isDisabled,
      isRequired: isOpen,
      name: "commentText",
      label: formatMessage(messages.commentLabel),
      description: formatMessage(messages.atMentionTipDescription),
      onChange: this.onMentionSelectorChangeHandler,
      onFocus: onFocus,
      onMention: getMentionWithQuery,
      placeholder: tagged_message ? undefined : placeholder,
      validateOnBlur: false
    }), showTip && React.createElement("div", {
      className: "bcs-CommentForm-tip"
    }, React.createElement(FormattedMessage, messages.atMentionTip)), isOpen && React.createElement(CommentFormControls, {
      onCancel: onCancel
    }))));
  }

} // For testing only


_defineProperty(CommentForm, "defaultProps", {
  isOpen: false,
  shouldFocusOnOpen: false
});

export { CommentForm as CommentFormUnwrapped };
export default injectIntl(CommentForm);
//# sourceMappingURL=CommentForm.js.map