function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import noop from 'lodash/noop';
import { FormattedMessage } from 'react-intl';
import TetherComponent from 'react-tether';
import Checkmark16 from '../../../../icon/line/Checkmark16';
import Trash16 from '../../../../icon/line/Trash16';
import Pencil16 from '../../../../icon/line/Pencil16';
import X16 from '../../../../icon/fill/X16';
import Avatar from '../Avatar';
import Media from '../../../../components/media';
import { MenuItem } from '../../../../components/menu';
import { ACTIVITY_TARGETS } from '../../../common/interactionTargets';
import DeleteConfirmation from '../common/delete-confirmation';
import ActivityTimestamp from '../common/activity-timestamp';
import UserLink from '../common/user-link';
import ActivityCard from '../ActivityCard';
import ActivityError from '../common/activity-error';
import ActivityMessage from '../common/activity-message';
import ActivityStatus from '../common/activity-status';
import CommentForm from '../comment-form';
import { COMMENT_STATUS_OPEN, COMMENT_STATUS_RESOLVED, PLACEHOLDER_USER } from '../../../../constants';
import messages from './messages';
import './Comment.scss';

class Comment extends React.Component {
  constructor() {
    var _this;

    super(...arguments);
    _this = this;

    _defineProperty(this, "state", {
      isConfirmingDelete: false,
      isEditing: false,
      isInputOpen: false
    });

    _defineProperty(this, "selectComment", function () {
      let isSelected = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
      const {
        onSelect
      } = _this.props;
      onSelect(isSelected);
    });

    _defineProperty(this, "handleDeleteConfirm", () => {
      const {
        id,
        onDelete,
        permissions
      } = this.props;
      onDelete({
        id,
        permissions
      });
      this.selectComment(false);
    });

    _defineProperty(this, "handleDeleteCancel", () => {
      this.setState({
        isConfirmingDelete: false
      });
      this.selectComment(false);
    });

    _defineProperty(this, "handleDeleteClick", () => {
      this.setState({
        isConfirmingDelete: true
      });
      this.selectComment();
    });

    _defineProperty(this, "handleEditClick", () => {
      this.setState({
        isEditing: true,
        isInputOpen: true
      });
      this.selectComment();
    });

    _defineProperty(this, "handleMenuClose", () => {
      const {
        isConfirmingDelete,
        isEditing,
        isInputOpen
      } = this.state;

      if (isConfirmingDelete || isEditing || isInputOpen) {
        return;
      }

      this.selectComment(false);
    });

    _defineProperty(this, "handleMenuOpen", () => {
      this.selectComment();
    });

    _defineProperty(this, "commentFormFocusHandler", () => {
      this.setState({
        isInputOpen: true
      });
      this.selectComment();
    });

    _defineProperty(this, "commentFormCancelHandler", () => {
      this.setState({
        isInputOpen: false,
        isEditing: false
      });
      this.selectComment(false);
    });

    _defineProperty(this, "commentFormSubmitHandler", () => {
      this.setState({
        isInputOpen: false,
        isEditing: false
      });
      this.selectComment(false);
    });

    _defineProperty(this, "handleMessageUpdate", (_ref) => {
      let {
        id,
        text,
        hasMention
      } = _ref;
      const {
        onEdit,
        permissions
      } = this.props;
      onEdit({
        id,
        text,
        hasMention,
        permissions
      });
      this.commentFormSubmitHandler();
    });

    _defineProperty(this, "handleStatusUpdate", status => {
      const {
        id,
        onEdit,
        permissions
      } = this.props;
      onEdit({
        id,
        status,
        hasMention: false,
        permissions
      });
    });
  }

  render() {
    const {
      created_by,
      created_at,
      permissions = {},
      id,
      isPending,
      error,
      tagged_message = '',
      translatedTaggedMessage,
      translations,
      currentUser,
      isDisabled,
      getAvatarUrl,
      getUserProfileUrl,
      getMentionWithQuery,
      mentionSelectorContacts,
      modified_at,
      onEdit,
      status
    } = this.props;
    const {
      isConfirmingDelete,
      isEditing,
      isInputOpen
    } = this.state;
    const canDelete = permissions.can_delete;
    const canEdit = onEdit !== noop && permissions.can_edit;
    const canResolve = onEdit !== noop && permissions.can_resolve;
    const createdAtTimestamp = new Date(created_at).getTime();
    const createdByUser = created_by || PLACEHOLDER_USER;
    const isEdited = modified_at !== undefined && modified_at !== created_at;
    const isMenuVisible = (canDelete || canEdit || canResolve) && !isPending;
    const isResolved = status === COMMENT_STATUS_RESOLVED;
    return React.createElement(ActivityCard, {
      className: "bcs-Comment"
    }, React.createElement(Media, {
      className: classNames('bcs-Comment-media', {
        'bcs-is-pending': isPending || error
      })
    }, React.createElement(Media.Figure, null, React.createElement(Avatar, {
      getAvatarUrl: getAvatarUrl,
      user: createdByUser
    })), React.createElement(Media.Body, null, isMenuVisible && React.createElement(TetherComponent, {
      attachment: "top right",
      className: "bcs-Comment-deleteConfirmationModal",
      constraints: [{
        to: 'scrollParent',
        attachment: 'together'
      }],
      targetAttachment: "bottom right"
    }, React.createElement(Media.Menu, {
      isDisabled: isConfirmingDelete,
      "data-testid": "comment-actions-menu",
      dropdownProps: {
        onMenuOpen: this.handleMenuOpen,
        onMenuClose: this.handleMenuClose
      },
      menuProps: {
        'data-resin-component': ACTIVITY_TARGETS.COMMENT_OPTIONS
      }
    }, canResolve && isResolved && React.createElement(MenuItem, {
      className: "bcs-Comment-unresolveComment",
      "data-resin-target": ACTIVITY_TARGETS.COMMENT_OPTIONS_EDIT,
      "data-testid": "unresolve-comment",
      onClick: () => this.handleStatusUpdate(COMMENT_STATUS_OPEN)
    }, React.createElement(X16, null), React.createElement(FormattedMessage, messages.commentUnresolveMenuItem)), canResolve && !isResolved && React.createElement(MenuItem, {
      "data-resin-target": ACTIVITY_TARGETS.COMMENT_OPTIONS_EDIT,
      "data-testid": "resolve-comment",
      onClick: () => this.handleStatusUpdate(COMMENT_STATUS_RESOLVED)
    }, React.createElement(Checkmark16, null), React.createElement(FormattedMessage, messages.commentResolveMenuItem)), canEdit && React.createElement(MenuItem, {
      "data-resin-target": ACTIVITY_TARGETS.COMMENT_OPTIONS_EDIT,
      "data-testid": "edit-comment",
      onClick: this.handleEditClick
    }, React.createElement(Pencil16, null), React.createElement(FormattedMessage, messages.commentEditMenuItem)), canDelete && React.createElement(MenuItem, {
      "data-resin-target": ACTIVITY_TARGETS.COMMENT_OPTIONS_DELETE,
      "data-testid": "delete-comment",
      onClick: this.handleDeleteClick
    }, React.createElement(Trash16, null), React.createElement(FormattedMessage, messages.commentDeleteMenuItem))), isConfirmingDelete && React.createElement(DeleteConfirmation, {
      "data-resin-component": ACTIVITY_TARGETS.COMMENT_OPTIONS,
      isOpen: isConfirmingDelete,
      message: messages.commentDeletePrompt,
      onDeleteCancel: this.handleDeleteCancel,
      onDeleteConfirm: this.handleDeleteConfirm
    })), React.createElement("div", {
      className: "bcs-Comment-headline"
    }, React.createElement(UserLink, {
      "data-resin-target": ACTIVITY_TARGETS.PROFILE,
      id: createdByUser.id,
      name: createdByUser.name,
      getUserProfileUrl: getUserProfileUrl
    })), React.createElement("div", {
      className: "bcs-Comment-timestamp"
    }, React.createElement(ActivityTimestamp, {
      date: createdAtTimestamp
    })), React.createElement(ActivityStatus, {
      status: status
    }), isEditing ? React.createElement(CommentForm, {
      isDisabled: isDisabled,
      className: classNames('bcs-Comment-editor', {
        'bcs-is-disabled': isDisabled
      }),
      updateComment: this.handleMessageUpdate,
      isOpen: isInputOpen // $FlowFixMe
      ,
      user: currentUser,
      onCancel: this.commentFormCancelHandler,
      onFocus: this.commentFormFocusHandler,
      isEditing: isEditing,
      entityId: id,
      tagged_message: tagged_message,
      getAvatarUrl: getAvatarUrl,
      mentionSelectorContacts: mentionSelectorContacts,
      getMentionWithQuery: getMentionWithQuery
    }) : React.createElement(ActivityMessage, _extends({
      id: id,
      isEdited: isEdited && !isResolved,
      tagged_message: tagged_message,
      translatedTaggedMessage: translatedTaggedMessage
    }, translations, {
      translationFailed: error ? true : null,
      getUserProfileUrl: getUserProfileUrl
    })))), error ? React.createElement(ActivityError, error) : null);
  }

}

_defineProperty(Comment, "defaultProps", {
  onDelete: noop,
  onEdit: noop
});

export default Comment;
//# sourceMappingURL=Comment.js.map