function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import noop from 'lodash/noop';
import { FormattedMessage } from 'react-intl';
import CollapsableMessage from './CollapsableMessage';
import formatTaggedMessage from '../../utils/formatTaggedMessage';
import LoadingIndicator from '../../../../../components/loading-indicator';
import messages from './messages';
import ShowOriginalButton from './ShowOriginalButton';
import TranslateButton from './TranslateButton';
import { withFeatureConsumer, isFeatureEnabled } from '../../../../common/feature-checking';
import './ActivityMessage.scss';

class ActivityMessage extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isLoading: false,
      isTranslation: false
    });

    _defineProperty(this, "handleTranslate", event => {
      const {
        id,
        tagged_message,
        onTranslate = noop,
        translatedTaggedMessage
      } = this.props;

      if (!translatedTaggedMessage) {
        this.setState({
          isLoading: true
        });
        onTranslate({
          id,
          tagged_message
        });
      }

      this.setState({
        isTranslation: true
      });
      event.preventDefault();
    });

    _defineProperty(this, "handleShowOriginal", event => {
      this.setState({
        isTranslation: false
      });
      event.preventDefault();
    });
  }

  componentDidUpdate(prevProps) {
    const {
      translatedTaggedMessage,
      translationFailed
    } = this.props;
    const {
      translatedTaggedMessage: prevTaggedMessage,
      translationFailed: prevTranslationFailed
    } = prevProps;

    if (prevTaggedMessage === translatedTaggedMessage || prevTranslationFailed === translationFailed) {
      return;
    }

    if (translatedTaggedMessage || translationFailed) {
      this.setState({
        isLoading: false
      });
    }
  }

  getButton(isTranslation) {
    let button = null;

    if (isTranslation) {
      button = React.createElement(ShowOriginalButton, {
        handleShowOriginal: this.handleShowOriginal
      });
    } else {
      button = React.createElement(TranslateButton, {
        handleTranslate: this.handleTranslate
      });
    }

    return button;
  }

  render() {
    const {
      features,
      getUserProfileUrl,
      id,
      isEdited,
      tagged_message,
      translatedTaggedMessage,
      translationEnabled
    } = this.props;
    const {
      isLoading,
      isTranslation
    } = this.state;
    const commentToDisplay = translationEnabled && isTranslation && translatedTaggedMessage ? translatedTaggedMessage : tagged_message;
    const MessageWrapper = isFeatureEnabled(features, 'activityFeed.collapsableMessages.enabled') ? CollapsableMessage : React.Fragment;
    return isLoading ? React.createElement("div", {
      className: "bcs-ActivityMessageLoading"
    }, React.createElement(LoadingIndicator, {
      size: "small"
    })) : React.createElement("div", {
      className: "bcs-ActivityMessage"
    }, React.createElement(MessageWrapper, null, formatTaggedMessage(commentToDisplay, id, false, getUserProfileUrl), isEdited && React.createElement("span", {
      className: "bcs-ActivityMessage-edited"
    }, React.createElement(FormattedMessage, messages.activityMessageEdited))), translationEnabled ? this.getButton(isTranslation) : null);
  }

}

_defineProperty(ActivityMessage, "defaultProps", {
  isEdited: false,
  translationEnabled: false
});

export { ActivityMessage };
export default withFeatureConsumer(ActivityMessage);
//# sourceMappingURL=ActivityMessage.js.map