function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Sidebar Additional Tab component
 * @author Box
 */
import * as React from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';
import { bdlGray50 } from '../../../styles/variables';
import PlainButton from '../../../components/plain-button/PlainButton';
import AdditionalTabTooltip from './AdditionalTabTooltip';
import AdditionalTabPlaceholder from './AdditionalTabPlaceholder';
import Apps16 from '../../../icon/fill/Apps16';
import messages from './messages';
import './AdditionalTab.scss';
const BLOCKED_BY_SHEILD = 'BLOCKED_BY_SHIELD_ACCESS_POLICY';

class AdditionalTab extends React.PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isErrored: false
    });

    _defineProperty(this, "onImageError", () => {
      this.props.onImageLoad();
      this.setState({
        isErrored: true
      });
    });
  }

  isDisabled() {
    const {
      status
    } = this.props;
    return status === BLOCKED_BY_SHEILD;
  }

  getDisabledReason() {
    let reason = '';
    const {
      status
    } = this.props;

    switch (status) {
      case BLOCKED_BY_SHEILD:
        reason = React.createElement(FormattedMessage, messages.blockedByShieldAccessPolicy);
        break;

      default: // noop

    }

    return reason;
  }

  getTabIcon() {
    const {
      id,
      iconUrl,
      onImageLoad,
      title
    } = this.props;
    const {
      isErrored
    } = this.state;
    let TabIcon;

    if (isErrored) {
      TabIcon = React.createElement(AdditionalTabPlaceholder, {
        isLoading: false
      });
    } else if (id && id > 0) {
      TabIcon = React.createElement("img", {
        className: "bdl-AdditionalTab-icon",
        src: iconUrl,
        onError: this.onImageError,
        onLoad: onImageLoad,
        alt: title
      });
    } else {
      TabIcon = React.createElement(Apps16, {
        color: bdlGray50,
        width: 20,
        height: 20
      });
    }

    return TabIcon;
  }

  render() {
    const _this$props = this.props,
          {
      callback: callbackFn,
      id,
      isLoading,
      iconUrl,
      ftuxTooltipData,
      onImageLoad,
      title
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["callback", "id", "isLoading", "iconUrl", "ftuxTooltipData", "onImageLoad", "title"]);

    const isDisabled = this.isDisabled();
    const className = classNames('bdl-AdditionalTab', {
      'bdl-is-hidden': isLoading,
      'bdl-is-disabled': isDisabled,
      'bdl-is-overflow': id && id < 0
    });
    const tooltipText = isDisabled ? this.getDisabledReason() : title;
    return React.createElement(AdditionalTabTooltip, {
      defaultTooltipText: tooltipText,
      ftuxTooltipData: ftuxTooltipData,
      isFtuxVisible: !isLoading
    }, React.createElement(PlainButton, {
      "aria-label": title,
      className: className,
      "data-testid": "additionaltab",
      type: "button",
      isDisabled: isDisabled,
      onClick: () => callbackFn({
        id,
        callbackData: rest
      })
    }, this.getTabIcon()));
  }

}

export default AdditionalTab;
//# sourceMappingURL=AdditionalTab.js.map