function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Faces Skill Card component
 * @author Box
 */
import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import PlainButton from '../../../../components/plain-button/PlainButton';
import PrimaryButton from '../../../../components/primary-button/PrimaryButton';
import LoadingIndicatorWrapper from '../../../../components/loading-indicator/LoadingIndicatorWrapper';
import InlineError from '../../../../components/inline-error/InlineError';
import Tooltip from '../../../../components/tooltip/Tooltip';
import Button from '../../../../components/button/Button';
import IconEdit from '../../../../icons/general/IconEdit';
import messages from '../../../common/messages';
import { SKILLS_TARGETS } from '../../../common/interactionTargets';
import Face from './Face';
import Timeline from '../timeline';
import './Faces.scss';

class Faces extends React.PureComponent {
  /**
   * [constructor]
   *
   * @public
   * @return {Faces}
   */
  constructor(props) {
    super(props);

    _defineProperty(this, "toggleIsEditing", () => {
      this.setState(prevState => ({
        isEditing: !prevState.isEditing
      }));
    });

    _defineProperty(this, "onSelect", face => {
      const {
        selected
      } = this.state;
      this.setState({
        selected: selected === face ? undefined : face
      });
    });

    _defineProperty(this, "onDelete", face => {
      const {
        removes
      } = this.state;
      removes.push(face);
      this.setState({
        removes: removes.slice(0)
      });
    });

    _defineProperty(this, "onSave", () => {
      const {
        onSkillChange
      } = this.props;
      const {
        removes
      } = this.state;
      this.toggleIsEditing();

      if (removes.length > 0) {
        this.setState({
          isLoading: true
        });
        onSkillChange(removes);
      }
    });

    _defineProperty(this, "onCancel", () => {
      this.resetState(this.props);
    });

    this.state = {
      faces: props.card.entries,
      removes: [],
      isEditing: props.hasError,
      hasError: props.hasError,
      isLoading: false
    };
  }
  /**
   * Helper to reset the state
   *
   * @private
   * @param {Object} props - component props
   * @return {void}
   */


  resetState(props) {
    this.setState({
      faces: props.card.entries,
      removes: [],
      isEditing: false,
      selected: undefined,
      hasError: false,
      isLoading: false
    });
  }
  /**
   * Toggles the edit mode
   *
   * @private
   * @return {void}
   */


  /**
   * Renders the faces
   *
   * @private
   * @return {void}
   */
  render() {
    const {
      card,
      isEditable,
      getViewer
    } = this.props;
    const {
      selected,
      faces,
      removes,
      isEditing,
      hasError,
      isLoading
    } = this.state;
    const {
      duration
    } = card;
    const hasFaces = faces.length > 0;
    const entries = faces.filter(face => !removes.includes(face));
    const editClassName = classNames('be-face-edit', {
      'be-faces-is-editing': isEditing
    });
    return React.createElement(LoadingIndicatorWrapper, {
      className: "be-faces",
      isLoading: isLoading
    }, hasFaces && isEditable && !isLoading && React.createElement(Tooltip, {
      text: React.createElement(FormattedMessage, messages.editLabel)
    }, React.createElement(PlainButton, {
      className: editClassName,
      "data-resin-target": SKILLS_TARGETS.FACES.EDIT,
      onClick: this.toggleIsEditing,
      type: "button"
    }, React.createElement(IconEdit, null))), hasError && React.createElement(InlineError, {
      title: React.createElement(FormattedMessage, messages.sidebarSkillsErrorTitle)
    }, React.createElement(FormattedMessage, messages.sidebarSkillsErrorContent)), hasFaces ? entries.map((face, index) =>
    /* eslint-disable react/no-array-index-key */
    React.createElement(Face, {
      key: index,
      face: face,
      isEditing: isEditing,
      onDelete: this.onDelete,
      onSelect: this.onSelect,
      selected: selected
    })
    /* eslint-enable react/no-array-index-key */
    ) : React.createElement(FormattedMessage, messages.skillNoInfoFoundError), !!selected && !isEditing && Array.isArray(selected.appears) && selected.appears.length > 0 && React.createElement(Timeline, {
      duration: duration,
      getViewer: getViewer,
      interactionTarget: SKILLS_TARGETS.FACES.TIMELINE,
      timeslices: selected.appears
    }), isEditing && React.createElement("div", {
      className: "be-faces-buttons"
    }, React.createElement(Button, {
      "data-resin-target": SKILLS_TARGETS.FACES.EDIT_CANCEL,
      onClick: this.onCancel,
      type: "button"
    }, React.createElement(FormattedMessage, messages.cancel)), React.createElement(PrimaryButton, {
      "data-resin-target": SKILLS_TARGETS.FACES.EDIT_SAVE,
      onClick: this.onSave,
      type: "button"
    }, React.createElement(FormattedMessage, messages.save))));
  }

}

export default Faces;
//# sourceMappingURL=Faces.js.map