function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Editable Skill Keywords card component
 * @author Box
 */
import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import PillSelector from '../../../../components/pill-selector-dropdown/PillSelector';
import PrimaryButton from '../../../../components/primary-button/PrimaryButton';
import Button from '../../../../components/button/Button';
import messages from '../../../common/messages';
import { SKILLS_TARGETS } from '../../../common/interactionTargets';
import getPills from './keywordUtils';
import './EditableKeywords.scss';

class EditableKeywords extends React.PureComponent {
  /**
   * [constructor]
   *
   * @public
   * @return {EditableKeywords}
   */
  constructor(props) {
    super(props);

    _defineProperty(this, "onRemove", (option, index) => {
      // eslint-disable-line
      const {
        onDelete,
        keywords
      } = this.props;
      onDelete(keywords[index]);
    });

    _defineProperty(this, "onKeyDown", (_ref) => {
      let {
        key
      } = _ref;

      if (key === 'Enter' && !this.state.isInCompositionMode) {
        this.onBlur();
      }
    });

    _defineProperty(this, "onBlur", () => {
      const {
        onAdd
      } = this.props;
      const {
        keyword
      } = this.state;

      if (keyword) {
        onAdd({
          type: 'text',
          text: keyword
        });
      }
    });

    _defineProperty(this, "onCompositionStart", () => {
      this.setState({
        isInCompositionMode: true
      });
    });

    _defineProperty(this, "onCompositionEnd", () => {
      this.setState({
        isInCompositionMode: false
      });
    });

    _defineProperty(this, "onInput", event => {
      const currentTarget = event.currentTarget;
      this.setState({
        keyword: currentTarget.value
      });
    });

    this.state = {
      pills: getPills(props.keywords),
      keyword: '',
      isInCompositionMode: false
    };
  }
  /**
   * Called when keywords gets new properties.
   * Should reset to original state.
   *
   * @private
   * @param {Object} nextProps - component props
   * @return {void}
   */


  componentDidUpdate(_ref2) {
    let {
      keywords: prevKeywords
    } = _ref2;
    const {
      keywords
    } = this.props;

    if (prevKeywords !== keywords) {
      this.setState({
        pills: getPills(keywords),
        keyword: ''
      });
    }
  }
  /**
   * Called when keywords gets new properties.
   * Should reset to original state.
   *
   * @private
   * @param {Object} option - pill
   * @param {number} index - pill index
   * @return {void}
   */


  /**
   * Renders the keywords
   *
   * @private
   * @return {void}
   */
  render() {
    const {
      onSave,
      onCancel
    } = this.props;
    const {
      pills,
      keyword
    } = this.state;
    return React.createElement("span", {
      className: "bdl-EditableKeywords"
    }, React.createElement(PillSelector, {
      onBlur: this.onBlur,
      onCompositionEnd: this.onCompositionEnd,
      onCompositionStart: this.onCompositionStart,
      onInput: this.onInput,
      onKeyDown: this.onKeyDown,
      onPaste: this.onInput,
      onRemove: this.onRemove,
      selectedOptions: pills,
      value: keyword
    }), React.createElement("div", {
      className: "be-keywords-buttons"
    }, React.createElement(Button, {
      "data-resin-target": SKILLS_TARGETS.KEYWORDS.EDIT_CANCEL,
      onClick: onCancel,
      type: "button"
    }, React.createElement(FormattedMessage, messages.cancel)), React.createElement(PrimaryButton, {
      "data-resin-target": SKILLS_TARGETS.KEYWORDS.EDIT_SAVE,
      onClick: onSave,
      type: "button"
    }, React.createElement(FormattedMessage, messages.save))));
  }

}

export default EditableKeywords;
//# sourceMappingURL=EditableKeywords.js.map