/**
 * 
 * @file Timeline component
 * @author Box
 */
import React from 'react';
import { FormattedMessage } from 'react-intl';
import PlainButton from '../../../../components/plain-button/PlainButton';
import IconTrackNext from '../../../../icons/general/IconTrackNext';
import IconTrackPrevious from '../../../../icons/general/IconTrackPrevious';
import messages from '../../../common/messages';
import { SKILLS_TARGETS } from '../../../common/interactionTargets';
import Timeslice from './Timeslice';
import { isValidStartTime } from '../transcript/timeSliceUtils';
import './Timeline.scss';

const Timeline = (_ref) => {
  let {
    text = '',
    duration = 0,
    timeslices = [],
    getViewer,
    interactionTarget
  } = _ref;
  let timeSliceIndex = -1;

  const playSegment = function playSegment(index) {
    let incr = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    const newIndex = incr > 0 ? Math.min(timeslices.length - 1, index + incr) : Math.max(0, index + incr);
    const viewer = getViewer ? getViewer() : null;
    const timeslice = timeslices[newIndex];
    const validTime = isValidStartTime(timeslice);

    if (validTime && viewer && typeof viewer.play === 'function') {
      viewer.play(timeslice.start);
      timeSliceIndex = newIndex;
    }
  };

  return React.createElement("div", {
    className: "be-timeline"
  }, text && React.createElement("div", {
    className: "be-timeline-label"
  }, text), React.createElement("div", {
    className: "be-timeline-line-wrapper"
  }, React.createElement("div", {
    className: "be-timeline-line"
  }), timeslices.map((_ref2, index) => {
    let {
      start,
      end
    } = _ref2;
    return (
      /* eslint-disable react/no-array-index-key */
      React.createElement(Timeslice, {
        key: index,
        duration: duration,
        end: end,
        index: index,
        interactionTarget: interactionTarget,
        onClick: playSegment,
        start: start
      })
    );
  }
  /* eslint-enable react/no-array-index-key */
  )), React.createElement("div", {
    className: "be-timeline-btns"
  }, React.createElement(PlainButton, {
    "data-resin-target": SKILLS_TARGETS.TIMELINE.PREVIOUS,
    onClick: () => playSegment(timeSliceIndex, -1),
    type: "button"
  }, React.createElement(IconTrackPrevious, {
    title: React.createElement(FormattedMessage, messages.previousSegment)
  })), React.createElement(PlainButton, {
    "data-resin-target": SKILLS_TARGETS.TIMELINE.NEXT,
    onClick: () => playSegment(timeSliceIndex, 1),
    type: "button"
  }, React.createElement(IconTrackNext, {
    title: React.createElement(FormattedMessage, messages.nextSegment)
  }))));
};

export default Timeline;
//# sourceMappingURL=Timeline.js.map