function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Transcript component
 * @author Box
 */
import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import { bdlGray50 } from '../../../../styles/variables';
import PlainButton from '../../../../components/plain-button/PlainButton';
import IconEdit from '../../../../icons/general/IconEdit';
import IconCopy from '../../../../icons/general/IconCopy';
import IconExpand from '../../../../icons/general/IconExpand';
import IconCollapse from '../../../../icons/general/IconCollapse';
import { formatTime } from '../../../../utils/datetime';
import LoadingIndicatorWrapper from '../../../../components/loading-indicator/LoadingIndicatorWrapper';
import Tooltip from '../../../../components/tooltip/Tooltip';
import { copy } from '../../../../utils/download';
import { SKILLS_TARGETS } from '../../../common/interactionTargets';
import messages from '../../../common/messages';
import { isValidTimeSlice } from './timeSliceUtils';
import TranscriptRow from './TranscriptRow';
import './Transcript.scss';

class Transcript extends React.PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isEditingIndex: undefined,
      newTranscriptText: '',
      isCollapsed: true,
      isLoading: false
    });

    _defineProperty(this, "transcriptReducer", (accumulator, _ref) => {
      let {
        appears,
        text
      } = _ref;
      const start = isValidTimeSlice(appears) && Array.isArray(appears) ? "".concat(formatTime(appears[0].start), ":") : '';
      return "".concat(accumulator).concat(start, " ").concat(text || '', "\r\n");
    });

    _defineProperty(this, "transcriptMapper", (_ref2, index) => {
      let {
        appears,
        text
      } = _ref2;
      const {
        isEditingIndex,
        newTranscriptText
      } = this.state;
      const isEditingRow = isEditingIndex === index;
      const transcriptText = isEditingRow ? newTranscriptText : text;
      const interactionTarget = isEditingRow ? SKILLS_TARGETS.TRANSCRIPTS.EDIT_TEXT : SKILLS_TARGETS.TRANSCRIPTS.TRANSCRIPT;
      return React.createElement(TranscriptRow, {
        key: index,
        appears: appears,
        interactionTarget: interactionTarget,
        isEditing: isEditingRow,
        onCancel: this.onCancel,
        onChange: this.onChange,
        onClick: () => this.onClick(index),
        onSave: this.onSave,
        text: transcriptText
      });
    });

    _defineProperty(this, "toggleIsEditing", () => {
      this.setState(prevState => ({
        isEditingIndex: typeof prevState.isEditingIndex === 'number' ? undefined : -1
      }));
    });

    _defineProperty(this, "onSave", () => {
      const {
        card: {
          entries
        },
        onSkillChange
      } = this.props;
      const {
        isEditingIndex,
        newTranscriptText
      } = this.state;

      if (typeof isEditingIndex !== 'number') {
        return;
      }

      const entry = entries[isEditingIndex];

      if (entry.text === newTranscriptText) {
        this.onCancel();
      } else {
        this.setState({
          isLoading: true,
          isEditingIndex: -1
        });
        onSkillChange(null, null, [{
          replacement: _objectSpread({}, entry, {
            text: newTranscriptText
          }),
          replaced: entry
        }]);
      }
    });

    _defineProperty(this, "onCancel", () => {
      this.setState({
        isEditingIndex: -1,
        newTranscriptText: ''
      });
    });

    _defineProperty(this, "onChange", event => {
      const currentTarget = event.currentTarget;
      this.setState({
        newTranscriptText: currentTarget.value
      });
    });

    _defineProperty(this, "onClick", index => {
      const {
        card: {
          entries
        }
      } = this.props;
      const {
        isEditingIndex
      } = this.state;

      if (typeof isEditingIndex === 'number') {
        this.setState({
          isEditingIndex: index,
          newTranscriptText: entries[index].text
        });
      } else {
        this.previewSegment(index);
      }
    });

    _defineProperty(this, "copyTranscript", () => {
      const {
        card: {
          entries
        }
      } = this.props;
      const copiedClass = 'be-transcript-copied';
      copy(entries.reduce(this.transcriptReducer, '')); // Animate the button by adding a class

      if (this.copyBtn) {
        this.copyBtn.classList.add(copiedClass);
      } // Remove the animation class


      setTimeout(() => {
        if (this.copyBtn) {
          this.copyBtn.classList.remove(copiedClass);
        }
      }, 1000);
    });

    _defineProperty(this, "copyBtnRef", btn => {
      this.copyBtn = btn;
    });

    _defineProperty(this, "toggleExpandCollapse", () => {
      this.setState(prevState => ({
        isCollapsed: !prevState.isCollapsed
      }));
    });
  }

  /**
   * Called when transcripts gets new properties
   *
   * @private
   * @return {void}
   */
  componentDidUpdate(prevProps) {
    if (prevProps === this.props) {
      return;
    }

    const wasEditing = typeof this.state.isEditingIndex === 'number';
    this.setState({
      isEditingIndex: wasEditing ? -1 : undefined,
      newTranscriptText: '',
      isLoading: false
    });
  }
  /**
   * Reducer to accumulate all transcript entries for copying
   *
   * @param {Object} accumulator - reducer accumulator
   * @return {string} accumulated transcript entries
   */


  /**
   * Previews a transcript segment
   *
   * @private
   * @param {number|void} [index] - row index to edit
   * @return {void}
   */
  previewSegment(index) {
    const {
      card: {
        entries
      },
      getViewer
    } = this.props;
    const {
      appears
    } = entries[index];
    const viewer = getViewer ? getViewer() : null;
    const isValid = isValidTimeSlice(appears) && Array.isArray(appears) && appears.length === 1;
    const timeSlice = appears;
    const start = isValid ? timeSlice[0].start : 0;

    if (isValid && viewer && typeof viewer.play === 'function') {
      viewer.play(start);
    }
  }
  /**
   * Saves the new card data
   *
   * @private
   * @return {void}
   */


  /**
   * Renders the transcript
   *
   * @private
   * @return {Object}
   */
  render() {
    const {
      card: {
        entries
      },
      isEditable
    } = this.props;
    const {
      isEditingIndex,
      isCollapsed,
      isLoading
    } = this.state;
    const hasEntries = entries.length > 0;
    const hasManyEntries = entries.length > 5;
    const isEditing = typeof isEditingIndex === 'number';
    const editBtnClassName = classNames('be-transcript-edit', {
      'be-transcript-is-editing': isEditing
    });
    const contentClassName = classNames({
      'be-transcript-content-collapsed': isCollapsed
    });
    const expandCollapseMessage = isCollapsed ? messages.expand : messages.collapse;
    return React.createElement(LoadingIndicatorWrapper, {
      className: "be-transcript",
      isLoading: isLoading
    }, hasEntries && !isLoading && React.createElement("div", {
      className: "be-transcript-actions"
    }, React.createElement(Tooltip, {
      text: React.createElement(FormattedMessage, messages.copy)
    }, React.createElement(PlainButton, {
      className: "be-transcript-copy",
      "data-resin-target": SKILLS_TARGETS.TRANSCRIPTS.COPY,
      getDOMRef: this.copyBtnRef,
      onClick: this.copyTranscript,
      type: "button"
    }, React.createElement(IconCopy, {
      color: bdlGray50
    }))), hasManyEntries && React.createElement(Tooltip, {
      text: React.createElement(FormattedMessage, expandCollapseMessage)
    }, React.createElement(PlainButton, {
      className: "be-transcript-expand",
      "data-resin-target": SKILLS_TARGETS.TRANSCRIPTS.EXPAND,
      onClick: this.toggleExpandCollapse,
      type: "button"
    }, isCollapsed ? React.createElement(IconExpand, {
      color: bdlGray50
    }) : React.createElement(IconCollapse, {
      color: bdlGray50
    }))), isEditable && React.createElement(Tooltip, {
      text: React.createElement(FormattedMessage, messages.editLabel)
    }, React.createElement(PlainButton, {
      className: editBtnClassName,
      "data-resin-target": SKILLS_TARGETS.TRANSCRIPTS.EDIT,
      onClick: this.toggleIsEditing,
      type: "button"
    }, React.createElement(IconEdit, null)))), isEditing ? React.createElement("div", {
      className: "be-transcript-edit-message"
    }, React.createElement(FormattedMessage, messages.transcriptEdit)) : null, hasEntries ? React.createElement("div", {
      className: contentClassName
    }, entries.map(this.transcriptMapper)) : React.createElement(FormattedMessage, messages.skillNoInfoFoundError));
  }

}

export default Transcript;
//# sourceMappingURL=Transcript.js.map