function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * 
 * @file Versions Item component
 * @author Box
 */
import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import messages from './messages';
import selectors from '../../common/selectors/version';
import sizeUtil from '../../../utils/size';
import VersionsItemActions from './VersionsItemActions';
import VersionsItemButton from './VersionsItemButton';
import VersionsItemBadge from './VersionsItemBadge';
import VersionsItemRetention from './VersionsItemRetention';
import { ReadableTime } from '../../../components/time';
import { FILE_REQUEST_NAME, VERSION_DELETE_ACTION, VERSION_PROMOTE_ACTION, VERSION_RESTORE_ACTION, VERSION_UPLOAD_ACTION } from '../../../constants';
import './VersionsItem.scss';
const ACTION_MAP = {
  [VERSION_DELETE_ACTION]: messages.versionDeletedBy,
  [VERSION_RESTORE_ACTION]: messages.versionRestoredBy,
  [VERSION_PROMOTE_ACTION]: messages.versionPromotedBy,
  [VERSION_UPLOAD_ACTION]: messages.versionUploadedBy
};
const FILE_EXTENSIONS_OFFICE = ['xlsb', 'xlsm', 'xlsx'];
const FIVE_MINUTES_MS = 5 * 60 * 1000;

const VersionsItem = (_ref) => {
  let {
    fileId,
    isCurrent = false,
    isSelected = false,
    isWatermarked = false,
    onDelete,
    onDownload,
    onPreview,
    onPromote,
    onRestore,
    version,
    versionCount,
    versionLimit
  } = _ref;
  const {
    created_at: createdAt,
    extension,
    id: versionId,
    is_download_available,
    permissions = {},
    restored_at: restoredAt,
    retention,
    size,
    trashed_at: trashedAt,
    version_number: versionNumber,
    version_promoted: versionPromoted
  } = version;
  const {
    can_delete,
    can_download,
    can_preview,
    can_upload
  } = permissions;
  const {
    applied_at: retentionAppliedAt,
    disposition_at: retentionDispositionAt
  } = retention || {};
  const retentionDispositionAtDate = retentionDispositionAt && new Date(retentionDispositionAt); // Version info helpers

  const versionAction = selectors.getVersionAction(version);
  const versionInteger = versionNumber ? parseInt(versionNumber, 10) : 1;
  const versionTime = restoredAt || trashedAt || createdAt;
  const versionTimestamp = versionTime && new Date(versionTime).getTime();
  const versionUserName = selectors.getVersionUser(version).name || React.createElement(FormattedMessage, messages.versionUserUnknown);
  const versionDisplayName = versionUserName !== FILE_REQUEST_NAME ? versionUserName : React.createElement(FormattedMessage, messages.fileRequestDisplayName); // Version state helpers

  const isDeleted = versionAction === VERSION_DELETE_ACTION;
  const isDownloadable = !!is_download_available;
  const isLimited = versionCount - versionInteger >= versionLimit;
  const isOffice = FILE_EXTENSIONS_OFFICE.includes(extension);
  const isRestricted = (isOffice || isWatermarked) && !isCurrent;
  const isRetained = !!retentionAppliedAt && (!retentionDispositionAtDate || retentionDispositionAtDate > new Date()); // Version action helpers

  const canPreview = can_preview && !isDeleted && !isLimited && !isRestricted;
  const showDelete = can_delete && !isDeleted && !isCurrent;
  const showDownload = can_download && !isDeleted && isDownloadable;
  const showPromote = can_upload && !isDeleted && !isCurrent;
  const showRestore = can_delete && isDeleted;
  const showPreview = canPreview && !isSelected;
  const hasActions = showDelete || showDownload || showPreview || showPromote || showRestore; // Version action callback helper

  const handleAction = handler => () => {
    if (handler) {
      handler(versionId);
    }
  };

  return React.createElement("div", {
    className: "bcs-VersionsItem"
  }, React.createElement(VersionsItemButton, {
    fileId: fileId,
    isCurrent: isCurrent,
    isDisabled: !canPreview,
    isSelected: isSelected,
    onClick: handleAction(onPreview)
  }, React.createElement("div", {
    className: "bcs-VersionsItem-badge"
  }, React.createElement(VersionsItemBadge, {
    versionNumber: versionNumber
  })), React.createElement("div", {
    className: "bcs-VersionsItem-details"
  }, isCurrent && React.createElement("div", {
    className: "bcs-VersionsItem-current"
  }, React.createElement(FormattedMessage, messages.versionCurrent)), React.createElement("div", {
    className: "bcs-VersionsItem-log",
    "data-testid": "bcs-VersionsItem-log",
    title: versionDisplayName
  }, React.createElement(FormattedMessage, _extends({}, ACTION_MAP[versionAction], {
    values: {
      name: versionDisplayName,
      versionPromoted
    }
  }))), React.createElement("div", {
    className: "bcs-VersionsItem-info"
  }, versionTimestamp && React.createElement("time", {
    className: "bcs-VersionsItem-date",
    dateTime: versionTime
  }, React.createElement(ReadableTime, {
    alwaysShowTime: true,
    relativeThreshold: FIVE_MINUTES_MS,
    timestamp: versionTimestamp
  })), !!size && React.createElement("span", {
    className: "bcs-VersionsItem-size"
  }, sizeUtil(size))), isRetained && React.createElement("div", {
    className: "bcs-VersionsItem-retention"
  }, React.createElement(VersionsItemRetention, {
    retention: retention
  })), isLimited && hasActions && React.createElement("div", {
    className: "bcs-VersionsItem-footer"
  }, React.createElement(FormattedMessage, _extends({}, messages.versionLimitExceeded, {
    values: {
      versionLimit
    }
  }))))), !isLimited && hasActions && React.createElement(VersionsItemActions, {
    fileId: fileId,
    isCurrent: isCurrent,
    isRetained: isRetained,
    onDelete: handleAction(onDelete),
    onDownload: handleAction(onDownload),
    onPreview: handleAction(onPreview),
    onPromote: handleAction(onPromote),
    onRestore: handleAction(onRestore),
    showDelete: showDelete,
    showDownload: showDownload,
    showPreview: showPreview,
    showPromote: showPromote,
    showRestore: showRestore
  }));
};

export default VersionsItem;
//# sourceMappingURL=VersionsItem.js.map