/**
 * 
 * @file Versions Item Actions component
 * @author Box
 */
import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import DropdownMenu from '../../../components/dropdown-menu';
import IconClockPast from '../../../icons/general/IconClockPast';
import IconDownload from '../../../icons/general/IconDownload';
import IconEllipsis from '../../../icons/general/IconEllipsis';
import IconOpenWith from '../../../icons/general/IconOpenWith';
import IconTrash from '../../../icons/general/IconTrash';
import IconUpload from '../../../icons/general/IconUpload';
import messages from './messages';
import PlainButton from '../../../components/plain-button';
import Tooltip from '../../../components/tooltip/Tooltip';
import VersionsItemAction from './VersionsItemAction';
import { Menu } from '../../../components/menu';
import './VersionsItemActions.scss';

const handleMenuClose = event => {
  event.stopPropagation();
};

const handleToggleClick = event => {
  event.stopPropagation();
};

const VersionsItemActions = (_ref) => {
  let {
    fileId,
    isCurrent = false,
    isRetained = false,
    onDelete,
    onDownload,
    onPreview,
    onPromote,
    onRestore,
    showDelete = false,
    showDownload = false,
    showPreview = false,
    showPromote = false,
    showRestore = false
  } = _ref;

  if (!showDelete && !showDownload && !showPreview && !showPromote && !showRestore) {
    return null;
  }

  return React.createElement(DropdownMenu, {
    className: "bcs-VersionsItemActions",
    constrainToScrollParent: true,
    constrainToWindow: true,
    isRightAligned: true,
    onMenuClose: handleMenuClose
  }, React.createElement(PlainButton, {
    className: "bcs-VersionsItemActions-toggle",
    "data-resin-iscurrent": isCurrent,
    "data-resin-itemid": fileId,
    "data-resin-target": "overflow",
    onClick: handleToggleClick,
    type: "button"
  }, React.createElement(IconEllipsis, {
    height: 4,
    width: 14
  }), React.createElement(FormattedMessage, messages.versionActionToggle, text => React.createElement("span", {
    className: "accessibility-hidden"
  }, text))), React.createElement(Menu, {
    className: "bcs-VersionsItemActions-menu",
    "data-resin-component": "preview" // Needed for resin events due to tether moving menu to body
    ,
    "data-resin-feature": "versions" // Needed for resin events due to tether moving menu to body

  }, showPreview && React.createElement(VersionsItemAction, {
    action: "preview",
    fileId: fileId,
    isCurrent: isCurrent,
    onClick: onPreview
  }, React.createElement(IconOpenWith, null), React.createElement(FormattedMessage, messages.versionActionPreview)), showDownload && React.createElement(VersionsItemAction, {
    action: "download",
    fileId: fileId,
    isCurrent: isCurrent,
    onClick: onDownload
  }, React.createElement(IconDownload, null), React.createElement(FormattedMessage, messages.versionActionDownload)), showPromote && React.createElement(VersionsItemAction, {
    action: "promote",
    fileId: fileId,
    isCurrent: isCurrent,
    onClick: onPromote
  }, React.createElement(IconUpload, null), React.createElement(FormattedMessage, messages.versionActionPromote)), showRestore && React.createElement(VersionsItemAction, {
    action: "restore",
    fileId: fileId,
    isCurrent: isCurrent,
    onClick: onRestore
  }, React.createElement(IconClockPast, {
    height: 14,
    width: 14
  }), React.createElement(FormattedMessage, messages.versionActionRestore)), showDelete && React.createElement(Tooltip, {
    position: "middle-left",
    text: React.createElement(FormattedMessage, messages.versionActionDisabledRetention),
    isTabbable: false,
    isDisabled: !isRetained
  }, React.createElement(VersionsItemAction, {
    action: "remove",
    fileId: fileId,
    isCurrent: isCurrent,
    isDisabled: isRetained,
    onClick: onDelete
  }, React.createElement(IconTrash, null), React.createElement(FormattedMessage, messages.versionActionDelete)))));
};

export default VersionsItemActions;
//# sourceMappingURL=VersionsItemActions.js.map