function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Versions Item Button component
 * @author Box
 */
import * as React from 'react';
import classNames from 'classnames';
import PlainButton from '../../../components/plain-button';
import { scrollIntoView } from '../../../utils/dom';
import './VersionsItemButton.scss';

class VersionsItemButton extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "setButtonRef", buttonRef => {
      this.buttonRef = buttonRef;
    });

    _defineProperty(this, "setScroll", () => {
      const {
        isSelected
      } = this.props;

      if (this.buttonRef && isSelected) {
        scrollIntoView(this.buttonRef);
      }
    });
  }

  componentDidMount() {
    this.setScroll();
  }

  componentDidUpdate(_ref) {
    let {
      isSelected: prevIsSelected
    } = _ref;
    const {
      isSelected
    } = this.props;

    if (isSelected !== prevIsSelected) {
      this.setScroll();
    }
  }

  render() {
    const {
      children,
      fileId,
      isCurrent,
      isDisabled,
      isSelected,
      onClick
    } = this.props;
    const buttonClassName = classNames('bcs-VersionsItemButton', {
      'bcs-is-disabled': isDisabled,
      'bcs-is-selected': isSelected && !isDisabled
    });
    return React.createElement(PlainButton, {
      "aria-disabled": isDisabled,
      className: buttonClassName,
      "data-resin-iscurrent": isCurrent,
      "data-resin-itemid": fileId,
      "data-resin-target": "select",
      "data-testid": "versions-item-button",
      getDOMRef: this.setButtonRef,
      isDisabled: isDisabled,
      onClick: onClick,
      type: "button"
    }, children);
  }

}

_defineProperty(VersionsItemButton, "defaultProps", {
  isCurrent: false,
  isDisabled: false,
  isSelected: false
});

export default VersionsItemButton;
//# sourceMappingURL=VersionsItemButton.js.map