function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Versions Sidebar API Helper
 * @author Box
 */
import API from '../../../api';
import { FILE_VERSION_FIELDS_TO_FETCH } from '../../../utils/fields';
export default class VersionsSidebarAPI {
  constructor(_ref) {
    let {
      api,
      fileId
    } = _ref;

    _defineProperty(this, "fetchData", () => {
      return Promise.all([this.fetchFile(), this.fetchVersions()]).then(this.fetchVersionCurrent);
    });

    _defineProperty(this, "fetchDownloadUrl", version => {
      return new Promise((resolve, reject) => {
        if (!version) {
          return reject(new Error('Could not find requested version'));
        }

        return this.api.getFileAPI().getDownloadUrl(this.fileId, version, resolve, reject);
      });
    });

    _defineProperty(this, "fetchFile", () => {
      return new Promise((resolve, reject) => this.api.getFileAPI().getFile(this.fileId, resolve, reject, {
        fields: FILE_VERSION_FIELDS_TO_FETCH,
        forceFetch: true
      }));
    });

    _defineProperty(this, "fetchVersions", () => {
      return new Promise((resolve, reject) => this.api.getVersionsAPI(false).getVersions(this.fileId, resolve, reject));
    });

    _defineProperty(this, "fetchVersionCurrent", (_ref2) => {
      let [fileResponse, versionsResponse] = _ref2;
      const {
        file_version = {}
      } = fileResponse;
      return new Promise((resolve, reject) => this.api.getVersionsAPI(false).getVersion(this.fileId, file_version.id, currentVersionResponse => {
        resolve([fileResponse, this.api.getVersionsAPI(false).addCurrentVersion(currentVersionResponse, versionsResponse, fileResponse)]);
      }, reject));
    });

    _defineProperty(this, "fetchVersion", versionId => {
      return new Promise((resolve, reject) => this.api.getVersionsAPI(false).getVersion(this.fileId, versionId, resolve, reject));
    });

    _defineProperty(this, "deleteVersion", version => {
      const {
        id: versionId,
        permissions = {}
      } = version || {};
      return new Promise((resolve, reject) => this.api.getVersionsAPI(false).deleteVersion({
        fileId: this.fileId,
        permissions,
        successCallback: resolve,
        errorCallback: reject,
        versionId
      }));
    });

    _defineProperty(this, "promoteVersion", version => {
      const {
        id: versionId,
        permissions = {}
      } = version || {};
      return new Promise((resolve, reject) => this.api.getVersionsAPI(false).promoteVersion({
        fileId: this.fileId,
        permissions,
        successCallback: resolve,
        errorCallback: reject,
        versionId
      }));
    });

    _defineProperty(this, "restoreVersion", version => {
      const {
        id: versionId,
        permissions = {}
      } = version || {};
      return new Promise((resolve, reject) => this.api.getVersionsAPI(false).restoreVersion({
        fileId: this.fileId,
        permissions,
        successCallback: resolve,
        errorCallback: reject,
        versionId
      }));
    });

    this.api = api;
    this.fileId = fileId;
  }

}
//# sourceMappingURL=VersionsSidebarAPI.js.map