function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Versions Sidebar container
 * @author Box
 */
import React from 'react';
import flow from 'lodash/flow';
import getProp from 'lodash/get';
import merge from 'lodash/merge';
import noop from 'lodash/noop';
import { generatePath, withRouter } from 'react-router-dom';
import API from '../../../api';
import messages from './messages';
import openUrlInsideIframe from '../../../utils/iframe';
import StaticVersionsSidebar from './StaticVersionSidebar';
import VersionsSidebar from './VersionsSidebar';
import VersionsSidebarAPI from './VersionsSidebarAPI';
import { withAPIContext } from '../../common/api-context';

class VersionsSidebarContainer extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isLoading: true,
      isWatermarked: false,
      versionCount: Infinity,
      versionLimit: Infinity,
      versions: []
    });

    _defineProperty(this, "window", window);

    _defineProperty(this, "handleActionDelete", versionId => {
      this.setState({
        isLoading: true
      });
      return this.api.deleteVersion(this.findVersion(versionId)).then(() => this.api.fetchVersion(versionId)).then(this.handleDeleteSuccess).then(() => this.props.onVersionDelete(versionId)).catch(() => this.handleActionError(messages.versionActionDeleteError));
    });

    _defineProperty(this, "handleActionDownload", versionId => {
      return this.api.fetchDownloadUrl(this.findVersion(versionId)).then(openUrlInsideIframe).then(() => this.props.onVersionDownload(versionId)).catch(() => this.handleActionError(messages.versionActionDownloadError));
    });

    _defineProperty(this, "handleActionPreview", versionId => {
      this.updateVersion(versionId);
      this.props.onVersionPreview(versionId);
    });

    _defineProperty(this, "handleActionPromote", versionId => {
      this.setState({
        isLoading: true
      });
      return this.api.promoteVersion(this.findVersion(versionId)).then(this.api.fetchData).then(this.handleFetchSuccess).then(this.handlePromoteSuccess).then(() => this.props.onVersionPromote(versionId)).catch(() => this.handleActionError(messages.versionActionPromoteError));
    });

    _defineProperty(this, "handleActionRestore", versionId => {
      this.setState({
        isLoading: true
      });
      return this.api.restoreVersion(this.findVersion(versionId)).then(() => this.api.fetchVersion(versionId)).then(this.handleRestoreSuccess).then(() => this.props.onVersionRestore(versionId)).catch(() => this.handleActionError(messages.versionActionRestoreError));
    });

    _defineProperty(this, "handleActionError", message => {
      this.setState({
        error: message,
        isLoading: false
      });
    });

    _defineProperty(this, "handleDeleteSuccess", data => {
      const {
        versionId: selectedVersionId
      } = this.props;
      const {
        id: versionId
      } = data;
      this.mergeResponse(data); // Bump the user to the current version if they deleted their selected version

      if (versionId === selectedVersionId) {
        this.updateVersionToCurrent();
      }
    });

    _defineProperty(this, "handleRestoreSuccess", data => {
      this.mergeResponse(data);
    });

    _defineProperty(this, "handleFetchError", () => {
      this.setState({
        error: messages.versionFetchError,
        isLoading: false,
        isWatermarked: false,
        versionCount: 0,
        versions: []
      });
    });

    _defineProperty(this, "handleFetchSuccess", (_ref) => {
      let [fileResponse, versionsResponse] = _ref;
      const {
        api
      } = this.props;
      const {
        version_limit
      } = fileResponse;
      const isWatermarked = getProp(fileResponse, 'watermark_info.is_watermarked', false);
      const versionLimit = version_limit !== null && version_limit !== undefined ? version_limit : Infinity;
      const versionsWithPermissions = api.getVersionsAPI(false).addPermissions(versionsResponse, fileResponse) || {};
      const {
        entries: versions,
        total_count: versionCount
      } = versionsWithPermissions;
      this.setState({
        error: undefined,
        isLoading: false,
        isWatermarked,
        versionCount,
        versionLimit,
        versions: this.sortVersions(versions)
      }, this.verifyVersion);
      return [fileResponse, versionsResponse];
    });

    _defineProperty(this, "handlePromoteSuccess", (_ref2) => {
      let [file] = _ref2;
      const {
        file_version: fileVersion
      } = file;

      if (fileVersion) {
        this.updateVersion(fileVersion.id);
      }
    });

    _defineProperty(this, "initialize", () => {
      this.api = new VersionsSidebarAPI(this.props);
    });

    _defineProperty(this, "fetchData", () => {
      return this.api.fetchData().then(this.handleFetchSuccess).catch(this.handleFetchError);
    });

    _defineProperty(this, "findVersion", versionId => {
      const {
        versions
      } = this.state;
      return versions.find(version => version.id === versionId);
    });

    _defineProperty(this, "getCurrentVersionId", () => {
      const {
        versions
      } = this.state;
      return versions[0] ? versions[0].id : null;
    });

    _defineProperty(this, "mergeVersions", newVersion => {
      const {
        versions
      } = this.state;
      const newVersionId = newVersion ? newVersion.id : '';
      return versions.map(version => version.id === newVersionId ? merge(_objectSpread({}, version), newVersion) : version);
    });

    _defineProperty(this, "mergeResponse", data => {
      const newVersions = this.mergeVersions(data);
      this.setState({
        error: undefined,
        isLoading: false,
        versions: newVersions
      });
    });

    _defineProperty(this, "updateVersion", versionId => {
      const {
        history,
        match
      } = this.props;
      return history.push(generatePath(match.path, _objectSpread({}, match.params, {
        versionId
      })));
    });

    _defineProperty(this, "updateVersionToCurrent", () => {
      this.updateVersion(this.getCurrentVersionId());
    });

    _defineProperty(this, "verifyVersion", () => {
      const {
        onVersionChange,
        versionId
      } = this.props;
      const selectedVersion = this.findVersion(versionId);

      if (selectedVersion) {
        onVersionChange(selectedVersion, {
          currentVersionId: this.getCurrentVersionId(),
          updateVersionToCurrent: this.updateVersionToCurrent
        });
      } else {
        this.updateVersionToCurrent();
      }
    });
  }

  componentDidMount() {
    const {
      onLoad
    } = this.props;
    this.initialize();
    this.fetchData().then(() => {
      onLoad({
        component: 'preview',
        feature: 'versions'
      });
    });
  }

  componentDidUpdate(_ref3) {
    let {
      fileId: prevFileId,
      versionId: prevVersionId
    } = _ref3;
    const {
      fileId,
      versionId
    } = this.props;

    if (fileId !== prevFileId) {
      this.refresh();
    }

    if (versionId !== prevVersionId) {
      this.verifyVersion();
    }
  }

  refresh() {
    this.initialize();
    this.setState({
      isLoading: true
    }, this.fetchData);
  }

  sortVersions() {
    let versions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    return [...versions].sort((a, b) => Date.parse(b.created_at) - Date.parse(a.created_at));
  }

  render() {
    const {
      fileId,
      parentName,
      onUpgradeClick
    } = this.props;

    if (onUpgradeClick) {
      return React.createElement(StaticVersionsSidebar, _extends({
        onUpgradeClick: onUpgradeClick,
        parentName: parentName
      }, this.state));
    }

    return React.createElement(VersionsSidebar, _extends({
      fileId: fileId,
      onDelete: this.handleActionDelete,
      onDownload: this.handleActionDownload,
      onPreview: this.handleActionPreview,
      onPromote: this.handleActionPromote,
      onRestore: this.handleActionRestore,
      parentName: parentName
    }, this.state));
  }

}

_defineProperty(VersionsSidebarContainer, "defaultProps", {
  onLoad: noop,
  onVersionChange: noop,
  onVersionDelete: noop,
  onVersionDownload: noop,
  onVersionPreview: noop,
  onVersionPromote: noop,
  onVersionRestore: noop,
  parentName: ''
});

export default flow([withRouter, withAPIContext])(VersionsSidebarContainer);
//# sourceMappingURL=VersionsSidebarContainer.js.map