/**
 * 
 * @file Droppable area containing upload item list
 */
import React from 'react';
import makeDroppable from '../common/droppable';
import ItemList from './ItemList';
import UploadState from './UploadState';
import './DroppableContent.scss';

/**
 * Definition for drag and drop behavior.
 */
const dropDefinition = {
  /**
   * Validates whether a file can be dropped or not.
   */
  dropValidator: (_ref, _ref2) => {
    let {
      allowedTypes
    } = _ref;
    let {
      types
    } = _ref2;

    if (types instanceof Array) {
      return Array.from(types).some(type => allowedTypes.indexOf(type) > -1);
    }

    const allowedList = allowedTypes.filter(allowed => types.contains(allowed));
    return allowedList.length > 0;
  },

  /**
   * Determines what happens after a file is dropped
   */
  onDrop: (event, _ref3) => {
    let {
      addDataTransferItemsToUploadQueue
    } = _ref3;
    const {
      dataTransfer
    } = event;
    addDataTransferItemsToUploadQueue(dataTransfer);
  }
};
const DroppableContent = makeDroppable(dropDefinition)((_ref4) => {
  let {
    canDrop,
    isOver,
    isTouch,
    view,
    items,
    addFiles,
    onClick,
    isFolderUploadEnabled
  } = _ref4;

  const handleSelectFiles = (_ref5) => {
    let {
      target: {
        files
      }
    } = _ref5;
    return addFiles(files);
  };

  const hasItems = items.length > 0;
  return React.createElement("div", {
    className: "bcu-droppable-content"
  }, React.createElement(ItemList, {
    items: items,
    onClick: onClick,
    view: view
  }), React.createElement(UploadState, {
    canDrop: canDrop,
    hasItems: hasItems,
    isFolderUploadEnabled: isFolderUploadEnabled,
    isOver: isOver,
    isTouch: isTouch,
    onSelect: handleSelectFiles,
    view: view
  }));
});
export default DroppableContent;
//# sourceMappingURL=DroppableContent.js.map