/**
 * 
 * @file Item list component
 */
import React from 'react';
import noop from 'lodash/noop';
import { Table, Column } from '@box/react-virtualized/dist/es/Table';
import AutoSizer from '@box/react-virtualized/dist/es/AutoSizer';
import nameCellRenderer from './nameCellRenderer';
import progressCellRenderer from './progressCellRenderer';
import actionCellRenderer from './actionCellRenderer';
import removeCellRenderer from './removeCellRenderer';
import '@box/react-virtualized/styles.css';
import './ItemList.scss';

const ItemList = (_ref) => {
  let {
    isResumableUploadsEnabled = false,
    items,
    onClick,
    onRemoveClick = noop,
    onUpgradeCTAClick
  } = _ref;
  return React.createElement(AutoSizer, null, (_ref2) => {
    let {
      width,
      height
    } = _ref2;
    const nameCell = nameCellRenderer(isResumableUploadsEnabled);
    const progressCell = progressCellRenderer(!!onUpgradeCTAClick);
    const actionCell = actionCellRenderer(isResumableUploadsEnabled, onClick, onUpgradeCTAClick);
    const removeCell = removeCellRenderer(onRemoveClick);
    return React.createElement(Table, {
      className: "bcu-item-list",
      disableHeader: true,
      headerHeight: 0,
      height: height,
      rowClassName: "bcu-item-row",
      rowCount: items.length,
      rowGetter: (_ref3) => {
        let {
          index
        } = _ref3;
        return items[index];
      },
      rowHeight: 50,
      width: width
    }, React.createElement(Column, {
      cellRenderer: nameCell,
      dataKey: "name",
      flexGrow: 1,
      flexShrink: 1,
      width: 300
    }), React.createElement(Column, {
      cellRenderer: progressCell,
      dataKey: "progress",
      flexGrow: 1,
      flexShrink: 1,
      style: {
        textAlign: 'right'
      },
      width: 300
    }), React.createElement(Column, {
      className: isResumableUploadsEnabled ? '' : 'bcu-item-list-action-column',
      cellRenderer: actionCell,
      dataKey: "status",
      flexShrink: 0,
      width: onUpgradeCTAClick ? 100 : 25
    }), isResumableUploadsEnabled && React.createElement(Column, {
      className: "bcu-item-list-action-column",
      cellRenderer: removeCell,
      dataKey: "remove",
      flexShrink: 0,
      width: 25
    }));
  });
};

export default ItemList;
//# sourceMappingURL=ItemList.js.map