function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as React from 'react';
import { FormattedDate, FormattedMessage } from 'react-intl';
import { isValidDate } from '../../utils/datetime';
import Label from '../../components/label/Label';
import LoadingIndicator from '../../components/loading-indicator/LoadingIndicator';
import ClassifiedBadge from './ClassifiedBadge';
import SecurityControls from './security-controls';
import messages from './messages';
import './Classification.scss';
const STYLE_INLINE = 'inline';
const STYLE_TOOLTIP = 'tooltip';

const Classification = (_ref) => {
  let {
    className = '',
    color,
    controls,
    controlsFormat,
    definition,
    isImportedClassification = false,
    isLoadingControls,
    itemName = '',
    maxAppCount,
    messageStyle,
    modifiedAt,
    modifiedBy,
    name,
    onClick
  } = _ref;
  const isClassified = !!name;
  const hasDefinition = !!definition;
  const hasModifiedAt = !!modifiedAt;
  const hasModifiedBy = !!modifiedBy;
  const hasSecurityControls = !!controls;
  const isTooltipMessageEnabled = isClassified && hasDefinition && messageStyle === STYLE_TOOLTIP;
  const isInlineMessageEnabled = isClassified && hasDefinition && messageStyle === STYLE_INLINE;
  const isNotClassifiedMessageVisible = !isClassified && messageStyle === STYLE_INLINE;
  const isControlsIndicatorEnabled = isClassified && isLoadingControls && messageStyle === STYLE_INLINE;
  const isSecurityControlsEnabled = isClassified && !isLoadingControls && hasSecurityControls && messageStyle === STYLE_INLINE;
  const modifiedDate = new Date(modifiedAt || 0);
  const isModifiedMessageVisible = isClassified && hasModifiedAt && isValidDate(modifiedDate) && hasModifiedBy && messageStyle === STYLE_INLINE;
  const formattedModifiedAt = isModifiedMessageVisible && React.createElement(FormattedDate, {
    value: modifiedDate,
    month: "long",
    year: "numeric",
    day: "numeric"
  });
  const modifiedByMessage = isImportedClassification ? messages.importedBy : messages.modifiedBy;
  return React.createElement("article", {
    className: "bdl-Classification ".concat(className)
  }, isClassified && React.createElement(ClassifiedBadge, {
    color: color,
    name: name,
    onClick: onClick,
    tooltipText: isTooltipMessageEnabled ? definition : undefined
  }), isInlineMessageEnabled && React.createElement(Label, {
    text: React.createElement(FormattedMessage, messages.definition)
  }, React.createElement("p", {
    className: "bdl-Classification-definition"
  }, definition)), isNotClassifiedMessageVisible && React.createElement("span", {
    className: "bdl-Classification-missingMessage"
  }, React.createElement(FormattedMessage, messages.missing)), isModifiedMessageVisible && React.createElement(Label, {
    text: React.createElement(FormattedMessage, messages.modifiedByLabel)
  }, React.createElement("p", {
    className: "bdl-Classification-modifiedBy",
    "data-testid": "classification-modifiedby"
  }, React.createElement(FormattedMessage, _extends({}, modifiedByMessage, {
    values: {
      modifiedAt: formattedModifiedAt,
      modifiedBy
    }
  })))), isSecurityControlsEnabled && React.createElement(SecurityControls, {
    classificationColor: color,
    classificationName: name,
    controls: controls,
    controlsFormat: controlsFormat,
    definition: definition,
    itemName: itemName,
    maxAppCount: maxAppCount,
    shouldRenderLabel: true
  }), isControlsIndicatorEnabled && React.createElement(LoadingIndicator, null));
};

export { STYLE_INLINE, STYLE_TOOLTIP };
export default Classification;
//# sourceMappingURL=Classification.js.map