function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import { DEFAULT_MAX_APP_COUNT, SECURITY_CONTROLS_FORMAT } from '../constants';
import { getShortSecurityControlsMessage, getFullSecurityControlsMessages } from './utils';
import messages from './messages';
import PlainButton from '../../../components/plain-button';
import Label from '../../../components/label/Label';
import SecurityControlsItem from './SecurityControlsItem';
import SecurityControlsModal from './SecurityControlsModal';
import './SecurityControls.scss';
const {
  FULL,
  SHORT,
  SHORT_WITH_BTN
} = SECURITY_CONTROLS_FORMAT;

class SecurityControls extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isSecurityControlsModalOpen: false
    });

    _defineProperty(this, "openModal", () => this.setState({
      isSecurityControlsModalOpen: true
    }));

    _defineProperty(this, "closeModal", () => this.setState({
      isSecurityControlsModalOpen: false
    }));
  }

  render() {
    const {
      classificationColor,
      classificationName,
      controls,
      controlsFormat,
      definition,
      itemName,
      maxAppCount,
      shouldRenderLabel
    } = this.props;
    let items = [];
    let modalItems;

    if (controlsFormat === FULL) {
      items = getFullSecurityControlsMessages(controls, maxAppCount);
    } else {
      items = getShortSecurityControlsMessage(controls);

      if (items.length && controlsFormat === SHORT_WITH_BTN) {
        modalItems = getFullSecurityControlsMessages(controls, maxAppCount);
      }
    }

    if (!items.length) {
      return null;
    }

    const {
      isSecurityControlsModalOpen
    } = this.state;
    const shouldShowSecurityControlsModal = controlsFormat === SHORT_WITH_BTN && !!itemName && !!classificationName && !!definition;
    let itemsList = React.createElement("ul", {
      className: "bdl-SecurityControls"
    }, items.map((_ref, index) => {
      let {
        message,
        tooltipMessage
      } = _ref;
      return React.createElement(SecurityControlsItem, {
        key: index,
        message: message,
        tooltipMessage: tooltipMessage
      });
    }));

    if (shouldRenderLabel) {
      itemsList = React.createElement(Label, {
        text: React.createElement(FormattedMessage, messages.securityControlsLabel)
      }, itemsList);
    }

    return React.createElement(React.Fragment, null, itemsList, shouldShowSecurityControlsModal && React.createElement(React.Fragment, null, React.createElement(PlainButton, {
      className: "lnk",
      onClick: this.openModal,
      type: "button"
    }, React.createElement(FormattedMessage, messages.viewAll)), React.createElement(SecurityControlsModal, {
      classificationColor: classificationColor,
      classificationName: classificationName,
      closeModal: this.closeModal,
      definition: definition,
      itemName: itemName,
      isSecurityControlsModalOpen: isSecurityControlsModalOpen,
      modalItems: modalItems
    })));
  }

}

_defineProperty(SecurityControls, "defaultProps", {
  classificationName: '',
  definition: '',
  itemName: '',
  controls: {},
  controlsFormat: SHORT,
  maxAppCount: DEFAULT_MAX_APP_COUNT,
  shouldRenderLabel: false
});

export default SecurityControls;
//# sourceMappingURL=SecurityControls.js.map