function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import getProp from 'lodash/get';
import isNil from 'lodash/isNil';
import appRestrictionsMessageMap from './appRestrictionsMessageMap';
import downloadRestrictionsMessageMap from './downloadRestrictionsMessageMap';
import messages from './messages';
import { ACCESS_POLICY_RESTRICTION, APP_RESTRICTION_MESSAGE_TYPE, DOWNLOAD_CONTROL, LIST_ACCESS_LEVEL, SHARED_LINK_ACCESS_LEVEL } from '../constants';
const {
  APP,
  BOX_SIGN_REQUEST,
  DOWNLOAD,
  EXTERNAL_COLLAB,
  SHARED_LINK,
  WATERMARK
} = ACCESS_POLICY_RESTRICTION;
const {
  DEFAULT,
  WITH_APP_LIST,
  WITH_OVERFLOWN_APP_LIST
} = APP_RESTRICTION_MESSAGE_TYPE;
const {
  DESKTOP,
  MOBILE,
  WEB
} = DOWNLOAD_CONTROL;
const {
  BLOCK,
  WHITELIST,
  BLACKLIST
} = LIST_ACCESS_LEVEL;
const {
  COLLAB_ONLY,
  COLLAB_AND_COMPANY_ONLY,
  PUBLIC
} = SHARED_LINK_ACCESS_LEVEL;

const getShortSecurityControlsMessage = controls => {
  const items = [];
  const {
    app,
    boxSignRequest,
    download,
    externalCollab,
    sharedLink,
    watermark
  } = controls; // Shared link and external collab restrictions are grouped
  // together as generic "sharing" restrictions

  const sharing = sharedLink && sharedLink.accessLevel !== PUBLIC || externalCollab; // 4 restriction combinations

  if (sharing && download && app && boxSignRequest) {
    items.push({
      message: messages.shortSharingDownloadAppSign
    });
  } // 3 restriction combinations
  else if (sharing && download && app) {
      items.push({
        message: messages.shortSharingDownloadApp
      });
    } else if (download && app && boxSignRequest) {
      items.push({
        message: messages.shortDownloadAppSign
      });
    } else if (sharing && app && boxSignRequest) {
      items.push({
        message: messages.shortSharingAppSign
      });
    } else if (sharing && download && boxSignRequest) {
      items.push({
        message: messages.shortSharingDownloadSign
      });
    } // 2 restriction combinations
    else if (sharing && boxSignRequest) {
        items.push({
          message: messages.shortSharingSign
        });
      } else if (download && boxSignRequest) {
        items.push({
          message: messages.shortDownloadSign
        });
      } else if (app && boxSignRequest) {
        items.push({
          message: messages.shortAppSign
        });
      } else if (sharing && download) {
        items.push({
          message: messages.shortSharingDownload
        });
      } else if (sharing && app) {
        items.push({
          message: messages.shortSharingApp
        });
      } else if (download && app) {
        items.push({
          message: messages.shortDownloadApp
        });
      } // 1 restriction combinations
      else if (boxSignRequest) {
          items.push({
            message: messages.shortSign
          });
        } else if (sharing) {
          items.push({
            message: messages.shortSharing
          });
        } else if (download) {
          items.push({
            message: messages.shortDownload
          });
        } else if (app) {
          items.push({
            message: messages.shortApp
          });
        }

  if (watermark) {
    items.push({
      message: messages.shortWatermarking
    });
  }

  return items;
};

const getSharedLinkMessages = controls => {
  const items = [];
  const accessLevel = getProp(controls, "".concat(SHARED_LINK, ".accessLevel"));

  switch (accessLevel) {
    case COLLAB_ONLY:
      items.push({
        message: messages.sharingCollabOnly
      });
      break;

    case COLLAB_AND_COMPANY_ONLY:
      items.push({
        message: messages.sharingCollabAndCompanyOnly
      });
      break;

    default:
      // no-op
      break;
  }

  return items;
};

const getWatermarkingMessages = controls => {
  const items = [];
  const isWatermarkEnabled = getProp(controls, "".concat(WATERMARK, ".enabled"), false);

  if (isWatermarkEnabled) {
    items.push({
      message: messages.watermarkingApplied
    });
  }

  return items;
};

const getExternalCollabMessages = controls => {
  const items = [];
  const accessLevel = getProp(controls, "".concat(EXTERNAL_COLLAB, ".accessLevel"));

  switch (accessLevel) {
    case BLOCK:
      items.push({
        message: messages.externalCollabBlock
      });
      break;

    case WHITELIST:
    case BLACKLIST:
      items.push({
        message: messages.externalCollabDomainList
      });
      break;

    default:
      // no-op
      break;
  }

  return items;
};

const getAppDownloadMessages = (controls, maxAppCount) => {
  const items = [];
  const accessLevel = getProp(controls, "".concat(APP, ".accessLevel"));

  switch (accessLevel) {
    case BLOCK:
      items.push({
        message: messages.appDownloadRestricted
      });
      break;

    case WHITELIST:
    case BLACKLIST:
      {
        const apps = getProp(controls, "".concat(APP, ".apps"), []);
        maxAppCount = isNil(maxAppCount) ? apps.length : maxAppCount;
        const appsToDisplay = apps.slice(0, maxAppCount);
        const remainingAppCount = apps.slice(maxAppCount).length;
        const appNames = appsToDisplay.map((_ref) => {
          let {
            displayText
          } = _ref;
          return displayText;
        }).join(', ');

        if (remainingAppCount) {
          const appsList = apps.map((_ref2) => {
            let {
              displayText
            } = _ref2;
            return displayText;
          }).join(', ');
          items.push({
            message: _objectSpread({}, appRestrictionsMessageMap[accessLevel][WITH_OVERFLOWN_APP_LIST], {
              values: {
                appNames,
                remainingAppCount
              }
            }),
            tooltipMessage: _objectSpread({}, messages.allAppNames, {
              values: {
                appsList
              }
            })
          });
        } else {
          // Display list of apps if available, otherwise use generic
          // app restriction copy
          const messageType = apps.length ? WITH_APP_LIST : DEFAULT;
          items.push({
            message: _objectSpread({}, appRestrictionsMessageMap[accessLevel][messageType], {
              values: {
                appNames
              }
            })
          });
        }

        break;
      }

    default:
      // no-op
      break;
  }

  return items;
};

const getDownloadMessages = controls => {
  const items = [];
  const {
    web,
    mobile,
    desktop
  } = getProp(controls, DOWNLOAD, {});
  const downloadRestrictions = {
    [WEB]: {
      platform: WEB,
      restrictions: web
    },
    [MOBILE]: {
      platform: MOBILE,
      restrictions: mobile
    },
    [DESKTOP]: {
      platform: DESKTOP,
      restrictions: desktop
    }
  };
  Object.keys(downloadRestrictions).forEach(platformKey => {
    const {
      platform,
      restrictions
    } = downloadRestrictions[platformKey];

    if (!restrictions) {
      return;
    }

    const {
      restrictExternalUsers,
      restrictManagedUsers
    } = restrictions;

    if (restrictManagedUsers && restrictExternalUsers) {
      items.push({
        message: downloadRestrictionsMessageMap[platform].externalRestricted[restrictManagedUsers]
      });
    } else if (restrictManagedUsers) {
      items.push({
        message: downloadRestrictionsMessageMap[platform].externalAllowed[restrictManagedUsers]
      });
    } else if (restrictExternalUsers) {
      items.push({
        message: downloadRestrictionsMessageMap[platform].externalRestricted.default
      });
    }
  });
  return items;
};

const getBoxSignRequestMessages = controls => {
  const isBoxSignRequestRestrictionEnabled = getProp(controls, "".concat(BOX_SIGN_REQUEST, ".enabled"), false);
  const items = isBoxSignRequestRestrictionEnabled ? [{
    message: messages.boxSignRequestRestricted
  }] : [];
  return items;
};

const getFullSecurityControlsMessages = (controls, maxAppCount) => {
  const items = [...getSharedLinkMessages(controls), ...getExternalCollabMessages(controls), ...getDownloadMessages(controls), ...getAppDownloadMessages(controls, maxAppCount), ...getWatermarkingMessages(controls), ...getBoxSignRequestMessages(controls)];
  return items;
};

export { getShortSecurityControlsMessage, getFullSecurityControlsMessages };
//# sourceMappingURL=utils.js.map