function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import CollaboratorAvatarItem from './CollaboratorAvatarItem';
import PlainButton from '../../components/plain-button';
import messages from './messages';
import './CollaboratorAvatars.scss';
const MAX_ADDITIONAL_COLLABORATOR_NUM_CAP = 99;

class CollaboratorAvatars extends Component {
  isVisible() {
    return this.props.collaborators.length > 0;
  }

  hasAdditionalCollaborators() {
    const {
      collaborators,
      maxDisplayedUserAvatars
    } = this.props;
    return collaborators.length > maxDisplayedUserAvatars;
  }

  collaboratorsOverMaxCount() {
    const {
      collaborators,
      maxDisplayedUserAvatars,
      maxAdditionalCollaboratorsNum
    } = this.props;
    const remainingCollabCount = collaborators.length - maxDisplayedUserAvatars;
    return remainingCollabCount > maxAdditionalCollaboratorsNum;
  }

  formatAdditionalCollaboratorCount() {
    const {
      maxAdditionalCollaboratorsNum,
      maxDisplayedUserAvatars,
      collaborators
    } = this.props;
    return this.collaboratorsOverMaxCount() ? "".concat(maxAdditionalCollaboratorsNum, "+") : "+".concat(collaborators.length - maxDisplayedUserAvatars);
  }

  render() {
    const {
      collaborators,
      maxDisplayedUserAvatars,
      containerAttributes,
      onClick
    } = this.props;
    return React.createElement(PlainButton, _extends({
      className: classNames('collaborator-avatar-container', {
        'are-avatars-hidden': !this.isVisible()
      }),
      onClick: onClick
    }, containerAttributes, {
      "aria-hidden": this.isVisible() ? 'false' : 'true',
      type: "button"
    }), React.createElement("div", {
      className: "avatars-label"
    }, React.createElement(FormattedMessage, messages.collaboratorAvatarsLabel)), React.createElement("div", {
      className: "avatars"
    }, this.isVisible() && collaborators.slice(0, maxDisplayedUserAvatars).map((collaborator, index) => {
      const {
        collabID,
        imageURL,
        hasCustomAvatar,
        name
      } = collaborator;
      return React.createElement(CollaboratorAvatarItem, {
        key: "collab-avatar-".concat(collabID),
        avatarUrl: imageURL,
        hasCustomAvatar: hasCustomAvatar,
        id: index,
        name: name
      });
    })), this.isVisible() && this.hasAdditionalCollaborators() && React.createElement("div", {
      className: "avatars-count"
    }, this.formatAdditionalCollaboratorCount()));
  }

}

_defineProperty(CollaboratorAvatars, "defaultProps", {
  /** Maximum number of avatars to display before showing a +{n} avatar */
  maxDisplayedUserAvatars: 3,

  /** Maximum number of collaborators before displaying a {maxAdditionalCollaboratorsNum}+ avatar */
  maxAdditionalCollaboratorsNum: MAX_ADDITIONAL_COLLABORATOR_NUM_CAP,
  containerAttributes: {}
});

export default CollaboratorAvatars;
//# sourceMappingURL=CollaboratorAvatars.js.map