function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Sidebar component that supports rendering different elements based on expand/collapse state
 * @author Box
 *
 * A sidebar component that supports collapsed/expanded state and responsive sizing.
 */
import * as React from 'react';
import classNames from 'classnames';
import styled from 'styled-components';
import tabbable from 'tabbable';
import { KEYS } from '../../constants';
import './CollapsibleSidebar.scss';
const StyledNav = styled.nav.withConfig({
  displayName: "CollapsibleSidebar__StyledNav",
  componentId: "sc-4t6rz4-0"
})(["background-color:", ";border-right:1px solid ", ";color:", ";.crawler > div{background-color:", ";}"], props => props.theme.primary.background, props => props.theme.primary.border, props => props.theme.primary.foreground, props => props.theme.primary.foreground);

class CollapsibleSidebar extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "navRef", React.createRef());

    _defineProperty(this, "focusEl", direction => {
      if (this.navRef.current) {
        const tabbableEls = tabbable(this.navRef.current);
        const currentElIndex = tabbableEls.findIndex(el => el === document.activeElement);
        let index;

        if (direction === 'down') {
          index = currentElIndex === tabbableEls.length - 1 ? 0 : currentElIndex + 1;
        } else {
          index = currentElIndex === 0 ? tabbableEls.length - 1 : currentElIndex - 1;
        }

        tabbableEls[index].focus();
      }
    });

    _defineProperty(this, "handleKeyDown", event => {
      if (this.navRef.current && this.navRef.current.contains(document.activeElement)) {
        switch (event.key) {
          case KEYS.arrowDown:
            event.stopPropagation();
            event.preventDefault();
            this.focusEl('down');
            break;

          case KEYS.arrowUp:
            event.stopPropagation();
            event.preventDefault();
            this.focusEl('up');
            break;

          default:
            break;
        }
      }
    });
  }

  render() {
    const {
      children,
      className,
      expanded,
      isHidden,
      htmlAttributes,
      wrapperClassName
    } = this.props;
    const navClasses = classNames({
      'is-expanded': expanded
    }, 'bdl-CollapsibleSidebar', className);
    const ariaAttributes = {
      'aria-hidden': isHidden ? 'true' : undefined
    };
    return React.createElement("div", _extends({
      className: classNames('bdl-CollapsibleSidebar-wrapper', wrapperClassName)
    }, htmlAttributes, ariaAttributes, {
      "data-testid": "CollapsibleSidebar-wrapper"
    }), React.createElement(StyledNav, {
      ref: this.navRef,
      className: navClasses,
      onKeyDown: this.handleKeyDown
    }, children));
  }

}

_defineProperty(CollapsibleSidebar, "defaultProps", {
  expanded: false
});

export default CollapsibleSidebar;
//# sourceMappingURL=CollapsibleSidebar.js.map