function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Scroll container for lists to be used within CollapsibleSidebar component.
 * @author Box
 *
 * A Scroll container for lists to be used within CollapsibleSidebar component.
 * Applies scroll shadow in the container based on scroll position.
 */
import * as React from 'react';
import classNames from 'classnames';
import debounce from 'lodash/debounce';
import throttle from 'lodash/throttle';
import Scrollbar from 'react-scrollbars-custom';
import styled from 'styled-components';
import CollapsibleSidebarContext from './CollapsibleSidebarContext';
import { getScrollShadowClassName } from './utils/scrollShadow';
const StyledScrollThumb = styled.div.withConfig({
  displayName: "CollapsibleSidebarNav__StyledScrollThumb",
  componentId: "csqupn-0"
})(["background:", ";opacity:0;transition:opacity 0.15s;.scroll-shadow-container:hover &,&.dragging{opacity:0.5;}"], props => props.theme.primary.foreground); // The following values match the derived values from scrollShadow.scss

const StyledScrollContainer = styled.div.withConfig({
  displayName: "CollapsibleSidebarNav__StyledScrollContainer",
  componentId: "csqupn-1"
})(["&::before{box-shadow:0 6px 6px -2px ", ";}&::after{box-shadow:0 -6px 6px -2px ", ";}"], props => props.theme.primary.scrollShadowRgba, props => props.theme.primary.scrollShadowRgba);

class CollapsibleSidebarNav extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "scrollRef", React.createRef());

    _defineProperty(this, "turnOffScrollingState", () => {
      this.setState({
        isScrolling: false
      });
    });

    _defineProperty(this, "debouncedTurnOffScrollingState", debounce(this.turnOffScrollingState, 100));

    _defineProperty(this, "onScrollHandler", () => {
      if (!this.scrollRef.current) {
        return;
      }

      const {
        scrollHeight,
        clientHeight,
        scrollTop
      } = this.scrollRef.current;
      const scrollShadowClassName = getScrollShadowClassName(scrollTop, scrollHeight, clientHeight);
      this.setState({
        isScrolling: true,
        scrollShadowClassName
      });
      this.debouncedTurnOffScrollingState();
    });

    _defineProperty(this, "onUpdateHandler", (scrollValues, prevScrollValues) => {
      const {
        clientHeight,
        contentScrollHeight
      } = scrollValues;
      const {
        clientHeight: prevClientHeight,
        contentScrollHeight: prevContentScrollHeight
      } = prevScrollValues;

      if (clientHeight !== prevClientHeight || contentScrollHeight !== prevContentScrollHeight) {
        this.setScrollShadowState();
      }
    });

    _defineProperty(this, "setScrollShadowState", () => {
      if (!this.scrollRef.current) {
        return;
      }

      const {
        scrollShadowClassName
      } = this.state;
      const {
        scrollHeight,
        clientHeight,
        scrollTop
      } = this.scrollRef.current;
      const newScrollShadowClassName = getScrollShadowClassName(scrollTop, scrollHeight, clientHeight);

      if (scrollShadowClassName !== newScrollShadowClassName) {
        this.setState({
          scrollShadowClassName: newScrollShadowClassName
        });
      }
    });

    _defineProperty(this, "throtteldOnScrollHandler", throttle(this.onScrollHandler, 50));

    _defineProperty(this, "throttleOnUpdateHandler", throttle(this.onUpdateHandler, 50));

    this.state = {
      isScrolling: false
    };
  }

  componentDidMount() {
    this.setScrollShadowState();
  }

  render() {
    const {
      className,
      children,
      customScrollBarProps = {}
    } = this.props;
    const {
      isScrolling,
      scrollShadowClassName
    } = this.state;
    const classes = classNames('bdl-CollapsibleSidebar-nav', className, {
      'is-scrolling': isScrolling
    });
    return React.createElement(CollapsibleSidebarContext.Provider, {
      value: {
        isScrolling
      }
    }, React.createElement(Scrollbar, _extends({
      ref: this.scrollRef,
      className: scrollShadowClassName,
      noScrollX: true,
      onScroll: this.throtteldOnScrollHandler,
      onUpdate: this.throttleOnUpdateHandler,
      renderer: props => {
        const {
          elementRef
        } = props,
              restProps = _objectWithoutProperties(props, ["elementRef"]);

        return React.createElement(StyledScrollContainer, _extends({}, restProps, {
          ref: elementRef
        }));
      },
      style: {
        height: 'auto',
        width: '100%',
        flexGrow: 1
      },
      thumbYProps: {
        renderer: renderProps => {
          const {
            elementRef,
            style
          } = renderProps,
                restProps = _objectWithoutProperties(renderProps, ["elementRef", "style"]);

          if (style && style.background) {
            delete style.background; // remove the hardcoded valued so that the theme value can be assigned
          }

          return React.createElement(StyledScrollThumb, _extends({
            style: style
          }, restProps, {
            ref: elementRef
          }));
        }
      },
      trackYProps: {
        style: {
          background: 'none',
          top: '0',
          height: '100%',
          width: '8px',
          marginRight: '1px'
        }
      }
    }, customScrollBarProps), React.createElement("div", {
      className: classes
    }, children)));
  }

}

export default CollapsibleSidebarNav;
//# sourceMappingURL=CollapsibleSidebarNav.js.map