function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { useState, useCallback } from 'react';
import { FormattedMessage } from 'react-intl';
import withCurrentUser from '../../elements/common/current-user';
import BoxAiLogo from '../../icon/logo/BoxAiLogo';
import ContentAnswersModalContent from './ContentAnswersModalContent';
import ContentAnswersModalFooter from './ContentAnswersModalFooter'; // @ts-ignore flow import

import Modal from '../../components/modal/Modal'; // @ts-ignore: no ts definition
// eslint-disable-next-line import/named

// @ts-ignore: no ts definition
// eslint-disable-next-line import/named
import { withAPIContext } from '../../elements/common/api-context'; // @ts-ignore: no ts definition

import messages from './messages';
import './ContentAnswersModal.scss';

const ContentAnswersModal = (_ref) => {
  let {
    api,
    currentUser,
    file,
    isOpen,
    onAsk,
    onRequestClose
  } = _ref;
  const fileName = file && file.name;
  const [hasError, setHasError] = useState(false);
  const [isLoading, setIsLoading] = useState(false);
  const [questions, setQuestions] = useState([]);
  const handleSuccessCallback = useCallback(response => {
    const question = {
      answer: response.data.answer,
      createdAt: response.data.created_at
    };
    setQuestions(prevState => {
      const lastQuestion = prevState[prevState.length - 1];
      return [...prevState.slice(0, -1), _objectSpread({}, lastQuestion, {}, question)];
    });
  }, []);
  const handleErrorCallback = useCallback(error => {
    setHasError(true);
    setQuestions(prevState => {
      const lastQuestion = prevState[prevState.length - 1];
      return [...prevState.slice(0, -1), _objectSpread({}, lastQuestion, {
        error
      })];
    });
  }, []);
  const handleAsk = useCallback(async function (prompt) {
    let isRetry = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    setHasError(false);
    onAsk();
    const id = file && file.id;
    const items = [{
      id,
      type: 'file'
    }];
    const nextQuestions = [...(isRetry ? questions.slice(0, -1) : questions)];
    setQuestions([...nextQuestions, {
      prompt
    }]);
    setIsLoading(true);

    try {
      const response = await api.getIntelligenceAPI(true).ask(prompt, items);
      handleSuccessCallback(response);
    } catch (e) {
      handleErrorCallback(e);
    }

    setIsLoading(false);
  }, [api, file, handleErrorCallback, handleSuccessCallback, onAsk, questions]);
  const handleRetry = useCallback(() => {
    handleAsk(questions[questions.length - 1].prompt, true);
  }, [handleAsk, questions]);
  return React.createElement(Modal, {
    className: "bdl-ContentAnswersModal",
    "data-testid": "content-answers-modal",
    isOpen: isOpen,
    onRequestClose: onRequestClose,
    title: React.createElement(React.Fragment, null, React.createElement(BoxAiLogo, {
      className: "bdl-BoxAiLogo",
      "data-testid": "content-answers-icon-color",
      width: 32,
      height: 32
    }), React.createElement(FormattedMessage, messages.contentAnswersTitle))
  }, React.createElement(ContentAnswersModalContent, {
    currentUser: currentUser,
    "data-testid": "content-answers-modal-content",
    fileName: fileName,
    isLoading: isLoading,
    questions: questions
  }), React.createElement(ContentAnswersModalFooter, {
    currentUser: currentUser,
    "data-testid": "content-answers-modal-footer",
    hasError: hasError,
    isLoading: isLoading,
    onAsk: handleAsk,
    onRetry: handleRetry
  }));
};

export default withAPIContext(withCurrentUser(ContentAnswersModal));
//# sourceMappingURL=ContentAnswersModal.js.map