import React, { useCallback, useEffect, useRef } from 'react';
import Answer from './Answer';
import InlineError from './InlineError';
import Question from './Question';
import WelcomeMessage from './WelcomeMessage';
import './ContentAnswersModalContent.scss';

const ContentAnswersModalContent = (_ref) => {
  let {
    currentUser,
    fileName,
    isLoading,
    questions
  } = _ref;
  const messagesEndRef = useRef(null);
  const handleScrollToBottom = useCallback(behavior => {
    if (messagesEndRef.current && messagesEndRef.current.scrollIntoView) {
      messagesEndRef.current.scrollIntoView({
        behavior
      });
    }
  }, [messagesEndRef]); // scroll to bottom instantly when modal opens

  useEffect(() => {
    setTimeout(() => {
      handleScrollToBottom('instant');
    }, 0);
  }, [handleScrollToBottom]); // scroll to bottom for both cases that answer is loading and answer has been generated

  useEffect(() => {
    handleScrollToBottom('smooth');
  }, [handleScrollToBottom, isLoading]);
  return React.createElement("div", {
    className: "bdl-ContentAnswersModalContent",
    "data-testid": "content-answers-modal-content"
  }, React.createElement(WelcomeMessage, {
    fileName: fileName
  }), React.createElement("ul", null, questions.map((_ref2, index) => {
    let {
      prompt,
      error,
      answer = ''
    } = _ref2;
    const hasError = !!error;
    return React.createElement("li", {
      key: index
    }, React.createElement(Question, {
      currentUser: currentUser,
      prompt: prompt
    }), hasError ? React.createElement(InlineError, null) : React.createElement(Answer, {
      answer: answer,
      isLoading: isLoading
    }));
  })), React.createElement("div", {
    ref: messagesEndRef
  }));
};

export default ContentAnswersModalContent;
//# sourceMappingURL=ContentAnswersModalContent.js.map