import React, { useCallback, useState } from 'react';
import { injectIntl, FormattedMessage } from 'react-intl';
import Avatar from '../../components/avatar';
import PrimaryButton from '../../components/primary-button'; // @ts-ignore flow import

import TextArea from '../../components/text-area';
import { TEXT_AREA } from './constants'; // @ts-ignore: no ts definition
// eslint-disable-next-line import/named

import ContentAnswersModalFooterActions from './ContentAnswersModalFooterActions';
import messages from './messages';
import './ContentAnswersModalFooter.scss';

const ContentAnswersModalFooter = (_ref) => {
  let {
    currentUser,
    hasError,
    intl,
    isLoading,
    onAsk,
    onRetry
  } = _ref;
  const {
    formatMessage
  } = intl;
  const {
    id,
    name
  } = currentUser || {};
  const [prompt, setPrompt] = useState('');
  const [isSubmitDisabled, setIsSubmitDisabled] = useState(true);
  const [hasMaxCharacterError, setHasMaxCharacterError] = useState(false);
  const handleInputChange = useCallback(event => {
    let currentInput = event.currentTarget.value;

    if (currentInput.length > TEXT_AREA.MAX_LENGTH) {
      currentInput = currentInput.slice(0, TEXT_AREA.MAX_LENGTH);
    }

    setPrompt(currentInput);
    setHasMaxCharacterError(currentInput.length >= TEXT_AREA.MAX_LENGTH);

    if (!isLoading) {
      setIsSubmitDisabled(currentInput.trim().length === 0);
    }
  }, [isLoading]);
  const handleOnAsk = useCallback(() => {
    if (!isSubmitDisabled && prompt) {
      onAsk(prompt);
      setPrompt('');
      setIsSubmitDisabled(true);
    }
  }, [isSubmitDisabled, onAsk, prompt]);
  const handleKeyDown = useCallback(event => {
    if (event.keyCode === 13 && event.shiftKey === false) {
      event.preventDefault();
      handleOnAsk();
    }
  }, [handleOnAsk]);
  return React.createElement("div", {
    className: "bdl-ContentAnswersModalFooter"
  }, React.createElement(ContentAnswersModalFooterActions, {
    hasError: hasError,
    onRetry: onRetry
  }), React.createElement("div", {
    className: "bdl-ContentAnswersModalFooter-questionInput"
  }, React.createElement("div", {
    className: "bdl-ContentAnswersModalFooter-avatar"
  }, React.createElement(Avatar, {
    id: id,
    name: name
  })), React.createElement(TextArea, {
    "data-testid": "content-answers-question-input",
    error: hasMaxCharacterError && formatMessage(messages.maxCharactersReachedError, {
      characterLimit: TEXT_AREA.MAX_LENGTH
    }),
    hideLabel: true,
    label: formatMessage(messages.askQuestionPlaceholder),
    maxLength: TEXT_AREA.MAX_LENGTH,
    onChange: handleInputChange,
    placeholder: formatMessage(messages.askQuestionPlaceholder),
    value: prompt,
    onKeyDown: handleKeyDown
  }), React.createElement(PrimaryButton, {
    className: "bdl-ContentAnswersModalFooter-submitButton",
    "data-testid": "content-answers-submit-button",
    isDisabled: isSubmitDisabled,
    onClick: handleOnAsk
  }, React.createElement(FormattedMessage, messages.ask))));
};

export default injectIntl(ContentAnswersModalFooter);
//# sourceMappingURL=ContentAnswersModalFooter.js.map