import React, { useEffect } from 'react';
import { injectIntl } from 'react-intl';
import classNames from 'classnames';
import BoxAiLogo from '../../icon/logo/BoxAiLogo';
import Button from '../../components/button';
import Tooltip from '../../components/tooltip';
import { CODE_FILE_EXTENSIONS, DOCUMENT_FILE_EXTENSIONS, TEXT_FILE_EXTENSIONS } from './constants';
import messages from './messages';
import './ContentAnswersOpenButton.scss';

const ContentAnswersOpenButton = (_ref) => {
  let {
    fileExtension,
    intl,
    isHighlighted,
    isModalOpen,
    onClick
  } = _ref;
  const {
    formatMessage
  } = intl;
  const buttonRef = React.useRef(null);
  useEffect(() => {
    if (isHighlighted && !isModalOpen && buttonRef.current) {
      buttonRef.current.focus();
    }
  }, [isHighlighted, isModalOpen]);

  const isAllowedFileType = extension => {
    const allowedTypes = [...CODE_FILE_EXTENSIONS, ...DOCUMENT_FILE_EXTENSIONS, ...TEXT_FILE_EXTENSIONS];
    return allowedTypes.includes(extension);
  };

  const getTooltipText = () => {
    if (isHighlighted) {
      return formatMessage(messages.hasQuestionsTooltip);
    }

    if (!isAllowedFileType(fileExtension)) {
      return formatMessage(messages.disabledTooltipFileNotCompatible);
    }

    return formatMessage(messages.defaultTooltip);
  };

  const openButtonClassNames = classNames('bdl-ContentAnswersOpenButton', {
    'bdl-ContentAnswersOpenButton--hasQuestions': isHighlighted
  });
  return React.createElement(Tooltip, {
    className: "bdl-ContentAnswersOpenButton-tooltip",
    text: getTooltipText()
  }, React.createElement(Button, {
    "aria-label": formatMessage(messages.contentAnswersTitle),
    className: openButtonClassNames,
    "data-testid": "content-answers-open-button",
    isDisabled: !isAllowedFileType(fileExtension),
    onClick: onClick,
    setRef: ref => {
      buttonRef.current = ref;
    }
  }, React.createElement(BoxAiLogo, {
    className: "bdl-ContentAnswersOpenButton-icon",
    width: 20,
    height: 20
  })));
};

export default injectIntl(ContentAnswersOpenButton);
//# sourceMappingURL=ContentAnswersOpenButton.js.map