import PropTypes from 'prop-types';
import React from 'react';
import { FormattedMessage, injectIntl } from 'react-intl';
import Button from '../../../components/button';
import { ContentExplorerModePropType } from '../prop-types';
import ContentExplorerModes from '../modes';
import messages from '../messages';

const ContentExplorerNewFolderButton = (_ref) => {
  let {
    contentExplorerMode,
    intl,
    onClick,
    isDisabled = false,
    isCreateNewFolderAllowed = true
  } = _ref;
  const doesModeAllowCreateNewFolder = contentExplorerMode === ContentExplorerModes.COPY || contentExplorerMode === ContentExplorerModes.MOVE_COPY || contentExplorerMode === ContentExplorerModes.MULTI_SELECT || contentExplorerMode === ContentExplorerModes.SELECT_FOLDER;
  return doesModeAllowCreateNewFolder ? React.createElement(Button, {
    className: "content-explorer-new-folder-button",
    type: "button",
    onClick: onClick,
    isDisabled: isDisabled,
    title: !isCreateNewFolderAllowed ? intl.formatMessage(messages.newFolderForbidden) : ''
  }, React.createElement(FormattedMessage, messages.newFolder)) : null;
};

ContentExplorerNewFolderButton.propTypes = {
  contentExplorerMode: ContentExplorerModePropType.isRequired,
  intl: PropTypes.any,
  onClick: PropTypes.func,
  isDisabled: PropTypes.bool,
  isCreateNewFolderAllowed: PropTypes.bool
};
export { ContentExplorerNewFolderButton as ContentExplorerNewFolderButtonBase };
export default injectIntl(ContentExplorerNewFolderButton);
//# sourceMappingURL=ContentExplorerNewFolderButton.js.map