function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import PropTypes from 'prop-types';
import React from 'react';
import classNames from 'classnames';
import getProp from 'lodash/get';
import AutoSizer from '@box/react-virtualized/dist/commonjs/AutoSizer';
import Column from '@box/react-virtualized/dist/commonjs/Table/Column';
import Table from '@box/react-virtualized/dist/commonjs/Table';
import defaultTableRowRenderer from '@box/react-virtualized/dist/commonjs/Table/defaultRowRenderer';
import '@box/react-virtualized/styles.css';
import { withInfiniteLoader } from '../../../components/react-virtualized-helpers';
import { ContentExplorerModePropType, ItemsPropType, ItemsMapPropType } from '../prop-types';
import ItemListIcon from './ItemListIcon';
import ItemListLoadingPlaceholder from './ItemListLoadingPlaceholder';
import ItemListName from './ItemListName';
import ItemListButton from './ItemListButton';
import './ItemList.scss';
const TABLE_CELL_CLASS = 'table-cell';
const InfiniteLoaderTable = withInfiniteLoader(Table);
const DEFAULT_ROW_HEIGHT = 40;

const withAutoSizer = WrappedComponent => {
  return props => {
    return React.createElement("div", {
      style: {
        flex: 1
      }
    }, React.createElement(AutoSizer, null, (_ref) => {
      let {
        width: w,
        height: h
      } = _ref;
      return React.createElement(WrappedComponent, _extends({}, props, {
        width: w,
        height: h
      }));
    }));
  };
};

const TableResponsive = withAutoSizer(Table);

const itemIconCellRenderer = rendererParams => {
  const {
    rowData: {
      type,
      extension,
      hasCollaborations,
      isExternallyOwned
    },
    columnData: {
      itemIconRenderer
    }
  } = rendererParams;
  return React.createElement("div", {
    className: TABLE_CELL_CLASS
  }, itemIconRenderer ? itemIconRenderer(rendererParams) : React.createElement(ItemListIcon, {
    type: type,
    extension: extension,
    hasCollaborations: hasCollaborations,
    isExternallyOwned: isExternallyOwned
  }));
};

const isItemSelected = (itemId, selectedItems) => selectedItems[itemId] !== undefined;

const itemNameCellRenderer = rendererParams => {
  const {
    rowIndex,
    rowData: {
      id,
      type,
      name,
      label
    },
    columnData: {
      selectedItems,
      onItemNameClick,
      itemNameLinkRenderer
    }
  } = rendererParams; // loading placeholder may not have name and ItemListName requires name

  return name && React.createElement("div", {
    className: TABLE_CELL_CLASS
  }, React.createElement(ItemListName, {
    itemId: id,
    type: type,
    name: name,
    label: label,
    isSelected: isItemSelected(id, selectedItems),
    onClick: event => onItemNameClick(event, rowIndex),
    linkRenderer: itemNameLinkRenderer
  }));
};

const renderItemListButton = (contentExplorerMode, id, isActionDisabled, isDisabled, name, selectedItems) => name && React.createElement(ItemListButton, {
  contentExplorerMode: contentExplorerMode,
  id: id,
  isDisabled: isActionDisabled,
  isSelected: isItemSelected(id, selectedItems),
  name: name
});

const itemButtonCellRenderer = rendererParams => {
  const {
    columnData: {
      contentExplorerMode,
      itemButtonRenderer,
      selectedItems
    },
    rowData: {
      id,
      isActionDisabled,
      isDisabled,
      name
    }
  } = rendererParams;
  return !isDisabled && React.createElement("div", {
    className: TABLE_CELL_CLASS
  }, itemButtonRenderer ? itemButtonRenderer(rendererParams) : renderItemListButton(contentExplorerMode, id, isActionDisabled, isDisabled, name, selectedItems));
};

const itemLoadingPlaceholderRenderer = rendererParams => {
  const {
    loadingPlaceholderColumnWidths,
    columnIndex
  } = rendererParams;
  return React.createElement("div", {
    className: TABLE_CELL_CLASS
  }, React.createElement(ItemListLoadingPlaceholder, {
    width: loadingPlaceholderColumnWidths && loadingPlaceholderColumnWidths[columnIndex]
  }));
};

const ItemList = (_ref2) => {
  let {
    additionalColumns,
    contentExplorerMode,
    className = '',
    isResponsive = false,
    items,
    numItemsPerPage,
    numTotalItems,
    selectedItems = {},
    onItemClick,
    onItemDoubleClick,
    onItemNameClick,
    onLoadMoreItems,
    headerHeight,
    headerRenderer,
    itemIconRenderer,
    itemNameLinkRenderer,
    itemButtonRenderer,
    itemRowRenderer = defaultTableRowRenderer,
    noItemsRenderer,
    width,
    height,
    rowHeight = DEFAULT_ROW_HEIGHT
  } = _ref2;

  const getRow = (_ref3) => {
    let {
      index
    } = _ref3;
    return items[index];
  };

  const getRowClassNames = (index, item) => {
    let result = index === -1 ? 'table-header' : 'table-row';

    if (isItemSelected(item.id, selectedItems)) {
      result = classNames('is-selected', result);
    }

    if (item && (item.isDisabled || item.isLoading)) {
      result = classNames('disabled', result);
    }

    return result;
  };

  const renderRow = rendererParams => {
    const {
      index,
      key,
      style,
      className: rowClassName,
      columns
    } = rendererParams;
    const item = items[index];
    const itemRowClassname = classNames(rowClassName, getRowClassNames(index, item));
    const testId = getProp(rendererParams, 'rowData.id', '');

    if (item.isLoading) {
      return React.createElement("div", {
        key: key,
        style: style,
        className: itemRowClassname,
        role: "row"
      }, columns.map((column, columnIndex) => React.createElement("div", {
        key: columnIndex,
        className: column.props.className,
        style: column.props.style,
        role: "gridcell"
      }, itemLoadingPlaceholderRenderer({
        item,
        columnIndex
      }))));
    }

    const defaultRow = itemRowRenderer(_objectSpread({}, rendererParams, {
      className: itemRowClassname
    }));
    return React.cloneElement(defaultRow, {
      'data-testid': "item-row-".concat(testId)
    });
  };

  let TableComponent = isResponsive ? TableResponsive : Table;
  const tableProps = {};

  if (onLoadMoreItems) {
    TableComponent = InfiniteLoaderTable;
    tableProps.infiniteLoaderProps = {
      isRowLoaded: getRow,
      loadMoreRows: onLoadMoreItems,
      minimumBatchSize: numItemsPerPage,
      rowCount: numTotalItems,
      threshold: numItemsPerPage
    };
  }

  if (!noItemsRenderer || items.length > 0) {
    tableProps.headerHeight = headerHeight;
    tableProps.headerRowRenderer = headerRenderer;
  }

  return React.createElement("div", {
    className: classNames('content-explorer-item-list table', className, {
      'bdl-ContentExplorerItemList--responsive': isResponsive
    })
  }, React.createElement(TableComponent, _extends({
    gridClassName: "table-body",
    headerClassName: "table-header-item",
    width: width,
    height: height,
    rowHeight: rowHeight,
    rowCount: items.length,
    onRowClick: onItemClick,
    onRowDoubleClick: onItemDoubleClick,
    rowGetter: getRow,
    rowRenderer: renderRow,
    noRowsRenderer: noItemsRenderer
  }, tableProps), React.createElement(Column, {
    className: "item-list-icon-col",
    cellRenderer: itemIconCellRenderer,
    columnData: {
      itemIconRenderer
    },
    dataKey: "icon",
    width: 32
  }), React.createElement(Column, {
    className: "item-list-name-col",
    cellRenderer: itemNameCellRenderer,
    columnData: {
      selectedItems,
      onItemNameClick,
      itemNameLinkRenderer
    },
    dataKey: "name",
    width: 0,
    flexGrow: 1,
    flexShrink: 0
  }), additionalColumns, React.createElement(Column, {
    className: "item-list-button-col",
    cellRenderer: itemButtonCellRenderer,
    columnData: {
      contentExplorerMode,
      itemButtonRenderer,
      selectedItems
    },
    dataKey: "button",
    width: 30
  })));
};

ItemList.displayName = 'ItemList';
ItemList.propTypes = {
  additionalColumns: PropTypes.arrayOf(PropTypes.element),
  className: PropTypes.string,
  contentExplorerMode: ContentExplorerModePropType.isRequired,
  isResponsive: PropTypes.bool,
  items: ItemsPropType.isRequired,
  numItemsPerPage: PropTypes.number,
  numTotalItems: PropTypes.number,
  selectedItems: ItemsMapPropType.isRequired,
  onItemClick: PropTypes.func,
  onItemDoubleClick: PropTypes.func,
  onItemNameClick: PropTypes.func,
  onLoadMoreItems: PropTypes.func,
  headerHeight: PropTypes.number,
  headerRenderer: PropTypes.func,
  itemIconRenderer: PropTypes.func,
  itemNameLinkRenderer: PropTypes.func,
  itemButtonRenderer: PropTypes.func,
  itemRowRenderer: PropTypes.func,
  noItemsRenderer: PropTypes.func,
  width: PropTypes.number.isRequired,
  height: PropTypes.number.isRequired,
  rowHeight: PropTypes.number
};
export { ItemList as ItemListBase };
export default ItemList;
//# sourceMappingURL=ItemList.js.map