function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import classNames from 'classnames';
import { FormattedMessage, injectIntl } from 'react-intl';
import { Modal, ModalActions } from '../../../components/modal';
import TextInput from '../../../components/text-input';
import Button from '../../../components/button';
import PrimaryButton from '../../../components/primary-button';
import messages from '../messages';
import './NewFolderModal.scss';

class NewFolderModal extends Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "handleCreateClick", () => {
      const {
        onCreateFolderSubmit
      } = this.props;
      const {
        folderNameInput
      } = this.state;
      onCreateFolderSubmit(folderNameInput);
    });

    _defineProperty(this, "handleFolderNameInput", event => {
      const {
        onCreateFolderInput
      } = this.props;
      const input = event.target.value;
      this.setState({
        folderNameInput: input
      });

      if (onCreateFolderInput) {
        onCreateFolderInput(input);
      }
    });

    this.state = {
      folderNameInput: ''
    };
  }

  render() {
    const {
      className,
      intl,
      isOpen,
      onRequestClose,
      parentFolderName,
      isCreatingFolder,
      createFolderError,
      shouldNotUsePortal
    } = this.props;
    const {
      folderNameInput
    } = this.state;
    const isCreateButtonDisabled = !folderNameInput.trim().length || !!createFolderError || !!isCreatingFolder;
    return React.createElement(Modal, {
      className: classNames('new-folder-modal', className),
      focusElementSelector: ".folder-name-input input",
      isOpen: isOpen,
      onRequestClose: onRequestClose,
      shouldNotUsePortal: shouldNotUsePortal,
      title: React.createElement(FormattedMessage, _extends({}, messages.newFolderModalTitle, {
        values: {
          parentFolderName
        }
      }))
    }, React.createElement(TextInput, {
      className: "folder-name-input",
      error: createFolderError,
      isRequired: true,
      label: React.createElement(FormattedMessage, messages.newFolderModalFolderNameLabel),
      onInput: this.handleFolderNameInput,
      placeholder: intl.formatMessage(messages.newFolderModalFolderNamePlaceholder),
      type: "text",
      value: folderNameInput
    }), React.createElement(ModalActions, null, React.createElement(Button, {
      className: "new-folder-modal-cancel-button",
      onClick: onRequestClose,
      type: "button"
    }, React.createElement(FormattedMessage, messages.newFolderModalCancel)), React.createElement(PrimaryButton, {
      className: "new-folder-modal-create-button",
      isDisabled: isCreateButtonDisabled,
      isLoading: isCreatingFolder,
      onClick: this.handleCreateClick,
      type: "button"
    }, React.createElement(FormattedMessage, messages.newFolderModalCreate))));
  }

}

_defineProperty(NewFolderModal, "propTypes", {
  /** Adds class name to modal. */
  className: PropTypes.string,
  intl: PropTypes.any,

  /** Opens the modal. */
  isOpen: PropTypes.bool,

  /** Called when the modal is requested to be closed. */
  onRequestClose: PropTypes.func.isRequired,

  /**
   * Called when the folder creation is submitted.
   *
   * @param {string} folderName
   */
  onCreateFolderSubmit: PropTypes.func.isRequired,

  /**
   * Called with the latest folder name input.
   *
   * @param {string} folderName
   */
  onCreateFolderInput: PropTypes.func,

  /** The name of the parent folder that the new folder will be created in. */
  parentFolderName: PropTypes.string,

  /** Folder is in the process of being created. */
  isCreatingFolder: PropTypes.bool,

  /** Message that will be shown when there was an error creating the folder. */
  createFolderError: PropTypes.string,

  /** Whether the modal should be nested in a Portal or in a div */
  shouldNotUsePortal: PropTypes.bool
});

_defineProperty(NewFolderModal, "defaultProps", {
  className: '',
  isOpen: false,
  parentFolderName: '',
  isCreatingFolder: false,
  createFolderError: null,
  shouldNotUsePortal: false
});

export { NewFolderModal as NewFolderModalBase };
export default injectIntl(NewFolderModal);
//# sourceMappingURL=NewFolderModal.js.map