import * as React from 'react';
import isFinite from 'lodash/isFinite';
import isNaN from 'lodash/isNaN';
import { injectIntl } from 'react-intl';
import HeaderWithCount from './HeaderWithCount';
import messages from './messages';
import TrendPill from './TrendPill';
import { formatCount } from './numberUtils';
import { METRIC } from './constants';
import './MetricSummary.scss';
const METRIC_MAP = {
  [METRIC.PREVIEWS]: {
    headerMessage: messages.previewGraphType,
    getPeriodCount: data => data.reduce((count, _ref) => {
      let {
        previewsCount
      } = _ref;
      return count + previewsCount;
    }, 0)
  },
  [METRIC.DOWNLOADS]: {
    getPeriodCount: data => data.reduce((count, _ref2) => {
      let {
        downloadsCount
      } = _ref2;
      return count + downloadsCount;
    }, 0),
    headerMessage: messages.downloadGraphType
  },
  [METRIC.USERS]: {
    getPeriodCount: data => {
      const periodUsers = data.reduce((totalUsers, _ref3) => {
        let {
          users
        } = _ref3;
        return new Set([...Array.from(totalUsers), ...Array.from(users)]);
      }, new Set());
      return periodUsers.size;
    },
    headerMessage: messages.peopleTitle
  }
}; // Limit the trend to a finite number (in case the previous period count was 0 and the calculated trend is Infinity)

const formatTrend = calculatedTrend => !isFinite(calculatedTrend) ? 1 : calculatedTrend;

function MetricSummary(_ref4) {
  let {
    data = [],
    intl,
    metric,
    period,
    previousPeriodCount = 0,
    totalCount
  } = _ref4;
  const {
    getPeriodCount,
    headerMessage
  } = METRIC_MAP[metric];
  const periodCount = getPeriodCount(data);
  const calculatedTrend = (periodCount - previousPeriodCount) / previousPeriodCount;
  const trend = isNaN(calculatedTrend) ? 0 : formatTrend(calculatedTrend);
  return React.createElement("div", {
    className: "MetricSummary"
  }, React.createElement(HeaderWithCount, {
    title: intl.formatMessage(headerMessage),
    totalCount: totalCount
  }), React.createElement("div", {
    className: "MetricSummary-period"
  }, React.createElement("span", {
    className: "MetricSummary-periodCount"
  }, formatCount(periodCount, intl)), React.createElement(TrendPill, {
    period: period,
    trend: trend
  })));
}

export default injectIntl(MetricSummary);
//# sourceMappingURL=MetricSummary.js.map