import React from 'react';
import classNames from 'classnames';
import { FormattedMessage, injectIntl } from 'react-intl';
import LabelPill from '../../components/label-pill';
import messages from './messages';
import './TrendPill.scss';

const getTrendStatus = trend => {
  if (trend === 0) {
    return 'neutral';
  }

  return trend > 0 ? 'up' : 'down';
};

const getTrendByPeriod = period => {
  switch (period) {
    case 'month':
      return messages.trendMonth;

    case 'threemonths':
      return messages.trendThreeMonths;

    case 'year':
      return messages.trendYear;

    case 'week':
    default:
      return messages.trendWeek;
  }
};

function TrendPill(_ref) {
  let {
    intl,
    period,
    trend
  } = _ref;

  const getTrendLabel = value => {
    return intl.formatMessage(value > 0 ? messages.trendUp : messages.trendDown);
  };

  const trendStatus = getTrendStatus(trend);
  const trendLabel = getTrendLabel(trend);
  return React.createElement(LabelPill.Pill, {
    className: classNames('TrendPill', {
      'TrendPill--up': trendStatus === 'up',
      'TrendPill--down': trendStatus === 'down'
    })
  }, React.createElement(React.Fragment, null, trendStatus !== 'neutral' && React.createElement("span", {
    "aria-label": trendLabel,
    className: "TrendPill-trend",
    role: "img"
  }), React.createElement(LabelPill.Text, null, React.createElement(React.Fragment, null, React.createElement("span", {
    className: "TrendPill-percentage"
  }, intl.formatNumber(trend, {
    style: 'percent'
  })), React.createElement(FormattedMessage, getTrendByPeriod(period))))));
}

export default injectIntl(TrendPill);
//# sourceMappingURL=TrendPill.js.map