function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage, injectIntl } from 'react-intl';
import TextInput from '../../components/text-input/TextInput';
import commonMessages from '../../common/messages';
import messages from './messages';
const VALUE_MISSING = 'valueMissing';
const TYPE_MISMATCH = 'typeMismatch';
const errorMap = {
  [VALUE_MISSING]: React.createElement(FormattedMessage, commonMessages.requiredFieldError),
  [TYPE_MISMATCH]: React.createElement(FormattedMessage, commonMessages.invalidURLError)
};

class EditableURL extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      error: '',
      value: this.props.value
    });

    _defineProperty(this, "handleBlur", () => {
      if (!this.inputEl) {
        return;
      }

      const {
        valid,
        valueMissing
      } = this.inputEl.validity;

      if (!valid) {
        this.setState({
          error: valueMissing ? VALUE_MISSING : TYPE_MISMATCH
        });
        return;
      }

      this.props.onValidURLChange(this.state.value);
    });

    _defineProperty(this, "handleChange", event => {
      this.setState({
        value: event.currentTarget.value
      });
    });

    _defineProperty(this, "handleFocus", () => {
      this.setState({
        error: ''
      });
    });
  }

  componentDidUpdate(_ref) {
    let {
      value: prevValue
    } = _ref;
    const {
      value
    } = this.props;

    if (prevValue !== value) {
      this.setState({
        value
      });
    }
  }

  render() {
    const {
      intl: {
        formatMessage
      }
    } = this.props;
    const {
      error,
      value
    } = this.state;
    return React.createElement(TextInput, {
      className: "url-input",
      error: error ? errorMap[error] : undefined,
      hideLabel: true,
      inputRef: ref => {
        this.inputEl = ref;
      },
      isRequired: true,
      label: formatMessage(messages.url),
      onBlur: this.handleBlur,
      onChange: this.handleChange,
      onFocus: this.handleFocus,
      placeholder: formatMessage(messages.urlPlaceholder),
      type: "url",
      value: value
    });
  }

}

export { EditableURL as EditableURLBase, VALUE_MISSING, TYPE_MISMATCH };
export default injectIntl(EditableURL);
//# sourceMappingURL=EditableURL.js.map