function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import debounce from 'lodash/debounce';
import throttle from 'lodash/throttle';
import { NavSidebar, NavList, NavListCollapseHeader } from '../../components/nav-sidebar';
import FooterIndicator from '../../components/footer-indicator/FooterIndicator';
import LoadingIndicatorWrapper from '../../components/loading-indicator/LoadingIndicatorWrapper';
import { bdlBoxBlue } from '../../styles/variables';
import CopyrightFooter from './CopyrightFooter';
import InstantLogin from './InstantLogin';
import LeftSidebarDropWrapper from './LeftSidebarDropWrapper';
import LeftSidebarIconWrapper from './LeftSidebarIconWrapper';
import NewItemsIndicator from './NewItemsIndicator';
import defaultNavLinkRenderer from './defaultNavLinkRenderer';
import './styles/LeftSidebar.scss';

class LeftSidebar extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "onListScroll", () => {
      this.changeIsScrollingState();
      this.throttledCheckAndChangeScrollShadows();
    });

    _defineProperty(this, "checkAndChangeScrollShadows", () => {
      if (this.elScrollableList) {
        this.setState(this.calculateOverflow(this.elScrollableList));
      }
    });

    _defineProperty(this, "changeIsScrollingState", () => {
      if (!this.state.isScrolling) {
        this.setState({
          isScrolling: true
        });
      }

      this.debouncedTurnOffScrollingState();
    });

    _defineProperty(this, "turnOffScrollingState", () => {
      this.setState({
        isScrolling: false
      });
    });

    _defineProperty(this, "debouncedTurnOffScrollingState", debounce(this.turnOffScrollingState, 100));

    _defineProperty(this, "throttledCheckAndChangeScrollShadows", throttle(this.checkAndChangeScrollShadows, 50));

    this.state = {
      isScrollableAbove: false,
      isScrollableBelow: false,
      isScrolling: false
    };
  }

  componentDidUpdate() {
    if (!this.elScrollableList) {
      return;
    }

    const overflow = this.calculateOverflow(this.elScrollableList);
    /**
     * recalculate overflow when dropdown is visible and new collabs are added
     * This will not go into an infinite loop because we check for changes in local component state
     */

    if (overflow.isScrollableAbove !== this.state.isScrollableAbove || overflow.isScrollableBelow !== this.state.isScrollableBelow) {
      // eslint-disable-next-line react/no-did-update-set-state
      this.setState(overflow);
    }
  }

  getIcon(iconElement, IconComponent) {
    let customTheme = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    let selected = arguments.length > 3 ? arguments[3] : undefined;
    let scaleIcon = arguments.length > 4 ? arguments[4] : undefined;
    const wrapperClass = scaleIcon ? 'scaled-icon' : '';

    if (iconElement) {
      return React.createElement(LeftSidebarIconWrapper, {
        className: wrapperClass
      }, iconElement);
    }

    if (IconComponent) {
      return React.createElement(LeftSidebarIconWrapper, {
        className: wrapperClass
      }, React.createElement(IconComponent, {
        color: selected && customTheme.secondaryColor ? customTheme.secondaryColor : bdlBoxBlue,
        selected: selected
      }));
    }

    return null;
  }

  getNewItemBadge(newItemBadge) {
    let customTheme = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    const {
      secondaryColor
    } = customTheme;
    return newItemBadge ? React.createElement(NewItemsIndicator, {
      customColor: secondaryColor
    }) : null;
  }

  getNavList(headerLinkProps, leftSidebarProps, showLoadingIndicator, onToggleCollapse) {
    const {
      canReceiveDrop = false,
      className = '',
      collapsed,
      dropTargetRef,
      id,
      menuItems,
      placeholder,
      showDropZoneOnHover
    } = headerLinkProps;
    const heading = onToggleCollapse ? React.createElement(NavListCollapseHeader, {
      onToggleCollapse: onToggleCollapse
    }, this.getNavLink(headerLinkProps, leftSidebarProps)) : this.getNavLink(headerLinkProps, leftSidebarProps);
    const placeholderEl = menuItems && menuItems.length || showLoadingIndicator ? null : React.createElement("div", {
      className: "placeholder"
    }, placeholder);
    const classes = classNames('left-sidebar-list', className, {
      'is-loading-empty': showLoadingIndicator && menuItems && menuItems.length === 0,
      'is-loading': showLoadingIndicator && menuItems && menuItems.length > 0,
      'lsb-scrollable-shadow-top': this.state.isScrollableAbove,
      'lsb-scrollable-shadow-bottom': this.state.isScrollableBelow
    });
    const ulProps = onToggleCollapse ? {
      onScroll: this.onListScroll,
      ref: elScrollableList => {
        this.elScrollableList = elScrollableList;
      }
    } : {};
    const builtNavList = React.createElement(NavList, {
      className: classes,
      collapsed: collapsed,
      heading: heading,
      placeholder: placeholderEl,
      key: "list-".concat(id),
      ulProps: ulProps
    }, menuItems && menuItems.map(props => this.getNavLink(props, leftSidebarProps)) || null);
    return canReceiveDrop ? React.createElement(LeftSidebarDropWrapper, {
      isDragging: leftSidebarProps.isDragging,
      dropTargetRef: dropTargetRef,
      showDropZoneOnHover: showDropZoneOnHover
    }, builtNavList) : builtNavList;
  }

  getNavLink(props, leftSidebarProps) {
    const {
      callout,
      canReceiveDrop = false,
      className = '',
      dropTargetRef,
      htmlAttributes,
      iconComponent,
      iconElement,
      id,
      message,
      navLinkRenderer,
      newItemBadge,
      onClickRemove,
      removeButtonHtmlAttributes,
      routerLink,
      routerProps,
      scaleIcon,
      selected = false,
      showTooltip,
      showDropZoneOnHover
    } = props;
    const linkClassNames = classNames('left-sidebar-link', className, {
      'is-selected': selected
    });
    const linkProps = {
      callout,
      className: linkClassNames,
      customTheme: leftSidebarProps.customTheme,
      onClickRemove,
      htmlAttributes,
      icon: this.getIcon(iconElement, iconComponent, leftSidebarProps.customTheme, selected, scaleIcon),
      isScrolling: this.state.isScrolling,
      message,
      newItemBadge: this.getNewItemBadge(newItemBadge, leftSidebarProps.customTheme),
      removeButtonHtmlAttributes,
      routerLink,
      routerProps,
      selected,
      showTooltip
    };
    const builtLink = navLinkRenderer ? navLinkRenderer(linkProps) : defaultNavLinkRenderer(linkProps); // Check for menu items on links so we don't double-highlight groups

    return canReceiveDrop && !props.menuItems ? React.createElement(LeftSidebarDropWrapper, {
      isDragging: leftSidebarProps.isDragging,
      dropTargetRef: dropTargetRef,
      key: "link-".concat(id),
      showDropZoneOnHover: showDropZoneOnHover
    }, builtLink) : React.createElement(React.Fragment, {
      key: "link-".concat(id)
    }, builtLink);
  }

  calculateOverflow(elem) {
    const isScrollableAbove = elem.scrollTop > 0;
    const isScrollableBelow = elem.scrollTop < elem.scrollHeight - elem.clientHeight;
    return {
      isScrollableAbove,
      isScrollableBelow
    };
  }

  render() {
    const {
      leftSidebarProps,
      menuItems
    } = this.props;
    const className = leftSidebarProps.className || '';
    const navSidebarProps = leftSidebarProps.htmlAttributes || {};
    const instantLoginProps = leftSidebarProps.instantLoginProps || {};
    const preparedMenu = menuItems.map((props, key) => {
      if (props.menuItems) {
        if (props.onToggleCollapse) {
          const {
            collapsed,
            showLoadingIndicator
          } = props;
          return React.createElement(LoadingIndicatorWrapper, {
            className: "favorites-loading-wrapper",
            crawlerPosition: "top",
            isLoading: showLoadingIndicator && !collapsed,
            key: "loading-indicator-".concat(key)
          }, this.getNavList(props, leftSidebarProps, showLoadingIndicator, props.onToggleCollapse));
        }

        return this.getNavList(props, leftSidebarProps);
      }

      return this.getNavLink(props, leftSidebarProps);
    });
    return React.createElement(NavSidebar, _extends({
      className: "left-sidebar ".concat(className)
    }, navSidebarProps), leftSidebarProps.isInstantLoggedIn ? React.createElement(InstantLogin, instantLoginProps) : null, React.createElement("div", {
      className: "left-sidebar-container"
    }, preparedMenu), React.createElement(CopyrightFooter, {
      linkProps: leftSidebarProps.copyrightFooterProps
    }), leftSidebarProps.indicatorText ? React.createElement(FooterIndicator, {
      indicatorText: leftSidebarProps.indicatorText
    }) : null);
  }

}

_defineProperty(LeftSidebar, "defaultProps", {
  leftSidebarProps: {},
  menuItems: []
});

export default LeftSidebar;
//# sourceMappingURL=LeftSidebar.js.map