function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * 
 * @file Metadata Queries API Helper
 * @author Box
 */
import cloneDeep from 'lodash/cloneDeep';
import find from 'lodash/find';
import getProp from 'lodash/get';
import includes from 'lodash/includes';
import isArray from 'lodash/isArray';
import isNil from 'lodash/isNil';
import API from '../../api';
import { ITEM_TYPE_FILE, JSON_PATCH_OP_ADD, JSON_PATCH_OP_REMOVE, JSON_PATCH_OP_REPLACE, JSON_PATCH_OP_TEST, METADATA_FIELD_TYPE_ENUM, METADATA_FIELD_TYPE_MULTISELECT } from '../../common/constants';
import { FIELD_NAME, FIELD_METADATA } from '../../constants';
const SELECT_TYPES = [METADATA_FIELD_TYPE_ENUM, METADATA_FIELD_TYPE_MULTISELECT];
export default class MetadataQueryAPIHelper {
  constructor(api) {
    _defineProperty(this, "createJSONPatchOperations", (field, oldValue, newValue) => {
      let operation = JSON_PATCH_OP_REPLACE;

      if (isNil(oldValue) && newValue) {
        operation = JSON_PATCH_OP_ADD;
      }

      if (oldValue && isNil(newValue)) {
        operation = JSON_PATCH_OP_REMOVE;
      }

      const testOp = {
        op: JSON_PATCH_OP_TEST,
        path: "/".concat(field),
        value: oldValue
      };
      const patchOp = {
        op: operation,
        path: "/".concat(field),
        value: newValue
      };

      if (operation === JSON_PATCH_OP_REMOVE) {
        delete patchOp.value;
      }

      return operation === JSON_PATCH_OP_ADD ? [patchOp] : [testOp, patchOp];
    });

    _defineProperty(this, "getMetadataQueryFields", () => {
      /*
          Example metadata query:
          const query = {
              from: 'enterprise_12345.myAwesomeTemplateKey',
              fields: [
                  'name', // base representation field for an item (name, size, etag etc.)
                  'metadata.enterprise_12345.myAwesomeTemplateKey.field_1', // metadata instance field
                  'metadata.enterprise_12345.myAwesomeTemplateKey.field_2', // metadata instance field
                  'metadata.enterprise_12345.myAwesomeTemplateKey.field_3' // metadata instance field
              ],
              ancestor_folder_id: 0,
          };
           This function will return ['field_1', 'field_2', 'field_3']
      */
      const {
        fields = [],
        from
      } = this.metadataQuery;
      return fields.filter(field => field.includes(from)).map(field => field.split('.').pop());
    });

    _defineProperty(this, "flattenMetadata", metadata => {
      const templateFields = getProp(this.metadataTemplate, 'fields', []);
      const instance = getProp(metadata, "".concat(this.templateScope, ".").concat(this.templateKey));

      if (!instance) {
        return {};
      }

      const queryFields = this.getMetadataQueryFields();
      const fields = queryFields.map(queryField => {
        const templateField = find(templateFields, ['key', queryField]);
        const type = getProp(templateField, 'type'); // get data type

        const displayName = getProp(templateField, 'displayName', queryField); // get displayName, defaults to key

        const field = {
          key: "".concat(FIELD_METADATA, ".").concat(this.templateScope, ".").concat(this.templateKey, ".").concat(queryField),
          value: instance[queryField],
          type,
          displayName
        };

        if (includes(SELECT_TYPES, type)) {
          // get "options" for enums or multiselects
          field.options = getProp(templateField, 'options');
        }

        return field;
      });
      return {
        enterprise: {
          fields,
          id: instance.$id
        }
      };
    });

    _defineProperty(this, "flattenResponseEntry", metadataEntry => {
      const {
        metadata
      } = metadataEntry;
      return _objectSpread({}, metadataEntry, {
        metadata: this.flattenMetadata(metadata)
      });
    });

    _defineProperty(this, "filterMetdataQueryResponse", response => {
      const {
        entries = [],
        next_marker
      } = response;
      return {
        entries: entries.filter(entry => getProp(entry, 'type') === ITEM_TYPE_FILE),
        // return only file items
        next_marker
      };
    });

    _defineProperty(this, "getFlattenedDataWithTypes", templateSchemaResponse => {
      this.metadataTemplate = getProp(templateSchemaResponse, 'data');
      const {
        entries,
        next_marker
      } = this.metadataQueryResponseData;
      return {
        items: entries.map(this.flattenResponseEntry),
        nextMarker: next_marker
      };
    });

    _defineProperty(this, "getTemplateSchemaInfo", data => {
      const {
        entries
      } = data;
      this.metadataQueryResponseData = this.filterMetdataQueryResponse(data);

      if (!entries || entries.length === 0) {
        // Don't make metadata API call to get template info
        return Promise.resolve();
      }

      const metadata = getProp(entries, '[0].metadata');
      this.templateScope = Object.keys(metadata)[0];
      const instance = metadata[this.templateScope];
      this.templateKey = Object.keys(instance)[0];
      return this.api.getMetadataAPI(true).getSchemaByTemplateKey(this.templateKey);
    });

    _defineProperty(this, "queryMetadata", () => {
      return new Promise((resolve, reject) => {
        this.api.getMetadataQueryAPI().queryMetadata(this.metadataQuery, resolve, reject, {
          forceFetch: true
        });
      });
    });

    _defineProperty(this, "fetchMetadataQueryResults", (metadataQuery, successsCallback, errorCallback) => {
      this.metadataQuery = this.verifyQueryFields(metadataQuery);
      return this.queryMetadata().then(this.getTemplateSchemaInfo).then(this.getFlattenedDataWithTypes).then(successsCallback).catch(errorCallback);
    });

    _defineProperty(this, "updateMetadata", (file, field, oldValue, newValue, successsCallback, errorCallback) => {
      const operations = this.createJSONPatchOperations(field, oldValue, newValue);
      return this.api.getMetadataAPI(true).updateMetadata(file, this.metadataTemplate, operations, successsCallback, errorCallback);
    });

    _defineProperty(this, "verifyQueryFields", metadataQuery => {
      const clonedQuery = cloneDeep(metadataQuery);
      const clonedFields = isArray(clonedQuery.fields) ? clonedQuery.fields : []; // Make sure the query fields array has "name" field which is necessary to display info.

      if (!clonedFields.includes(FIELD_NAME)) {
        clonedFields.push(FIELD_NAME);
      }

      clonedQuery.fields = clonedFields;
      return clonedQuery;
    });

    this.api = api;
  }

}
//# sourceMappingURL=MetadataQueryAPIHelper.js.map