function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import isEqual from 'lodash/isEqual';
import CustomNewField from './CustomInstanceNewField';
import CustomMetadataField from '../metadata-instance-fields/CustomMetadataField';
import EmptyContent from './EmptyContent';
import { FIELD_TYPE_STRING } from '../metadata-instance-fields/constants';

class CustomInstance extends React.PureComponent {
  static getDerivedStateFromProps(_ref, _ref2) {
    let {
      data
    } = _ref;
    let {
      properties
    } = _ref2;

    if (!isEqual(data, properties)) {
      return {
        properties: _objectSpread({}, data)
      };
    }

    return null;
  }

  constructor(props) {
    super(props);

    _defineProperty(this, "onFieldChange", (key, value) => {
      const {
        canEdit,
        onFieldChange
      } = this.props;

      if (canEdit && onFieldChange) {
        onFieldChange(key, value, FIELD_TYPE_STRING);
      }
    });

    _defineProperty(this, "onFieldRemove", key => {
      const {
        canEdit,
        onFieldRemove
      } = this.props;

      if (canEdit && onFieldRemove) {
        onFieldRemove(key);
      }
    });

    _defineProperty(this, "onAddFieldToggle", () => {
      this.setState(prevState => ({
        isAddFieldVisible: !prevState.isAddFieldVisible
      }));
    });

    this.state = {
      isAddFieldVisible: false,
      properties: _objectSpread({}, props.data)
    };
  }
  /**
   * Adds/updates a new metadata key value pair
   *
   * @param {string} key - metadata key
   * @param {string} value - metadata value
   * @return {void}
   */


  render() {
    const {
      canEdit
    } = this.props;
    const {
      isAddFieldVisible,
      properties
    } = this.state;
    const fields = Object.keys(properties);
    const canAddFields = canEdit && (isAddFieldVisible || fields.length === 0);
    return React.createElement(React.Fragment, null, fields.map((key, index) => React.createElement(CustomMetadataField, {
      key: key,
      canEdit: canEdit,
      dataKey: key,
      dataValue: properties[key],
      isLast: !isAddFieldVisible && index === fields.length - 1,
      onAdd: this.onAddFieldToggle,
      onChange: this.onFieldChange,
      onRemove: this.onFieldRemove
    })), !canAddFields && fields.length === 0 && React.createElement(EmptyContent, null), canAddFields && React.createElement(CustomNewField, {
      isCancellable: fields.length !== 0,
      onAdd: this.onFieldChange,
      onCancel: this.onAddFieldToggle,
      properties: this.props.data
    }));
  }

}

_defineProperty(CustomInstance, "defaultProps", {
  canEdit: true,
  data: {}
});

export default CustomInstance;
//# sourceMappingURL=CustomInstance.js.map