function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage, injectIntl } from 'react-intl';
import Button from '../../components/button/Button';
import TextInput from '../../components/text-input/TextInput';
import Tooltip from '../../components/tooltip/Tooltip';
import commonMessages from '../../common/messages';
import IconInfo from '../../icons/general/IconInfo';
import messages from './messages';
import './CustomInstanceNewField.scss';

class CustomInstanceNewField extends React.PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      key: '',
      value: '',
      error: ''
    });

    _defineProperty(this, "onKeyChange", event => {
      this.onChange(event, 'key');
    });

    _defineProperty(this, "onValueChange", event => {
      this.onChange(event, 'value');
    });

    _defineProperty(this, "onAdd", () => {
      const {
        key,
        value
      } = this.state;
      const {
        onAdd,
        properties
      } = this.props;

      if (Object.prototype.hasOwnProperty.call(properties, key)) {
        this.setState({
          error: React.createElement(FormattedMessage, messages.customErrorDuplicateKey)
        });
      } else if (key.startsWith('$')) {
        this.setState({
          error: React.createElement(FormattedMessage, messages.customErrorInternalKey)
        });
      } else if (key) {
        onAdd(key, value);
      } else {
        this.setState({
          error: React.createElement(FormattedMessage, messages.customErrorRequired)
        });
      }
    });
  }

  /**
   * Common change handler
   *
   * @param {Event} event - keyboard event
   * @param {string} attr - key or value
   * @return {void}
   */
  onChange(event, attr) {
    const currentTarget = event.currentTarget;
    this.setState({
      error: '',
      [attr]: currentTarget.value
    });
  }
  /**
   * Change handler for the key
   *
   * @param {Event} event - keyboard event
   * @return {void}
   */


  render() {
    const {
      intl,
      isCancellable,
      onCancel
    } = this.props;
    const {
      key,
      value,
      error
    } = this.state;
    return React.createElement("div", {
      className: "custom-new-field"
    }, React.createElement("div", {
      className: "custom-new-field-header"
    }, React.createElement(FormattedMessage, _extends({
      tagName: "h5"
    }, messages.customNewField)), React.createElement(Tooltip, {
      text: React.createElement(FormattedMessage, messages.customNewFieldMessage)
    }, React.createElement("div", {
      tabIndex: "-1"
    }, React.createElement(IconInfo, {
      color: "#777",
      height: 18,
      width: 18
    })))), React.createElement(TextInput, {
      error: error,
      isRequired: true,
      label: React.createElement(FormattedMessage, messages.customKey),
      onChange: this.onKeyChange,
      placeholder: intl.formatMessage(messages.customKeyPlaceholder),
      type: "text",
      value: key
    }), React.createElement(TextInput, {
      hideOptionalLabel: true,
      label: React.createElement(FormattedMessage, messages.customValue),
      onChange: this.onValueChange,
      placeholder: intl.formatMessage(messages.customValuePlaceholder),
      type: "text",
      value: value
    }), React.createElement("div", {
      className: "custom-new-field-actions"
    }, isCancellable && React.createElement(Button, {
      "data-resin-target": "metadata-customfieldcancel",
      onClick: onCancel,
      type: "button"
    }, React.createElement(FormattedMessage, commonMessages.cancel)), React.createElement(Button, {
      "data-resin-target": "metadata-customfieldadd",
      onClick: this.onAdd,
      type: "button"
    }, React.createElement(FormattedMessage, messages.customAdd))));
  }

}

export { CustomInstanceNewField as CustomInstanceNewFieldBase };
export default injectIntl(CustomInstanceNewField);
//# sourceMappingURL=CustomInstanceNewField.js.map