function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { injectIntl, FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import isEqual from 'lodash/isEqual';
import cloneDeep from 'lodash/cloneDeep';
import noop from 'lodash/noop';
import Collapsible from '../../components/collapsible/Collapsible';
import Form from '../../components/form-elements/form/Form';
import LoadingIndicatorWrapper from '../../components/loading-indicator/LoadingIndicatorWrapper';
import PlainButton from '../../components/plain-button/PlainButton';
import Tooltip from '../../components/tooltip';
import IconMetadataColored from '../../icons/general/IconMetadataColored';
import IconAlertCircle from '../../icons/general/IconAlertCircle';
import IconEdit from '../../icons/general/IconEdit';
import { bdlWatermelonRed } from '../../styles/variables';
import { scrollIntoView } from '../../utils/dom';
import CascadePolicy from './CascadePolicy';
import TemplatedInstance from './TemplatedInstance';
import CustomInstance from './CustomInstance';
import MetadataInstanceConfirmDialog from './MetadataInstanceConfirmDialog';
import Footer from './Footer';
import messages from './messages';
import { FIELD_TYPE_FLOAT, FIELD_TYPE_INTEGER } from '../metadata-instance-fields/constants';
import TEMPLATE_CUSTOM_PROPERTIES from './constants';
import { JSON_PATCH_OP_REMOVE, JSON_PATCH_OP_ADD, JSON_PATCH_OP_REPLACE, JSON_PATCH_OP_TEST } from '../../common/constants';
import { isValidValue } from '../metadata-instance-fields/validateMetadataField';
import { isHidden } from './metadataUtil';
import { RESIN_TAG_TARGET } from '../../common/variables';
import './Instance.scss';

const createFieldKeyToTypeMap = function createFieldKeyToTypeMap() {
  let fields = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return fields.reduce((prev, _ref) => {
    let {
      key,
      type
    } = _ref;
    prev[key] = type;
    return prev;
  }, {});
};

const getValue = (data, key, type) => {
  const value = data[key];

  switch (type) {
    case FIELD_TYPE_FLOAT:
      return parseFloat(value);

    case FIELD_TYPE_INTEGER:
      return parseInt(value, 10);

    default:
      return value;
  }
};

class Instance extends React.PureComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "onCancel", () => {
      const {
        id,
        onModification
      } = this.props;
      this.setState(this.getState(this.props)); // Callback to parent to tell that something is dirty

      if (onModification) {
        onModification(id, false);
      }
    });

    _defineProperty(this, "onConfirmRemove", () => {
      this.setState({
        shouldConfirmRemove: true
      });
    });

    _defineProperty(this, "onConfirmCancel", () => {
      this.setState({
        shouldConfirmRemove: false
      });
    });

    _defineProperty(this, "onRemove", () => {
      if (!this.isEditing()) {
        return;
      }

      const {
        id,
        onRemove
      } = this.props;

      if (onRemove) {
        onRemove(id);
        this.setState({
          isBusy: true
        });
      }
    });

    _defineProperty(this, "onSave", () => {
      const {
        cascadePolicy,
        data: originalData,
        id,
        isDirty,
        isCascadingPolicyApplicable,
        onSave
      } = this.props;
      const {
        data: currentData,
        errors,
        isCascadingEnabled,
        isCascadingOverwritten
      } = this.state;

      if (!this.isEditing() || !isDirty || !onSave || Object.keys(errors).length) {
        return;
      }

      this.setState({
        isBusy: true,
        isEditing: false,
        shouldShowCascadeOptions: false
      });
      onSave(id, this.createJSONPatch(currentData, originalData), isCascadingPolicyApplicable ? {
        canEdit: cascadePolicy ? cascadePolicy.canEdit : false,
        id: cascadePolicy ? cascadePolicy.id : undefined,
        isEnabled: isCascadingEnabled,
        overwrite: isCascadingOverwritten
      } : undefined, cloneDeep(currentData));
    });

    _defineProperty(this, "onFieldChange", (key, value, type) => {
      const {
        data,
        errors
      } = this.state; // Don't do anything if data is the same or not in edit mode

      if (!this.isEditing() || isEqual(data[key], value)) {
        return;
      }

      const isValid = isValidValue(type, value);

      const finalErrors = _objectSpread({}, errors);

      const finalData = cloneDeep(data);
      finalData[key] = value;

      if (isValid) {
        delete finalErrors[key];
      } else {
        finalErrors[key] = React.createElement(FormattedMessage, messages.invalidInput);
      }

      this.setState({
        data: finalData,
        errors: finalErrors
      }, () => {
        this.setDirty(type);
      });
    });

    _defineProperty(this, "onFieldRemove", key => {
      if (!this.isEditing()) {
        return;
      }

      const {
        data,
        errors
      } = this.state;
      const finalData = cloneDeep(data);

      const finalErrors = _objectSpread({}, errors);

      delete finalData[key];
      delete finalErrors[key];
      this.setState({
        data: finalData,
        errors: finalErrors
      }, this.setDirty);
    });

    _defineProperty(this, "onCascadeToggle", value => {
      const {
        isCascadingPolicyApplicable
      } = this.props;

      if (!isCascadingPolicyApplicable) {
        return;
      }

      this.setState({
        isCascadingEnabled: value,
        shouldShowCascadeOptions: value
      }, this.setDirty);
    });

    _defineProperty(this, "onCascadeModeChange", value => {
      const {
        isCascadingPolicyApplicable
      } = this.props;

      if (!isCascadingPolicyApplicable) {
        return;
      }

      this.setState({
        isCascadingOverwritten: value
      }, this.setDirty);
    });

    _defineProperty(this, "renderDeleteMessage", (isFile, template) => {
      let message;
      const isProperties = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES;

      if (isProperties) {
        message = isFile ? 'fileMetadataRemoveCustomTemplateConfirm' : 'folderMetadataRemoveCustomTemplateConfirm';
      } else {
        message = isFile ? 'fileMetadataRemoveTemplateConfirm' : 'folderMetadataRemoveTemplateConfirm';
      }

      return React.createElement(FormattedMessage, _extends({}, messages[message], {
        values: {
          metadataName: template.displayName
        }
      }));
    });

    _defineProperty(this, "setDirty", type => {
      const {
        id,
        isCascadingPolicyApplicable,
        onModification
      } = this.props;
      const {
        data,
        isCascadingEnabled,
        isCascadingOverwritten
      } = this.state;
      const hasDataChanged = !isEqual(data, this.props.data);
      let hasCascadingChanged = false;

      if (isCascadingPolicyApplicable) {
        // isCascadingOverwritten always starts out as false, so true signifies a change
        hasCascadingChanged = isCascadingOverwritten || isCascadingEnabled !== this.isCascadingEnabled(this.props);
      } // Callback to parent to tell that something is dirty


      if (onModification) {
        onModification(id, hasDataChanged || hasCascadingChanged, type);
      }
    });

    _defineProperty(this, "collapsibleRef", React.createRef());

    _defineProperty(this, "toggleIsEditing", () => {
      this.setState(prevState => ({
        isEditing: !prevState.isEditing
      }));
    });

    _defineProperty(this, "renderEditButton", () => {
      const {
        intl,
        isDirty
      } = this.props;
      const {
        isBusy
      } = this.state;
      const canEdit = this.canEdit();
      const isEditing = this.isEditing();
      const editClassName = classNames('metadata-instance-editor-instance-edit', {
        'metadata-instance-editor-instance-is-editing': isEditing
      });

      if (canEdit && !isDirty && !isBusy) {
        const metadataLabelEditText = intl.formatMessage(messages.metadataEditTooltip);
        return React.createElement(Tooltip, {
          position: "top-left",
          text: metadataLabelEditText
        }, React.createElement(PlainButton, {
          "aria-label": metadataLabelEditText,
          "aria-pressed": isEditing,
          className: editClassName,
          "data-resin-target": "metadata-instanceedit",
          onClick: this.toggleIsEditing,
          type: "button"
        }, React.createElement(IconEdit, null)));
      }

      return null;
    });

    this.state = this.getState(props);
    this.fieldKeyToTypeMap = createFieldKeyToTypeMap(props.template.fields);
  }

  componentDidUpdate(_ref2, prevState) {
    let {
      hasError: prevHasError,
      isDirty: prevIsDirty
    } = _ref2;
    const currentElement = this.collapsibleRef.current;
    const {
      hasError,
      isDirty
    } = this.props;
    const {
      isEditing
    } = prevState;

    if (currentElement && this.state.shouldConfirmRemove) {
      scrollIntoView(currentElement, {
        block: 'start',
        behavior: 'smooth'
      });
    }

    if (hasError && hasError !== prevHasError) {
      // If hasError is true, which means an error occurred while
      // doing a network operation and hence hide the busy indicator
      // Saving also disables isEditing, so need to enable that back.
      // isDirty remains as it was before.
      this.setState({
        isBusy: false,
        isEditing: true
      });
    } else if (prevIsDirty && !isDirty) {
      // If the form was dirty and now its not dirty
      // we know a successful save may have happened.
      // We don't modify isEditing here because we maintain the
      // prior state for that. If we came here from a save
      // success then save already disabled isEditing.
      if (isEditing) {
        // We are still editing so don't reset it
        this.setState({
          isBusy: false
        });
      } else {
        // For a successfull save we reset cascading overwrite radio
        this.setState({
          isBusy: false,
          isCascadingOverwritten: false
        });
      }
    }
  }
  /**
   * Undo any changes made
   *
   * @return {void}
   */


  /**
   * Returns the state from props
   *
   * @return {Object} - react state
   */
  getState(props) {
    return {
      data: cloneDeep(props.data),
      errors: {},
      isBusy: false,
      isCascadingEnabled: this.isCascadingEnabled(props),
      isCascadingOverwritten: false,
      isEditing: false,
      shouldConfirmRemove: false,
      shouldShowCascadeOptions: false
    };
  }
  /**
   * Returns the card title with possible error mark
   *
   * @return {Object} - react title element
   */


  getTitle() {
    const {
      cascadePolicy = {},
      hasError,
      isCascadingPolicyApplicable,
      template
    } = this.props;
    const isProperties = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES;
    const type = isCascadingPolicyApplicable && cascadePolicy.id ? 'cascade' : 'default';
    return React.createElement("span", {
      className: "metadata-instance-editor-instance-title"
    }, React.createElement(IconMetadataColored, {
      type: type
    }), React.createElement("span", {
      className: classNames('metadata-instance-editor-instance-title-text', {
        'metadata-instance-editor-instance-has-error': hasError
      })
    }, isProperties ? React.createElement(FormattedMessage, messages.customTitle) : template.displayName), hasError && React.createElement(IconAlertCircle, {
      color: bdlWatermelonRed
    }));
  }
  /**
   * Render the correct delete message to show based on custom metadata and file/folder metadata
   */


  /**
   * Get the delete confirmation message base on the template key
   */
  getConfirmationMessage() {
    const {
      template,
      isCascadingPolicyApplicable
    } = this.props;
    const isFile = !isCascadingPolicyApplicable;
    return this.renderDeleteMessage(isFile, template);
  }
  /**
   * Evaluates if the metadata was changed or cascading policy
   * altered or enabled.
   *
   * @return {void}
   */


  /**
   * Determines if cascading policy is enabled based on
   * whether it has an id or not.
   *
   * @param {Object} props - component props
   * @return {boolean} true if cascading policy is enabled
   */
  isCascadingEnabled(props) {
    if (props.cascadePolicy) {
      return !!props.cascadePolicy.id;
    }

    return false;
  }
  /**
   * Toggles the edit mode
   *
   * @private
   * @return {void}
   */


  /**
   * Creates JSON Patch operations from the passed in
   * data while comparing it to the original data from props.
   *
   * Only diffs at the root level and primitives.
   *
   * @param {*} currentData - the latest changes by the user
   * @param {*} originalData - the original values
   * @return {Array} - JSON patch operations
   */
  createJSONPatch(currentData, originalData) {
    const ops = [];
    const data = cloneDeep(currentData); // clone the data for mutation
    // Iterate over the original data and find keys that have changed.
    // Also remove them from the data object to only leave new keys.

    Object.keys(originalData).forEach(key => {
      const type = this.fieldKeyToTypeMap[key];
      const originalValue = getValue(originalData, key, type);
      const path = "/".concat(key);

      if (Object.prototype.hasOwnProperty.call(data, key)) {
        const value = getValue(data, key, type); // Only register changed data

        if (!isEqual(value, originalValue)) {
          // Add a test OP for each replaces
          ops.push({
            op: JSON_PATCH_OP_TEST,
            path,
            value: originalValue
          });
          ops.push({
            op: JSON_PATCH_OP_REPLACE,
            path,
            value
          });
        }
      } else {
        // Key was removed
        // Add a test OP for removes
        ops.push({
          op: JSON_PATCH_OP_TEST,
          path,
          value: originalValue
        });
        ops.push({
          op: JSON_PATCH_OP_REMOVE,
          path
        });
      }

      delete data[key];
    }); // Iterate over the remaining keys that are new.

    Object.keys(data).forEach(key => {
      const type = this.fieldKeyToTypeMap[key];
      const value = getValue(data, key, type);
      ops.push({
        op: JSON_PATCH_OP_ADD,
        path: "/".concat(key),
        value
      });
    });
    return ops;
  }
  /**
   * Utility function to determine if instance is editable
   *
   * @return {boolean} true if editable
   */


  canEdit() {
    const {
      canEdit,
      onModification,
      onRemove,
      onSave
    } = this.props;
    return canEdit && typeof onRemove === 'function' && typeof onSave === 'function' && typeof onModification === 'function';
  }
  /**
   * Utility function to determine if instance is in edit mode
   *
   * @return {boolean} true if editing
   */


  isEditing() {
    const {
      isEditing
    } = this.state;
    return this.canEdit() && isEditing;
  }

  render() {
    const {
      cascadePolicy = {},
      isDirty,
      isCascadingPolicyApplicable,
      isOpen,
      template
    } = this.props;
    const {
      fields = []
    } = template;
    const {
      data,
      errors,
      isBusy,
      isCascadingEnabled,
      shouldConfirmRemove,
      shouldShowCascadeOptions,
      isCascadingOverwritten
    } = this.state;
    const isProperties = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES;
    const isEditing = this.isEditing();

    if (!template || isHidden(template)) {
      return null;
    } // Animate short and tall cards at consistent speeds.


    const animationDuration = (fields.length + 1) * 50;
    return React.createElement("div", {
      ref: this.collapsibleRef
    }, React.createElement(Collapsible, {
      animationDuration: animationDuration,
      buttonProps: {
        [RESIN_TAG_TARGET]: 'metadata-card'
      },
      hasStickyHeader: true,
      headerActionItems: this.renderEditButton(),
      isBordered: true,
      isOpen: isOpen,
      title: this.getTitle()
    }, shouldConfirmRemove && React.createElement(LoadingIndicatorWrapper, {
      isLoading: isBusy
    }, React.createElement(MetadataInstanceConfirmDialog, {
      confirmationMessage: this.getConfirmationMessage(),
      onCancel: this.onConfirmCancel,
      onConfirm: this.onRemove
    })), !shouldConfirmRemove && React.createElement(LoadingIndicatorWrapper, {
      isLoading: isBusy
    }, React.createElement(Form, {
      onValidSubmit: isDirty ? this.onSave : noop
    }, React.createElement("div", {
      className: "metadata-instance-editor-instance"
    }, isCascadingPolicyApplicable && React.createElement(CascadePolicy, {
      canEdit: isEditing && !!cascadePolicy.canEdit,
      isCascadingEnabled: isCascadingEnabled,
      isCascadingOverwritten: isCascadingOverwritten,
      isCustomMetadata: isProperties,
      onCascadeModeChange: this.onCascadeModeChange,
      onCascadeToggle: this.onCascadeToggle,
      shouldShowCascadeOptions: shouldShowCascadeOptions
    }), isProperties ? React.createElement(CustomInstance, {
      canEdit: isEditing,
      data: data,
      onFieldChange: this.onFieldChange,
      onFieldRemove: this.onFieldRemove
    }) : React.createElement(TemplatedInstance, {
      canEdit: isEditing,
      data: data,
      errors: errors,
      onFieldChange: this.onFieldChange,
      onFieldRemove: this.onFieldRemove,
      template: template
    })), isEditing && React.createElement(Footer, {
      onCancel: this.onCancel,
      onRemove: this.onConfirmRemove,
      showSave: isDirty
    })))));
  }

}

_defineProperty(Instance, "defaultProps", {
  data: {},
  isDirty: false
});

export { Instance as InstanceBase };
export default injectIntl(Instance);
//# sourceMappingURL=Instance.js.map