function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import isEqual from 'lodash/isEqual';
import { FormattedMessage, injectIntl } from 'react-intl';
import DatalistItem from '../../components/datalist-item';
import SelectorDropdown from '../../components/selector-dropdown';
import SearchForm from '../../components/search-form/SearchForm';
import PlainButton from '../../components/plain-button';
import LoadingIndicator from '../../components/loading-indicator';
import { Flyout, Overlay } from '../../components/flyout';
import MenuToggle from '../../components/dropdown-menu/MenuToggle';
import messages from './messages';
import TEMPLATE_CUSTOM_PROPERTIES from './constants';
import './TemplateDropdown.scss';

const getAvailableTemplates = (allTemplates, usedTemplates) => allTemplates.filter(template => usedTemplates.findIndex(usedTemplate => usedTemplate.templateKey === template.templateKey && usedTemplate.scope === template.scope) === -1);

class TemplateDropdown extends React.PureComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "getDropdown", () => {
      const {
        isDropdownBusy,
        onAdd,
        activeTemplate,
        defaultTemplateIcon,
        activeTemplateIcon,
        templates: allTemplates,
        title,
        usedTemplates
      } = this.props;
      const {
        templates
      } = this.state;
      const hasUnusedTemplates = getAvailableTemplates(allTemplates, usedTemplates).length > 0;
      const hasTemplates = allTemplates.length > 0;
      const hasResults = templates.length > 0;
      let indicatorOrMessage = null;

      if (isDropdownBusy) {
        indicatorOrMessage = React.createElement(LoadingIndicator, {
          className: "metadata-instance-editor-template-message template-dropdown-loading-indicator"
        });
      } else if (!hasTemplates || !hasUnusedTemplates || !hasResults) {
        let message = {
          id: ''
        };

        if (!hasTemplates) {
          message = messages.metadataTemplatesServerHasNoTemplates;
        } else if (!hasUnusedTemplates) {
          message = messages.metadataTemplatesNoRemainingTemplates;
        } else if (!hasResults) {
          message = messages.metadataTemplatesNoResults;
        }

        indicatorOrMessage = React.createElement("i", {
          className: "metadata-instance-editor-template-message"
        }, React.createElement(FormattedMessage, message));
      }

      const renderedTemplates = templates.map(template => {
        const isTemplateSelected = activeTemplate && activeTemplate.id === template.id;
        const buttonClassName = classNames('metadata-template-dropdown-select-template', {
          'metadata-template-dropdown-is-selected': isTemplateSelected
        });
        return React.createElement(DatalistItem, {
          key: template.id
        }, React.createElement(PlainButton, {
          className: buttonClassName,
          tabIndex: "-1",
          type: "button"
        }, isTemplateSelected ? activeTemplateIcon : defaultTemplateIcon, this.getTemplateName(template)));
      });
      return React.createElement(React.Fragment, null, React.createElement(SelectorDropdown, {
        className: "metadata-instance-editor-template-dropdown-menu",
        title: title,
        isAlwaysOpen: true,
        onSelect: index => {
          onAdd(templates[index]);
        },
        selector: this.getSelector(),
        shouldScroll: true
      }, indicatorOrMessage ? null : renderedTemplates), indicatorOrMessage);
    });

    _defineProperty(this, "getSelector", () => {
      const {
        intl
      } = this.props;
      const {
        filterText
      } = this.state;
      return React.createElement(SearchForm, {
        "data-resin-target": "metadata-templatesearch",
        label: "",
        onChange: this.handleUserInput,
        placeholder: intl.formatMessage(messages.metadataTemplateSearchPlaceholder),
        shouldPreventClearEventPropagation: true,
        type: "text",
        useClearButton: true,
        value: filterText
      });
    });

    _defineProperty(this, "handleUserInput", userInput => {
      const {
        templates: allTemplates,
        usedTemplates
      } = this.props;
      const filterText = userInput;
      const templates = getAvailableTemplates(allTemplates, usedTemplates);
      this.setState({
        filterText,
        templates: templates.filter(template => {
          const label = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES ? messages.customTitle.defaultMessage : template.displayName;
          return label.toLowerCase().includes(filterText.toLowerCase());
        })
      });
    });

    _defineProperty(this, "onOpen", () => {
      const {
        onDropdownToggle,
        templates,
        usedTemplates
      } = this.props;

      if (onDropdownToggle) {
        onDropdownToggle(true);
      }

      this.setState({
        isDropdownOpen: true,
        filterText: '',
        templates: getAvailableTemplates(templates, usedTemplates)
      });
    });

    _defineProperty(this, "onClose", () => {
      const {
        onDropdownToggle
      } = this.props;

      if (onDropdownToggle) {
        onDropdownToggle(false);
      }

      this.setState({
        isDropdownOpen: false
      });
    });

    _defineProperty(this, "renderEntryButton", () => {
      const {
        entryButton
      } = this.props;
      const {
        isDropdownOpen
      } = this.state;
      const buttonToggleClassName = classNames('lnk', {
        'is-toggled': isDropdownOpen
      });

      if (entryButton) {
        return entryButton;
      }

      return React.createElement(PlainButton, {
        "data-resin-target": "metadata-templateaddmenu",
        className: buttonToggleClassName,
        type: "button"
      }, React.createElement(MenuToggle, null, React.createElement(FormattedMessage, messages.metadataTemplateAdd)));
    });

    this.state = {
      isDropdownOpen: false,
      filterText: '',
      templates: getAvailableTemplates(props.templates, props.usedTemplates)
    };
  }
  /**
   * Updates the state
   *
   * @param {Object} prevProps - next props
   * @return {void}
   */


  componentDidUpdate(_ref) {
    let {
      templates: prevTemplates,
      usedTemplates: prevUsedTemplates
    } = _ref;
    const {
      templates,
      usedTemplates
    } = this.props;

    if (!isEqual(prevTemplates, templates) || !isEqual(prevUsedTemplates, usedTemplates)) {
      this.setState({
        templates: getAvailableTemplates(templates, usedTemplates)
      });
    }
  }

  /**
   * Returns template display name.
   * For custom metadata we have it on the client.
   *
   * @return {React.Node} - string or formatted name
   */
  getTemplateName(template) {
    return template.templateKey === TEMPLATE_CUSTOM_PROPERTIES ? React.createElement(FormattedMessage, _extends({
      className: "template-display-name"
    }, messages.customTitle)) : React.createElement("div", {
      className: "template-display-name"
    }, template.displayName);
  }
  /**
   * Updates the filter text and filters the results
   *
   * @param {UserInput} userInput - input value returned from onChangeHandler from SearchForm.js
   * @return {void}
   */


  render() {
    const {
      className
    } = this.props;
    const flyoutClassName = classNames('metadata-instance-editor-template-dropdown-flyout', className);
    return React.createElement(Flyout, {
      className: flyoutClassName,
      closeOnClick: true,
      closeOnClickOutside: true,
      constrainToWindowWithPin: true,
      onClose: this.onClose,
      onOpen: this.onOpen,
      position: "bottom-left",
      shouldDefaultFocus: true
    }, this.renderEntryButton(), React.createElement(Overlay, null, this.getDropdown()));
  }

}

export { TemplateDropdown as TemplateDropdownBase };
export default injectIntl(TemplateDropdown);
//# sourceMappingURL=TemplateDropdown.js.map