/**
 * 
 * @file Pagination controls for navigation
 * @author Box
 */
import React from 'react';
import { FormattedMessage } from 'react-intl';
import PaginationMenu from './PaginationMenu';
import Button from '../../components/button';
import ButtonGroup from '../../components/button-group';
import IconPageBack from '../../icons/general/IconPageBack';
import IconPageForward from '../../icons/general/IconPageForward';
import Tooltip from '../../elements/common/Tooltip';
import messages from '../../elements/common/messages';
const PAGE_ICON_STYLE = {
  height: 9,
  width: 6
};

const PaginationControls = (_ref) => {
  let {
    handleNextClick,
    handlePreviousClick,
    hasNextPage,
    hasPreviousPage,
    isOffsetBasedPagination = true,
    onPageClick,
    pageCount = 0,
    pageNumber = 0
  } = _ref;
  return React.createElement("div", {
    className: "bdl-Pagination"
  }, isOffsetBasedPagination && React.createElement("div", {
    className: "bdl-Pagination-count"
  }, React.createElement(PaginationMenu, {
    onPageClick: onPageClick,
    pageCount: pageCount,
    pageNumber: pageNumber
  })), React.createElement(ButtonGroup, {
    className: "bdl-Pagination-nav"
  }, React.createElement(Tooltip, {
    isDisabled: !hasPreviousPage,
    text: React.createElement(FormattedMessage, messages.previousPage)
  }, React.createElement(Button, {
    isDisabled: !hasPreviousPage,
    onClick: handlePreviousClick
  }, React.createElement(IconPageBack, PAGE_ICON_STYLE))), React.createElement(Tooltip, {
    isDisabled: !hasNextPage,
    text: React.createElement(FormattedMessage, messages.nextPage)
  }, React.createElement(Button, {
    isDisabled: !hasNextPage,
    onClick: handleNextClick
  }, React.createElement(IconPageForward, PAGE_ICON_STYLE)))));
};

export default PaginationControls;
//# sourceMappingURL=PaginationControls.js.map