function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import * as React from 'react';
import classNames from 'classnames';
import noop from 'lodash/noop'; // @ts-ignore flow import

import PresenceAvatar from './PresenceAvatar';
import PresenceAvatarTooltipContent from './PresenceAvatarTooltipContent';
import Tooltip, { TooltipPosition } from '../../components/tooltip';
import './PresenceAvatarList.scss';

function PresenceAvatarList(props, ref) {
  const {
    avatarAttributes,
    className,
    collaborators,
    hideAdditionalCount,
    hideTooltips,
    maxAdditionalCollaborators = 99,
    maxDisplayedAvatars = 3,
    onAvatarMouseEnter = noop,
    onAvatarMouseLeave = noop
  } = props,
        rest = _objectWithoutProperties(props, ["avatarAttributes", "className", "collaborators", "hideAdditionalCount", "hideTooltips", "maxAdditionalCollaborators", "maxDisplayedAvatars", "onAvatarMouseEnter", "onAvatarMouseLeave"]);

  const [activeTooltip, setActiveTooltip] = React.useState(null);

  const hideTooltip = () => {
    setActiveTooltip(null);

    if (onAvatarMouseLeave) {
      onAvatarMouseLeave();
    }
  };

  const showTooltip = id => {
    setActiveTooltip(id);

    if (onAvatarMouseEnter) {
      onAvatarMouseEnter(id);
    }
  };

  if (!collaborators.length) {
    return null;
  }

  return React.createElement("div", _extends({
    ref: ref,
    className: classNames('bdl-PresenceAvatarList', className)
  }, rest), collaborators.slice(0, maxDisplayedAvatars).map(collaborator => {
    const {
      id,
      avatarUrl,
      name,
      isActive,
      interactedAt,
      interactionType
    } = collaborator;
    return React.createElement(Tooltip, {
      key: id,
      isShown: !hideTooltips && activeTooltip === id,
      position: TooltipPosition.BOTTOM_CENTER,
      text: React.createElement(PresenceAvatarTooltipContent, {
        name: name,
        interactedAt: interactedAt,
        interactionType: interactionType,
        isActive: isActive
      })
    }, React.createElement(PresenceAvatar, _extends({
      "aria-hidden": "true",
      avatarUrl: avatarUrl,
      id: id,
      isActive: isActive,
      name: name,
      onBlur: hideTooltip,
      onFocus: () => showTooltip(id),
      onMouseEnter: () => showTooltip(id),
      onMouseLeave: hideTooltip
    }, avatarAttributes)));
  }), !hideAdditionalCount && collaborators.length > maxDisplayedAvatars && React.createElement("div", _extends({
    className: classNames('bdl-PresenceAvatarList-count', 'avatar') // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
    ,
    tabIndex: 0
  }, avatarAttributes), collaborators.length - maxDisplayedAvatars > maxAdditionalCollaborators ? "".concat(maxAdditionalCollaborators, "+") : "+".concat(collaborators.length - maxDisplayedAvatars)));
}

export { PresenceAvatarList as PresenceAvatarListComponent };
export default React.forwardRef(PresenceAvatarList);
//# sourceMappingURL=PresenceAvatarList.js.map