function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import { Flyout, Overlay } from '../../../components/flyout';
import Button from '../../../components/button/Button';
import MenuToggle from '../../../components/dropdown-menu/MenuToggle';
import IconMetadataColumns from '../../../icons/metadata-view/IconMetadataColumns';
import ColumnButtonOverlay from './ColumnButtonOverlay';
import messages from '../messages';

class ColumnButton extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "onClose", () => {
      this.setState({
        isColumnMenuOpen: false
      });
    });

    _defineProperty(this, "onOpen", () => {
      this.setState({
        isColumnMenuOpen: true
      });
    });

    _defineProperty(this, "toggleColumnButton", () => {
      this.setState({
        isColumnMenuOpen: !this.state.isColumnMenuOpen
      });
    });

    _defineProperty(this, "getNumberOfHiddenColumns", () => {
      const {
        columns
      } = this.props;
      return columns ? columns.reduce((total, column) => {
        if (!column.isShown) {
          return total + 1;
        }

        return total;
      }, 0) : 0;
    });

    this.state = {
      isColumnMenuOpen: false
    };
  }

  render() {
    const {
      template,
      columns,
      onColumnChange
    } = this.props;
    const {
      isColumnMenuOpen
    } = this.state;
    const numberOfHiddenColumns = this.getNumberOfHiddenColumns();
    const buttonClasses = classNames('query-bar-button', numberOfHiddenColumns !== 0 ? 'is-active' : '');
    let columnsButtonText;

    if (numberOfHiddenColumns === 0) {
      columnsButtonText = React.createElement(FormattedMessage, messages.columnsButtonText);
    } else {
      columnsButtonText = React.createElement(FormattedMessage, _extends({
        values: {
          count: numberOfHiddenColumns
        }
      }, messages.columnsHiddenButtonText));
    }

    return React.createElement(Flyout, {
      className: "query-bar-column-dropdown-flyout",
      closeOnClick: true,
      closeOnClickOutside: true,
      onClose: this.onClose,
      onOpen: this.onOpen,
      position: "bottom-right"
    }, React.createElement(Button, {
      className: buttonClasses,
      isDisabled: template === undefined,
      onClick: this.toggleColumnButton,
      type: "button"
    }, React.createElement(MenuToggle, null, React.createElement(IconMetadataColumns, null), React.createElement("span", {
      className: "button-label"
    }, columnsButtonText))), React.createElement(Overlay, null, isColumnMenuOpen ? React.createElement(ColumnButtonOverlay, {
      columns: columns,
      onColumnChange: onColumnChange
    }) : React.createElement("div", null)));
  }

}

export default ColumnButton;
//# sourceMappingURL=ColumnButton.js.map