function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import uniqueId from 'lodash/uniqueId';
import cloneDeep from 'lodash/cloneDeep';
import Checkbox from '../../../components/checkbox/Checkbox';
import DraggableList from '../../../components/draggable-list';
import PortaledDraggableListItem from '../../../components/draggable-list/PortaledDraggableListItem';
import PrimaryButton from '../../../components/primary-button/PrimaryButton';
import reorder from '../../../components/draggable-list/draggable-list-utils/reorder';
import messages from '../messages';

class ColumnButtonOverlay extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "onDragEnd", (sourceIndex, destinationIndex) => {
      const {
        pendingColumns
      } = this.state;
      const columns = reorder(pendingColumns, sourceIndex, destinationIndex);
      this.setState({
        pendingColumns: cloneDeep(columns)
      });
    });

    _defineProperty(this, "updatePendingColumns", column => {
      const {
        pendingColumns
      } = this.state;
      const pendingColumnsCopy = cloneDeep(pendingColumns);

      const newColumn = _objectSpread({}, column, {
        isShown: !column.isShown
      });

      const foundIndex = pendingColumnsCopy.findIndex(originalColumn => originalColumn.id === column.id);
      pendingColumnsCopy[foundIndex] = newColumn;
      this.setState({
        pendingColumns: pendingColumnsCopy
      });
    });

    _defineProperty(this, "applyFilters", () => {
      const {
        onColumnChange
      } = this.props;
      const {
        pendingColumns
      } = this.state;

      if (onColumnChange) {
        onColumnChange(pendingColumns);
      }
    });

    _defineProperty(this, "getNumberOfHiddenColumns", () => {
      const {
        columns
      } = this.props;
      return columns ? columns.reduce((total, column) => {
        if (!column.isShown) {
          return total + 1;
        }

        return total;
      }, 0) : 0;
    });

    this.state = {
      listId: uniqueId(),
      pendingColumns: props.columns ? cloneDeep(props.columns) : []
    };
  }

  render() {
    const {
      listId,
      pendingColumns
    } = this.state;
    return React.createElement("div", {
      className: "column-button-dropdown"
    }, React.createElement("div", {
      className: "column-button-dropdown-header"
    }, React.createElement(DraggableList, {
      className: "draggable-list-example",
      listId: listId,
      onDragEnd: this.onDragEnd
    }, pendingColumns.map((item, index) => {
      return React.createElement(PortaledDraggableListItem, {
        id: item.id,
        index: index,
        isDraggableViaHandle: true,
        key: index
      }, React.createElement(Checkbox, {
        isChecked: item.isShown,
        label: item.displayName,
        name: item.displayName,
        onChange: () => this.updatePendingColumns(item)
      }));
    }))), React.createElement("div", {
      className: "column-button-dropdown-footer"
    }, React.createElement(PrimaryButton, {
      type: "button",
      onClick: this.applyFilters
    }, React.createElement(FormattedMessage, messages.applyFiltersButtonText))));
  }

}

export default ColumnButtonOverlay;
//# sourceMappingURL=ColumnButtonOverlay.js.map