function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import MetadataDefaultBadge from '../../../icons/badges/MetadataDefaultBadge';
import MetadataActiveBadge from '../../../icons/badges/MetadataActiveBadge';
import TemplateDropdown from '../../metadata-instance-editor/TemplateDropdown';
import Button from '../../../components/button/Button';
import MenuToggle from '../../../components/dropdown-menu/MenuToggle';
import messages from '../messages';
import LoadingIndicator from '../../../components/loading-indicator';

class TemplateButton extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isTemplateMenuOpen: false
    });

    _defineProperty(this, "toggleTemplateDropdownButton", () => {
      this.setState({
        isTemplateMenuOpen: !this.state.isTemplateMenuOpen
      });
    });

    _defineProperty(this, "updateActiveTemplate", template => {
      const {
        onTemplateChange
      } = this.props;

      if (onTemplateChange) {
        onTemplateChange(template);
      }
    });

    _defineProperty(this, "renderEntryButton", () => {
      const {
        templates,
        activeTemplate
      } = this.props;
      let icon;
      let text;
      const isLoadingTemplates = !templates;
      const hasTemplates = templates && templates.length > 0;

      if (isLoadingTemplates) {
        icon = React.createElement(LoadingIndicator, {
          className: "loading-indicator"
        });
        text = React.createElement(FormattedMessage, messages.templatesLoadingButtonText);
      } else if (!hasTemplates) {
        text = React.createElement(FormattedMessage, messages.noTemplatesText);
      } else if (activeTemplate) {
        icon = React.createElement(MetadataActiveBadge, null);
        text = activeTemplate.displayName;
      } else if (!activeTemplate) {
        icon = React.createElement(MetadataDefaultBadge, null);
        text = React.createElement(FormattedMessage, messages.templatesButtonText);
      }

      const buttonClasses = classNames('query-bar-button', {
        'is-active': activeTemplate
      });
      return React.createElement(Button, {
        className: buttonClasses,
        isDisabled: !templates || templates.length === 0,
        type: "button",
        onClick: this.toggleTemplateDropdownButton
      }, React.createElement(MenuToggle, null, icon, React.createElement("span", {
        className: "button-label"
      }, text)));
    });

    _defineProperty(this, "renderTitle", () => React.createElement("div", {
      className: "template-dropdown-list-title"
    }, React.createElement(FormattedMessage, messages.metadataViewTemplateListHeaderTitle)));
  }

  render() {
    const {
      activeTemplate,
      templates,
      usedTemplates
    } = this.props;
    return React.createElement(TemplateDropdown, {
      className: "query-bar-template-dropdown-flyout",
      defaultTemplateIcon: React.createElement(MetadataDefaultBadge, {
        className: "template-list-item-badge"
      }),
      title: this.renderTitle(),
      onAdd: this.updateActiveTemplate,
      activeTemplate: activeTemplate,
      activeTemplateIcon: React.createElement(MetadataActiveBadge, {
        className: "template-list-item-badge"
      }),
      templates: templates || [],
      usedTemplates: usedTemplates,
      entryButton: this.renderEntryButton()
    });
  }

}

_defineProperty(TemplateButton, "defaultProps", {
  usedTemplates: []
});

export default TemplateButton;
//# sourceMappingURL=TemplateButton.js.map