function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import uniqueId from 'lodash/uniqueId';
import cloneDeep from 'lodash/cloneDeep';
import IconMetadataFilter from '../../../../icons/metadata-view/IconMetadataFilter';
import Condition from './Condition';
import Button from '../../../../components/button/Button';
import PrimaryButton from '../../../../components/primary-button/PrimaryButton';
import MenuToggle from '../../../../components/dropdown-menu/MenuToggle';
import { Flyout, Overlay } from '../../../../components/flyout';
import { AND, OR, COLUMN_OPERATORS } from '../../constants';
import messages from '../../messages';

class FilterButton extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "onClose", () => {
      this.setState({
        isMenuOpen: false
      });
    });

    _defineProperty(this, "onOpen", () => {
      this.setState({
        isMenuOpen: true
      });
    });

    _defineProperty(this, "toggleButton", () => {
      this.setState({
        isMenuOpen: !this.state.isMenuOpen
      });
    });

    _defineProperty(this, "createCondition", () => {
      const conditionID = uniqueId();
      const {
        columns
      } = this.props;

      if (columns && columns.length > 0) {
        const firstColumn = columns[0];
        const operator = COLUMN_OPERATORS[firstColumn.type][0].key;
        return {
          columnId: firstColumn.id,
          id: conditionID,
          operator,
          values: []
        };
      }

      throw new Error('Columns Required');
    });

    _defineProperty(this, "addFilter", () => {
      const newCondition = this.createCondition();
      this.setState({
        transientConditions: [...this.state.transientConditions, newCondition],
        hasUserSubmitted: false
      });
    });

    _defineProperty(this, "applyFilters", () => {
      const {
        onFilterChange
      } = this.props;
      const {
        transientConditions
      } = this.state;
      const areAllValid = this.areAllValid();

      if (areAllValid) {
        if (onFilterChange) {
          onFilterChange(transientConditions);
        }

        this.setState({
          isMenuOpen: false,
          transientConditions: [],
          hasUserSubmitted: false
        });
      } else {
        this.setState({
          hasUserSubmitted: true
        });
      }
    });

    _defineProperty(this, "updateConditionState", (conditionId, updateCondition) => {
      const {
        transientConditions
      } = this.state;
      let newConditionIndex = 0;
      const conditionToUpdate = transientConditions.find((currentCondition, index) => {
        newConditionIndex = index;
        return currentCondition.id === conditionId;
      });

      let newCondition = _objectSpread({}, conditionToUpdate);

      newCondition = updateCondition(newCondition);
      const newConditions = cloneDeep(transientConditions);
      newConditions[newConditionIndex] = newCondition;
      this.setState({
        transientConditions: newConditions
      });
    });

    _defineProperty(this, "handleColumnChange", (condition, columnId) => {
      const {
        columns
      } = this.props;
      const {
        transientConditions
      } = this.state;
      let newConditionIndex = 0;
      const conditionToUpdate = transientConditions.find((currentCondition, index) => {
        newConditionIndex = index;
        return currentCondition.id === condition.id;
      });
      const column = columns && columns.find(c => c.id === columnId);

      if (!column) {
        throw new Error('Invalid Column.id');
      }

      const type = column && column.type;
      const operator = COLUMN_OPERATORS[type][0].key;

      const newCondition = _objectSpread({}, conditionToUpdate, {
        columnId,
        operator,
        values: []
      });

      const newConditions = cloneDeep(transientConditions);
      newConditions[newConditionIndex] = newCondition;
      this.setState({
        transientConditions: newConditions
      });
    });

    _defineProperty(this, "handleOperatorChange", (conditionId, value) => {
      this.updateConditionState(conditionId, condition => {
        condition.operator = value;
        return condition;
      });
    });

    _defineProperty(this, "handleValueChange", (conditionId, values) => {
      this.updateConditionState(conditionId, condition => {
        condition.values = values;
        return condition;
      });
    });

    _defineProperty(this, "handleConnectorChange", option => {
      const convert = str => {
        switch (str) {
          case AND:
            return AND;

          case OR:
            return OR;

          default:
            throw new Error('Invalid connector');
        }
      };

      this.setState({
        selectedConnector: convert(option.value)
      });
    });

    _defineProperty(this, "deleteCondition", index => {
      const {
        transientConditions
      } = this.state;
      const conditionsAfterDeletion = transientConditions.filter((condition, conditionIndex) => {
        return conditionIndex !== index;
      });
      this.setState({
        transientConditions: conditionsAfterDeletion
      });
    });

    _defineProperty(this, "areAllValid", () => {
      const {
        transientConditions
      } = this.state;
      let areAllValid = true;
      transientConditions.forEach(condition => {
        if (condition.values.length === 0) {
          areAllValid = false;
        }
      });
      return areAllValid;
    });

    _defineProperty(this, "shouldClose", event => {
      // The current approach assumes that the Apply button contains at most one child element.
      const areAllValid = this.areAllValid();

      if (event && event.target && areAllValid) {
        if (event.target.classList.contains('apply-filters-button') || event.target.parentNode.classList.contains('apply-filters-button')) {
          return true;
        }
      }

      return false;
    });

    this.state = {
      hasUserSubmitted: false,
      isMenuOpen: false,
      selectedConnector: AND,
      transientConditions: cloneDeep(this.props.conditions)
    };
  }

  componentDidUpdate(prevProps, prevState) {
    const {
      columns,
      conditions
    } = this.props;
    const {
      isMenuOpen,
      transientConditions
    } = this.state;
    const {
      isMenuOpen: prevIsMenuOpen
    } = prevState;
    const wasFlyoutOpened = isMenuOpen && !prevIsMenuOpen;

    if (wasFlyoutOpened) {
      const hasUnsavedConditions = transientConditions.length > 0;
      const shouldSetInitialCondition = conditions.length === 0;

      if (!hasUnsavedConditions) {
        if (shouldSetInitialCondition) {
          const newConditions = columns && columns.length === 0 ? [] : [this.createCondition()];
          this.setState({
            transientConditions: newConditions
          });
        } else {
          this.setState({
            transientConditions: cloneDeep(this.props.conditions)
          });
        }
      }
    }
  }

  render() {
    const {
      columns,
      conditions
    } = this.props;
    const {
      transientConditions,
      hasUserSubmitted,
      isMenuOpen,
      selectedConnector
    } = this.state;
    const numberOfConditions = conditions.length;
    const areAllValid = this.areAllValid();
    const buttonClasses = classNames('query-bar-button', numberOfConditions !== 0 && areAllValid ? 'is-active' : '');
    const isFilterDisabled = !columns || columns.length === 0;
    return React.createElement(Flyout, {
      className: "query-bar-filter-dropdown-flyout",
      closeOnClick: true,
      closeOnClickOutside: true,
      closeOnClickPredicate: this.shouldClose,
      onClose: this.onClose,
      onOpen: this.onOpen,
      overlayIsVisible: isMenuOpen,
      portaledClasses: ['pika-single']
      /* Element in DatePicker package  */
      ,
      position: "bottom-right",
      shouldDefaultFocus: true
    }, React.createElement(Button, {
      className: buttonClasses,
      isDisabled: isFilterDisabled,
      onClick: this.toggleButton,
      type: "button"
    }, React.createElement(MenuToggle, null, React.createElement(IconMetadataFilter, {
      className: "button-icon"
    }), React.createElement("span", {
      className: "button-label"
    }, numberOfConditions === 0 ? React.createElement(FormattedMessage, messages.filtersButtonText) : React.createElement(FormattedMessage, _extends({}, messages.multipleFiltersButtonText, {
      values: {
        number: numberOfConditions
      }
    }))))), React.createElement(Overlay, null, isMenuOpen ? React.createElement("div", {
      className: "filter-button-dropdown"
    }, React.createElement("div", {
      className: "filter-button-dropdown-header"
    }, transientConditions.length === 0 ? React.createElement(FormattedMessage, messages.noFiltersAppliedText) : null, transientConditions.map((condition, index) => {
      return React.createElement(Condition, {
        key: "metadata-view-filter-item-".concat(condition.id),
        hasUserSubmitted: hasUserSubmitted,
        columns: columns,
        condition: condition,
        deleteCondition: this.deleteCondition,
        index: index,
        onColumnChange: this.handleColumnChange,
        onConnectorChange: this.handleConnectorChange,
        onOperatorChange: this.handleOperatorChange,
        onValueChange: this.handleValueChange,
        selectedConnector: selectedConnector
      });
    })), React.createElement("div", {
      className: "filter-button-dropdown-footer"
    }, React.createElement(Button, {
      type: "button",
      onClick: this.addFilter
    }, React.createElement(FormattedMessage, messages.addFilterButtonText)), React.createElement(PrimaryButton, {
      className: "apply-filters-button",
      onClick: this.applyFilters,
      type: "button"
    }, React.createElement(FormattedMessage, messages.applyFiltersButtonText)))) : React.createElement("div", null)));
  }

}

export default FilterButton;
//# sourceMappingURL=FilterButton.js.map