function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import * as React from 'react';
import classNames from 'classnames';
import { injectIntl, FormattedMessage } from 'react-intl';
import { RecordOf } from 'immutable';
import { convertToMs, isToday, isYesterday } from '../../utils/datetime';
import DatalistItem from '../../components/datalist-item';
import Folder16 from '../../icon/fill/Folder16';
import ItemIcon from '../../icons/item-icon';
import { Link } from '../../components/link';
import { TYPE_FILE, TYPE_FOLDER, TYPE_WEBLINK } from '../../constants';
import messages from './messages';
import './QuickSearchItem.scss';
const QUERY_SEPARATOR = '<mark>';

const QuickSearchItem = (_ref) => {
  let {
    className,
    closeDropdown,
    intl,
    itemData,
    parentFolderRenderer,
    shouldNavigateOnItemClick
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["className", "closeDropdown", "intl", "itemData", "parentFolderRenderer", "shouldNavigateOnItemClick"]);

  const {
    formatMessage
  } = intl;
  const {
    extension,
    iconType,
    id,
    name,
    nameWithMarkedQuery,
    parentName,
    sharedLink,
    type,
    updatedBy,
    updatedDate
  } = itemData;
  const updatedDateInMs = convertToMs(updatedDate);
  const markedQueryMatches = [];
  nameWithMarkedQuery.split(QUERY_SEPARATOR).forEach((element, index) => index % 2 === 0 ? markedQueryMatches.push(element) : markedQueryMatches.push(React.createElement("mark", {
    key: index,
    className: "search-term"
  }, element)));
  let itemIconTitle;

  switch (type) {
    case TYPE_WEBLINK:
      itemIconTitle = React.createElement(FormattedMessage, messages.bookmark);
      break;

    case TYPE_FILE:
      itemIconTitle = React.createElement(FormattedMessage, messages.file);
      break;

    case TYPE_FOLDER:
      if (iconType === 'folder-collab') {
        itemIconTitle = React.createElement(FormattedMessage, messages.collaboratedFolder);
      } else if (iconType === 'folder-external') {
        itemIconTitle = React.createElement(FormattedMessage, messages.externalFolder);
      } else {
        itemIconTitle = React.createElement(FormattedMessage, messages.personalFolder);
      }

      break;

    default:
  }

  let updatedText;

  if (isToday(updatedDateInMs)) {
    updatedText = formatMessage(messages.updatedTextToday, {
      user: updatedBy
    });
  } else if (isYesterday(updatedDateInMs)) {
    updatedText = formatMessage(messages.updatedTextYesterday, {
      user: updatedBy
    });
  } else {
    updatedText = formatMessage(messages.updatedText, {
      date: updatedDateInMs,
      user: updatedBy
    });
  }

  let href;
  let targetProps = {};
  const isBoxNote = extension === 'boxnote';

  switch (type) {
    case 'folder':
      href = "/folder/".concat(id);
      break;

    case 'web_link':
      href = "/web_link/".concat(id);
      targetProps = {
        target: '_blank'
      };
      break;

    case 'file':
      // shared link should take precedence over other link types
      if (sharedLink) {
        href = sharedLink;
      } else if (isBoxNote) {
        href = "/notes/".concat(id);
      } else {
        href = "/file/".concat(id);
      }

      if (isBoxNote) targetProps = {
        target: '_blank'
      };
      break;

    default:
  }

  const itemName = href && shouldNavigateOnItemClick ? React.createElement(Link, _extends({
    onClick: e => e.stopPropagation(),
    className: "item-name",
    href: href,
    title: name
  }, targetProps), markedQueryMatches) : React.createElement("span", {
    className: "item-name",
    title: name
  }, markedQueryMatches);
  return React.createElement(DatalistItem, _extends({
    className: classNames('quick-search-item', className)
  }, rest), React.createElement(ItemIcon, {
    iconType: iconType,
    title: itemIconTitle
  }), React.createElement("span", {
    className: "item-info"
  }, itemName, React.createElement("span", {
    className: "item-subtext"
  }, (parentName || parentFolderRenderer) && React.createElement(React.Fragment, null, React.createElement(Folder16, {
    title: React.createElement(FormattedMessage, messages.parentFolder),
    height: 12,
    width: 12
  }), parentFolderRenderer ? parentFolderRenderer(itemData, closeDropdown) : React.createElement("span", {
    className: "parent-folder"
  }, parentName), React.createElement("span", {
    className: "separator"
  }, "\u2022")), React.createElement("span", {
    className: "txt-ellipsis",
    title: updatedText
  }, updatedText))));
};

export default injectIntl(QuickSearchItem);
//# sourceMappingURL=QuickSearchItem.js.map