function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';
import PlainButton from '../../components/plain-button';
import DropdownMenu, { MenuToggle } from '../../components/dropdown-menu';
import { Menu, MenuSeparator, MenuSectionHeader, SelectMenuItem } from '../../components/menu';
import messages from './messages';
import { PEOPLE_WITH_LINK, PEOPLE_IN_COMPANY, PEOPLE_IN_ITEM } from './constants';
import { accessLevelPropType, allowedAccessLevelsPropType } from './propTypes';
import AccessLabel from './AccessLabel';
import RemoveLinkConfirmModal from './RemoveLinkConfirmModal';
const accessLevels = [PEOPLE_WITH_LINK, PEOPLE_IN_COMPANY, PEOPLE_IN_ITEM];

class AccessMenu extends Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isConfirmModalOpen: false
    });

    _defineProperty(this, "openConfirmModal", () => {
      this.setState({
        isConfirmModalOpen: true
      });
    });

    _defineProperty(this, "closeConfirmModal", () => {
      this.setState({
        isConfirmModalOpen: false
      });
    });
  }

  renderMenu() {
    const {
      accessLevel,
      allowedAccessLevels,
      canRemoveLink,
      changeAccessLevel,
      enterpriseName,
      itemType,
      removeLinkButtonProps
    } = this.props;
    return React.createElement(Menu, {
      className: "share-access-menu"
    }, React.createElement(MenuSectionHeader, null, React.createElement(FormattedMessage, messages.accessTypeTitle)), accessLevels.map(level => allowedAccessLevels[level] ? React.createElement(SelectMenuItem, {
      key: level,
      isSelected: level === accessLevel,
      onClick: () => changeAccessLevel(level)
    }, React.createElement(AccessLabel, {
      accessLevel: level,
      enterpriseName: enterpriseName,
      itemType: itemType
    })) : null), canRemoveLink && React.createElement(MenuSeparator, null), canRemoveLink && React.createElement(SelectMenuItem, _extends({
      onClick: this.openConfirmModal
    }, removeLinkButtonProps), React.createElement(FormattedMessage, messages.removeLink)));
  }

  render() {
    const {
      accessDropdownMenuProps,
      accessLevel,
      accessMenuButtonProps,
      enterpriseName,
      itemType,
      removeLink,
      submitting
    } = this.props;
    const {
      isConfirmModalOpen
    } = this.state;
    return React.createElement("span", null, React.createElement(DropdownMenu, accessDropdownMenuProps, React.createElement(PlainButton, _extends({
      className: classNames('lnk', {
        'is-disabled bdl-is-disabled': submitting
      }),
      disabled: submitting
    }, accessMenuButtonProps), React.createElement(MenuToggle, null, React.createElement(AccessLabel, {
      accessLevel: accessLevel,
      enterpriseName: enterpriseName,
      itemType: itemType
    }))), this.renderMenu()), React.createElement(RemoveLinkConfirmModal, {
      isOpen: isConfirmModalOpen,
      onRequestClose: this.closeConfirmModal,
      removeLink: removeLink,
      submitting: submitting
    }));
  }

}

_defineProperty(AccessMenu, "defaultProps", {
  accessDropdownMenuProps: {},
  accessMenuButtonProps: {},
  removeLinkButtonProps: {}
});

export default AccessMenu;
//# sourceMappingURL=AccessMenu.js.map