function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { FormattedMessage, injectIntl } from 'react-intl';
import PillSelectorDropdown from '../../components/pill-selector-dropdown';
import ContactDatalistItem from '../../components/contact-datalist-item';
import TextArea from '../../components/text-area';
import PrimaryButton from '../../components/primary-button';
import { ModalActions } from '../../components/modal';
import Button from '../../components/button';
import parseEmails from '../../utils/parseEmails';
import commonMessages from '../../common/messages';
import messages from './messages';
import './EmailSharedLink.scss';

class EmailSharedLink extends Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "getSelectorOptions", () => {
      const {
        contacts
      } = this.props;
      const {
        pillSelectorInputValue,
        selectedOptions
      } = this.state;

      if (pillSelectorInputValue !== '') {
        return contacts.filter( // filter contacts who have already been selected
        (_ref) => {
          let {
            email,
            id
          } = _ref;
          return !selectedOptions.find((_ref2) => {
            let {
              value
            } = _ref2;
            return value === email || value === id;
          });
        }).map((_ref3) => {
          let {
            email,
            id,
            name,
            type
          } = _ref3;
          return {
            // map to standardized DatalistItem format
            // TODO: refactor this so inline conversions aren't required at every usage
            email,
            id,
            text: name,
            type,
            value: email || id // if email doesn't exist, contact is a group, use id

          };
        });
      } // return empty selector options if input value is empty


      return [];
    });

    _defineProperty(this, "handlePillSelectorInput", value => {
      const {
        getContacts
      } = this.props;
      const trimmedValue = value.trim();
      getContacts(trimmedValue); // As user is typing, reset error

      this.setState({
        pillSelectorError: '',
        pillSelectorInputValue: trimmedValue
      });
    });

    _defineProperty(this, "handlePillSelect", pills => {
      this.setState({
        selectedOptions: [...this.state.selectedOptions, ...pills]
      });
    });

    _defineProperty(this, "handlePillRemove", (option, index) => {
      const selectedOptions = this.state.selectedOptions.slice();
      selectedOptions.splice(index, 1);
      this.setState({
        selectedOptions
      });
    });

    _defineProperty(this, "validateForError", text => {
      const {
        intl: {
          formatMessage
        }
      } = this.props;
      let pillSelectorError = '';

      if (text && !this.validator(text)) {
        pillSelectorError = formatMessage(commonMessages.invalidEmailError);
      }

      this.setState({
        pillSelectorError
      });
    });

    _defineProperty(this, "validator", text => {
      // email input validation
      const pattern = /^[^\s<>@,]+@[^\s<>@,/\\]+\.[^\s<>@,]+$/i;
      return pattern.test(text);
    });

    _defineProperty(this, "sendEmail", event => {
      event.preventDefault();
      const {
        intl: {
          formatMessage
        },
        sendEmail
      } = this.props;
      const {
        selectedOptions,
        emailMessage,
        pillSelectorError
      } = this.state;

      if (pillSelectorError !== '') {
        return;
      }

      if (selectedOptions.length === 0) {
        // Block submission if no pills are selected
        this.setState({
          pillSelectorError: formatMessage(messages.enterAtLeastOneEmailError)
        });
        return;
      }

      sendEmail({
        emails: selectedOptions.map((_ref4) => {
          let {
            value
          } = _ref4;
          return value;
        }),
        emailMessage
      });
    });

    _defineProperty(this, "handleMessageChange", event => {
      this.setState({
        emailMessage: event.target.value
      });
    });

    const {
      defaultEmailMessage
    } = props;
    this.state = {
      pillSelectorError: '',
      pillSelectorInputValue: '',
      emailMessage: defaultEmailMessage || '',
      selectedOptions: []
    };
  }

  render() {
    const {
      pillSelectorError,
      selectedOptions,
      emailMessage
    } = this.state;
    const {
      emailMessageProps,
      intl: {
        formatMessage
      },
      isExpanded,
      onExpand,
      onRequestClose,
      submitting
    } = this.props;
    const selectorOptions = this.getSelectorOptions();
    return React.createElement("form", {
      onSubmit: this.sendEmail,
      className: classNames('email-shared-link', {
        'is-expanded': isExpanded
      })
    }, React.createElement(PillSelectorDropdown, {
      allowCustomPills: true,
      error: pillSelectorError,
      label: React.createElement(FormattedMessage, messages.emailSharedLink),
      inputProps: _objectSpread({
        onFocus: onExpand
      }, emailMessageProps),
      onInput: this.handlePillSelectorInput,
      onRemove: this.handlePillRemove,
      onSelect: this.handlePillSelect,
      parseItems: parseEmails,
      placeholder: formatMessage(commonMessages.pillSelectorPlaceholder),
      selectedOptions: selectedOptions,
      selectorOptions: selectorOptions,
      validateForError: this.validateForError,
      validator: this.validator
    }, selectorOptions.map((_ref5) => {
      let {
        email,
        text,
        value
      } = _ref5;
      return React.createElement(ContactDatalistItem, {
        key: value,
        name: text,
        subtitle: email
      });
    })), React.createElement(TextArea, {
      isRequired: true,
      label: React.createElement(FormattedMessage, messages.messageTitle),
      onChange: this.handleMessageChange,
      rows: 3,
      value: emailMessage
    }), isExpanded && React.createElement(ModalActions, null, React.createElement(Button, {
      isDisabled: submitting,
      onClick: onRequestClose,
      type: "button"
    }, React.createElement(FormattedMessage, commonMessages.cancel)), React.createElement(PrimaryButton, {
      isDisabled: submitting,
      isLoading: submitting,
      type: "submit"
    }, React.createElement(FormattedMessage, commonMessages.send))));
  }

}

_defineProperty(EmailSharedLink, "propTypes", {
  contacts: PropTypes.arrayOf(PropTypes.shape({
    email: PropTypes.string,
    id: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isrequired,
    name: PropTypes.string.isRequired,
    type: PropTypes.string.isRequired
  })).isRequired,
  defaultEmailMessage: PropTypes.string,
  emailMessageProps: PropTypes.object,
  intl: PropTypes.any,
  getContacts: PropTypes.func.isRequired,
  isExpanded: PropTypes.bool,
  onExpand: PropTypes.func.isRequired,
  onRequestClose: PropTypes.func.isRequired,
  sendEmail: PropTypes.func.isRequired,
  submitting: PropTypes.bool
});

_defineProperty(EmailSharedLink, "defaultProps", {
  emailMessageProps: {}
});

export { EmailSharedLink as EmailSharedLinkBase };
export default injectIntl(EmailSharedLink);
//# sourceMappingURL=EmailSharedLink.js.map