import React from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';
import DropdownMenu, { MenuToggle } from '../../components/dropdown-menu';
import PlainButton from '../../components/plain-button';
import { Menu, SelectMenuItem } from '../../components/menu';
import { permissionLevelPropType } from './propTypes';
import { CAN_VIEW, CAN_EDIT } from './constants';
import messages from './messages';
const permissionLevels = [CAN_VIEW, CAN_EDIT];

const PermissionMenu = props => {
  const {
    changePermissionLevel,
    permissionLevel,
    submitting
  } = props;

  if (!changePermissionLevel || !permissionLevel) {
    return null;
  }

  const permissionLabels = {
    [CAN_VIEW]: React.createElement(FormattedMessage, messages.canView),
    [CAN_EDIT]: React.createElement(FormattedMessage, messages.canEdit)
  };
  return React.createElement(DropdownMenu, null, React.createElement(PlainButton, {
    className: classNames('lnk', {
      'is-disabled bdl-is-disabled': submitting
    }),
    disabled: submitting
  }, React.createElement(MenuToggle, null, permissionLabels[permissionLevel])), React.createElement(Menu, null, permissionLevels.map(level => React.createElement(SelectMenuItem, {
    key: level,
    isSelected: level === permissionLevel,
    onClick: () => changePermissionLevel(level)
  }, permissionLabels[level]))));
};

PermissionMenu.displayName = 'PermissionMenu';
export default PermissionMenu;
//# sourceMappingURL=PermissionMenu.js.map