function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import { FormattedMessage } from 'react-intl';
import Button from '../../components/button';
import { Modal, ModalActions } from '../../components/modal';
import commonMessages from '../../common/messages';
import SharedLink from './SharedLink';
import EmailSharedLink from './EmailSharedLink';
import messages from './messages';
import { accessLevelPropType, allowedAccessLevelsPropType, permissionLevelPropType } from './propTypes';

class SharedLinkModal extends Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      isEmailSharedLinkExpanded: false
    });

    _defineProperty(this, "handleEmailSharedLinkExpand", () => {
      this.setState({
        isEmailSharedLinkExpanded: true
      });
    });
  }

  renderSharedLink() {
    const {
      accessLevel,
      accessMenuButtonProps,
      allowedAccessLevels,
      canRemoveLink,
      changeAccessLevel,
      changePermissionLevel,
      copyButtonProps,
      enterpriseName,
      expiration,
      isDownloadAllowed,
      isEditAllowed,
      isPreviewAllowed,
      itemType,
      onCopySuccess,
      onSettingsClick,
      permissionLevel,
      removeLink,
      removeLinkButtonProps,
      sharedLink,
      submitting
    } = this.props;
    return React.createElement(SharedLink, {
      accessLevel: accessLevel,
      accessMenuButtonProps: accessMenuButtonProps,
      allowedAccessLevels: allowedAccessLevels,
      canRemoveLink: canRemoveLink,
      changeAccessLevel: changeAccessLevel,
      changePermissionLevel: changePermissionLevel,
      copyButtonProps: copyButtonProps,
      enterpriseName: enterpriseName,
      expiration: expiration,
      isDownloadAllowed: isDownloadAllowed,
      isEditAllowed: isEditAllowed,
      isPreviewAllowed: isPreviewAllowed,
      itemType: itemType,
      onCopySuccess: onCopySuccess,
      onSettingsClick: onSettingsClick,
      permissionLevel: permissionLevel,
      removeLink: removeLink,
      removeLinkButtonProps: removeLinkButtonProps,
      sharedLink: sharedLink,
      submitting: submitting
    });
  }

  renderEmailSharedLink() {
    const {
      contacts,
      defaultEmailMessage,
      emailMessageProps,
      getContacts,
      onRequestClose,
      sendEmail,
      submitting
    } = this.props;

    if (!getContacts || !contacts || !sendEmail) {
      return null;
    }

    return React.createElement(EmailSharedLink, {
      contacts: contacts,
      defaultEmailMessage: defaultEmailMessage,
      emailMessageProps: emailMessageProps,
      getContacts: getContacts,
      isExpanded: this.state.isEmailSharedLinkExpanded,
      sendEmail: sendEmail,
      onRequestClose: onRequestClose,
      submitting: submitting,
      onExpand: this.handleEmailSharedLinkExpand
    });
  }

  render() {
    const {
      isOpen,
      itemName,
      modalProps,
      onRequestClose,
      submitting
    } = this.props;
    const {
      isEmailSharedLinkExpanded
    } = this.state;
    return React.createElement(Modal, _extends({
      className: "shared-link-modal",
      focusElementSelector: ".shared-link-container input",
      isOpen: isOpen,
      onRequestClose: submitting ? undefined : onRequestClose,
      title: React.createElement(FormattedMessage, _extends({}, messages.sharedLinkModalTitle, {
        values: {
          itemName
        }
      }))
    }, modalProps), this.renderSharedLink(), React.createElement("hr", null), this.renderEmailSharedLink(), !isEmailSharedLinkExpanded && React.createElement(ModalActions, null, React.createElement(Button, {
      isDisabled: submitting,
      onClick: onRequestClose,
      type: "button"
    }, React.createElement(FormattedMessage, commonMessages.close))));
  }

}

export default SharedLinkModal;
//# sourceMappingURL=SharedLinkModal.js.map