function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import Checkbox from '../../components/checkbox';
import DatePicker from '../../components/date-picker';
import Fieldset from '../../components/fieldset';
import messages from './messages';
const displayFormat = {
  weekday: 'short',
  year: 'numeric',
  month: 'short',
  day: 'numeric'
};

const ExpirationSection = (_ref) => {
  let {
    canChangeExpiration,
    dateFormat,
    error,
    expirationCheckboxProps = {},
    expirationDate,
    expirationInputProps = {},
    isExpirationEnabled,
    onCheckboxChange,
    onExpirationDateChange
  } = _ref;
  const tomorrow = new Date(new Date().getTime() + 24 * 60 * 60 * 1000);
  const datepicker = React.createElement("div", null, React.createElement(DatePicker, {
    dateFormat: dateFormat,
    displayFormat: displayFormat,
    error: error,
    hideLabel: true,
    inputProps: expirationInputProps,
    isDisabled: !canChangeExpiration,
    isRequired: true,
    label: React.createElement(FormattedMessage, messages.expirationLabel),
    minDate: tomorrow,
    name: "expiration",
    onChange: onExpirationDateChange,
    value: expirationDate
  }));
  return React.createElement("div", null, React.createElement("hr", null), React.createElement(Fieldset, {
    className: "be expiration-section",
    title: React.createElement(FormattedMessage, messages.expirationTitle)
  }, React.createElement(Checkbox, _extends({
    isChecked: isExpirationEnabled,
    isDisabled: !canChangeExpiration,
    label: React.createElement(FormattedMessage, messages.expirationLabel),
    name: "isExpirationEnabled",
    onChange: onCheckboxChange,
    subsection: isExpirationEnabled ? datepicker : undefined
  }, expirationCheckboxProps))));
};

ExpirationSection.propTypes = {
  canChangeExpiration: PropTypes.bool.isRequired,

  /** The format of the date value for form submit */
  dateFormat: PropTypes.string,
  error: PropTypes.string,
  expirationCheckboxProps: PropTypes.object,
  expirationDate: PropTypes.instanceOf(Date),
  expirationInputProps: PropTypes.object,
  isExpirationEnabled: PropTypes.bool.isRequired,
  onCheckboxChange: PropTypes.func.isRequired,
  onExpirationDateChange: PropTypes.func.isRequired
};
export default ExpirationSection;
//# sourceMappingURL=ExpirationSection.js.map