function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import PlainButton from '../../components/plain-button';
import DropdownMenu, { MenuToggle } from '../../components/dropdown-menu';
import { Menu, SelectMenuItem } from '../../components/menu';
import Tooltip from '../../components/tooltip';
import { ITEM_TYPE_WEBLINK } from '../../common/constants';
import getDefaultPermissionLevel from './utils/defaultPermissionLevel';
import InviteePermissionsLabel from './InviteePermissionsLabel';
import messages from './messages';

class InviteePermissionsMenu extends Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "onChangeInviteePermissionsLevel", newInviteePermissionLevel => {
      const {
        inviteePermissionLevel,
        changeInviteePermissionLevel
      } = this.props;

      if (inviteePermissionLevel !== newInviteePermissionLevel) {
        changeInviteePermissionLevel(newInviteePermissionLevel);
      }
    });
  }

  renderMenu() {
    const {
      inviteePermissionLevel,
      inviteePermissions,
      itemType
    } = this.props;
    const defaultPermissionLevel = getDefaultPermissionLevel(inviteePermissions);
    const selectedPermissionLevel = inviteePermissionLevel || defaultPermissionLevel;
    return React.createElement(Menu, {
      className: "usm-share-access-menu"
    }, inviteePermissions.map(level => level.value ? React.createElement(SelectMenuItem, {
      key: level.value,
      isDisabled: level.disabled,
      isSelected: level.value === selectedPermissionLevel,
      onClick: () => this.onChangeInviteePermissionsLevel(level.value)
    }, React.createElement(InviteePermissionsLabel, {
      hasDescription: true,
      inviteePermissionLevel: level.value,
      inviteePermissions: true,
      itemType: itemType
    })) : null));
  }

  render() {
    const {
      inviteePermissions,
      inviteePermissionsButtonProps,
      inviteePermissionLevel,
      disabled,
      itemType
    } = this.props;
    const defaultPermissionLevel = getDefaultPermissionLevel(inviteePermissions);
    const selectedPermissionLevel = inviteePermissionLevel || defaultPermissionLevel;
    const disabledTooltip = itemType === ITEM_TYPE_WEBLINK ? React.createElement(FormattedMessage, messages.inviteDisabledWeblinkTooltip) : React.createElement(FormattedMessage, messages.inviteDisabledTooltip);
    const plainButton = React.createElement(PlainButton, _extends({
      className: classNames('lnk', {
        'is-disabled': disabled,
        'bdl-is-disabled': disabled
      }),
      disabled: disabled,
      type: "button"
    }, inviteePermissionsButtonProps), React.createElement(MenuToggle, null, selectedPermissionLevel && React.createElement(InviteePermissionsLabel, {
      hasDescription: false,
      inviteePermissionLevel: selectedPermissionLevel,
      itemType: itemType
    })));
    const plainButtonWrap = disabled ? React.createElement(Tooltip, {
      position: "bottom-center",
      text: disabledTooltip
    }, React.createElement("div", {
      className: "tooltip-target"
    }, plainButton)) : plainButton; // TODO: `DropdownMenu` doesn't currently handle a scenario where the menu is taller than
    // the available vertical space. cannot use the constraint props here in short windows.

    return React.createElement("div", {
      className: "be invitee-menu-wrap"
    }, React.createElement(DropdownMenu, null, plainButtonWrap, this.renderMenu()));
  }

}

_defineProperty(InviteePermissionsMenu, "defaultProps", {
  disabled: false,
  inviteePermissions: [],
  inviteePermissionsButtonProps: {}
});

export default InviteePermissionsMenu;
//# sourceMappingURL=InviteePermissionsMenu.js.map