function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { FormattedMessage } from 'react-intl';
import { ANYONE_WITH_LINK, ANYONE_IN_COMPANY, PEOPLE_IN_ITEM } from './constants';
import { ITEM_TYPE_FOLDER, ITEM_TYPE_HUBS } from '../../common/constants';
import messages from './messages';

const SharedLinkAccessDescription = (_ref) => {
  let {
    accessLevel,
    enterpriseName,
    itemType
  } = _ref;

  const getDescriptionForAnyoneWithLink = type => {
    switch (type) {
      case ITEM_TYPE_HUBS:
        return messages.peopleWithLinkSignedInRequiredDescription;

      default:
        return messages.peopleWithLinkDescription;
    }
  };

  const getDescriptionForAnyoneInCompany = type => {
    switch (type) {
      case ITEM_TYPE_FOLDER:
        return enterpriseName ? messages.peopleInSpecifiedCompanyCanAccessFolder : messages.peopleInCompanyCanAccessFolder;

      case ITEM_TYPE_HUBS:
        return enterpriseName ? messages.peopleInSpecifiedCompanyCanAccessHub : messages.peopleInCompanyCanAccessHub;

      default:
        return enterpriseName ? messages.peopleInSpecifiedCompanyCanAccessFile : messages.peopleInCompanyCanAccessFile;
    }
  };

  const getDescriptionForPeopleInItem = type => {
    switch (type) {
      case ITEM_TYPE_FOLDER:
        return messages.peopleInItemCanAccessFolder;

      case ITEM_TYPE_HUBS:
        return messages.peopleInItemCanAccessHub;

      default:
        return messages.peopleInItemCanAccessFile;
    }
  };

  let description;

  switch (accessLevel) {
    case ANYONE_WITH_LINK:
      description = getDescriptionForAnyoneWithLink(itemType);
      break;

    case ANYONE_IN_COMPANY:
      description = getDescriptionForAnyoneInCompany(itemType);
      break;

    case PEOPLE_IN_ITEM:
      description = getDescriptionForPeopleInItem(itemType);
      break;

    default:
      return null;
  }

  return React.createElement("small", {
    className: "usm-menu-description"
  }, React.createElement(FormattedMessage, _extends({}, description, {
    values: {
      company: enterpriseName
    }
  })));
};

export default SharedLinkAccessDescription;
//# sourceMappingURL=SharedLinkAccessDescription.js.map