function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';
import DropdownMenu, { MenuToggle } from '../../components/dropdown-menu';
import { Menu, SelectMenuItem } from '../../components/menu';
import PlainButton from '../../components/plain-button';
import Tooltip from '../../components/tooltip';
import SharedLinkAccessLabel from './SharedLinkAccessLabel';
import { ANYONE_WITH_LINK, ANYONE_IN_COMPANY, DISABLED_REASON_ACCESS_POLICY, DISABLED_REASON_MALICIOUS_CONTENT, PEOPLE_IN_ITEM } from './constants';
import messages from './messages';
const accessLevels = [ANYONE_WITH_LINK, ANYONE_IN_COMPANY, PEOPLE_IN_ITEM];

class SharedLinkAccessMenu extends React.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "onChangeAccessLevel", newAccessLevel => {
      const {
        accessLevel,
        changeAccessLevel,
        trackingProps
      } = this.props;
      const {
        onChangeSharedLinkAccessLevel
      } = trackingProps;

      if (accessLevel !== newAccessLevel) {
        changeAccessLevel(newAccessLevel);

        if (onChangeSharedLinkAccessLevel) {
          onChangeSharedLinkAccessLevel(newAccessLevel);
        }
      }
    });
  }

  renderMenu() {
    const {
      accessLevel,
      accessLevelsDisabledReason,
      allowedAccessLevels,
      enterpriseName,
      itemType
    } = this.props;
    return React.createElement(Menu, {
      className: "usm-share-access-menu",
      "data-testid": "usm-share-access-menu"
    }, accessLevels.map(level => {
      const isDisabled = !allowedAccessLevels[level];
      const isDisabledByAccessPolicy = accessLevelsDisabledReason[level] === DISABLED_REASON_ACCESS_POLICY;
      const isDisabledByMaliciousContent = accessLevelsDisabledReason[level] === DISABLED_REASON_MALICIOUS_CONTENT;
      const isDisabledByPolicy = isDisabledByAccessPolicy || isDisabledByMaliciousContent;
      const tooltipMessage = isDisabledByMaliciousContent ? messages.disabledMaliciousContentShareLinkPermission : messages.disabledShareLinkPermission; // If an access level is disabled for reasons other than access policy enforcement
      // then we just don't show that menu item. If it is disabled because of an access policy
      // instead, then we show the menu item in a disabled state and with a tooltip.

      if (isDisabled && !isDisabledByPolicy) {
        return null;
      }

      return React.createElement(Tooltip, {
        isDisabled: !isDisabledByPolicy,
        key: "tooltip-".concat(level),
        position: "top-center",
        text: React.createElement(FormattedMessage, tooltipMessage)
      }, React.createElement(SelectMenuItem, {
        key: level,
        isDisabled: isDisabled,
        isSelected: level === accessLevel,
        onClick: () => this.onChangeAccessLevel(level)
      }, React.createElement(SharedLinkAccessLabel, {
        accessLevel: level,
        enterpriseName: enterpriseName,
        hasDescription: true,
        itemType: itemType
      })));
    }));
  }

  render() {
    const {
      accessLevel,
      enterpriseName,
      itemType,
      onDismissTooltip,
      submitting,
      tooltipContent,
      trackingProps
    } = this.props;
    const {
      onSharedLinkAccessMenuOpen,
      sharedLinkAccessMenuButtonProps
    } = trackingProps;
    return React.createElement(Tooltip, {
      className: "usm-ftux-tooltip",
      isShown: !!tooltipContent,
      onDismiss: onDismissTooltip,
      position: "middle-left",
      showCloseButton: true,
      text: tooltipContent,
      theme: "callout"
    }, React.createElement(DropdownMenu, {
      onMenuOpen: onSharedLinkAccessMenuOpen,
      constrainToWindow: true
    }, React.createElement(PlainButton, _extends({
      className: classNames('lnk', {
        'is-disabled': submitting,
        'bdl-is-disabled': submitting
      }),
      "data-testid": "usm-share-access-toggle",
      disabled: submitting,
      type: "button"
    }, sharedLinkAccessMenuButtonProps), React.createElement(MenuToggle, null, React.createElement(SharedLinkAccessLabel, {
      accessLevel: accessLevel,
      enterpriseName: enterpriseName,
      hasDescription: false,
      itemType: itemType
    }))), this.renderMenu()));
  }

}

_defineProperty(SharedLinkAccessMenu, "defaultProps", {
  accessLevelsDisabledReason: {},
  allowedAccessLevels: {},
  trackingProps: {}
});

export default SharedLinkAccessMenu;
//# sourceMappingURL=SharedLinkAccessMenu.js.map