function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';
import DropdownMenu, { MenuToggle } from '../../components/dropdown-menu';
import LabelPill from '../../components/label-pill';
import PlainButton from '../../components/plain-button';
import { Menu, SelectMenuItem } from '../../components/menu';
import { VIEW_SIZE_TYPE } from '../../components/media-query/constants';
import withMediaQuery from '../../components/media-query/withMediaQuery';
import { CAN_EDIT, CAN_VIEW_DOWNLOAD, CAN_VIEW_ONLY } from './constants';
import messages from './messages';
import './SharedLinkPermissionMenu.scss';

class SharedLinkPermissionMenu extends Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "onChangePermissionLevel", newPermissionLevel => {
      const {
        changePermissionLevel,
        permissionLevel,
        trackingProps
      } = this.props;
      const {
        onChangeSharedLinkPermissionLevel
      } = trackingProps;

      if (permissionLevel !== newPermissionLevel) {
        changePermissionLevel(newPermissionLevel);

        if (onChangeSharedLinkPermissionLevel) {
          onChangeSharedLinkPermissionLevel(newPermissionLevel);
        }
      }
    });
  }

  render() {
    const {
      allowedPermissionLevels,
      isSharedLinkEditTooltipShown,
      permissionLevel,
      sharedLinkEditTagTargetingApi,
      sharedLinkEditTooltipTargetingApi,
      size,
      submitting,
      trackingProps
    } = this.props;
    const {
      sharedLinkPermissionsMenuButtonProps
    } = trackingProps;
    const canShowTag = sharedLinkEditTagTargetingApi ? sharedLinkEditTagTargetingApi.canShow : false;
    const canShowTooltip = sharedLinkEditTooltipTargetingApi ? sharedLinkEditTooltipTargetingApi.canShow : false;

    if (!permissionLevel) {
      return null;
    }

    const permissionLevels = {
      [CAN_EDIT]: {
        label: React.createElement(FormattedMessage, messages.sharedLinkPermissionsEdit)
      },
      [CAN_VIEW_DOWNLOAD]: {
        label: React.createElement(FormattedMessage, messages.sharedLinkPermissionsViewDownload)
      },
      [CAN_VIEW_ONLY]: {
        label: React.createElement(FormattedMessage, messages.sharedLinkPermissionsViewOnly)
      }
    };
    const isRightAligned = size === VIEW_SIZE_TYPE.small || size === VIEW_SIZE_TYPE.medium;
    return React.createElement(DropdownMenu, {
      constrainToWindow: true,
      isRightAligned: isRightAligned,
      onMenuClose: () => {
        if (allowedPermissionLevels.includes(CAN_EDIT) && canShowTag && sharedLinkEditTagTargetingApi) {
          sharedLinkEditTagTargetingApi.onComplete();
        }
      },
      onMenuOpen: () => {
        if (allowedPermissionLevels.includes(CAN_EDIT) && canShowTag && sharedLinkEditTagTargetingApi) {
          sharedLinkEditTagTargetingApi.onShow();
        } // complete tooltip FTUX on opening of dropdown menu


        if (isSharedLinkEditTooltipShown && canShowTooltip && sharedLinkEditTooltipTargetingApi) {
          sharedLinkEditTooltipTargetingApi.onComplete();
        }
      }
    }, React.createElement(PlainButton, _extends({
      className: classNames('lnk', {
        'is-disabled': submitting,
        'bdl-is-disabled': submitting
      }),
      "data-testid": "usm-share-permissions-toggle",
      disabled: submitting,
      type: "button"
    }, sharedLinkPermissionsMenuButtonProps), React.createElement(MenuToggle, null, permissionLevels[permissionLevel].label)), React.createElement(Menu, {
      className: "ums-share-permissions-menu",
      "data-testid": "usm-share-permissions-menu"
    }, allowedPermissionLevels.map(level => React.createElement(SelectMenuItem, {
      key: level,
      isSelected: level === permissionLevel,
      onClick: () => this.onChangePermissionLevel(level)
    }, React.createElement("div", {
      className: "ums-share-permissions-menu-item"
    }, React.createElement("span", null, permissionLevels[level].label), level === CAN_EDIT && canShowTag && React.createElement(LabelPill.Pill, {
      className: "ftux-editable-shared-link",
      type: "ftux"
    }, React.createElement(LabelPill.Text, null, React.createElement(FormattedMessage, messages.ftuxSharedLinkPermissionsEditTag))))))));
  }

}

_defineProperty(SharedLinkPermissionMenu, "defaultProps", {
  trackingProps: {}
});

const sharedLinkPermissionMenu = withMediaQuery(SharedLinkPermissionMenu);
sharedLinkPermissionMenu.displayName = 'SharedLinkPermissionMenu';
export { SharedLinkPermissionMenu as SharedLinkPermissionMenuBase };
export default sharedLinkPermissionMenu;
//# sourceMappingURL=SharedLinkPermissionMenu.js.map