function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { injectIntl } from 'react-intl';
import { Modal } from '../../components/modal';
import UnifiedShareModalTitle from './UnifiedShareModalTitle';
import UnifiedShareForm from './UnifiedShareForm';
import RemoveLinkConfirmModal from './RemoveLinkConfirmModal';
import './UnifiedShareModal.scss';

class UnifiedShareModal extends React.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "getInitialData", () => {
      const {
        getInitialData
      } = this.props;
      getInitialData().finally(() => {
        this.setState({
          isFetching: false,
          shouldRenderFTUXTooltip: true
        });
      });
      this.setState({
        getInitialDataCalled: true
      });
    });

    _defineProperty(this, "handleFtuxCloseClick", () => {
      this.setState({
        shouldRenderFTUXTooltip: false
      });
    });

    _defineProperty(this, "openConfirmModal", () => {
      this.setState({
        isConfirmModalOpen: true
      });
    });

    _defineProperty(this, "closeConfirmModal", () => {
      this.setState({
        isConfirmModalOpen: false
      });
    });

    _defineProperty(this, "removeLink", () => {
      const {
        onRemoveLink,
        displayInModal
      } = this.props;
      onRemoveLink();

      if (!displayInModal) {
        this.closeConfirmModal();
      }
    });

    _defineProperty(this, "renderUSF", () => {
      const {
        sharedLinkEditTagTargetingApi,
        sharedLinkEditTooltipTargetingApi
      } = this.props;
      const {
        isFetching,
        sharedLinkLoaded,
        shouldRenderFTUXTooltip
      } = this.state;
      return React.createElement(UnifiedShareForm, _extends({}, this.props, {
        handleFtuxCloseClick: this.handleFtuxCloseClick,
        isFetching: isFetching,
        openConfirmModal: this.openConfirmModal,
        sharedLinkEditTagTargetingApi: sharedLinkEditTagTargetingApi,
        sharedLinkEditTooltipTargetingApi: sharedLinkEditTooltipTargetingApi,
        sharedLinkLoaded: sharedLinkLoaded,
        shouldRenderFTUXTooltip: shouldRenderFTUXTooltip
      }));
    });

    const {
      initialDataReceived
    } = props;
    this.state = {
      getInitialDataCalled: !!initialDataReceived,
      isConfirmModalOpen: false,
      isEmailLinkSectionExpanded: false,
      isFetching: !initialDataReceived,
      sharedLinkLoaded: false,
      shouldRenderFTUXTooltip: false,
      showCollaboratorList: false
    };
  }

  componentDidMount() {
    const {
      item,
      trackingProps
    } = this.props;
    const {
      type,
      typedID
    } = item;
    const {
      modalTracking
    } = trackingProps;
    const {
      onLoad
    } = modalTracking;
    const {
      getInitialDataCalled
    } = this.state; // This check is to ensure minimum item props are
    // hydrated before we fetch data

    if (!getInitialDataCalled && type && typedID) {
      this.getInitialData();
    }

    if (onLoad) {
      onLoad();
    }
  }

  componentDidUpdate(prevProps) {
    const {
      item,
      sharedLink,
      trackingProps
    } = this.props;
    const {
      type,
      typedID
    } = item;
    const {
      modalTracking
    } = trackingProps;
    const {
      onLoadSharedLink
    } = modalTracking;
    const prevSharedLink = prevProps.sharedLink;
    const {
      getInitialDataCalled
    } = this.state; // This check is to ensure minimum item props are
    // hydrated before we fetch data

    if (!getInitialDataCalled && type && typedID) {
      this.getInitialData();
    } // this ensures that we obtain shared link information the first time data is returned
    // so we can pass the corresponding permissions in the callback


    if (!prevSharedLink.permissionLevel && sharedLink.permissionLevel && onLoadSharedLink) {
      onLoadSharedLink(sharedLink.permissionLevel);
    } // we use state to override the default auto copy prop when a URL comes into view


    if (prevSharedLink.url !== sharedLink.url && sharedLink.url) {
      this.setState({
        sharedLinkLoaded: true
      });
    }
  }

  render() {
    // Shared link section props
    const {
      canInvite,
      displayInModal,
      isOpen,
      item,
      onRequestClose,
      submitting,
      trackingProps
    } = this.props;
    const {
      modalTracking,
      removeLinkConfirmModalTracking
    } = trackingProps;
    const {
      modalProps
    } = modalTracking;
    const {
      isEmailLinkSectionExpanded,
      isConfirmModalOpen,
      showCollaboratorList
    } = this.state; // focus logic at modal level

    const extendedModalProps = _objectSpread({
      focusElementSelector: canInvite ? '.bdl-PillSelector-input' // focus on invite collabs field
      : '.toggle-simple'
    }, modalProps);

    return React.createElement(React.Fragment, null, displayInModal ? React.createElement(Modal, _extends({
      className: "be-modal unified-share-modal",
      isOpen: isConfirmModalOpen ? false : isOpen,
      onRequestClose: submitting ? undefined : onRequestClose,
      title: React.createElement(UnifiedShareModalTitle, {
        isEmailLinkSectionExpanded: isEmailLinkSectionExpanded,
        showCollaboratorList: showCollaboratorList,
        item: item
      })
    }, extendedModalProps), this.renderUSF()) : React.createElement("div", {
      className: "bdl-UnifiedShareForm-container"
    }, this.renderUSF()), isConfirmModalOpen && React.createElement(RemoveLinkConfirmModal, _extends({
      isOpen: isConfirmModalOpen,
      onRequestClose: this.closeConfirmModal,
      removeLink: this.removeLink,
      submitting: submitting
    }, removeLinkConfirmModalTracking)));
  }

}

_defineProperty(UnifiedShareModal, "defaultProps", {
  displayInModal: true,
  initiallySelectedContacts: [],
  isAllowEditSharedLinkForFileEnabled: false,
  createSharedLinkOnLoad: false,
  focusSharedLinkOnLoad: false,
  restrictedCollabEmails: [],
  restrictedGroups: [],
  trackingProps: {
    inviteCollabsEmailTracking: {},
    sharedLinkEmailTracking: {},
    sharedLinkTracking: {},
    inviteCollabTracking: {},
    modalTracking: {},
    removeLinkConfirmModalTracking: {},
    collaboratorListTracking: {}
  }
});

export { UnifiedShareModal as UnifiedShareModalBase };
export default injectIntl(UnifiedShareModal);
//# sourceMappingURL=UnifiedShareModal.js.map