import * as React from 'react';
import classNames from 'classnames';
import { TYPE_FOLDER, DEFAULT_ROOT } from '../../constants';
import messages from './messages';
import Breadcrumb from '../../components/breadcrumb';
import FolderIcon from '../../icons/folder-icon';
import FileIcon from '../../icons/file-icon';
import getSize from '../../utils/size';
import { getFileExtension } from '../../utils/file';
import baseCellRenderer from './baseCellRenderer';
import './FilePathCell.scss';

const getName = function getName() {
  let {
    name,
    type,
    isExternal,
    id
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let intl = arguments.length > 1 ? arguments[1] : undefined;

  if (id === DEFAULT_ROOT) {
    return intl.formatMessage(messages.allFiles);
  }

  if (isExternal) {
    const message = type === TYPE_FOLDER ? messages.externalFolder : messages.externalFile;
    return intl.formatMessage(message);
  }

  return name || id;
};

const fileNameCellRenderer = intl => cellRendererParams => baseCellRenderer(cellRendererParams, cellValue => {
  const {
    id,
    name = '',
    size,
    itemPath = [],
    itemType,
    isExternal
  } = cellValue;
  const extension = getFileExtension(name);
  const icon = itemType === TYPE_FOLDER ? React.createElement(FolderIcon, null) : React.createElement(FileIcon, {
    extension: extension
  });
  const path = itemPath.map(pathInfo => getName(pathInfo, intl));
  const displaySize = size ? " (".concat(getSize(size), ")") : '';
  const contentName = getName({
    id,
    isExternal,
    type: itemType,
    name
  }, intl);
  const displayName = "".concat(contentName).concat(displaySize);
  const fullPath = [...path, displayName];
  const filePathCellClass = classNames('bdl-FilePathCell', {
    'bdl-is-external': isExternal
  });
  return React.createElement("span", {
    className: filePathCellClass,
    title: fullPath.join(' > ')
  }, icon, React.createElement(Breadcrumb, {
    label: "contentPath"
  }, fullPath.map(itemPathName => React.createElement("span", {
    key: itemPathName,
    className: "bdl-FilePathCell-breadcrumbName"
  }, itemPathName))));
});

export default fileNameCellRenderer;
//# sourceMappingURL=filePathCellRenderer.js.map