function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as React from 'react';
import classNames from 'classnames';
import noop from 'lodash/noop';
import { getFileExtension } from '../../utils/file';
import messages from './messages';
import FileIcon from '../../icons/file-icon';
import FolderIcon from '../../icons/folder-icon';
import PlainButton from '../../components/plain-button/PlainButton';
import baseCellRenderer from './baseCellRenderer';
import './ItemNameCell.scss';

const itemNameCellRenderer = function itemNameCellRenderer(intl) {
  let _onClick = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : noop;

  return cellRendererParams => baseCellRenderer(cellRendererParams, cellValue => {
    const {
      name,
      type,
      isExternal,
      dataAttributes
    } = cellValue;
    const extension = getFileExtension(name);
    const displayName = isExternal ? intl.formatMessage(messages.externalFile) : name;
    const isFolder = type === 'folder';
    const itemNameCellClass = classNames('bdl-ItemNameCell-name', {
      'bdl-is-external': isExternal,
      'bdl-is-folder': isFolder
    });
    return React.createElement("span", {
      className: "bdl-ItemNameCell",
      title: displayName
    }, isFolder ? React.createElement(React.Fragment, null, React.createElement(FolderIcon, {
      dimension: 32,
      isExternal: isExternal
    }), React.createElement(PlainButton, _extends({
      className: itemNameCellClass,
      onClick: () => _onClick(cellValue),
      type: "button"
    }, dataAttributes), displayName)) : React.createElement(React.Fragment, null, React.createElement(FileIcon, {
      dimension: 32,
      extension: extension
    }), React.createElement("span", _extends({
      className: itemNameCellClass
    }, dataAttributes), displayName)));
  });
};

export default itemNameCellRenderer;
//# sourceMappingURL=itemNameCellRenderer.js.map