function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import Color from 'color';
import * as variables from './variables';
import mdNotes from './colors.md';
const bdlColors = {};
const WCAG_AA = 4.5; // minimum contrast ratio for text

const isPaletteColor = (hex, key) => {
  return key.startsWith('bdl') && !key.includes('Neutral') && key !== 'bdlSecondaryBlue' && hex.startsWith('#');
};

Object.keys(variables).forEach(colorKey => {
  const colorHex = variables[colorKey];
  if (Array.isArray(colorHex)) return;

  if (isPaletteColor(colorHex, colorKey)) {
    const paletteGroup = colorKey.match(/[A-Z][a-z]+/g).join(' ');

    if (!bdlColors[paletteGroup]) {
      bdlColors[paletteGroup] = [];
    }

    const color = Color(colorHex);
    const scssVariableName = colorKey.match(/(bdl)|([A-Z][a-z]+)|(\d+)/g).join('-');
    const contrastRatio = color.contrast(Color('#fff'));
    bdlColors[paletteGroup].push({
      scssVariableName,
      colorHex,
      colorKey,
      contrastRatio
    });
  }
});
const wrapper = {
  display: 'flex',
  flexDirection: 'row',
  flexWrap: 'wrap'
};
const palette = {};
const swatchContainer = {
  display: 'flex',
  alignItems: 'center'
};
const swatch = {
  borderRadius: '4px',
  height: '40px',
  width: '200px',
  display: 'inline-block'
};
const label = {
  margin: '0 8px 0 16px'
};

const LabelCell = props => React.createElement("td", {
  style: {
    minWidth: 240
  }
}, props.children);

const Swatch = (_ref) => {
  let {
    color
  } = _ref;
  return React.createElement("div", {
    style: swatchContainer
  }, React.createElement("span", {
    style: _objectSpread({}, swatch, {
      backgroundColor: color.colorHex
    })
  }), React.createElement("table", {
    style: label
  }, React.createElement("tr", null, React.createElement(LabelCell, null, React.createElement("strong", null, "SCSS:"), " ", React.createElement("code", null, "$", color.scssVariableName.toLowerCase())), React.createElement(LabelCell, null, React.createElement("strong", {
    title: "WCAG contrast ratio against white background"
  }, "WCAG:"), ' ', React.createElement("code", null, color.contrastRatio.toFixed(2)), ' ', color.contrastRatio > WCAG_AA ? '(AA ✔︎)' : React.createElement("s", null, "(AA)"))), React.createElement("tr", null, React.createElement(LabelCell, null, React.createElement("strong", null, "JS:"), " ", React.createElement("code", null, color.colorKey)), React.createElement(LabelCell, null, React.createElement("strong", null, "Hex:"), " ", React.createElement("code", null, color.colorHex)))));
};

const allColors = () => React.createElement("div", {
  style: wrapper
}, React.createElement("div", null, React.createElement("h4", null, "Base"), React.createElement("div", {
  style: palette
}, React.createElement(Swatch, {
  key: "black",
  color: {
    scssVariableName: 'black',
    colorHex: '#000000',
    colorKey: 'black',
    contrastRatio: 100
  }
}), React.createElement(Swatch, {
  key: "white",
  color: {
    scssVariableName: 'white',
    colorHex: '#ffffff',
    colorKey: 'white',
    contrastRatio: 0
  }
}))), Object.entries(bdlColors).sort((A, B) => {
  // Sort the palette by grayness (hue/saturation = 0) and then by color
  const a = Color(A[1][0].colorHex);
  const b = Color(B[1][0].colorHex);
  if (a.hsl().object().h === 0) return -1;
  if (b.hsl().object().h === 0) return 1;
  return a.rgbNumber() - b.rgbNumber();
}).map((_ref2) => {
  let [name, colors] = _ref2;
  return React.createElement("div", {
    key: name
  }, React.createElement("h4", null, name), React.createElement("div", {
    style: palette
  }, colors.map(color => React.createElement(Swatch, {
    key: color.colorKey,
    color: color
  }))));
}));

export { allColors };
export default {
  title: 'Theming/Colors',
  parameters: {
    notes: mdNotes
  }
};
//# sourceMappingURL=colors.stories.js.map